/* ThemeREX Addons
------------------------------------------------------------------------------------ */
/* Common rules
--------------------------------------------- */
/* User styles
------------------------------------------ */
.trx_addons_accent,
.trx_addons_accent > a,
.trx_addons_accent > * {
  color: var(--theme-color-text_link);
}

.trx_addons_accent > a:hover {
  color: var(--theme-color-text_dark);
}

.sidebar .trx_addons_accent,
[class*="scheme_"].sidebar .trx_addons_accent,
.sidebar .trx_addons_accent > a,
[class*="scheme_"].sidebar .trx_addons_accent > a,
.sidebar .trx_addons_accent > *,
[class*="scheme_"].sidebar .trx_addons_accent > *,
.footer_wrap .trx_addons_accent,
[class*="scheme_"].footer_wrap .trx_addons_accent,
.footer_wrap .trx_addons_accent > a,
[class*="scheme_"].footer_wrap .trx_addons_accent > a,
.footer_wrap .trx_addons_accent > *,
[class*="scheme_"].footer_wrap .trx_addons_accent > * {
  color: var(--theme-color-alter_link);
}

.sidebar .trx_addons_accent > a:hover,
[class*="scheme_"].sidebar .trx_addons_accent > a:hover,
.footer_wrap .trx_addons_accent > a:hover,
[class*="scheme_"].footer_wrap .trx_addons_accent > a:hover {
  color: var(--theme-color-alter_dark);
}

.trx_addons_title_with_link {
  font-size: 1.056em;
  line-height: 1.8em;
  letter-spacing: 0.5px;
}

.trx_addons_title_with_link,
.trx_addons_title_with_link > a {
  color: var(--theme-color-alter_text) !important;
}

.trx_addons_title_with_link > a {
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.trx_addons_title_with_link > a.underline_anim {
  padding-bottom: 0.4em;
  font-weight: 400;
}

.trx_addons_title_with_link_2 {
  font-size: 1em;
  line-height: 1.8em;
  letter-spacing: 0;
}

.trx_addons_title_with_link_2,
.trx_addons_title_with_link_2 > a {
  color: var(--theme-color-alter_dark) !important;
}

.trx_addons_title_with_link_2 > a {
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.trx_addons_title_with_link_2 > a.underline_anim {
  padding-bottom: 0.4em;
  font-weight: 400;
}

.trx_addons_alter_text {
  font-size: 20px;
  line-height: 1.5em;
  font-weight: 400;
  letter-spacing: -0.4px;
}

.trx_addons_alter_text,
.trx_addons_alter_text > a {
  color: var(--theme-color-alter_text);
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.trx_addons_alter_text > a:hover,
a:hover > .trx_addons_alter_text {
  color: var(--theme-color-alter_dark);
}

.trx_addons_alter_text_2 {
  font-size: 19px;
  line-height: 1.5em;
  font-weight: 400;
  letter-spacing: -0.4px;
}

.trx_addons_alter_text_2,
.trx_addons_alter_text_2 > a {
  color: var(--theme-color-alter_text);
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.trx_addons_alter_text_2 > a:hover,
a:hover > .trx_addons_alter_text_2 {
  color: var(--theme-color-alter_dark);
}

.trx_addons_hover,
.trx_addons_hover > * {
  color: var(--theme-color-text_hover);
}

.trx_addons_accent_bg {
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-bg_color);
}

.trx_addons_inverse {
  color: var(--theme-color-bg_color);
  background-color: var(--theme-color-text_dark);
}

.trx_addons_dark,
.trx_addons_dark > a {
  color: var(--theme-color-text_dark);
}

.trx_addons_dark > a:hover {
  color: var(--theme-color-text_link);
}

.trx_addons_inverse,
.trx_addons_inverse > a {
  color: var(--theme-color-bg_color);
  background-color: var(--theme-color-text_dark);
}

.trx_addons_inverse > a:hover {
  color: var(--theme-color-inverse_hover);
}

.trx_addons_dropcap {
  float: left;
  display: block;
  font-size: 47px;
  padding: 0;
  margin: 0.15em 0.4em 0 0;
  text-align: center;
  font-weight: 700;
  width: 70px;
  height: 70px;
  line-height: 70px;
  text-align: center;
  line-height: 72px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.trx_addons_dropcap_style_1 {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link2);
}

.trx_addons_dropcap_style_2 {
  background-color: transparent;
  color: var(--theme-color-text_dark);
  font-size: 57px;
  height: 55px;
  line-height: 53px;
  margin: 0;
  text-align: left;
  width: auto !important;
  min-width: 60px;
  padding-right: 5px;
  overflow: visible;
}

ul.text_link2[class*="trx_addons_list"] > li:before {
  color: var(--theme-color-text_link2);
}

ul[class*="trx_addons_list"] > li:before {
  color: var(--theme-color-text_link);
}

ul[class*="trx_addons_list"][class*="_circled"] > li:before {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}

.trx_addons_list_parameters {
  color: var(--theme-color-text_dark);
}
.trx_addons_list_parameters > li {
  font-size: 19px;
  line-height: 24px;
  font-weight: 500;
  border: none !important;
  padding: 0 !important;
  overflow: hidden;
}
.trx_addons_list_parameters > li + li {
  margin-top: 17px !important;
}
.trx_addons_list_parameters > li strong {
  position: relative;
  width: auto;
}
.trx_addons_list_parameters > li strong:last-child {
  position: absolute;
  top: 0;
  right: 0;
  max-width: 50%;
  display: inline-block;
  text-align: right;
  padding-left: 5px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-bg_color);
}
.trx_addons_list_parameters > li:after {
  display: inline-block;
  content: "";
  border-bottom: 2px dotted #DDD;
  width: 5000%;
}

/* dot */
ul[class*="trx_addons_list_dot"] {
  padding-left: 16px;
}
ul[class*="trx_addons_list_dot"] > li {
  margin: 1px 0;
}
ul[class*="trx_addons_list_dot"] > li:first-child {
  margin-top: 0 !important;
}
ul[class*="trx_addons_list_dot"] > li:last-child {
  margin-bottom: 0 !important;
}
ul[class*="trx_addons_list_dot"] > li:before {
  font-size: 28px;
  left: -16px;
  top: 1px;
}

/* success */
ul[class*="trx_addons_list_success"] {
  color: var(--theme-color-text_dark);
  padding-left: 30px;
}
ul[class*="trx_addons_list_success"] > li {
  margin: 10px 0;
}
ul[class*="trx_addons_list_success"] > li:first-child {
  margin-top: 0 !important;
}
ul[class*="trx_addons_list_success"] > li:last-child {
  margin-bottom: 0 !important;
}
ul[class*="trx_addons_list_success"] > li:before {
  content: '\e9a2';
  font-family: "fontello";
  font-size: 11px;
  left: -30px;
}

.trx_addons_tooltip {
  border-color: var(--theme-color-text);
  color: var(--theme-color-text);
  display: inline-block;
  line-height: 1;
}

[data-tooltip-text]:after {
  background-color: var(--theme-color-text_link2);
  color: var(--theme-color-inverse_link);
  font-size: 14px;
  line-height: 20px;
  font-weight: 700;
  padding: 7px 12px;
  top: -38px;
}

[data-tooltip-text]:before {
  border-top-color: var(--theme-color-text_link2);
  top: -4px;
}

blockquote.trx_addons_blockquote_style_1,
blockquote.trx_addons_blockquote_style_2 {
  padding: 1.8em 2.55em;
}
blockquote.trx_addons_blockquote_style_1:before,
blockquote.trx_addons_blockquote_style_2:before {
  content: '\e9a1';
  display: block;
  font-family: "fontello";
  font-size: 16px;
  margin: 0 0 8px;
}

blockquote.trx_addons_blockquote_style_1 {
  border-left: 2px solid var(--theme-color-alter_link2);
}

blockquote.trx_addons_blockquote_style_2 {
  border-left: 2px solid var(--theme-color-alter_link);
}

blockquote.trx_addons_blockquote_style_1:before {
  color: var(--theme-color-alter_link2);
}

blockquote.trx_addons_blockquote_style_1 {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}

blockquote.trx_addons_blockquote_style_1 b {
  color: var(--theme-color-alter_dark);
}

blockquote.trx_addons_blockquote_style_1 a,
blockquote.trx_addons_blockquote_style_1 cite {
  color: var(--theme-color-alter_link2);
}
blockquote.trx_addons_blockquote_style_1 a:before,
blockquote.trx_addons_blockquote_style_1 cite:before {
  background-color: var(--theme-color-alter_link2);
}

blockquote.trx_addons_blockquote_style_1 a:hover {
  color: var(--theme-color-alter_hover2);
}

blockquote.trx_addons_blockquote_style_2 {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}

blockquote.trx_addons_blockquote_style_2:before,
blockquote.trx_addons_blockquote_style_2 a,
blockquote.trx_addons_blockquote_style_2 cite {
  color: var(--theme-color-alter_link);
}

blockquote.trx_addons_blockquote_style_2 cite:before {
  background-color: var(--theme-color-alter_link);
}

blockquote.trx_addons_blockquote_style_2 a:hover {
  color: var(--theme-color-alter_hover);
}

.trx_addons_hover_mask {
  background-color: var(--theme-color-extra_bg_color_07);
}

.trx_addons_hover_title {
  color: var(--theme-color-extra_dark);
}

.trx_addons_hover_content .trx_addons_hover_text {
  color: var(--theme-color-extra_text);
}
.trx_addons_hover_content .trx_addons_hover_icon,
.trx_addons_hover_content .trx_addons_hover_links a {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-extra_link);
}
.trx_addons_hover_content .trx_addons_hover_icon:hover,
.trx_addons_hover_content .trx_addons_hover_links a:hover {
  color: var(--theme-color-inverse_hover) !important;
  background-color: var(--theme-color-extra_hover);
}

/* Gradient */
body:not(.ua_ie) .trx_addons_text_gradient {
  background: var(--theme-color-text_link);
  background: linear-gradient(0deg, var(--theme-color-text_link), var(--theme-color-text_hover));
}

/* Layouts
--------------------------------------- */
.menu_side_left .sc_layouts_row_fixed_on {
  margin-left: 6rem !important;
}

.menu_side_right .sc_layouts_row_fixed_on {
  margin-right: 6rem !important;
}

body.mobile_layout.menu_side_left .sc_layouts_row_fixed_on {
  margin-left: 0 !important;
}

body.mobile_layout.menu_side_right .sc_layouts_row_fixed_on {
  margin-right: 0 !important;
}

.header_position_under:not(.mobile_layout) .top_panel .wpb_row {
  background-color: transparent !important;
}

.top_panel.with_bg_image .sc_layouts_row:not(.sc_layouts_row_fixed_on) {
  background-color: transparent;
}

body.body_style_boxed .sc_layouts_row_fixed_on {
  right: calc( ( 100% - var(--theme-var-page_boxed) ) / 2 );
  left: calc( ( 100% - var(--theme-var-page_boxed) ) / 2 );
}

/* Stack rows */
.menu_side_right .sc_stack_section_fixed {
  right: var(--theme-var-menu_side) !important;
}

.menu_side_left .sc_stack_section_fixed {
  left: var(--theme-var-menu_side) !important;
}

/* Grid */
.sidebar .trx_addons_columns_wrap {
  margin-right: 0;
}

.sidebar .trx_addons_columns_wrap [class*="trx_addons_column-"] {
  display: block;
  width: 100%;
  padding: 0;
}

/* CPT */
.post-type-archive-cpt_portfolio .sc_portfolio_default .trx_addons_columns_wrap:not(.columns_in_single_row),
.post-type-archive-cpt_services .sc_services_default .trx_addons_columns_wrap:not(.columns_in_single_row),
.post-type-archive-cpt_team .sc_team_default .trx_addons_columns_wrap:not(.columns_in_single_row) {
  margin-bottom: -30px;
}

/* Tabs */
.widget .trx_addons_tabs .trx_addons_tabs_titles {
  margin: -3px -3px 1.2em -3px;
}
.widget .trx_addons_tabs .trx_addons_tabs_titles li {
  font-size: 11px;
  line-height: 14px;
  font-weight: 700;
  letter-spacing: 0.6px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.widget .trx_addons_tabs .trx_addons_tabs_titles li, .widget .trx_addons_tabs .trx_addons_tabs_titles li + li {
  margin: 3px;
}
.widget .trx_addons_tabs .trx_addons_tabs_titles li a {
  display: inline-block;
  padding: 5px 17px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  color: var(--theme-color-text);
  background-color: var(--theme-color-bd_color);
}
.widget .trx_addons_tabs .trx_addons_tabs_titles li a:before {
  display: none;
}
.widget .trx_addons_tabs .trx_addons_tabs_titles li.ui-state-active a,
.widget .trx_addons_tabs .trx_addons_tabs_titles li a:hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}
[class*="scheme_"].sidebar .widget .trx_addons_tabs .trx_addons_tabs_titles li a {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bd_color);
}
[class*="scheme_"].sidebar .widget .trx_addons_tabs .trx_addons_tabs_titles li.ui-state-active a,
[class*="scheme_"].sidebar .widget .trx_addons_tabs .trx_addons_tabs_titles li a:hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_link);
}

/* Posts emotions */
.trx_addons_emotions_item {
  background-color: var(--theme-color-bg_color);
  border-color: var(--theme-color-bd_color);
  color: var(--theme-color-text_light);
}

.trx_addons_emotions_item:hover {
  color: var(--theme-color-alter_dark);
  border-color: var(--theme-color-alter_bd_hover);
  background-color: var(--theme-color-alter_bg_hover);
}

.trx_addons_emotions_active {
  color: var(--theme-color-alter_text);
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
}

.trx_addons_emotions_item_number {
  color: var(--theme-color-text);
}

/* Slider
---------------------------------------------- */
/* Pagination */
.sidebar .slider_pagination_pos_bottom > .swiper-pagination,
.sidebar .slider_outer_pagination_pos_bottom > .swiper-pagination {
  bottom: 0.5em;
}

.swiper-pagination-bullet {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.sidebar .slider_container .swiper-pagination-bullet,
.sidebar .slider_outer .swiper-pagination-bullet {
  width: 8px;
  height: 8px;
  line-height: 8px;
  text-align: center;
}

.sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet,
.swiper-pagination-custom .swiper-pagination-button,
.slider_container .swiper-pagination-bullet,
.slider_outer .swiper-pagination-bullet {
  -webkit-transition: color 0.3s ease, border-color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease;
  -ms-transition: color 0.3s ease, border-color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease;
  transition: color 0.3s ease, border-color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease;
}

.sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet,
.slider_container .slider_pagination_wrap .swiper-pagination-bullet,
.slider_outer .slider_pagination_wrap .swiper-pagination-bullet,
.swiper-pagination-custom .swiper-pagination-button {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
}

.swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active,
.sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active,
.sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover,
.slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover,
.slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

.slider_container .swiper-pagination-progressbar .swiper-pagination-progressbar-fill,
.slider_outer .swiper-pagination-progressbar .swiper-pagination-progressbar-fill {
  background-color: var(--theme-color-text_link);
}

.slider_outer > .swiper-pagination-fraction {
  color: var(--theme-color-text_dark);
}

.sc_slider_controls.slider_pagination_style_progress .sc_slider_controls_wrap {
  background-color: var(--theme-color-bd_color);
}

.sc_slider_controls .slider_progress_bar {
  background-color: var(--theme-color-text_link);
}

.sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination.swiper-pagination-progressbar {
  bottom: 0;
}

/* Controls */
.slider_outer.slider_outer_pagination_pos_left > .swiper-pagination-fraction,
.slider_outer.slider_outer_pagination_pos_right > .swiper-pagination-fraction {
  bottom: 6px;
}

.sc_slider_controls .slider_controls_wrap > a,
.slider_container.slider_controls_side .slider_controls_wrap > a,
.slider_outer_controls_outside .slider_controls_wrap > a,
.slider_outer_controls_side .slider_controls_wrap > a,
.slider_outer_controls_top .slider_controls_wrap > a,
.slider_outer_controls_bottom .slider_controls_wrap > a {
  width: 50px;
  height: 50px;
  line-height: 50px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}

.slider_container .swiper-button-next, .slider_container .swiper-button-prev {
  margin-top: -25px;
}

.slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_prev,
.slider_outer_controls_side:hover .slider_controls_wrap > a.slider_prev {
  margin-left: 30px;
}
.slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_next,
.slider_outer_controls_side:hover .slider_controls_wrap > a.slider_next {
  margin-right: 30px;
}

.slider_container.slider_controls_side .slider_container.slider_controls_side .slider_controls_wrap > a,
.slider_container.slider_controls_side .slider_outer_controls_side .slider_controls_wrap > a,
.slider_outer_controls_side .slider_container.slider_controls_side .slider_controls_wrap > a,
.slider_outer_controls_side .slider_outer_controls_side .slider_controls_wrap > a {
  opacity: 1 !important;
}
.slider_container.slider_controls_side .slider_container.slider_controls_side .slider_controls_wrap > a.slider_prev,
.slider_container.slider_controls_side .slider_outer_controls_side .slider_controls_wrap > a.slider_prev,
.slider_outer_controls_side .slider_container.slider_controls_side .slider_controls_wrap > a.slider_prev,
.slider_outer_controls_side .slider_outer_controls_side .slider_controls_wrap > a.slider_prev {
  margin-left: 25px;
  left: 0 !important;
}
.slider_container.slider_controls_side .slider_container.slider_controls_side .slider_controls_wrap > a.slider_next,
.slider_container.slider_controls_side .slider_outer_controls_side .slider_controls_wrap > a.slider_next,
.slider_outer_controls_side .slider_container.slider_controls_side .slider_controls_wrap > a.slider_next,
.slider_outer_controls_side .slider_outer_controls_side .slider_controls_wrap > a.slider_next {
  margin-right: 25px;
  right: 0 !important;
}

.sc_blogger .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets {
  margin-top: 2.7em;
}

.sc_blogger .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination.swiper-pagination-bullets {
  bottom: 0.8em;
}

.sc_item_slider.slider_outer_pagination_pos_bottom .slider_outer_pagination_pos_bottom .swiper-pagination {
  bottom: 1em !important;
}

.sc_slider_controls .slider_controls_wrap > a,
.slider_container.slider_controls_side .slider_controls_wrap > a,
.slider_outer_controls_side .slider_controls_wrap > a,
.slider_outer_controls_outside .slider_controls_wrap > a {
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bg_color);
}

.sc_slider_controls .slider_controls_wrap > a:hover,
.slider_container.slider_controls_side .slider_controls_wrap > a:hover,
.slider_outer_controls_side .slider_controls_wrap > a:hover,
.slider_outer_controls_outside .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link);
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bg_color);
}

.slider_container.slider_controls_top .slider_controls_wrap > a,
.slider_container.slider_controls_bottom .slider_controls_wrap > a,
.slider_outer_controls_top .slider_controls_wrap > a,
.slider_outer_controls_bottom .slider_controls_wrap > a {
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bg_color);
}

.slider_container.slider_controls_top .slider_controls_wrap > a:hover,
.slider_container.slider_controls_bottom .slider_controls_wrap > a:hover,
.slider_outer_controls_top .slider_controls_wrap > a:hover,
.slider_outer_controls_bottom .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link);
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bg_color);
}

.slider_style_modern .slider_controls_label {
  color: var(--theme-color-bg_color);
}

.slider_style_modern .slider_pagination_wrap {
  color: var(--theme-color-text_light);
}

.slider_style_modern .swiper-pagination-current {
  color: var(--theme-color-text_dark);
}

/* Icons in controls */
.sc_slider_controls .slider_controls_wrap > a:before,
.slider_container.slider_controls_side .slider_controls_wrap > a:before,
.slider_outer_controls_side .slider_controls_wrap > a:before,
.slider_outer_controls_outside .slider_controls_wrap > a:before,
.slider_outer_controls_top .slider_controls_wrap > a:before,
.slider_outer_controls_bottom .slider_controls_wrap > a:before {
  font-family: "fontello";
  font-size: 18px;
}

.sc_slider_controls .slider_controls_wrap > .slider_prev:before,
.slider_container.slider_controls_side .slider_controls_wrap > .slider_prev:before,
.slider_outer_controls_side .slider_controls_wrap > .slider_prev:before,
.slider_outer_controls_outside .slider_controls_wrap > .slider_prev:before,
.slider_outer_controls_top .slider_controls_wrap > .slider_prev:before,
.slider_outer_controls_bottom .slider_controls_wrap > .slider_prev:before {
  content: '\e907';
}

.sc_slider_controls .slider_controls_wrap > .slider_next:before,
.slider_container.slider_controls_side .slider_controls_wrap > .slider_next:before,
.slider_outer_controls_side .slider_controls_wrap > .slider_next:before,
.slider_outer_controls_outside .slider_controls_wrap > .slider_next:before,
.slider_outer_controls_top .slider_controls_wrap > .slider_next:before,
.slider_outer_controls_bottom .slider_controls_wrap > .slider_next:before {
  content: '\e908';
}

.slider_elastistack_outer.slider_outer_controls > .slider_controls_wrap > .slider_next:before,
.slider_elastistack.slider_controls > .slider_controls_wrap > .slider_next:before {
  content: '\e929';
}

.widget_slider.widget ul > li .slide_info a:first-child:before {
  display: none;
}

/* Slide info */
.slider_container .slide_info,
.slider_container .slide_content {
  padding: 0 2em;
  line-height: inherit;
}

.slider_container.slider_multi .slide_title,
.slider_container .slide_info:not(.slide_info_large) .slide_title {
  font-size: 1.333em;
  line-height: 1.3em;
  font-weight: 500;
}

.slider_container .slide_info .slide_cats,
.slider_container .slide_content .slide_cats {
  font-size: 16px;
  line-height: 1.5em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
}

.slider_container .slide_overlay {
  background: rgba(0, 0, 0, 0.3);
}

.slider_container .slider-slide:hover .slide_overlay {
  background: rgba(0, 0, 0, 0.4);
}

/* Type Text */
.slider_outer_overflow_hidden .slider_container.slider_type_text[data-slides-per-view="1"][class*="-fade"] .slider-slide {
  -webkit-justify-content: start;
  -ms-flex-pack: start;
  justify-content: start;
}
.slider_outer_overflow_hidden .slider_container.slider_type_text[data-slides-per-view="1"][class*="-fade"] .slider-slide:not(.swiper-slide-active) {
  opacity: 0 !important;
}

/* Type Images */
.slider_type_images.slider_container .slide_overlay {
  display: none;
}

.slider_type_images.slider_container.slider_multi:not(.slider_type_text) .slide_title,
.slider_type_images.slider_container.slider_multi:not(.slider_type_text) .slide_title a,
.slider_type_images.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_title,
.slider_type_images.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_title a {
  color: var(--theme-color-text_dark);
}

.slider_type_images.slider_container.slider_multi:not(.slider_type_text) .slide_date,
.slider_type_images.slider_container.slider_multi:not(.slider_type_text) .slide_cats,
.slider_type_images.slider_container.slider_multi:not(.slider_type_text) .slide_cats a,
.slider_type_images.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_date,
.slider_type_images.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_cats,
.slider_type_images.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_cats a {
  color: var(--theme-color-text);
}

.slider_type_images.slider_container.slider_titles_lb .slider-slide:not(.with_content) .slide_info_small,
.slider_type_images.slider_container.slider_titles_rb .slider-slide:not(.with_content) .slide_info_small,
.slider_type_images.slider_container.slider_titles_bottom .slider-slide:not(.with_content) .slide_info_small,
.slider_type_images.slider_container.slider_titles_lb .slide_content,
.slider_type_images.slider_container.slider_titles_rb .slide_content,
.slider_type_images.slider_container.slider_titles_bottom .slide_content {
  margin-top: 10px;
  margin-bottom: 0;
  padding: 0;
}

.slider_type_images.slider_container:not(.slider_type_text) .slide_info_small,
.slider_type_images.slider_container.slider_multi:not(.slider_type_text) .slide_info_small {
  text-shadow: none;
}

.slider_type_images.slider_container .slide_info.slide_info_large {
  padding: 0;
}

.slider_type_images.slider_container.slider_titles_rb .slide_info_large,
.slider_type_images.slider_container.slider_titles_lb .slide_info_large {
  max-width: none;
}

.slider_type_images.slider_container.slider_titles_rb .slide_info_large {
  padding-left: 5%;
}

.slider_type_images.slider_container.slider_titles_lb .slide_info_large {
  padding-right: 5%;
}

/* Type bg */
.slider_type_bg.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play + .slide_info,
.slider_type_bg.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play:hover + .slide_info {
  -webkit-transform: translateY(5em);
  -ms-transform: translateY(5em);
  transform: translateY(5em);
}

.slider_type_bg.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play ~ .slide_content {
  -webkit-transform: translateY(5em);
  -ms-transform: translateY(5em);
  transform: translateY(5em);
}

.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play + .slide_info,
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play:hover + .slide_info {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}

.slider_container.slider_titles_outside .trx_addons_video_player.with_cover.hover_play ~ .slide_link,
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play ~ .slide_link {
  z-index: 0;
}

.slider_container.slider_titles_outside .trx_addons_video_player.with_cover.hover_play ~ .slide_content {
  -webkit-transform: translateY(4em);
  -ms-transform: translateY(4em);
  transform: translateY(4em);
  text-shadow: 1px 1px #000;
}

/* Info Large */
.slider_container .slide_info.slide_info_large {
  padding: 1.5em;
  background-color: var(--theme-color-bg_color_09);
}

.slider_container .slide_info.slide_info_large:hover {
  background-color: var(--theme-color-bg_color);
}

.slider_container.slider_titles_center .slide_info:not(.slide_info_large),
.slider_container.slider_titles_center .slide_content {
  width: 100%;
  padding: 0 5%;
}

.slider_container .slide_info.slide_info_large .slide_title {
  margin: 0.3em 0;
  font-size: 1.4em;
  line-height: 1.3em;
  font-weight: 500;
  text-transform: none;
}

.slider_container.slider_type_bg .slide_info.slide_info_large .slide_title,
.slider_container.slider_type_images .slide_info.slide_info_large .slide_title,
.slider_container.slider_type_bg .slide_info.slide_info_large .slide_title a,
.slider_container.slider_type_images .slide_info.slide_info_large .slide_title a,
.slider_container.slider_type_bg .slide_info.slide_info_large:hover .slide_date,
.slider_container.slider_type_images .slide_info.slide_info_large:hover .slide_date,
.slider_container.slider_type_bg .slide_info.slide_info_large:hover .slide_cats,
.slider_container.slider_type_images .slide_info.slide_info_large:hover .slide_cats,
.slider_container.slider_type_bg .slide_info.slide_info_large:hover .slide_cats a,
.slider_container.slider_type_images .slide_info.slide_info_large:hover .slide_cats a {
  color: var(--theme-color-text_dark);
}

.slider_container .slide_info.slide_info_large .slide_cats {
  color: var(--theme-color-text);
}

.slider_container .slide_info.slide_info_large .slide_cats a {
  color: var(--theme-color-text);
  font-size: 16px;
  line-height: 1.5em;
  font-weight: 400;
  text-transform: none;
}

.slider_container .slide_info.slide_info_large .slide_title a {
  color: var(--theme-color-text_dark);
}

.slider_container .slide_info.slide_info_large .slide_date {
  color: var(--theme-color-text_dark);
}

.slider_container .slide_info.slide_info_large:hover .slide_date {
  color: var(--theme-color-text_dark);
}

.slider_container .slide_info.slide_info_large .slide_cats a:hover,
.slider_container .slide_info.slide_info_large .slide_title a:hover {
  color: var(--theme-color-text_dark);
}

.slider_container.slider_multi .slide_cats a:hover,
.slider_container.slider_multi .slide_title a:hover,
.slider_container.slider_multi a:hover .slide_title {
  color: var(--theme-color-text_dark);
}

.slider_titles_outside_wrap .slide_title {
  font-size: 1.333em;
  line-height: 1.3em;
}
.slider_titles_outside_wrap .slide_title + .slide_cats,
.slider_titles_outside_wrap .slide_title + .slide_subtitle {
  margin-top: 6px;
}

.slider_titles_outside_wrap .slide_title a {
  color: var(--theme-color-text_dark);
}

.slider_titles_outside_wrap .slide_title a:hover {
  color: var(--theme-color-text_dark);
}

.slider_titles_outside_wrap .slide_cats,
.slider_titles_outside_wrap .slide_subtitle {
  color: var(--theme-color-text);
  font-size: 16px;
  line-height: 1.5em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}

.slider_titles_outside_wrap .slide_cats a,
.slider_titles_outside_wrap .slide_subtitle a {
  color: var(--theme-color-text);
}

.slider_titles_outside_wrap .slide_cats a:hover,
.slider_titles_outside_wrap .slide_subtitle a:hover {
  color: var(--theme-color-text_dark);
}

.slider_outer.slider_outer_titles_outside_top {
  padding-top: 9em;
}
.slider_outer.slider_outer_titles_outside_top .slider_titles_outside_wrap {
  top: 2em;
  padding: 0 70px;
  max-height: 100%;
}
.slider_outer.slider_outer_titles_outside_top .slide_info {
  position: relative;
  text-align: left;
  padding-right: 60px;
}
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_cats {
  font-size: 12px;
  line-height: 18px;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 1.6px;
  margin-bottom: 5px;
  color: var(--theme-color-text_dark);
}
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_cats a {
  color: var(--theme-color-text_dark);
}
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_cats a:hover {
  color: var(--theme-color-text);
}
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_number {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  color: var(--theme-color-text_light);
  top: auto;
  bottom: 0;
  right: 0;
}
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_title {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 1;
  -webkit-box-orient: vertical;
}
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_title,
.slider_outer.slider_outer_titles_outside_top .slide_info .slide_number {
  font-size: var(--theme-font-h1_font-size);
  line-height: 1.2em;
  font-weight: var(--theme-font-h1_font-weight);
  padding-bottom: 5px;
}

/* Slider in the widgets area */
.header_widgets_wrap .slider_container .slide_overlay.slide_overlay_large {
  background-color: transparent;
}

.header_widgets_wrap .slider_container.slider_titles_center:not(.slider_multi) .slide_info.slide_info_large {
  width: 18em;
}

.sidebar .slider_container.slider_multi .slide_info:not(.slide_info_large),
.sidebar .slider_container .slide_info:not(.slide_info_large),
.footer_wrap .slider_container.slider_multi .slide_info:not(.slide_info_large),
.footer_wrap .slider_container .slide_info:not(.slide_info_large) {
  bottom: 8px;
}

.sidebar .slider_container.slider_multi .slide_title,
.sidebar .slider_container .slide_info:not(.slide_info_large) .slide_title,
.footer_wrap .slider_container.slider_multi .slide_title,
.footer_wrap .slider_container .slide_info:not(.slide_info_large) .slide_title {
  font-size: 1.2em;
  line-height: 1.2em;
  margin-bottom: 6px;
}

.sidebar .slider_container.slider_multi .slide_date,
.sidebar .slider_container .slide_info:not(.slide_info_large) .slide_date,
.footer_wrap .slider_container.slider_multi .slide_date,
.footer_wrap .slider_container .slide_info:not(.slide_info_large) .slide_date {
  font-size: 12px;
  line-height: 16px;
}

/* titles horizontal */
.sc_slider_controller_horizontal[data-controls="1"] {
  padding-left: 60px;
  padding-right: 57px;
}
.sc_slider_controller_horizontal[data-controls="1"] .sc_slider_controller_info {
  width: 83%;
}

.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > a {
  width: 60px;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > a.slider_prev {
  left: -60px;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > a.slider_prev:before {
  content: '\e939';
  font-size: 28px;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > a.slider_next {
  right: -57px;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > a.slider_next:before {
  content: '\e93a';
  font-size: 28px;
}

.sc_slider_controller_titles .slider-slide {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_slider_controller_titles .slider-slide:hover {
  background-color: var(--theme-color-alter_bg_color);
}

.sc_slider_controller_titles .slider-slide:after {
  background-color: var(--theme-color-alter_bd_color);
}

.sc_slider_controller_titles .slider-slide.swiper-slide-active {
  background-color: var(--theme-color-bg_color);
}
.sc_slider_controller_titles .slider-slide.swiper-slide-active:after {
  background-color: var(--theme-color-text_dark);
}

.sc_slider_controller_titles .slider-slide:before {
  width: 1px;
  background-color: var(--theme-color-alter_bd_color);
}

.sc_slider_controller_titles {
  padding-top: 12px;
}

.sc_slider_controller_titles .slider_outer_controls_side .slider_controls_wrap > a {
  top: 12px;
}

.sc_slider_controller_titles .swiper-slide {
  margin-top: 12px;
}

.sc_slider_controller_titles .swiper-slide.swiper-slide-active {
  margin-top: 0;
  margin-bottom: -12px;
}

.sc_slider_controller_titles .sc_slider_controller_info {
  text-transform: none;
  font-size: 24px;
  font-weight: 700;
}
.sc_slider_controller_titles .sc_slider_controller_info .sc_slider_controller_info_number {
  color: var(--theme-color-text_dark);
}
.sc_slider_controller_titles .sc_slider_controller_info .sc_slider_controller_info_number:after {
  content: '.';
}
.sc_slider_controller_titles .sc_slider_controller_info .sc_slider_controller_info_title {
  color: var(--theme-color-text_dark);
}
.sc_slider_controller_titles .sc_slider_controller_info .slider-slide::before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: auto;
  width: 1px;
  background-color: #ddd;
}

/* titles vertical */
.sc_slider_controller_vertical.sc_slider_controller_titles .swiper-slide,
.sc_slider_controller_vertical.sc_slider_controller_titles .swiper-slide.swiper-slide-active {
  margin-top: 0;
  margin-bottom: 0;
}

/* Slider controller */
.sc_slider_controller .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_prev,
.sc_slider_controller .slider_outer_controls_side:hover .slider_controls_wrap > a.slider_prev {
  margin-left: 0;
}

.sc_slider_controller .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_next,
.sc_slider_controller .slider_outer_controls_side:hover .slider_controls_wrap > a.slider_next {
  margin-right: 0;
}

.sc_slider_controller .slider-slide.swiper-slide-active:after {
  background-color: var(--theme-color-text_dark);
}

.sc_slider_controller_titles .slider_controls_wrap > a {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}

.sc_slider_controller_titles .slider_controls_wrap > a:hover {
  color: var(--theme-color-bg_color);
  background-color: var(--theme-color-text_dark);
}

.slider_outer_wrap .sc_slider_controller .slider-slide {
  padding: 1em 1em 1em 2em;
}

.slider_outer_wrap .sc_slider_controller .sc_slider_controller_item_info_date {
  color: var(--theme-color-text_light);
}

.slider_outer_wrap .sc_slider_controller .slider-slide.swiper-slide-active {
  background-color: var(--theme-color-alter_bg_hover);
}

.slider_outer_wrap .sc_slider_controller .slider-slide.swiper-slide-active .sc_slider_controller_item_info_date {
  color: var(--theme-color-alter_light);
}

.slider_outer_wrap .sc_slider_controller .slider-slide.swiper-slide-active .sc_slider_controller_item_info_title {
  color: var(--theme-color-alter_dark);
}

.slider_outer_wrap .sc_slider_controller .sc_slider_controller_item_image + .sc_slider_controller_item_info,
.slider_outer_wrap .sc_slider_controller .sc_slider_controller_item_image ~ .sc_slider_controller_item_info {
  padding-left: 1.5em;
  overflow: hidden;
}

.slider_outer_wrap .sc_slider_controller .slider-slide .sc_slider_controller_item_info_cats {
  font-size: 16px;
  line-height: 1.5em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
}
.slider_outer_wrap .sc_slider_controller .slider-slide .sc_slider_controller_item_info_cats a {
  color: var(--theme-color-alter_text);
}
.slider_outer_wrap .sc_slider_controller .slider-slide .sc_slider_controller_item_info_cats a:hover {
  color: var(--theme-color-alter_text);
}
.slider_outer_wrap .sc_slider_controller .slider-slide.swiper-slide-active .sc_slider_controller_item_info_cats a {
  color: var(--theme-color-alter_dark);
}
.slider_outer_wrap .sc_slider_controller .slider-slide.swiper-slide-active .sc_slider_controller_item_info_cats a:hover {
  color: var(--theme-color-alter_dark);
}

.slider_outer_wrap .sc_slider_controller .slider-slide .sc_slider_controller_item_info_date {
  font-weight: 400;
  color: var(--theme-color-alter_text);
}
.slider_outer_wrap .sc_slider_controller .slider-slide.swiper-slide-active .sc_slider_controller_item_info_date {
  color: var(--theme-color-alter_dark);
}

.slider_outer_wrap .sc_slider_controller .sc_slider_controller_item_info_title {
  font-size: 1.1em;
  line-height: 1.2em;
}

.slider_outer_wrap .sc_slider_controller .sc_slider_controller_item_info_cats + .sc_slider_controller_item_info_title {
  margin-top: 3px;
}

.slider_outer_wrap .sc_slider_controller .sc_slider_controller_item_info_title + .sc_slider_controller_item_info_date {
  margin-top: 5px;
}

.slider_outer_wrap.slider_outer_wrap_controller_pos_bottom .sc_slider_controller_horizontal {
  padding-top: 0;
}
.slider_outer_wrap.slider_outer_wrap_controller_pos_bottom .sc_slider_controller_horizontal .slider-slide.swiper-slide-active:after {
  background-color: var(--theme-color-alter_link);
}

/* Slider controls - Title */
.slider_pagination_style_title .slider_pagination_wrap {
  height: auto !important;
}

.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet {
  width: 100%;
  height: auto;
  font-size: 47px;
  font-weight: 700;
  line-height: 1.3em;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background: none !important;
  opacity: 1 !important;
  border: none !important;
  margin: 0 !important;
  color: var(--theme-color-text_light);
  cursor: pointer;
}
.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet + .slider_pagination_bullet {
  margin-top: 10px !important;
}
.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet:after {
  display: none !important;
}
.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet.slider_pagination_bullet_active {
  color: var(--theme-color-text_dark);
}

/* Light */
.slider_pagination_style_title.sc_slider_controls_light .slider_pagination_wrap .slider_pagination_bullet {
  width: 100%;
  height: auto;
  font-size: 16px;
  font-weight: 400;
  line-height: 1.3em;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background: none !important;
  opacity: 1 !important;
  border: none !important;
  margin: 0 !important;
  color: var(--theme-color-alter_text);
  cursor: pointer;
  text-align: left;
  padding: 0 0 0 20px;
  position: relative;
}
.slider_pagination_style_title.sc_slider_controls_light .slider_pagination_wrap .slider_pagination_bullet + .slider_pagination_bullet {
  margin-top: 18px !important;
}
.slider_pagination_style_title.sc_slider_controls_light .slider_pagination_wrap .slider_pagination_bullet:before {
  font-size: 7px;
  left: 0;
  top: 0;
  display: inline-block;
  position: absolute;
  color: var(--theme-color-alter_text);
  content: '\e814';
  font-family: "fontello";
  font-weight: 400;
}
.slider_pagination_style_title.sc_slider_controls_light .slider_pagination_wrap .slider_pagination_bullet:after {
  display: none !important;
}
.slider_pagination_style_title.sc_slider_controls_light .slider_pagination_wrap .slider_pagination_bullet.slider_pagination_bullet_active {
  color: var(--theme-color-text_dark);
}
.slider_pagination_style_title.sc_slider_controls_light .slider_pagination_wrap .slider_pagination_bullet.slider_pagination_bullet_active:before {
  color: var(--theme-color-text_link2);
}

/* Widgets
---------------------------------------------- */
/* Widgets in the Footer */
.footer_wrap .sc_layouts_row {
  line-height: 1.66em;
}

.footer_wrap .sc_layouts_row_type_compact {
  font-size: 15px;
}

.footer_wrap .sc_layouts_row .sc_layouts_item,
.footer_wrap .sc_layouts_row .widget {
  vertical-align: top;
  margin-top: 0.5em !important;
  margin-bottom: 0.5em !important;
}

.footer_wrap .sc_layouts_item.elementor-widget-divider,
.footer_wrap .sc_layouts_item.elementor-widget-spacer,
.footer_wrap .sc_layouts_item .widget {
  margin-top: 0 !important;
  margin-bottom: 0 !important;
}

/* Categories list */
.widget_categories_list .categories_list_style_1 .categories_list_icon {
  color: var(--theme-color-text_dark);
}

.widget_categories_list .categories_list_style_1 .categories_list_item:hover .categories_list_icon {
  color: var(--theme-color-text_link);
}

.widget_categories_list .categories_list_style_1 .categories_list_item:hover .categories_list_title {
  color: var(--theme-color-text_link);
}

.widget_categories_list .categories_list_style_2 .categories_list_title {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color_07);
}

.widget_categories_list .categories_list_style_2 .categories_list_item:hover .categories_list_title {
  color: var(--theme-color-alter_link);
  background-color: var(--theme-color-alter_bg_hover);
}

.widget_categories_list .categories_list_style_3 .categories_list_item {
  background-color: var(--theme-color-alter_bg_color);
}

.widget_categories_list .categories_list_style_3 .categories_list_item:hover .categories_list_title,
.widget_categories_list .categories_list_style_3 .categories_list_item:hover .categories_list_icon {
  color: var(--theme-color-text_link);
}

/* Widget Categories list in columns or sidebar */
.widget_categories_list[class*="column-"] [class*="column-"],
.sidebar .widget_categories_list [class*="column-"] {
  width: 100%;
  float: none;
  overflow: hidden;
}

.widget_categories_list[class*="column-"] [class*="column-"] + [class*="column-"],
.sidebar .widget_categories_list [class*="column-"] + [class*="column-"] {
  margin-top: 0.5em;
}

.widget_categories_list[class*="column-"] .categories_list_style_1 .categories_list_item,
.sidebar .widget_categories_list .categories_list_style_1 .categories_list_item {
  text-align: left;
}

.widget_categories_list[class*="column-"] .categories_list_style_1 .categories_list_image {
  display: inline-block;
  width: 20%;
}

.sidebar .widget_categories_list .categories_list_style_1 .categories_list_image {
  display: inline-block;
  width: 32px;
  vertical-align: middle;
}

.widget_categories_list[class*="column-"] .categories_list_style_1 .categories_list_image img,
.sidebar .widget_categories_list .categories_list_style_1 .categories_list_image img {
  width: 100%;
  height: auto;
}

.widget_categories_list[class*="column-"] .categories_list_style_1 .categories_list_title,
.sidebar .widget_categories_list .categories_list_style_1 .categories_list_title {
  display: inline-block;
  vertical-align: middle;
  width: 70%;
  margin: 0;
  font-size: 1em;
  text-align: left;
  text-transform: none;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.widget_categories_list[class*="column-"] .categories_list_style_1 .categories_list_image + .categories_list_title,
.sidebar .widget_categories_list .categories_list_style_1 .categories_list_image + .categories_list_title {
  padding-left: 1em;
}

/* Contacts */
.widget_contacts .contacts_socials {
  margin-bottom: -5px;
}
.widget_contacts .contacts_socials .social_item {
  margin: 0 5px 5px 0;
}

.widget_contacts .contacts_info {
  font-size: 16px;
  line-height: 1.7em;
}
.widget_contacts .contacts_info span,
.widget_contacts .contacts_info > div > a,
.widget_contacts .contacts_info > a {
  padding-left: 2.3em;
}
.widget_contacts .contacts_info .contacts_left > * {
  padding-right: 2.3em;
}
.widget_contacts .contacts_info .contacts_left > :before {
  text-align: center;
}
.widget_contacts .contacts_info span + span,
.widget_contacts .contacts_info span + a {
  margin-top: 1.5em;
}
.widget_contacts .contacts_info span:before,
.widget_contacts .contacts_info > div > a:before,
.widget_contacts .contacts_info > a::before {
  font-family: "fontello";
  font-size: 1.4em;
  width: 1.2em;
  text-align: center;
}
.widget_contacts .contacts_info span.contacts_address:before {
  content: '\E9D2';
}
.widget_contacts .contacts_info span.contacts_email:before {
  content: '\E9FC';
}
.widget_contacts .contacts_info span.contacts_phone:before,
.widget_contacts .contacts_info a.contacts_phone:before {
  content: '\E9CF';
}
.widget_contacts .contacts_info .contacts_left,
.widget_contacts .contacts_info .contacts_right {
  white-space: normal;
}
.widget_contacts .contacts_info .contacts_left .contacts_email,
.widget_contacts .contacts_info .contacts_left .contacts_phone,
.widget_contacts .contacts_info .contacts_right .contacts_email,
.widget_contacts .contacts_info .contacts_right .contacts_phone {
  white-space: nowrap;
}

.footer_wrap .widget_contacts .contacts_description,
.footer_wrap .widget_contacts .contacts_content {
  margin-left: auto;
  margin-right: auto;
}

.footer_wrap .columns_wrap .widget_contacts .contacts_description,
.footer_wrap .columns_wrap .widget_contacts .contacts_content {
  max-width: none;
}

.widget_contacts .contacts_info {
  color: var(--theme-color-text);
}

.widget_contacts .contacts_info span:before,
.widget_contacts .contacts_info > div > a:before,
.widget_contacts .contacts_info > a:before {
  color: var(--theme-color-text_link2);
}

.widget_contacts .contacts_info span a,
.widget_contacts .contacts_info > div > a,
.widget_contacts .contacts_info > a {
  color: var(--theme-color-text);
}

.widget_contacts .contacts_info span a:hover,
.widget_contacts .contacts_info > div > a:hover,
.widget_contacts .contacts_info > a:hover {
  color: var(--theme-color-text_dark);
}

[class*="scheme_"].sidebar .widget_contacts .contacts_info,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info {
  color: var(--theme-color-alter_text);
}

[class*="scheme_"].sidebar .widget_contacts .contacts_info span:before,
[class*="scheme_"].sidebar .widget_contacts .contacts_info > div > a:before,
[class*="scheme_"].sidebar .widget_contacts .contacts_info > a:before,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info span:before,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info > div > a:before,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info > a:before {
  color: var(--theme-color-alter_link2);
}

[class*="scheme_"].sidebar .widget_contacts .contacts_info span a,
[class*="scheme_"].sidebar .widget_contacts .contacts_info > div > a,
[class*="scheme_"].sidebar .widget_contacts .contacts_info > a,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info span a,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info > div > a,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info > a {
  color: var(--theme-color-alter_text);
}

[class*="scheme_"].sidebar .widget_contacts .contacts_info span a:hover,
[class*="scheme_"].sidebar .widget_contacts .contacts_info > div > a:hover,
[class*="scheme_"].sidebar .widget_contacts .contacts_info > a:hover,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info span a:hover,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info > div > a:hover,
[class*="scheme_"].footer_wrap .widget_contacts .contacts_info > a:hover {
  color: var(--theme-color-alter_dark);
}

.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .sc_layouts_item a:not(.sc_button):not([class*="button"]) {
  color: var(--theme-color-text);
}
.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .sc_layouts_item a:not(.sc_button):not([class*="button"]):hover {
  color: var(--theme-color-text_dark);
}
.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .sc_layouts_item .product_list_widget a:not(.sc_button):not([class*="button"]) {
  color: var(--theme-color-text_dark);
}
.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .sc_layouts_item .product_list_widget a:not(.sc_button):not([class*="button"]):hover {
  color: var(--theme-color-text_link);
}
.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .sc_layouts_item .product_list_widget span.price,
.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .sc_layouts_item .product_list_widget span.amount {
  color: var(--theme-color-text_dark);
}
.footer_wrap [class*="scheme_"].sc_layouts_row.sc_layouts_row_type_compact .trx_addons_alter_text a {
  color: var(--theme-color-text_dark) !important;
}

/* footer narrow row */
.footer_wrap .sc_layouts_row_type_narrow .sc_layouts_item_icon + .sc_layouts_item_details {
  margin-left: 0.4em;
}
.footer_wrap .sc_layouts_row_type_narrow .sc_layouts_item_details_line1,
.footer_wrap .sc_layouts_row_type_narrow .sc_layouts_item_details_line2,
.footer_wrap .sc_layouts_row_type_narrow .sc_layouts_item_icon {
  color: var(--theme-color-text_dark);
}

/* footer compact row */
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_default .socials_wrap .social_item .social_icon {
  position: relative;
  display: block;
  overflow: hidden;
  width: 45px;
  height: 45px;
  line-height: 42px;
  font-size: 16px;
  text-align: center;
  border: 1px solid var(--theme-color-text_dark_015);
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_default[class*="modern"] .socials_wrap .social_item .social_icon {
  width: 45px;
  height: 45px;
  line-height: 44px;
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_default .socials_wrap {
  margin-bottom: -5px;
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_default .socials_wrap .social_item {
  margin: 0 5px 5px 0;
}

/* widget custom links */
.widget_custom_links ul > li a:first-child:before {
  display: none;
}
.widget_custom_links ul.custom_links_list .custom_links_list_item + .custom_links_list_item {
  margin-top: 14px !important;
}
.widget_custom_links ul > li.custom_links_list_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_link {
  margin: 0;
  padding: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  color: var(--theme-color-text_dark);
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_link:hover {
  color: var(--theme-color-text_dark);
}
.widget_custom_links ul > li.custom_links_list_item:hover .custom_links_list_item_link {
  margin-left: 9px;
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_title {
  padding: 0;
  position: relative;
  display: inline-block;
  line-height: 1.2em;
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_title:after {
  content: "";
  display: block;
  position: relative;
  z-index: 1;
  top: auto;
  bottom: -5px;
  left: 0;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  width: 0;
  height: 1px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  background-color: var(--theme-color-text_dark);
}
.widget_custom_links ul > li.custom_links_list_item:hover .custom_links_list_item_title:after {
  width: 100%;
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_label {
  color: var(--theme-color-inverse_hover);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-text_dark);
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_description {
  margin-top: 5px;
  font-style: normal;
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_button {
  padding: 0 1.5em 0 0;
  font-size: 16px;
  line-height: 21px;
  color: var(--theme-color-text_dark);
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_button:focus, .widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_button:hover {
  color: var(--theme-color-text_dark) !important;
}
.widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_button:before, .widget_custom_links ul > li.custom_links_list_item .custom_links_list_item_button:after {
  font-size: 9px;
}

.footer_wrap .sc_layouts_row_type_compact .underline_anim {
  display: inline;
  padding: 0;
  padding-bottom: 6px;
  background-image: linear-gradient(to right, currentColor 0%, currentColor 100%);
  background-position: 0 100%;
  background-repeat: no-repeat;
  -webkit-background-size: 0 1px;
  background-size: 0 1px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.footer_wrap .sc_layouts_row_type_compact .underline_anim.underline_do_hover {
  animation: underline_hover_on 0.8s cubic-bezier(0.25, 0.8, 0.25, 1) both;
}
.footer_wrap .sc_layouts_row_type_compact .underline_anim.underline_do_hover:hover {
  animation: underline_hover_off 0.8s cubic-bezier(0.25, 0.8, 0.25, 1) both;
}

@-webkit-keyframes underline_hover_on {
  0% {
    -webkit-background-size: 0 1px;
    background-size: 0 1px;
  }
  100% {
    -webkit-background-size: 100% 1px;
    background-size: 100% 1px;
  }
}
@keyframes underline_hover_on {
  0% {
    -webkit-background-size: 0 1px;
    background-size: 0 1px;
  }
  100% {
    -webkit-background-size: 100% 1px;
    background-size: 100% 1px;
  }
}
@-webkit-keyframes underline_hover_off {
  0% {
    -webkit-background-size: 100% 1px;
    background-size: 100% 1px;
  }
  100% {
    -webkit-background-size: 0 1px;
    background-size: 0 1px;
  }
}
@keyframes underline_hover_off {
  0% {
    -webkit-background-size: 100% 1px;
    background-size: 100% 1px;
  }
  100% {
    -webkit-background-size: 0 1px;
    background-size: 0 1px;
  }
}
/* Icons + names Socials in footer */
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_icons_names .socials_wrap .social_item + .social_item {
  margin-top: 10px;
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_icons_names .socials_wrap .social_item .social_icon {
  font-size: 16px;
  width: 2em;
  height: 2em;
  line-height: 2em;
  margin-left: -0.5em;
  color: var(--theme-color-text);
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_icons_names .socials_wrap .social_item .social_icon + .social_name {
  display: inline-block;
  vertical-align: middle;
  margin: 0 0 0 6px;
  font-size: 17px;
  line-height: 20px;
  font-weight: 400;
  color: var(--theme-color-text);
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_icons_names .socials_wrap .social_item:hover .social_name,
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_icons_names .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-text_dark);
}

/* Names Socials in footer */
.footer_wrap .sc_layouts_row_type_normal .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item {
  margin-right: 43px;
  font-size: 21px;
  font-weight: 700;
  letter-spacing: -0.42px;
  color: var(--theme-color-text_dark);
}
.footer_wrap .sc_layouts_row_type_normal .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item:hover {
  color: var(--theme-color-text);
}

.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item + .social_item {
  margin-top: 10px;
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item {
  display: inline-block;
  width: 100%;
  text-align: inherit;
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names.sc_align_left:not(.alter) .socials_wrap .social_item {
  display: table;
  width: auto;
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item .social_icon {
  font-size: 16px;
  width: 2em;
  height: 2em;
  line-height: 2em;
  margin-left: -0.5em;
  color: var(--theme-color-text);
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item .social_icon + .social_name {
  display: inline-block;
  vertical-align: middle;
  margin: 0 0 0 6px;
  font-size: 17px;
  line-height: 20px;
  font-weight: 400;
  color: var(--theme-color-text);
}
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item:hover .social_name,
.footer_wrap .sc_layouts_row_type_compact .sc_socials.sc_socials_names:not(.alter) .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-text_dark);
}

/* Only Name Socials */
.sc_socials.sc_socials_names .socials_wrap .social_item {
  color: var(--theme-color-text_dark);
}
.sc_socials.sc_socials_names .socials_wrap .social_item:hover {
  color: var(--theme-color-text_link);
}

/* Modern Socials */
.sc_socials.sc_socials_default.modern_2 .socials_wrap,
.sc_socials.sc_socials_default.modern .socials_wrap {
  margin-bottom: -8px;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item,
.sc_socials.sc_socials_default.modern .socials_wrap .social_item {
  margin: 0 8px 8px 0;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item .social_icon,
.sc_socials.sc_socials_default.modern .socials_wrap .social_item .social_icon {
  position: relative;
  display: block;
  overflow: hidden;
  width: 45px;
  height: 45px;
  line-height: 44px;
  font-size: 16px;
  text-align: center;
  border: none !important;
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-text_dark);
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon,
.sc_socials.sc_socials_default.modern .socials_wrap .social_item:hover .social_icon {
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-text_link);
}

.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item .social_icon {
  background-color: #2C313D;
  color: var(--theme-color-inverse_link);
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-inverse_link) !important;
  background-color: var(--theme-color-text_link);
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="facebook"] {
  background-color: #3b5998 !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="twitter"] {
  background-color: #1da1f2 !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="dribble"], .sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="dribbble"] {
  background-color: #ea4c89 !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="instagram"] {
  background-color: #C862DC !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="youtube"] {
  background-color: #FF0000 !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="deviantart"] {
  background-color: #00E59B !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_socials.sc_socials_default.modern_2 .socials_wrap .social_item:hover .social_icon[class*="discord"] {
  background-color: #5562EA !important;
  color: var(--theme-color-inverse_link) !important;
}

/* Alter Socials */
.sc_socials.sc_socials_icons_names.alter .socials_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-around;
}
.sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item {
  margin: 0 !important;
  padding: 28px 10px;
  width: 100%;
  line-height: 1;
}
.sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item + .social_item {
  border-left: 1px solid var(--theme-color-bd_color);
}
.sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item .social_name {
  font-size: 15px;
  font-weight: 700;
  line-height: 20px;
  color: var(--theme-color-text_dark);
}
.sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item .social_icon {
  width: 1.5em;
  height: 1.5em;
  line-height: 1.5em;
  font-size: 16px;
  color: var(--theme-color-text_dark);
}
.sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item .social_icon + .social_name {
  display: inline-block;
  vertical-align: middle;
  margin: 0 0 0 5px;
}
.sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item:hover .social_name, .sc_socials.sc_socials_icons_names.alter .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-text_dark);
}

/* Extra Socials */
.sc_socials.sc_socials_icons_names.extra.sc_align_center .socials_wrap {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_socials.sc_socials_icons_names.extra.sc_align_right .socials_wrap {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item {
  padding: 0 1px;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  margin-right: 1.3em;
  color: var(--theme-color-alter_dark);
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item .social_icon {
  text-align: left;
  padding: 0 1px;
  font-size: 16px;
  width: auto;
  height: auto;
  line-height: inherit;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item .social_icon + .social_name {
  margin: 0 0 0 8px;
  font-size: 13px;
  line-height: 17px;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-alter_dark);
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="facebook"] {
  color: #4F5FBF !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="twitter"] {
  color: #48BDE9 !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="dribble"] {
  color: #EA4C89 !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="instagram"] {
  color: #C41BD1 !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="youtube"] {
  color: #FF0000 !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="deviantart"] {
  color: #00E59B !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_icon[class*="discord"] {
  color: #5562EA !important;
}
.sc_socials.sc_socials_icons_names.extra .socials_wrap .social_item:hover .social_name {
  color: var(--theme-color-text_dark);
}

/* Socials Simple */
.sc_socials.sc_socials_default.simple .socials_wrap .social_item {
  margin-right: 18px;
}
.sc_socials.sc_socials_default.simple .socials_wrap .social_item .social_icon {
  padding: 0 1px;
  width: auto;
  height: auto;
  line-height: inherit;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  border: none;
  text-align: unset;
}

/* Recent News + Shortcode Recent News */
body.expand_content .sc_recent_news_style_news-announce .post_size_full,
.sc_layouts_submenu .sc_recent_news_style_news-announce .post_size_full {
  height: 656px;
}

body.expand_content .sc_recent_news_style_news-announce .post_size_big,
.sc_layouts_submenu .sc_recent_news_style_news-announce .post_size_big {
  height: 328px;
}

body.expand_content .sc_recent_news_style_news-announce .post_size_medium,
.sc_layouts_submenu .sc_recent_news_style_news-announce .post_size_medium,
body.expand_content .sc_recent_news_style_news-announce .post_size_small,
.sc_layouts_submenu .sc_recent_news_style_news-announce .post_size_small {
  height: 164px;
}

/* Attention! This widget can be placed in the content area and should use main text colors */
.sc_recent_news_header {
  border-color: var(--theme-color-text_dark);
}

.sc_recent_news_header_category_item_more {
  color: var(--theme-color-text_link);
}

.sc_recent_news_header_more_categories {
  border-color: var(--theme-color-extra_bd_color);
  background-color: var(--theme-color-extra_bg_color);
}

.sc_recent_news_header_more_categories > a {
  color: var(--theme-color-extra_link);
}

.sc_recent_news_header_more_categories > a:hover {
  color: var(--theme-color-extra_hover);
  background-color: var(--theme-color-extra_bg_hover);
}

.sc_recent_news_style_news-magazine .post_accented_border {
  border-color: var(--theme-color-bd_color);
}

.sc_recent_news_style_news-excerpt .post_item {
  border-color: var(--theme-color-bd_color);
}

/* Twitter */
.widget_twitter .widget_content .sc_twitter_item,
.widget_twitter .widget_content li {
  color: var(--theme-color-text);
}

.widget_twitter .widget_content .sc_twitter_item .sc_twitter_item_icon {
  color: var(--theme-color-text_link) !important;
}

.widget_twitter .swiper-pagination-bullet {
  background-color: var(--theme-color-text_light);
}

.widget_twitter .swiper-pagination-bullet-active {
  background-color: var(--theme-color-text_link);
}

.widget_twitter .widget_content .sc_twitter_list li {
  color: var(--theme-color-text);
}

.widget_twitter .widget_content .sc_twitter_list li:before {
  color: var(--theme-color-text_link) !important;
}

[class*="scheme_"].sidebar .widget_twitter .widget_content .sc_twitter_list li {
  color: var(--theme-color-alter_text);
}

[class*="scheme_"].sidebar .widget_twitter .widget_content .sc_twitter_list li:before {
  color: var(--theme-color-alter_link) !important;
}

/* Video player in narrow posts */
.narrow_content .trx_addons_video_list_controller_bottom .trx_addons_video_list_controller_wrap .trx_addons_video_list_controller_item {
  width: 50%;
}
.narrow_content .trx_addons_video_list_controller_bottom .trx_addons_video_list_controller_wrap .trx_addons_video_list_controller_item .trx_addons_video_list_title {
  font-size: 1em;
}

/* Video sticky */
.trx_addons_video_sticky .trx_addons_video_sticky_inner .trx_addons_video_sticky_title {
  display: none;
}

.post_featured .trx_addons_video_sticky_inner .trx_addons_video_sticky_title {
  display: none;
}

.trx_addons_video_sticky_on .trx_addons_video_sticky_inner {
  right: 90px;
  width: 618px !important;
  height: 348px !important;
  z-index: 21;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner iframe {
  width: 618px !important;
  height: 348px !important;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .trx_addons_video_list_title_wrap {
  background-color: var(--theme-color-alter_bg_color);
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .trx_addons_video_list_title_wrap .trx_addons_video_list_title,
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .trx_addons_video_list_title_wrap .trx_addons_video_list_title a,
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .trx_addons_video_list_title_wrap .trx_addons_video_list_title a:hover {
  color: var(--theme-color-alter_dark);
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .post_video.video_frame {
  height: 100%;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .post_video.video_frame .mejs-container {
  width: 100% !important;
  height: 100% !important;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .post_video.video_frame .mejs-container .mejs-overlay.mejs-overlay-play {
  width: 100% !important;
  height: 100% !important;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .post_video.video_frame .mejs-container iframe, .trx_addons_video_sticky_on .trx_addons_video_sticky_inner .post_video.video_frame .mejs-container video, .trx_addons_video_sticky_on .trx_addons_video_sticky_inner .post_video.video_frame .mejs-container embed {
  width: 100% !important;
  height: 100% !important;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .trx_addons_video_list_title_wrap,
.trx_addons_video_sticky_on .trx_addons_video_sticky_inner .trx_addons_video_sticky_title {
  display: block;
  background-color: var(--theme-color-alter_bg_color);
  bottom: 100%;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  margin: 0;
  padding: 21px 4em 21px 30px;
  position: absolute;
  top: -4.1rem;
  height: auto;
  width: 100%;
  display: block;
  text-align: left;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.trx_addons_video_sticky_on .trx_addons_video_sticky_close {
  right: 110px;
  bottom: 358px;
}

.post_featured:not(.post_video_play):not(.with_video_sticky_on) .trx_addons_video_sticky_on .trx_addons_video_sticky_inner {
  height: 0 !important;
}

.post_featured:not(.post_video_play):not(.with_video_sticky_on) .trx_addons_video_sticky_on .trx_addons_video_sticky_close {
  bottom: 12px;
}

/* Reviews stars */
.trx_addons_reviews_stars_default,
.trx_addons_reviews_stars_hover {
  color: var(--theme-color-text_link);
}

[class*="scheme_"].sidebar .trx_addons_reviews_stars_default,
[class*="scheme_"].sidebar .trx_addons_reviews_stars_hover {
  color: var(--theme-color-alter_link);
}

.trx_addons_reviews_bubble {
  background-color: var(--theme-color-bg_color);
}

.trx_addons_reviews_bubble:before {
  background-color: var(--theme-color-bg_color);
  border-right-color: var(--theme-color-bd_color);
  border-bottom-color: var(--theme-color-bd_color);
}

/* Reviews in the single post */
.trx_addons_reviews_block_short .trx_addons_reviews_block_info {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}

.trx_addons_reviews_block_short .trx_addons_reviews_block_title {
  color: var(--theme-color-extra_dark);
  background-color: var(--theme-color-extra_bg_color);
  padding-left: 0.5em;
  padding-right: 0.5em;
}

.trx_addons_reviews_block_short .trx_addons_reviews_block_title:after {
  border-top-color: var(--theme-color-extra_bg_color);
}

.trx_addons_reviews_block_short .trx_addons_reviews_block_mark_value {
  border-color: var(--theme-color-alter_bd_hover);
  background-color: var(--theme-color-alter_bg_hover);
}

.trx_addons_reviews_block_detailed {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_title {
  color: var(--theme-color-extra_dark);
  background-color: var(--theme-color-extra_bg_color);
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_hover);
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_list li:before {
  color: var(--theme-color-alter_dark);
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_criterias {
  color: var(--theme-color-alter_dark);
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_criterias[data-mark-max="10"] [class*="trx_addons_reviews_block_list_mark_line"],
.trx_addons_reviews_block_detailed .trx_addons_reviews_block_criterias[data-mark-max="100"] [class*="trx_addons_reviews_block_list_mark_line"] {
  background-color: var(--theme-color-text_link);
}

.trx_addons_reviews_block_mark .trx_addons_reviews_block_mark_value {
  border-color: var(--theme-color-alter_bd_hover);
  background-color: var(--theme-color-alter_bg_hover);
}

.trx_addons_reviews_block_mark_text {
  font-weight: 500;
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_buttons {
  color: var(--theme-color-text_dark);
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_buttons .trx_addons_reviews_block_subtitle {
  font-weight: 500;
}

.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_list li:before {
  left: -1.5em;
}

.trx_addons_reviews_block .sc_button {
  font-size: 15px;
  line-height: 17px;
  padding: 17px 27px;
}
.trx_addons_reviews_block.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_negatives,
.trx_addons_reviews_block.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_positives {
  padding-left: 0;
  width: calc(50% - 1em);
}
.trx_addons_reviews_block.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_negatives .trx_addons_reviews_block_list li:before,
.trx_addons_reviews_block.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_positives .trx_addons_reviews_block_list li:before {
  font-family: "fontello";
  font-weight: 400;
  font-size: 0.9em;
  line-height: 1.9em;
}
.trx_addons_reviews_block.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_positives .trx_addons_reviews_block_list li:before {
  content: '\E8AD';
}
.trx_addons_reviews_block.trx_addons_reviews_block_detailed .trx_addons_reviews_block_pn .trx_addons_reviews_block_negatives .trx_addons_reviews_block_list li:before {
  content: '\E8AE';
}
.trx_addons_reviews_block .trx_addons_reviews_block_mark {
  overflow: visible;
}
.trx_addons_reviews_block .trx_addons_reviews_block_mark canvas {
  transform: rotate(-90deg) translateY(calc(-50% - -0.5px));
}
.trx_addons_reviews_block .trx_addons_reviews_block_mark .trx_addons_reviews_block_mark_value {
  width: 2.9em;
  height: 2.9em;
  line-height: 2.9em;
  border-width: 4px;
}

/* Shortcodes
--------------------------------------------- */
/* Common styles */
.sc_item_subtitle {
  color: var(--theme-color-text_dark);
}

.color_style_link2 .sc_item_subtitle {
  color: var(--theme-color-text_link2);
}

.color_style_link3 .sc_item_subtitle {
  color: var(--theme-color-text_link3);
}

.sc_item_subtitle.sc_item_title_style_shadow {
  color: var(--theme-color-text_light);
}

.theme_scroll_down:hover {
  color: var(--theme-color-text_link);
}

.sc_item_filters_more_link_wrap .sc_item_filters_more_link {
  overflow: visible;
}

.sc_item_filters_align_left,
.sc_item_filters_align_right,
.sc_item_filters .sc_item_filters_header {
  border-color: var(--theme-color-text_dark);
}

.sc_item_filters_align_left .sc_item_filters_header, .sc_item_filters_align_right .sc_item_filters_header {
  flex-basis: 50%;
}

.sc_item_filters_align_right .sc_item_filters_header {
  flex-basis: 50%;
  text-align: right;
}

.sc_blogger.sc_item_filters_tabs_left .sc_item_filters_tabs li > a {
  padding: 0.15em 0;
  margin-bottom: 0.5em;
}

ul.sc_layouts_submenu .sc_item_filters_tabs_left .sc_item_filters_tabs > li > a.active,
ul.sc_layouts_submenu .sc_item_filters_tabs_left .sc_item_filters_tabs > li > a.active > span {
  color: var(--theme-color-extra_dark) !important;
}
ul.sc_layouts_submenu .post_featured.hover_info .post_info {
  padding: 1em;
}
ul.sc_layouts_submenu .post_featured.hover_info .post_info .post_category {
  top: 1em;
  left: 1em;
}
ul.sc_layouts_submenu .post_featured .post_info .post_title {
  font-size: 1.25em;
}
ul.sc_layouts_submenu .post_featured .post_info .post_descr {
  display: none;
}

.menu_mobile ul.sc_layouts_submenu .sc_item_filters_tabs_left .sc_item_filters,
.menu_mobile ul.sc_layouts_submenu .sc_item_filters_tabs_left .sc_item_posts_container,
.menu_mobile ul.sc_layouts_submenu .sc_item_filters_tabs_left .sc_item_pagination {
  margin-left: 0;
}
.menu_mobile ul.sc_layouts_submenu .sc_item_filters_tabs_right .sc_item_filters,
.menu_mobile ul.sc_layouts_submenu .sc_item_filters_tabs_right .sc_item_posts_container,
.menu_mobile ul.sc_layouts_submenu .sc_item_filters_tabs_right .sc_item_pagination {
  margin-right: 0;
}
.menu_mobile ul.sc_layouts_submenu .sc_item_filters .sc_item_filters_tabs {
  position: static;
  width: 100%;
  padding: 0 !important;
  margin-bottom: 1em !important;
}
.menu_mobile ul.sc_layouts_submenu .sc_item_filters .sc_item_filters_tabs li {
  display: inline-block;
  vertical-align: top;
  margin-right: 1em;
  width: auto;
}
.menu_mobile ul.sc_layouts_submenu .sc_item_filters .sc_item_filters_tabs li > a {
  padding: 0;
}
.menu_mobile ul.sc_layouts_submenu .sc_item_filters .sc_item_filters_tabs li:last-child {
  margin-right: 0;
}
.menu_mobile ul.sc_layouts_submenu .sc_item_posts_container [class*="column-"] + [class*="column-"] {
  padding-top: 1em;
}

.sc_item_featured [class*="post_info_"] {
  color: var(--theme-color-extra_text);
  background-color: var(--theme-color-extra_bg_color_07);
}
.sc_item_featured:hover [class*="post_info_"] {
  background-color: var(--theme-color-extra_bg_color_07);
}
.sc_item_featured [class*="post_info_"] a {
  color: var(--theme-color-extra_dark);
}
.sc_item_featured [class*="post_info_"] a:hover,
.sc_item_featured [class*="post_info_"] a:focus {
  color: var(--theme-color-extra_hover);
}
.sc_item_featured .post_meta a {
  color: var(--theme-color-extra_light);
}
.sc_item_featured .post_meta a:hover,
.sc_item_featured .post_meta a:focus {
  color: var(--theme-color-extra_hover);
}
.sc_item_featured .post_meta_item.post_categories,
.sc_item_featured .post_meta_item.post_categories a {
  color: var(--theme-color-extra_link);
}
.sc_item_featured .post_meta_item.post_categories a:hover,
.sc_item_featured .post_meta_item.post_categories a:focus {
  color: var(--theme-color-extra_hover);
}

.sc_blogger .sc_item_featured .post_info_audio {
  background: transparent !important;
  padding: 0 !important;
  max-width: 100% !important;
  margin: 0 !important;
}
.sc_blogger .format-audio .post_featured.without_thumb .post_audio:not(.with_iframe) {
  padding: 1.8em;
}
.sc_blogger .format-audio .post_featured .post_audio_title {
  margin-bottom: 0.2em;
}

/* Typed title */
.sc_typed_entry {
  color: var(--theme-color-text_dark);
}

/* Action */
.sc_action_item .sc_action_item_subtitle {
  color: var(--theme-color-text_link);
}

.sc_action_item.color_style_link2 .sc_action_item_subtitle {
  color: var(--theme-color-text_link2);
}

.sc_action_item.color_style_link3 .sc_action_item_subtitle {
  color: var(--theme-color-text_link3);
}

.sc_action_item.color_style_dark .sc_action_item_subtitle {
  color: var(--theme-color-text_dark);
}

.sc_action_item_event .sc_action_item_date,
.sc_action_item_event .sc_action_item_info {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text);
}

.sc_action_item_event .sc_action_item_description {
  color: var(--theme-color-text);
}

.sc_action_item_event.with_image .sc_action_item_inner {
  background-color: var(--theme-color-bg_color);
}

/* Blogger */
.sc_blogger .post_featured + .post_header {
  max-width: none;
  padding: 0;
  display: block;
}

.sc_blogger_item_list.sc_blogger_item_image_position_left .sc_blogger_item_title,
.sc_blogger_item_list.sc_blogger_item_image_position_right .sc_blogger_item_title,
.sc_blogger_item_list.sc_blogger_item_image_position_alter .sc_blogger_item_title {
  font-size: 1.15em;
  line-height: 1.5em;
}

.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_title,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_title,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_alter .sc_blogger_item_title {
  margin-top: -0.5em;
}

.post_item_single .post_content_single .sc_item_filters_title,
.editor-block-list__layout .sc_item_filters_title {
  font-size: 1.15em;
  line-height: 1.25em;
  text-transform: uppercase;
}

.post_item_single .post_content_single .sc_blogger_item_excerpt,
.editor-block-list__layout .sc_blogger_item_excerpt {
  line-height: 1.5em;
}

.sc_blogger.slider_container .swiper-pagination-bullet {
  border-color: var(--theme-color-text_light);
}

.sc_blogger_item_on_plate .sc_blogger_item_body {
  color: var(--theme-color-alter_text);
}

.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_body,
.sc_blogger_item_list.sc_blogger_item_on_plate .sc_blogger_item_body,
.sc_blogger_item_wide.sc_blogger_item_on_plate {
  background-color: var(--theme-color-alter_bg_color);
}

.sc_blogger_item_on_plate .sc_blogger_item_content .post_meta,
.sc_blogger_item_on_plate .sc_blogger_item_content .post_meta a {
  color: var(--theme-color-alter_light);
}

.sc_blogger_item_on_plate .sc_blogger_item_content .post_meta a:hover {
  color: var(--theme-color-alter_dark);
}

.sc_blogger_item_on_plate .sc_blogger_item_content .post_meta .post_sponsored,
.sc_blogger_item_on_plate .sc_blogger_item_content .post_meta .post_sponsored a {
  color: var(--theme-color-alter_link);
}

.sc_blogger_item_on_plate .sc_blogger_item_content .post_meta .post_sponsored a:hover {
  color: var(--theme-color-alter_dark);
}

.sc_blogger_item_on_plate .sc_blogger_item_content a {
  color: var(--theme-color-alter_link);
}

.sc_blogger_item_on_plate .sc_blogger_item_content a:hover {
  color: var(--theme-color-alter_hover);
}

.sc_blogger_item_on_plate .sc_blogger_item_content a.sc_button_simple:hover {
  color: var(--theme-color-alter_hover) !important;
}

.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title a {
  color: var(--theme-color-alter_dark);
}

.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title a:hover {
  color: var(--theme-color-alter_link);
}

.sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_excerpt:after {
  background-image: -webkit-gradient(linear, left top, left bottom, from(var(--theme-color-alter_bg_color_00)), to(var(--theme-color-alter_bg_color)));
  background-image: -webkit-linear-gradient(top, var(--theme-color-alter_bg_color_00), var(--theme-color-alter_bg_color));
  background-image: -o-linear-gradient(top, var(--theme-color-alter_bg_color_00), var(--theme-color-alter_bg_color));
  background-image: linear-gradient(180deg, var(--theme-color-alter_bg_color_00), var(--theme-color-alter_bg_color));
}

.sc_blogger_content .sc_blogger_item {
  border-color: var(--theme-color-bd_color);
}

.sc_blogger_item_list.sc_blogger_item_with_numbers:not(.sc_blogger_item_with_image) .sc_blogger_item_title:before,
.sc_blogger_item_list.sc_blogger_item_with_numbers.sc_blogger_item_with_image .sc_blogger_item_featured:after {
  color: var(--theme-color-extra_dark);
  background-color: var(--theme-color-extra_bg_color);
}

.sc_blogger_item_list .post_featured[class*="hover_"] .post_info_back {
  display: none;
}

/* Content */
.sc_content_number {
  color: var(--theme-color-alter_bg_hover);
}

.sc_content_width_1_1, .sc_inner_width_1_1 > .elementor-column-wrap, .sc_inner_width_1_1 > .elementor-widget-wrap {
  width: var(--theme-var-page);
}

.sc_content_width_1_2, .sc_inner_width_1_2 > .elementor-column-wrap, .sc_inner_width_1_2 > .elementor-widget-wrap {
  width: calc( var(--theme-var-page ) / 2 );
}

.sc_content_width_1_3, .sc_inner_width_1_3 > .elementor-column-wrap, .sc_inner_width_1_3 > .elementor-widget-wrap {
  width: calc( var(--theme-var-page ) / 3 );
}

.sc_content_width_2_3, .sc_inner_width_2_3 > .elementor-column-wrap, .sc_inner_width_2_3 > .elementor-widget-wrap {
  width: calc( var(--theme-var-page ) / 3 * 2 );
}

.sc_content_width_1_4, .sc_inner_width_1_4 > .elementor-column-wrap, .sc_inner_width_1_4 > .elementor-widget-wrap {
  width: calc( var(--theme-var-page ) / 4 );
}

.sc_content_width_3_4, .sc_inner_width_3_4 > .elementor-column-wrap, .sc_inner_width_3_4 > .elementor-widget-wrap {
  width: calc( var(--theme-var-page ) / 4 * 3 );
}

/* Events */
.sc_events.slider_container .swiper-pagination-bullet {
  border-color: var(--theme-color-text_light);
}

/* Events Default */
.sc_events_default .sc_events_columns .sc_events_item,
.sc_events_default .sc_events_slider .sc_events_item {
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}
.sc_events_default .sc_events_columns .sc_events_item_info,
.sc_events_default .sc_events_slider .sc_events_item_info {
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  padding-right: 0;
}
.sc_events_default .sc_events_columns .sc_events_item_content_wrap,
.sc_events_default .sc_events_slider .sc_events_item_content_wrap {
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}
.sc_events_default .sc_events_columns .sc_events_item_thumb,
.sc_events_default .sc_events_slider .sc_events_item_thumb {
  flex-basis: 100%;
  margin-right: 0;
  margin-bottom: 1em;
}
.sc_events_default .sc_events_columns .sc_events_item_date_start,
.sc_events_default .sc_events_slider .sc_events_item_date_start {
  display: none;
  margin: 0 0 1em 0;
}
.sc_events_default .sc_events_columns .sc_events_item_price,
.sc_events_default .sc_events_slider .sc_events_item_price {
  width: 100%;
  margin-top: 0.6em;
}
.sc_events_default .sc_events_item {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  margin-bottom: 0;
}
.sc_events_default .sc_events_item + .sc_events_item {
  margin-top: 1.7em;
  padding-top: 1.7em;
  border-top: 1px solid var(--theme-color-bd_color);
}
.sc_events_default .post_featured.hover_link img {
  will-change: transform;
}
.sc_events_default .sc_events_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_events_default .sc_events_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_events_default .sc_events_item_info {
  width: 100%;
  padding: 0;
  padding-right: 8%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_events_default .sc_events_item_content_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}
.sc_events_default .sc_events_item_content {
  width: 100%;
  margin-top: 0.5em;
}
.sc_events_default .sc_events_item_thumb {
  width: 100%;
  margin-right: 1.6em;
  overflow: hidden !important;
  flex-basis: 170px;
  flex-shrink: 0;
}
.sc_events_default .sc_events_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
  margin: 0;
}
.sc_events_default .sc_events_item_title + .sc_events_item_meta {
  margin-top: 0.6em;
}
.sc_events_default .sc_events_item_meta + .sc_events_item_more_link,
.sc_events_default .sc_events_item_meta + .sc_events_item_text {
  margin-top: 0.8em;
}
.sc_events_default .sc_events_item_text + .sc_events_item_more_link {
  margin-top: 0.8em;
}
.sc_events_default .sc_events_item_price {
  margin-top: 0.3em;
  position: relative;
  z-index: 1;
  top: auto;
  right: auto;
  font-size: 1.333em;
  line-height: 1.2em;
  font-weight: 700;
  color: var(--theme-color-text_dark);
}
.sc_events_default .sc_events_item_price.free_price {
  color: var(--theme-color-text_link);
}
.sc_events_default .sc_events_item_price:not(.free_price):before {
  font-family: "fontello";
  content: '\E9BD';
  margin-right: 0.5em;
}
.sc_events_default .sc_events_item_meta {
  font-size: 12px;
  line-height: 24px;
  color: var(--theme-color-text_light);
}
.sc_events_default .sc_events_item_meta_date {
  position: relative;
}
.sc_events_default .sc_events_item_meta_date:before {
  font-size: 16px;
  font-weight: 400;
  margin-right: 10px;
  font-family: "fontello";
  content: '\E9B7';
  color: var(--theme-color-text_link);
}
.sc_events_default .sc_events_item_meta_locality {
  margin-right: 1em;
  font-size: 16px;
  line-height: 19px;
  font-weight: 400;
  color: var(--theme-color-text_dark);
}
.sc_events_default .sc_events_item_date_start {
  width: auto;
  min-width: 80px;
  margin-right: 1.3em;
  margin-top: 0.5em;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  flex-shrink: 0;
}
.sc_events_default .sc_events_item_date_start .sc_events_item_date_day {
  font-size: 1.944em;
  line-height: 1em;
  font-weight: 500;
  color: var(--theme-color-text_dark);
}
.sc_events_default .sc_events_item_date_start .sc_events_item_date_month {
  margin-top: 7px;
  font-size: 13px;
  line-height: 19px;
  color: var(--theme-color-text_light);
}
.sc_events_default .sc_events_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_events_default .sc_events_item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_events_default .sc_events_item:hover .sc_events_item_more_link .link_text,
.sc_events_default .sc_events_item .sc_events_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_events_default .sc_events_item .sc_events_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_events_default .sc_events_item .sc_events_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}

/* Events Classic */
.sc_events_classic .sc_events_slider .sc_events_item,
.sc_events_classic .sc_events_columns .sc_events_item {
  display: inline-block;
  vertical-align: top;
  width: 100%;
  height: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_events_classic .sc_events_item {
  position: relative;
  z-index: 1;
  overflow: hidden;
}
.sc_events_classic .sc_events_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 110%;
  display: inline-block;
  margin-left: -0.2em;
}
.sc_events_classic .sc_events_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
}
.sc_events_classic .sc_events_item_featured {
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  -webkit-backface-visibility: hidden;
  -ms-backface-visibility: hidden;
  backface-visibility: hidden;
}
.sc_events_classic .sc_events_item_featured:before {
  content: '';
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  opacity: .9;
}
.sc_events_classic .sc_events_item:hover .sc_events_item_featured {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_events_classic .sc_events_item_content_inner {
  position: relative;
  z-index: 1;
  padding: 2em 2.2em;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
}
.sc_events_classic .sc_events_item_content_inner_top {
  position: relative;
  z-index: 1;
}
.sc_events_classic .sc_events_item_content_inner_bottom {
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  position: relative;
  z-index: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_events_classic .sc_events_item.with_more .sc_events_item_content_inner_bottom {
  -webkit-transform: translateY(25px);
  -ms-transform: translateY(25px);
  transform: translateY(25px);
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_events_classic .sc_events_item.with_more:hover .sc_events_item_content_inner_bottom {
  -webkit-transform: translateY(-15px);
  -ms-transform: translateY(-15px);
  transform: translateY(-15px);
}
.sc_events_classic .sc_events_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_events_classic .sc_events_item_title {
  font-size: 1.556em;
}
.sc_events_classic .sc_events_item_title,
.sc_events_classic .sc_events_item_title a {
  color: #ffffff;
}
.sc_events_classic .sc_events_item_title a:hover {
  color: #ffffff;
}
.sc_events_classic .sc_events_item_meta_categories {
  display: block;
  line-height: normal;
}
.sc_events_classic .sc_events_item_meta_categories a {
  margin: 0 6px 6px 0;
  display: inline-block;
  padding: 4px 18px;
  font-size: 11px;
  line-height: 16px;
  font-weight: 700;
  letter-spacing: 0.8px;
  text-transform: uppercase;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link2);
}
.sc_events_classic .sc_events_item_meta_categories a:hover {
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-text_dark);
}
.sc_events_classic .sc_events_item:hover .sc_events_item_meta_categories a {
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-text_dark);
}
.sc_events_classic .sc_events_item_meta {
  margin-top: 1em;
  font-size: 12px;
  line-height: 24px;
  color: #A5A6AA;
}
.sc_events_classic .sc_events_item_date {
  letter-spacing: inherit;
  font-style: inherit;
}
.sc_events_classic .sc_events_item_meta_date {
  position: relative;
}
.sc_events_classic .sc_events_item_meta_date:before {
  font-size: 16px;
  font-weight: 400;
  margin-right: 13px;
  font-family: "fontello";
  content: '\E9B7';
  color: var(--theme-color-text_link);
}
.sc_events_classic .sc_events_item_text {
  color: #A5A6AA;
  margin-top: 0.6em;
  max-height: 3.6em;
  overflow: hidden;
}
.sc_events_classic .sc_events_item_more_link {
  margin-top: 1em;
  position: relative;
  z-index: 1;
  display: inline-block;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #ffffff;
  overflow: hidden;
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_events_classic .sc_events_item:hover .sc_events_item_more_link {
  opacity: 1;
}
.sc_events_classic .sc_events_item_more_link .link_text {
  position: relative;
  margin-right: 6px;
  display: inline-block;
  vertical-align: middle;
  white-space: nowrap;
  opacity: 1;
}
.sc_events_classic .sc_events_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_events_classic .sc_events_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}

/* Events Modern */
.sc_events_modern .sc_events_item {
  position: relative;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_events_modern .sc_events_item_thumb {
  position: relative;
  z-index: 1;
  width: 170px;
  height: 170px;
  margin-top: 1px;
  margin-bottom: 1px;
  margin-right: 1.6em;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  flex-shrink: 0;
}
.sc_events_modern .sc_events_item_thumb:before {
  display: none;
}
.sc_events_modern .sc_events_item_thumb .bg_in {
  margin-top: -1px;
  margin-bottom: -1px;
}
.sc_events_modern .sc_events_item:hover .sc_events_item_thumb > .bg_in {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_events_modern .sc_events_item_info {
  margin-top: 1.3em;
}
.sc_events_modern .sc_events_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
  margin: 0;
}
.sc_events_modern .sc_events_item_title,
.sc_events_modern .sc_events_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_events_modern .sc_events_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_events_modern .sc_events_item_title + .sc_events_item_meta {
  margin-top: 0.6em;
}
.sc_events_modern .sc_events_item_meta + .sc_events_item_more_link,
.sc_events_modern .sc_events_item_meta + .sc_events_item_text {
  margin-top: 1em;
}
.sc_events_modern .sc_events_item_text + .sc_events_item_more_link {
  margin-top: 1em;
}
.sc_events_modern .sc_events_item_price {
  display: inline-block;
  margin-bottom: 0.66em;
  font-size: 1.333em;
  line-height: 1.2em;
  font-weight: 700;
  color: var(--theme-color-text_link);
}
.sc_events_modern .sc_events_item_meta {
  margin-top: 1em;
  font-size: 13px;
  line-height: 24px;
  color: var(--theme-color-text_light);
}
.sc_events_modern .sc_events_item_meta_date {
  position: relative;
}
.sc_events_modern .sc_events_item_meta_date:before {
  font-size: 16px;
  font-weight: 400;
  margin-right: 10px;
  font-family: "fontello";
  content: '\E9B7';
  color: var(--theme-color-text_link);
}
.sc_events_modern .sc_events_item_meta_date_separator {
  margin: 0 0.5em;
}
.sc_events_modern .sc_events_item_meta_locality {
  margin-right: 1em;
  font-size: 16px;
  line-height: 19px;
  font-weight: 400;
  color: var(--theme-color-text_dark);
}
.sc_events_modern .sc_events_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_events_modern .sc_events_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_events_modern .sc_events_item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_events_modern .sc_events_item:hover .sc_events_item_more_link .link_text,
.sc_events_modern .sc_events_item .sc_events_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_events_modern .sc_events_item .sc_events_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_events_modern .sc_events_item .sc_events_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}

/* Events Alter */
.sc_events_alter .sc_events_item {
  position: relative;
}
.sc_events_alter .sc_events_item_info {
  position: relative;
  padding: 2em 2.2em 2.4em;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 3px 20px rgba(0, 0, 0, 0.03);
  -ms-box-shadow: 0 3px 20px rgba(0, 0, 0, 0.03);
  box-shadow: 0 3px 20px rgba(0, 0, 0, 0.03);
}
.sc_events_alter .sc_events_item_thumb {
  margin-bottom: 0;
}
.sc_events_alter .sc_events_item:hover .sc_events_item_thumb img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_events_alter .sc_events_item_meta + .sc_events_item_title,
.sc_events_alter .sc_events_item_meta + .sc_events_item_text,
.sc_events_alter .sc_events_item_meta + .sc_events_item_more_link {
  margin-top: 0.55em;
}
.sc_events_alter .sc_events_item_title + .sc_events_item_text,
.sc_events_alter .sc_events_item_title + .sc_events_item_more_link {
  margin-top: 1.2em;
}
.sc_events_alter .sc_events_item_text + .sc_events_item_more_link {
  margin-top: 1.2em;
}
.sc_events_alter .sc_events_item_title {
  font-size: 1.556em;
  line-height: 1.22em;
  margin: 0;
}
.sc_events_alter .sc_events_item_title,
.sc_events_alter .sc_events_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_events_alter .sc_events_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_events_alter .sc_events_item_price {
  padding: 12px;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  min-width: 65px;
  min-height: 65px;
  position: absolute;
  z-index: 5;
  top: -50px;
  right: 25px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  -webkit-box-sizing: content-box;
  -ms-box-sizing: content-box;
  box-sizing: content-box;
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-alter_dark);
}
.sc_events_alter .sc_events_item_price .sc_events_item_price_text {
  position: relative;
  top: 0;
  font-size: 24px;
  line-height: 1em;
  font-weight: 700;
}
.sc_events_alter .sc_events_item_meta {
  padding-right: 85px;
  font-size: 12px;
  line-height: 24px;
  color: var(--theme-color-text_light);
}
.sc_events_alter .sc_events_item_meta_date {
  position: relative;
}
.sc_events_alter .sc_events_item_meta_date:before {
  font-size: 16px;
  font-weight: 400;
  margin-right: 10px;
  font-family: "fontello";
  content: '\E9B7';
  color: var(--theme-color-text_link);
}
.sc_events_alter .sc_events_item_meta_date_separator {
  margin: 0 0.5em;
}
.sc_events_alter .sc_events_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_events_alter .sc_events_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_events_alter .sc_events_item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_events_alter .sc_events_item:hover .sc_events_item_more_link .link_text,
.sc_events_alter .sc_events_item .sc_events_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_events_alter .sc_events_item .sc_events_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_events_alter .sc_events_item .sc_events_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}

/* Form */
.trx_addons_field_error {
  border-color: #ff5b4a !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

.sc_form .sc_form_info_item .sc_form_info_icon:before {
  font-family: "fontello";
}

.sc_form .sc_form_info_item_address .sc_form_info_icon:before {
  content: '\e8fd';
}

.sc_form .sc_form_info_item_email .sc_form_info_icon:before {
  content: '\e8fa';
}

.sc_form .sc_form_info_item_phone .sc_form_info_icon:before {
  content: '\e8f5';
}

[class*="scheme_"].sc_form {
  background-color: var(--theme-color-bg_color);
}

span.sc_form_field_title {
  color: var(--theme-color-text_dark);
}

.sc_form .sc_form_info_icon {
  color: var(--theme-color-text_link);
}

.sc_form .sc_form_info_data > a,
.sc_form .sc_form_info_data > span {
  color: var(--theme-color-text_dark);
}

.sc_form .sc_form_info_data > a:hover {
  color: var(--theme-color-text_link);
}

/* input hovers */
[class*="sc_input_hover_"] .sc_form_field_hover {
  color: var(--theme-color-text_dark);
}

.sc_input_hover_accent input[type="text"]:focus,
.sc_input_hover_accent input[type="number"]:focus,
.sc_input_hover_accent input[type="email"]:focus,
.sc_input_hover_accent input[type="password"]:focus,
.sc_input_hover_accent input[type="search"]:focus,
.sc_input_hover_accent select:focus,
.sc_input_hover_accent .select2-container.select2-container--focus span.select2-selection,
.sc_input_hover_accent .select2-container.select2-container--open span.select2-selection,
.sc_input_hover_accent textarea:focus {
  border-color: var(--theme-color-text_link) !important;
}

.sc_input_hover_accent .sc_form_field_hover:before {
  color: var(--theme-color-text_link_02);
}

.sc_input_hover_path .sc_form_field_graphic {
  stroke: var(--theme-color-input_bd_color);
}

.sc_input_hover_jump .sc_form_field_hover {
  color: var(--theme-color-input_light);
}

.sc_input_hover_jump .sc_form_field_content:before {
  color: var(--theme-color-text_link);
}

.sc_input_hover_jump input[type="text"],
.sc_input_hover_jump input[type="number"],
.sc_input_hover_jump input[type="email"],
.sc_input_hover_jump input[type="password"],
.sc_input_hover_jump input[type="search"],
.sc_input_hover_jump textarea {
  border-color: var(--theme-color-input_bd_color);
}

.sc_input_hover_jump input[type="text"]:focus,
.sc_input_hover_jump input[type="number"]:focus,
.sc_input_hover_jump input[type="email"]:focus,
.sc_input_hover_jump input[type="password"]:focus,
.sc_input_hover_jump input[type="search"]:focus,
.sc_input_hover_jump textarea:focus {
  border-color: var(--theme-color-text_link) !important;
}

.sc_input_hover_underline .sc_form_field_hover:before {
  background-color: var(--theme-color-input_bd_color);
}

.sc_input_hover_underline input:focus + .sc_form_field_hover:before,
.sc_input_hover_underline textarea:focus + .sc_form_field_hover:before,
.sc_input_hover_underline input.filled + .sc_form_field_hover:before,
.sc_input_hover_underline textarea.filled + .sc_form_field_hover:before {
  background-color: var(--theme-color-text_link);
}

.sc_input_hover_underline .sc_form_field_content {
  color: var(--theme-color-input_dark);
}

.sc_input_hover_underline input:focus,
.sc_input_hover_underline textarea:focus,
.sc_input_hover_underline input.filled,
.sc_input_hover_underline textarea.filled,
.sc_input_hover_underline input:focus + .sc_form_field_hover > .sc_form_field_content,
.sc_input_hover_underline textarea:focus + .sc_form_field_hover > .sc_form_field_content,
.sc_input_hover_underline input.filled + .sc_form_field_hover > .sc_form_field_content,
.sc_input_hover_underline textarea.filled + .sc_form_field_hover > .sc_form_field_content {
  color: var(--theme-color-text_link) !important;
}

.sc_input_hover_iconed .sc_form_field_hover {
  overflow: hidden;
  padding: 0.88em 0 !important;
  font-size: 16px;
  font-weight: 400;
  line-height: 18px;
}

[class*="sc_input_hover_"] input[type="text"], [class*="sc_input_hover_"] input[type="number"], [class*="sc_input_hover_"] input[type="email"], [class*="sc_input_hover_"] input[type="password"], [class*="sc_input_hover_"] input[type="search"], [class*="sc_input_hover_"] select, [class*="sc_input_hover_"] textarea {
  padding: 1em !important;
  font-size: 16px;
  font-weight: 400;
}

[class*="sc_input_hover_"].sc_input_hover_iconed input[type="text"], [class*="sc_input_hover_"].sc_input_hover_iconed input[type="number"], [class*="sc_input_hover_"].sc_input_hover_iconed input[type="email"], [class*="sc_input_hover_"].sc_input_hover_iconed input[type="password"], [class*="sc_input_hover_"].sc_input_hover_iconed input[type="search"], [class*="sc_input_hover_"].sc_input_hover_iconed textarea {
  padding-left: 2.5em !important;
}

.sc_input_hover_iconed .sc_form_field_hover {
  color: var(--theme-color-input_light);
}

.sc_input_hover_iconed input:focus + .sc_form_field_hover,
.sc_input_hover_iconed textarea:focus + .sc_form_field_hover,
.sc_input_hover_iconed input.filled + .sc_form_field_hover,
.sc_input_hover_iconed textarea.filled + .sc_form_field_hover {
  color: var(--theme-color-input_dark);
}

/* Cart */
.sc_layouts_cart {
  display: inline-block;
}
.sc_layouts_cart .sc_layouts_cart_icon:before {
  position: relative;
  font-family: "fontello";
  content: '\e9f4';
}

/* Iconed Text */
.sc_layouts_item_details_line1 {
  font-size: 16px;
  line-height: 21px;
  font-weight: 400;
  color: var(--theme-color-text);
}

.sc_layouts_item_details_line2 {
  font-size: 19px;
  line-height: 26px;
  font-weight: 500;
  color: var(--theme-color-text_dark);
}

.sc_layouts_item_icon + .sc_layouts_item_details {
  margin-left: 0.7em;
}

/* Login & Logout */
.sc_layouts_login .sc_layouts_login_icon:before {
  font-family: "fontello";
  content: '\EA12';
}
.sc_layouts_row_type_compact .sc_layouts_login .sc_layouts_item_details_line1 + .sc_layouts_item_details_line2 {
  margin-left: 0.3em;
}

/* popup login form */
.trx_addons_popup .trx_addons_tabs_titles {
  margin-bottom: 0;
}
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title > a {
  text-transform: none;
}

.trx_addons_popup .trx_addons_tabs_titles + .trx_addons_tabs_content,
.trx_addons_popup .trx_addons_tabs_titles + .trx_addons_tabs_content + .trx_addons_tabs_content {
  padding: 1.7em 1.7em 2.2em;
}

.trx_addons_popup_form_field_remember, .trx_addons_popup_form_field_agree, .trx_addons_popup_form_field_pwd_description {
  font-size: 14px;
}

.trx_addons_popup_form_field_submit .submit_button {
  padding: 0.5em 2em;
}

.trx_addons_popup_form_field_submit {
  padding-top: 1.1em;
}

.trx_addons_popup_form_field_agree input[type="checkbox"] + label:before,
.trx_addons_popup_form_field_remember input[type="checkbox"] + label:before {
  top: 3px;
}

.trx_addons_popup_form_field_submit .submit_button {
  padding: 14px 48px;
  font-size: 16px;
  line-height: 21px;
}

/* Googlemap */
.sc_googlemap_content,
[class*="scheme_"].sc_googlemap_content {
  color: var(--theme-color-text);
  background-color: var(--theme-color-bg_color);
}

.sc_googlemap_content b,
.sc_googlemap_content strong,
[class*="scheme_"].sc_googlemap_content b,
[class*="scheme_"].sc_googlemap_content strong {
  color: var(--theme-color-text_dark);
}

.sc_googlemap_content_detailed:before {
  color: var(--theme-color-text_link);
}

/* OpenStreet map */
.sc_osmap_content,
[class*="scheme_"].sc_osmap_content {
  color: var(--theme-color-text);
  background-color: var(--theme-color-bg_color);
}

.sc_osmap_content b,
.sc_osmap_content strong,
[class*="scheme_"].sc_osmap_content b,
[class*="scheme_"].sc_osmap_content strong {
  color: var(--theme-color-text_dark);
}

.sc_osmap_content_detailed:before {
  color: var(--theme-color-text_link);
}

.sc_osmap input[type="text"] {
  padding: 0.3em 0.5em;
}

/* Portfolio */
.sc_portfolio_default .sc_portfolio_item {
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}

.portfolio_page_details_share {
  border-color: var(--theme-color-bd_color);
}

.portfolio_page_details_share .socials_wrap .social_item .social_icon {
  color: var(--theme-color-text_dark);
}

.portfolio_page_details_share .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-text_hover);
}

[class*="scheme_"].sc_portfolio_preview {
  color: var(--theme-color-text);
}

[class*="scheme_"].sc_portfolio_preview:before {
  background-color: var(--theme-color-bg_color);
}

/* Promo */
.sc_promo_icon {
  color: var(--theme-color-text_link);
}

.sc_promo .sc_promo_title,
.sc_promo .sc_promo_descr {
  color: var(--theme-color-text_dark);
}

.sc_promo .sc_promo_content {
  color: var(--theme-color-text);
}

.sc_promo_modern .sc_promo_link2 {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link) !important;
}

.sc_promo_modern .sc_promo_link2:hover {
  color: var(--theme-color-bg_color);
  background-color: var(--theme-color-text_dark);
}

[class*="scheme_"].sc_promo .sc_promo_text.trx_addons_stretch_height,
[class*="scheme_"].sc_promo .sc_promo_text_inner {
  background-color: var(--theme-color-alter_bg_color);
}

[class*="scheme_"].sc_promo .sc_promo_title {
  color: var(--theme-color-alter_link);
}

[class*="scheme_"].sc_promo .sc_promo_subtitle {
  color: var(--theme-color-alter_hover);
}

[class*="scheme_"].sc_promo .sc_promo_descr {
  color: var(--theme-color-alter_dark);
}

[class*="scheme_"].sc_promo .sc_promo_content {
  color: var(--theme-color-alter_text);
}

/* Reviews */
.sidebar_hide.narrow_content .trx_addons_reviews_block.trx_addons_reviews_block_short {
  margin-top: 0;
}

/* Services */
.services_single .services_page_content > h1:first-child,
.services_single .services_page_content > h2:first-child,
.services_single .services_page_content > h3:first-child,
.services_single .services_page_content > h4:first-child,
.services_single .services_page_content > h5:first-child,
.services_single .services_page_content > h6:first-child {
  margin-top: 0 !important;
}

.sc_services_motley > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_fashion > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_creative > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_minimal > .sc_services_content > .sc_services_item + .sc_services_item {
  margin-top: 2em;
}

.sc_services_strange > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_unusual > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_accent > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_shine > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_classic > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_strong > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_extra > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_cool > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_breezy > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_alter > .sc_services_content > .sc_services_item + .sc_services_item,
.sc_services_hover > .sc_services_content > .sc_services_item + .sc_services_item {
  margin-top: 2em;
}

.sc_services_backward > .sc_services_content > .sc_services_item + .sc_services_item {
  margin-top: 3.5em;
}

.services_page_tabs {
  margin-top: 5em;
}
.services_page_tabs.trx_addons_tabs .trx_addons_tabs_titles {
  border-bottom-color: var(--theme-color-bd_color);
}
.services_page_tabs.trx_addons_tabs .trx_addons_tabs_titles li > a {
  font-weight: 500;
  text-transform: none;
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-bd_color);
  background-color: var(--theme-color-bg_color);
}
.services_page_tabs.trx_addons_tabs .trx_addons_tabs_titles li:not(.ui-state-active) > a:hover {
  border-color: var(--theme-color-bd_color);
  background-color: var(--theme-color-bg_color);
}
.services_page_tabs.trx_addons_tabs .trx_addons_tabs_titles li.ui-state-active > a {
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-bg_color);
  border-color: var(--theme-color-bd_color);
  border-bottom-color: var(--theme-color-bg_color);
}
.services_page_tabs.trx_addons_tabs .trx_addons_tabs_titles li + li {
  margin-left: -1px;
}
.services_page_tabs .show_comments_single {
  display: none;
}
.services_page_tabs .comments_wrap {
  display: block;
}
.services_page_tabs .comments_list_wrap,
.services_page_tabs .comments_form_wrap:first-child {
  margin-top: 0;
  padding-top: 0;
  border-top-width: 0;
}
.services_page_tabs .comments_list_wrap + .comments_form_wrap {
  margin-top: 3em;
  padding-top: 3em;
  border-top-width: 1px;
}

.services_page_related + .services_page_section_contacts,
.services_single + .services_page_section_contacts {
  margin-top: 5em;
}

.sc_services .sc_services_item .post_featured .post_info_back {
  display: none;
}

.sc_services .sc_services_item_number {
  color: var(--theme-color-text_dark);
}

.sc_services .sc_services_item_subtitle {
  font-size: 15px;
  line-height: 1.5em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
}

.sc_services .post_featured > .sc_services_item_price,
.sc_services .post_featured > p > .sc_services_item_price {
  bottom: 15px;
  right: 15px;
  font-size: 1.5em;
  font-weight: 500;
  color: #fff;
  text-shadow: 0 0 8px #000;
  pointer-events: none;
}

.sc_services_item_button {
  display: inline-block;
}

/* Services Related */
.services_page_related.related_wrap .sc_services_item_number {
  display: none;
}
.services_page_related.related_wrap .sc_services_item.sc_services_item_featured_top {
  background-color: transparent;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.services_page_related.related_wrap .post_featured {
  margin-bottom: 1em;
}
.services_page_related.related_wrap .sc_services_item_info {
  padding: 0;
  text-align: left;
}
.services_page_related.related_wrap .sc_services_item_content {
  display: none;
}
.services_page_related.related_wrap .sc_services_item_header {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column-reverse;
  -ms-flex-direction: column-reverse;
  flex-direction: column-reverse;
}
.services_page_related.related_wrap .sc_services_item_title {
  font-size: 24px;
  line-height: 1.2em;
  font-weight: 700;
}
.services_page_related.related_wrap .sc_services_item_subtitle {
  margin-bottom: 0.85em;
  font-size: 13px;
  line-height: 1.5em;
  font-weight: 500;
  letter-spacing: 1.1px;
  text-transform: uppercase;
}
.services_page_related.related_wrap .sc_services_item_subtitle,
.services_page_related.related_wrap .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark);
}
.services_page_related.related_wrap .sc_services_item:hover .sc_services_item_subtitle,
.services_page_related.related_wrap .sc_services_item:hover .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark);
}
.services_page_related.related_wrap .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_link);
}
.services_page_related.related_wrap .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0;
}

/* Style 'Default' */
.sc_services_default .sc_services_item {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_services_default .sc_services_item.sc_services_item_featured_top {
  -webkit-box-shadow: 0 3px 60px rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 3px 60px rgba(0, 0, 0, 0.04);
  box-shadow: 0 3px 60px rgba(0, 0, 0, 0.04);
}
.sc_services_default .sc_services_slider .sc_services_item.sc_services_item_featured_top {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_services_default .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_default .sc_services_item_info {
  padding: 2.9em 2em;
  text-align: center;
}
.sc_services_default .sc_services_item_title {
  font-size: 1.867em;
  line-height: 1.214em;
}
.sc_services_default .sc_services_item_content {
  font-size: 15px;
  line-height: 1.868em;
  margin-top: 0.8em;
}
.sc_services_default .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_default .sc_services_item_number {
  display: inline-block;
  font-size: 6em;
  line-height: 1em;
  font-weight: 400;
  margin-top: 0.3em;
  color: var(--theme-color-alter_dark);
}
.sc_services_default .sc_services_item_featured_left .sc_services_item_number,
.sc_services_default .sc_services_item_featured_right .sc_services_item_number {
  font-size: 3em;
  line-height: 1em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: -5px;
  left: 0;
}
.sc_services_default .sc_services_item_featured_left .sc_services_item_icon,
.sc_services_default .sc_services_item_featured_right .sc_services_item_icon {
  font-size: 3.4em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
}
.sc_services_default .sc_services_item_featured_right .sc_services_item_thumb,
.sc_services_default .sc_services_item_featured_right .sc_services_item_icon,
.sc_services_default .sc_services_item_featured_right .sc_services_item_pictogram,
.sc_services_default .sc_services_item_featured_right .sc_services_item_number {
  left: auto;
  right: 0;
}
.sc_services_default .sc_services_item_featured_right .sc_services_item_info {
  margin-right: 5em;
}
.sc_services_default .sc_services_item_icon,
.sc_services_default .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4.4em;
  width: auto;
  height: auto;
  line-height: 1em;
  margin-top: 0.8em;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.sc_services_default .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.214em;
  margin: 0;
}
.sc_services_default .sc_services_item_subtitle,
.sc_services_default .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_default .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_default .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_default .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_default .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_default .sc_services_item .sc_services_item_title,
.sc_services_default .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_services_default .sc_services_item:hover .sc_services_item_title,
.sc_services_default .sc_services_item:hover .sc_services_item_title a,
.sc_services_default .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_default .sc_services_item .sc_services_item_button {
  margin: 1.1em 0 0;
}
.sc_services_default .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-alter_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_default .sc_services_item:hover .sc_services_item_more_link,
.sc_services_default .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_default .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_default .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_default .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_default .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2.3em;
  height: 2.3em;
  line-height: 2.2em;
  text-align: center;
  border: 1px solid var(--theme-color-alter_bd_color);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_services_default .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_default .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_default .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_default.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-alter_link2);
}
.sc_services_default.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_default.color_style_link2 .sc_services_item_subtitle, .sc_services_default.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_default.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_default.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_default.color_style_link2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_default.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-alter_link3);
}
.sc_services_default.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_default.color_style_link3 .sc_services_item_subtitle, .sc_services_default.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_default.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_default.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_default.color_style_link3 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_default.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_default.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_default.color_style_dark .sc_services_item_subtitle, .sc_services_default.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_default.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_default.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_default.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_default .sc_services_item_featured_left,
.sc_services_default .sc_services_item_featured_right {
  color: var(--theme-color-text);
  background-color: transparent;
}
.sc_services_default .sc_services_item_featured_left .sc_services_item_icon,
.sc_services_default .sc_services_item_featured_right .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_default .sc_services_item_featured_left:hover .sc_services_item_icon,
.sc_services_default .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_default .sc_services_item_featured_left .sc_services_item_subtitle a,
.sc_services_default .sc_services_item_featured_right .sc_services_item_subtitle a {
  color: var(--theme-color-text_link);
}
.sc_services_default .sc_services_item_featured_left .sc_services_item_subtitle a:hover,
.sc_services_default .sc_services_item_featured_right .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_hover);
}
.sc_services_default.color_style_link2 .sc_services_item_featured_left .sc_services_item_icon, .sc_services_default.color_style_link2 .sc_services_item_featured_right .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_default.color_style_link2 .sc_services_item_featured_left:hover .sc_services_item_icon, .sc_services_default.color_style_link2 .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_default.color_style_link2 .sc_services_item_featured_left .sc_services_item_subtitle a, .sc_services_default.color_style_link2 .sc_services_item_featured_right .sc_services_item_subtitle a {
  color: var(--theme-color-text_link2);
}
.sc_services_default.color_style_link2 .sc_services_item_featured_left .sc_services_item_subtitle a:hover, .sc_services_default.color_style_link2 .sc_services_item_featured_right .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_hover2);
}
.sc_services_default.color_style_link3 .sc_services_item_featured_left .sc_services_item_icon, .sc_services_default.color_style_link3 .sc_services_item_featured_right .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_default.color_style_link3 .sc_services_item_featured_left:hover .sc_services_item_icon, .sc_services_default.color_style_link3 .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_default.color_style_link3 .sc_services_item_featured_left .sc_services_item_subtitle a, .sc_services_default.color_style_link3 .sc_services_item_featured_right .sc_services_item_subtitle a {
  color: var(--theme-color-text_link3);
}
.sc_services_default.color_style_link3 .sc_services_item_featured_left .sc_services_item_subtitle a:hover, .sc_services_default.color_style_link3 .sc_services_item_featured_right .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_hover3);
}
.sc_services_default.color_style_dark .sc_services_item_featured_left .sc_services_item_icon, .sc_services_default.color_style_dark .sc_services_item_featured_right .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_default.color_style_dark .sc_services_item_featured_left:hover .sc_services_item_icon, .sc_services_default.color_style_dark .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_default.color_style_dark .sc_services_item_featured_left .sc_services_item_subtitle a, .sc_services_default.color_style_dark .sc_services_item_featured_right .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark);
}
.sc_services_default.color_style_dark .sc_services_item_featured_left .sc_services_item_subtitle a:hover, .sc_services_default.color_style_dark .sc_services_item_featured_right .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_link);
}

/* Style 'Alter' */
.sc_services_alter .sc_services_item {
  padding: 2em 1.5em;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_services_alter .sc_services_item.with_image {
  padding: 1.5em;
}
.sc_services_alter .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_alter .sc_services_item_content {
  font-size: 15px;
  line-height: 1.65em;
  margin-top: 0.8em;
}
.sc_services_alter .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_alter .sc_services_item_number {
  display: inline-block;
  font-size: 3.5em;
  line-height: 1em;
  font-weight: 400;
  margin-top: 0.3em;
  color: var(--theme-color-alter_dark);
}
.sc_services_alter .sc_services_item_icon,
.sc_services_alter .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  margin-top: 0.5em;
  width: auto;
  height: auto;
  line-height: 1em;
}
.sc_services_alter .sc_services_item_number + .sc_services_item_info,
.sc_services_alter .sc_services_item_icon + .sc_services_item_info,
.sc_services_alter .sc_services_item_pictogram + .sc_services_item_info {
  margin-top: 1.5em;
}
.sc_services_alter .sc_services_item_title {
  font-size: 19px;
  line-height: 1.514em;
  margin: 0;
  max-width: 70%;
}
.sc_services_alter .sc_services_item_subtitle,
.sc_services_alter .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_alter .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_alter .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_alter .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_alter .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_alter .sc_services_item .sc_services_item_title,
.sc_services_alter .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter .sc_services_item:hover .sc_services_item_title,
.sc_services_alter .sc_services_item:hover .sc_services_item_title a,
.sc_services_alter .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter .sc_services_item .sc_services_item_button {
  margin: 1.1em 0 0;
}
.sc_services_alter .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-alter_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_alter .sc_services_item:hover .sc_services_item_more_link,
.sc_services_alter .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_alter .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_alter .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_alter .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2.3em;
  height: 2.3em;
  line-height: 2.3em;
  text-align: center;
  border: 1px solid var(--theme-color-alter_bd_color);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_services_alter .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_alter .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_alter .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-alter_link2);
}
.sc_services_alter.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter.color_style_link2 .sc_services_item_subtitle, .sc_services_alter.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_alter.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_alter.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_alter.color_style_link2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_alter.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-alter_link3);
}
.sc_services_alter.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter.color_style_link3 .sc_services_item_subtitle, .sc_services_alter.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_alter.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_alter.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_alter.color_style_link3 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_alter.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_alter.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_alter.color_style_dark.sc_services_item_subtitle, .sc_services_alter.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_alter.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_alter.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_alter.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}

/* Style 'List' */
.sc_services_list .sc_services_item {
  color: var(--theme-color-text);
  background-color: transparent;
}
.sc_services_list .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link);
  border-color: var(--theme-color-text_link);
}
.sc_services_list .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_hover);
}
.sc_services_list .sc_services_item_featured_left:hover .sc_services_item_icon,
.sc_services_list .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_dark);
  background-color: var(--theme-color-text_link);
  border-color: var(--theme-color-text_link);
}
.sc_services_list.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
  border-color: var(--theme-color-text_link2);
}
.sc_services_list.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_hover2);
}
.sc_services_list.color_style_link2 .sc_services_item_featured_left:hover .sc_services_item_icon, .sc_services_list.color_style_link2 .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_dark);
  background-color: var(--theme-color-text_link2);
  border-color: var(--theme-color-text_link2);
}
.sc_services_list.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
  border-color: var(--theme-color-text_link3);
}
.sc_services_list.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_hover3);
}
.sc_services_list.color_style_link3 .sc_services_item_featured_left:hover .sc_services_item_icon, .sc_services_list.color_style_link3 .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_dark);
  background-color: var(--theme-color-text_link3);
  border-color: var(--theme-color-text_link3);
}
.sc_services_list.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
}
.sc_services_list.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_list.color_style_dark .sc_services_item_featured_left:hover .sc_services_item_icon, .sc_services_list.color_style_dark .sc_services_item_featured_right:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_dark);
  background-color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
}

/* Style 'Light' */
.sc_services_light .sc_services_item_icon {
  color: var(--theme-color-text_link);
}

.sc_services_light .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_hover);
}

.sc_services_light.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}

.sc_services_light.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_hover2);
}

.sc_services_light.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}

.sc_services_light.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_hover3);
}

.sc_services_light.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}

.sc_services_light.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_link);
}

.sc_services_callouts .sc_services_item {
  background-color: var(--theme-color-alter_bg_color);
}

.sc_services_callouts .sc_services_item_marker {
  border-color: var(--theme-color-bg_color);
  background-color: var(--theme-color-alter_link);
  color: var(--theme-color-inverse_link);
}

.sc_services_callouts .sc_services_item .sc_services_item_marker_back {
  border-color: var(--theme-color-bg_color);
  background-color: var(--theme-color-alter_hover);
  color: var(--theme-color-inverse_hover);
}

.sc_services_callouts.color_style_link2 .sc_services_item_marker {
  background-color: var(--theme-color-alter_link2);
}

.sc_services_callouts.color_style_link2 .sc_services_item .sc_services_item_marker_back {
  background-color: var(--theme-color-alter_hover2);
}

.sc_services_callouts.color_style_link3 .sc_services_item_marker {
  background-color: var(--theme-color-alter_link3);
}

.sc_services_callouts.color_style_link3 .sc_services_item .sc_services_item_marker_back {
  background-color: var(--theme-color-alter_hover3);
}

.sc_services_callouts.color_style_dark .sc_services_item_marker {
  background-color: var(--theme-color-alter_dark);
}

.sc_services_callouts.color_style_dark .sc_services_item .sc_services_item_marker_back {
  background-color: var(--theme-color-alter_link);
}

.sc_services_callouts .sc_services_item_marker_bg {
  border-color: var(--theme-color-bg_color);
  background-color: var(--theme-color-bg_color);
}

.sc_services_timeline .sc_services_item_timeline {
  border-color: var(--theme-color-bd_color);
}

.sc_services_timeline .sc_services_item_marker {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}

.sc_services_timeline .sc_services_item:hover .sc_services_item_marker {
  border-color: var(--theme-color-text_hover);
  background-color: var(--theme-color-text_hover);
  color: var(--theme-color-inverse_hover);
}

.sc_services_timeline.color_style_link2 .sc_services_item_marker {
  border-color: var(--theme-color-text_link2);
  background-color: var(--theme-color-text_link2);
}

.sc_services_timeline.color_style_link2 .sc_services_item:hover .sc_services_item_marker {
  border-color: var(--theme-color-text_hover2);
  background-color: var(--theme-color-text_hover2);
}

.sc_services_timeline.color_style_link3 .sc_services_item_marker {
  border-color: var(--theme-color-text_link3);
  background-color: var(--theme-color-text_link3);
}

.sc_services_timeline.color_style_link3 .sc_services_item:hover .sc_services_item_marker {
  border-color: var(--theme-color-text_hover3);
  background-color: var(--theme-color-text_hover3);
}

.sc_services_timeline.color_style_dark .sc_services_item_marker {
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-text_dark);
}

.sc_services_timeline.color_style_dark .sc_services_item:hover .sc_services_item_marker {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

.sc_services_timeline .sc_services_content .sc_services_item .sc_services_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_services_timeline .sc_services_content .sc_services_item .sc_services_item_content {
  font-size: 15px;
  line-height: 1.6em;
  margin-top: 15px;
}
.sc_services_timeline .sc_services_item {
  position: relative;
  z-index: 1;
  width: calc(25% - 15px);
  display: inline-block;
  vertical-align: top;
  margin: 0;
  padding: 0 !important;
}
.sc_services_timeline .sc_services_item + .sc_services_item {
  margin-left: 30px;
}
.sc_services_timeline .sc_services_item_info {
  text-align: center;
  padding: 55px 30px 50px !important;
  -webkit-box-shadow: 0 3px 50px rgba(0, 0, 0, 0.04) !important;
  -ms-box-shadow: 0 3px 50px rgba(0, 0, 0, 0.04) !important;
  box-shadow: 0 3px 50px rgba(0, 0, 0, 0.04) !important;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_services_timeline .sc_services_item_info .link_wrap {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  z-index: 2;
}
.sc_services_timeline .extra_row {
  position: relative;
  text-align: left;
  padding: 61px 0 50px 0;
}
.sc_services_timeline .extra_row .sc_services_item_timeline_point {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
  top: -72px;
  width: 18px;
  height: 18px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #ffffff;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_services_timeline .extra_row .sc_services_item_timeline_point:before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 8px;
  height: 8px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #000000;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_services_timeline .extra_row .sc_services_item {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_services_timeline .extra_row .sc_services_item:after {
  content: '';
  width: 22px;
  height: 22px;
  background-color: transparent;
  position: absolute;
  top: 0;
  left: 50%;
  bottom: auto;
  z-index: 1;
  -webkit-transform: translateX(-50%) rotate(130deg) skew(-10deg);
  -ms-transform: translateX(-50%) rotate(130deg) skew(-10deg);
  transform: translateX(-50%) rotate(130deg) skew(-10deg);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_services_timeline .extra_row .sc_services_item:hover .sc_services_item_info {
  -webkit-box-shadow: 0 3px 50px rgba(0, 0, 0, 0.1) !important;
  -ms-box-shadow: 0 3px 50px rgba(0, 0, 0, 0.1) !important;
  box-shadow: 0 3px 50px rgba(0, 0, 0, 0.1) !important;
}
.sc_services_timeline .extra_row .sc_services_item:hover .sc_services_item_timeline_point {
  background-color: var(--theme-color-text_link2_02);
}
.sc_services_timeline .extra_row .sc_services_item:hover .sc_services_item_timeline_point:before {
  background-color: var(--theme-color-text_link2);
}
.sc_services_timeline .extra_row .sc_services_item:hover:after {
  top: -8px;
  background-color: var(--theme-color-alter_bg_color);
}
.sc_services_timeline .extra_row:nth-child(odd) {
  padding: 0 0 65px 0;
  text-align: right;
}
.sc_services_timeline .extra_row:nth-child(odd) .sc_services_item_timeline_point {
  top: auto;
  bottom: -72px;
}
.sc_services_timeline .extra_row:nth-child(odd) .sc_services_item:after {
  width: 22px;
  height: 22px;
  bottom: 0;
  top: auto;
}
.sc_services_timeline .extra_row:nth-child(odd) .sc_services_item {
  vertical-align: bottom;
}
.sc_services_timeline .extra_row:nth-child(odd) .sc_services_item:hover:after {
  bottom: -8px;
}
.sc_services_timeline .extra_row:nth-child(odd):after {
  content: "";
  position: absolute;
  bottom: 0;
  left: 0;
  height: 4px;
  width: 100%;
  display: block;
  background-color: var(--theme-color-bd_color);
}

.sc_services_iconed .sc_services_item {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}

.sc_services_iconed .sc_services_item_icon:hover,
.sc_services_iconed .sc_services_item:hover .sc_services_item_icon,
.sc_services_iconed .sc_services_item_header .sc_services_item_subtitle a:hover,
.sc_services_iconed .sc_services_item:hover .sc_services_item_header .sc_services_item_subtitle a {
  color: var(--theme-color-text_link);
}

.sc_services_iconed.color_style_link2 .sc_services_item_icon:hover,
.sc_services_iconed.color_style_link2 .sc_services_item:hover .sc_services_item_icon,
.sc_services_iconed.color_style_link2 .sc_services_item_header .sc_services_item_subtitle a:hover,
.sc_services_iconed.color_style_link2 .sc_services_item:hover .sc_services_item_header .sc_services_item_subtitle a {
  color: var(--theme-color-text_link2);
}

.sc_services_iconed.color_style_link3 .sc_services_item_icon:hover,
.sc_services_iconed.color_style_link3 .sc_services_item:hover .sc_services_item_icon,
.sc_services_iconed.color_style_link3 .sc_services_item_header .sc_services_item_subtitle a:hover,
.sc_services_iconed.color_style_link3 .sc_services_item:hover .sc_services_item_header .sc_services_item_subtitle a {
  color: var(--theme-color-text_link3);
}

.sc_services_iconed .sc_services_item_header .sc_services_item_title a {
  color: var(--theme-color-text_link);
}

.sc_services_iconed.color_style_link2 .sc_services_item_header .sc_services_item_title a {
  color: var(--theme-color-text_link2);
}

.sc_services_iconed.color_style_link3 .sc_services_item_header .sc_services_item_title a {
  color: var(--theme-color-text_link3);
}

.sc_services_iconed .sc_services_item_header .sc_services_item_title a:hover,
.sc_services_iconed .sc_services_item:hover .sc_services_item_header .sc_services_item_title a {
  color: #fff;
}

.sc_services_iconed .sc_services_item .sc_services_item_header .sc_services_item_subtitle a {
  color: #fff;
}

.sc_services_iconed .sc_services_item:hover .sc_services_item_header .sc_services_item_subtitle a,
.sc_services_iconed .sc_services_item .sc_services_item_header .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_link);
}

.sc_services_iconed.color_style_link2 .sc_services_item:hover .sc_services_item_header .sc_services_item_subtitle a,
.sc_services_iconed.color_style_link2 .sc_services_item .sc_services_item_header .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_link2);
}

.sc_services_iconed.color_style_link3 .sc_services_item:hover .sc_services_item_header .sc_services_item_subtitle a,
.sc_services_iconed.color_style_link3 .sc_services_item .sc_services_item_header .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_link3);
}

.sc_services_iconed .sc_services_item_content .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}

.sc_services_iconed .sc_services_item_content .sc_services_item_title a:hover,
.sc_services_iconed .sc_services_item:hover .sc_services_item_content .sc_services_item_title a {
  color: var(--theme-color-alter_link);
}

.sc_services_iconed.color_style_link2 .sc_services_item_content .sc_services_item_title a:hover,
.sc_services_iconed.color_style_link2 .sc_services_item:hover .sc_services_item_content .sc_services_item_title a {
  color: var(--theme-color-alter_link2);
}

.sc_services_iconed.color_style_link3 .sc_services_item_content .sc_services_item_title a:hover,
.sc_services_iconed.color_style_link3 .sc_services_item:hover .sc_services_item_content .sc_services_item_title a {
  color: var(--theme-color-alter_link3);
}

.sc_services_iconed.color_style_dark .sc_services_item_content .sc_services_item_title a:hover,
.sc_services_iconed.color_style_dark .sc_services_item:hover .sc_services_item_content .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}

.sc_services.slider_container .swiper-pagination-bullet {
  border-color: var(--theme-color-text_light);
}

.sc_services_list .sc_services_item_featured_left .sc_services_item_number,
.sc_services_list .sc_services_item_featured_right .sc_services_item_number {
  color: var(--theme-color-text_light);
}

/* Style 'Strange' */
.sc_services_strange {
  overflow: hidden;
}
.sc_services_strange .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  position: relative;
  z-index: 1;
  overflow: hidden;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: background-color 0.3s ease;
  -ms-transition: background-color 0.3s ease;
  transition: background-color 0.3s ease;
}
.sc_services_strange .sc_services_item:hover .post_featured.hover_link.with_thumb > .bg_in {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_strange .sc_services_item_header {
  width: 100%;
  margin-bottom: 0 !important;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_services_strange .sc_services_item_header:before,
.sc_services_strange .sc_services_item_content:before {
  content: ' ';
  display: inline-block;
  width: 0;
  height: 0;
  padding-top: 95%;
  /* 112.5% - 16:9 */
  vertical-align: top;
  margin-left: -0.3em;
}
.sc_services_strange .sc_services_item_content {
  position: relative;
  z-index: 1;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
}
.sc_services_strange .sc_services_item_content_inner {
  width: 100%;
  max-height: 100%;
  position: absolute;
  z-index: 1;
  left: 50%;
  top: 50%;
  -webkit-transform: translate3d(-50%, -50%, 0);
  -ms-transform: translate3d(-50%, -50%, 0);
  transform: translate3d(-50%, -50%, 0);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  padding: 2.4em 2em;
}
.sc_services_strange .sc_services_item_icon {
  position: relative;
  display: inline-block;
  font-size: 4em;
  width: auto;
  height: auto;
  line-height: 1em;
  margin-top: 0;
  will-change: transform, color;
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  -webkit-transition: -webkit-transform 0.3s ease-out, color 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease-out, color 0.3s ease;
  transition: transform 0.3s ease-out, color 0.3s ease;
}
.sc_services_strange .sc_services_item:hover .sc_services_item_icon {
  -webkit-transform: translateY(-8px);
  -ms-transform: translateY(-8px);
  transform: translateY(-8px);
  color: var(--theme-color-alter_dark);
}
.sc_services_strange .sc_services_item_icon img {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.sc_services_strange .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
  position: relative;
  top: 2px;
}
.sc_services_strange .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.214em;
}
.sc_services_strange .sc_services_item_icon + .sc_services_item_title {
  margin-top: 1.1em;
}
.sc_services_strange .sc_services_item_text {
  font-size: 15px;
  line-height: 1.65em;
  text-align: center;
  max-height: 4.85em;
  overflow: hidden;
}
.sc_services_strange .sc_services_item_text p:last-child {
  margin-bottom: 0;
}
.sc_services_strange .sc_services_item_subtitle,
.sc_services_strange .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_strange .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_strange .sc_services_item .sc_services_item_title,
.sc_services_strange .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_services_strange .sc_services_item:hover .sc_services_item_title,
.sc_services_strange .sc_services_item:hover .sc_services_item_title a,
.sc_services_strange .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_strange .sc_services_item_title {
  margin: 0;
  text-align: center;
}
.sc_services_strange .sc_services_item_title + .sc_services_item_text,
.sc_services_strange .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.8em;
}
.sc_services_strange .sc_services_item .sc_services_item_button {
  margin: 1.6em 0 0;
}
.sc_services_strange .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-alter_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_strange .sc_services_item:hover .sc_services_item_more_link,
.sc_services_strange .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_strange .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_strange .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_strange .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_strange .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_strange .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_strange .sc_services_slider .slider-slide:nth-child(2n) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_2"]:nth-child(2n) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_4"]:nth-child(2n) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_6"]:nth-child(2n) .sc_services_item .sc_services_item_header {
  order: 2;
}
.sc_services_strange .sc_services_slider .slider-slide:nth-child(2n) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_2"]:nth-child(2n) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_4"]:nth-child(2n) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_6"]:nth-child(2n) .sc_services_item .sc_services_item_content {
  order: 1;
}
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_3"]:nth-child(3n-1) .sc_services_item .sc_services_item_header {
  order: 2;
}
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_3"]:nth-child(3n-1) .sc_services_item .sc_services_item_content {
  order: 1;
}
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(2) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(4) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(7) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(9) .sc_services_item .sc_services_item_header,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(12) .sc_services_item .sc_services_item_header {
  order: 2;
}
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(2) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(4) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(7) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(9) .sc_services_item .sc_services_item_content,
.sc_services_strange .sc_services_columns_wrap [class*="trx_addons_column-1_5"]:nth-child(12) .sc_services_item .sc_services_item_content {
  order: 1;
}
.sc_services_strange .sc_item_columns_5 .sc_services_item_content_inner,
.sc_services_strange .sc_item_columns_6 .sc_services_item_content_inner {
  padding: 1.5em;
}
.sc_services_strange .sc_item_columns_5 .sc_services_item_title,
.sc_services_strange .sc_item_columns_6 .sc_services_item_title {
  font-size: 1.2em;
  line-height: 1.114em;
}
.sc_services_strange .sc_item_columns_5 .sc_services_item_text,
.sc_services_strange .sc_item_columns_6 .sc_services_item_text {
  display: none;
}
.sc_services_strange .sc_item_columns_5 .sc_services_item_icon,
.sc_services_strange .sc_item_columns_6 .sc_services_item_icon {
  font-size: 3em;
}
.sc_services_strange .sc_item_columns_5 .sc_services_item_button,
.sc_services_strange .sc_item_columns_6 .sc_services_item_button {
  display: none;
}

/* Style 'Hover'
+++++++++++++++++++++++ */
.sc_services_hover {
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.sc_services_hover .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: center;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  perspective: none;
  -webkit-backface-visibility: hidden;
  -ms-backface-visibility: hidden;
  backface-visibility: hidden;
}
.sc_services_hover .sc_services_item:hover {
  z-index: 10;
}
.sc_services_hover .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 98%;
  display: inline-block;
}
.sc_services_hover .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  -webkit-transform: translateZ(60px);
  -ms-transform: translateZ(60px);
  transform: translateZ(60px);
}
.sc_services_hover .sc_services_item_content,
.sc_services_hover .sc_services_item:hover .sc_services_item_content {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  -webkit-transition: none;
  -ms-transition: none;
  transition: none;
}
.sc_services_hover .sc_services_item_content {
  position: relative;
  z-index: 1;
  top: auto;
  left: auto;
  bottom: auto;
  right: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  -webkit-backface-visibility: hidden;
  -ms-backface-visibility: hidden;
  backface-visibility: hidden;
  background-color: #05080d;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  width: 100%;
  max-height: 100%;
}
.sc_services_hover .sc_services_item.with_image .sc_services_item_content:before,
.sc_services_hover .sc_services_item.with_image:hover .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: -1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(5, 8, 13, 0.5);
  -webkit-transition: background-color 0.3s ease;
  -ms-transition: background-color 0.3s ease;
  transition: background-color 0.3s ease;
}
.sc_services_hover .sc_services_item_content_inner {
  position: relative;
  top: auto;
  left: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2em;
  -webkit-transform: translateZ(60px) scale(0.95);
  -ms-transform: translateZ(60px) scale(0.95);
  transform: translateZ(60px) scale(0.95);
}
.sc_services_hover .sc_services_item_icon,
.sc_services_hover .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
}
.sc_services_hover .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_hover .sc_services_item_number {
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
  font-weight: 500;
}
.sc_services_hover .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0;
}
.sc_services_hover .sc_services_item_content .sc_services_item_title {
  margin: 1em 0 0;
}
.sc_services_hover .sc_services_item_featured_none .sc_services_item_content .sc_services_item_title {
  margin-top: 0;
}
.sc_services_hover .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.2em;
}
.sc_services_hover .sc_services_item_title + .sc_services_item_text,
.sc_services_hover .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.4em;
}
.sc_services_hover .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  text-shadow: none;
  margin-top: 0.6em;
}
.sc_services_hover .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
  max-height: none;
}
.sc_services_hover .sc_services_item_content p {
  margin: 0;
}
.sc_services_hover .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image:before {
  display: none;
}
.sc_services_hover .sc_services_item_price,
.sc_services_hover .sc_services_item_price .amount,
.sc_services_hover .sc_services_item_icon,
.sc_services_hover .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_hover .sc_services_item_title,
.sc_services_hover .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_hover .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_hover .sc_services_item_subtitle,
.sc_services_hover .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_hover .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_hover .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_hover .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8);
}
.sc_services_hover.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2) !important;
}
.sc_services_hover.color_style_link2 .sc_services_item_title a:hover, .sc_services_hover.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_hover.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3) !important;
}
.sc_services_hover.color_style_link3 .sc_services_item_title a:hover, .sc_services_hover.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_hover [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_hover .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_hover [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_hover .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_hover [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_hover .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_hover.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_hover.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_hover.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_hover.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_hover.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_hover.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_hover .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}

/* Style Simple  */
.sc_services_tabs_simple .sc_services_item_icon {
  color: var(--theme-color-text_link);
}

.sc_services_tabs_simple.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}

.sc_services_tabs_simple.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}

.sc_services_tabs_simple.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}

.sc_services_tabs_simple .sc_services_item:hover .sc_services_item_icon,
.sc_services_tabs_simple .sc_services_item:hover .sc_services_item_title,
.sc_services_tabs_simple .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_tabs_simple .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs_simple .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_title,
.sc_services_tabs_simple .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_subtitle {
  color: var(--theme-color-text_hover);
}

.sc_services_tabs_simple.color_style_link2 .sc_services_item:hover .sc_services_item_icon,
.sc_services_tabs_simple.color_style_link2 .sc_services_item:hover .sc_services_item_title,
.sc_services_tabs_simple.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_tabs_simple.color_style_link2 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs_simple.color_style_link2 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_title,
.sc_services_tabs_simple.color_style_link2 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_subtitle {
  color: var(--theme-color-text_hover2);
}

.sc_services_tabs_simple.color_style_link3 .sc_services_item:hover .sc_services_item_icon,
.sc_services_tabs_simple.color_style_link3 .sc_services_item:hover .sc_services_item_title,
.sc_services_tabs_simple.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_tabs_simple.color_style_link3 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs_simple.color_style_link3 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_title,
.sc_services_tabs_simple.color_style_link3 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_subtitle {
  color: var(--theme-color-text_hover3);
}

.sc_services_tabs .sc_services_item_content {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}

.sc_services_tabs .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}

.sc_services_tabs .sc_services_item_title a:hover {
  color: var(--theme-color-alter_link);
}

.sc_services_tabs.color_style_link2 .sc_services_item_title a:hover {
  color: var(--theme-color-alter_link2);
}

.sc_services_tabs.color_style_link3 .sc_services_item_title a:hover {
  color: var(--theme-color-alter_link3);
}

.sc_services_tabs .sc_services_tabs_list_item .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}

.sc_services_tabs.color_style_link2 .sc_services_tabs_list_item .sc_services_item_icon {
  color: var(--theme-color-alter_link2);
}

.sc_services_tabs.color_style_link3 .sc_services_tabs_list_item .sc_services_item_icon {
  color: var(--theme-color-alter_link3);
}

.sc_services_tabs .sc_services_tabs_list_item .sc_services_item_number {
  color: var(--theme-color-alter_light);
}

.sc_services_tabs .sc_services_tabs_list_item {
  background-color: var(--theme-color-alter_bg_color);
}

.sc_services_tabs .sc_services_tabs_list_item:nth-child(2n+2) {
  background-color: var(--theme-color-alter_bg_hover);
}

.sc_services_tabs .sc_services_tabs_list_item:hover,
.sc_services_tabs .sc_services_tabs_list_item:nth-child(2n+2):hover {
  background-color: var(--theme-color-alter_bd_hover);
}

.sc_services_tabs .sc_services_tabs_list_item .sc_services_item_title {
  color: var(--theme-color-alter_dark);
}

.sc_services_tabs .sc_services_tabs_list_item:hover .sc_services_item_title {
  color: var(--theme-color-alter_link);
}

.sc_services_tabs.color_style_link2 .sc_services_tabs_list_item:hover .sc_services_item_title {
  color: var(--theme-color-alter_link2);
}

.sc_services_tabs.color_style_link3 .sc_services_tabs_list_item:hover .sc_services_item_title {
  color: var(--theme-color-alter_link3);
}

.sc_services_tabs.color_style_dark .sc_services_tabs_list_item:hover .sc_services_item_title {
  color: var(--theme-color-alter_dark);
}

.sc_services_tabs .sc_services_tabs_list_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_hover);
}

.sc_services_tabs.color_style_link2 .sc_services_tabs_list_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_hover2);
}

.sc_services_tabs.color_style_link3 .sc_services_tabs_list_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_hover3);
}

.sc_services_tabs.color_style_dark .sc_services_tabs_list_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}

.sc_services_tabs .sc_services_tabs_list_item:hover .sc_services_item_number {
  color: var(--theme-color-alter_text);
}

.sc_services_tabs .sc_services_tabs_list_item.sc_services_tabs_list_item_active {
  background-color: var(--theme-color-alter_dark) !important;
}

.sc_services_tabs .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_title {
  color: var(--theme-color-bg_color);
}

.sc_services_tabs .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_number {
  color: var(--theme-color-alter_link);
}

.sc_services_tabs.color_style_link2 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs.color_style_link2 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_number {
  color: var(--theme-color-alter_link2);
}

.sc_services_tabs.color_style_link3 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs.color_style_link3 .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_number {
  color: var(--theme-color-alter_link3);
}

.sc_services_tabs.color_style_dark .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_icon,
.sc_services_tabs.color_style_dark .sc_services_tabs_list_item.sc_services_tabs_list_item_active .sc_services_item_number {
  color: var(--theme-color-alter_dark);
}

/* Style Modern */
.sc_services_modern.sc_services_featured_top .swiper-wrapper .sc_services_item_thumb {
  margin-top: 14px;
}
.sc_services_modern .sc_services_item {
  margin-bottom: 2em;
  text-align: center;
  padding-top: 0.0001px;
}
.sc_services_modern.slider_swiper .sc_services_item,
.sc_services_modern .columns_padding_bottom .sc_services_item {
  margin-bottom: 0;
}
.sc_services_modern .sc_services_item_thumb {
  overflow: visible;
  margin: 0 auto;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  width: 60%;
}
.sc_services_modern .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_modern .post_featured_bg .post_thumb {
  display: block;
  width: 100%;
  height: 100%;
  position: absolute;
  z-index: 2;
  top: 0;
  left: 0;
  overflow: hidden;
  background-repeat: no-repeat;
  background-size: cover;
  background-position: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_services_modern .post_featured_bg:before {
  padding-top: 100%;
}
.sc_services_modern .post_featured > .sc_services_item_price,
.sc_services_modern .post_featured > p > .sc_services_item_price {
  position: absolute;
  z-index: 2;
  bottom: 1em;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_services_modern .sc_services_item:hover .post_featured > .sc_services_item_price,
.sc_services_modern .sc_services_item:hover .post_featured > p > .sc_services_item_price {
  -webkit-transform: translateX(0);
  -ms-transform: translateX(0);
  transform: translateX(0);
}
.sc_services_modern .sc_services_item_thumb .all-svg {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  z-index: 1;
}
.sc_services_modern .sc_services_item_thumb .all-svg span {
  display: inline-block;
  line-height: 0;
  opacity: 0;
  -webkit-transition: -webkit-transform 0.3s ease-out, opacity 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out, opacity 0.3s ease-out;
  transition: transform 0.3s ease-out, opacity 0.3s ease-out;
  will-change: transform;
}
.sc_services_modern .sc_services_item_thumb .all-svg .svg-1 {
  position: absolute;
  top: 0;
  right: 0;
  -webkit-transform: translate3d(-40px, 40px, 0);
  -ms-transform: translate3d(-40px, 40px, 0);
  transform: translate3d(-40px, 40px, 0);
}
.sc_services_modern .sc_services_item_thumb .all-svg .svg-1 svg {
  width: 100px;
  height: 100px;
  fill: var(--theme-color-text_dark);
  opacity: 0.1;
}
.sc_services_modern .sc_services_item_thumb .all-svg .svg-2 {
  position: absolute;
  left: 0;
  bottom: 0;
  -webkit-transform: translate3d(25px, -25px, 0);
  -ms-transform: translate3d(25px, -25px, 0);
  transform: translate3d(25px, -25px, 0);
}
.sc_services_modern .sc_services_item_thumb .all-svg .svg-2 svg {
  width: 88px;
  height: 88px;
  fill: transparent;
  stroke: var(--theme-color-text_link);
  stroke-width: 12px;
}
.sc_services_modern .sc_services_item:hover .all-svg .svg-1 {
  opacity: 1;
  -webkit-transform: translate3d(30px, -10px, 0);
  -ms-transform: translate3d(30px, -10px, 0);
  transform: translate3d(30px, -10px, 0);
}
.sc_services_modern .sc_services_item:hover .all-svg .svg-2 {
  opacity: 1;
  -webkit-transform: translate3d(-20px, 5px, 0);
  -ms-transform: translate3d(-20px, 5px, 0);
  transform: translate3d(-20px, 5px, 0);
}
.sc_services_modern .sc_services_item_thumb[class*="hover_"] {
  display: block;
}
.sc_services_modern .sc_services_item_thumb img {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  overflow: hidden;
  width: 100%;
  position: relative;
  z-index: 2;
}
.sc_services_modern .sc_services_item_icon,
.sc_services_modern .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  width: auto;
  height: auto;
  line-height: 1em;
}
.sc_services_modern .sc_services_item_icon img {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.sc_services_modern .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
  position: relative;
  top: 2px;
}
.sc_services_modern .sc_services_item_pictogram {
  border: none;
  width: auto;
}
.sc_services_modern .sc_services_item_number {
  display: inline-block;
  text-align: center;
  font-size: 5em;
  line-height: 1em;
  font-weight: 400;
}
.sc_services_modern .sc_services_item_featured_top .sc_services_item_pictogram + .sc_services_item_info,
.sc_services_modern .sc_services_item_featured_top .sc_services_item_icon + .sc_services_item_info,
.sc_services_modern .sc_services_item_featured_top .sc_services_item_number + .sc_services_item_info {
  margin-top: 1.5em;
}
.sc_services_modern .sc_services_item_info {
  padding: 0;
  text-align: center;
}
.sc_services_modern .sc_services_item_title {
  font-size: 1.556em;
  margin: 0;
}
.sc_services_modern .sc_services_item_title,
.sc_services_modern .sc_services_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_services_modern .sc_services_item_subtitle,
.sc_services_modern .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_modern .sc_services_item_subtitle + .sc_services_item_title {
  margin-top: 0.45em;
}
.sc_services_modern .sc_services_item_content {
  font-size: 15px;
  line-height: 1.62em;
  margin-top: 0.8em;
}
.sc_services_modern .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_modern .sc_services_item_button {
  margin: 1.5em 0 0;
}
.sc_services_modern.sc_services_featured_top .sc_services_item_thumb {
  margin-bottom: 1.9em;
}
.sc_services_modern.sc_services_featured_top .post_featured_bg .post_thumb {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  will-change: transform;
}
.sc_services_modern.sc_services_featured_top .sc_services_item:hover .post_thumb {
  -webkit-transform: scale3d(1.05, 1.05, 1.05);
  -ms-transform: scale3d(1.05, 1.05, 1.05);
  transform: scale3d(1.05, 1.05, 1.05);
}
.sc_services_modern .sc_services_item_featured_left,
.sc_services_modern .sc_services_item_featured_right {
  position: relative;
  overflow: hidden;
  background-color: transparent;
}
.sc_services_modern .sc_services_item_featured_left.with_number,
.sc_services_modern .sc_services_item_featured_right.with_number {
  min-height: 2.8em;
}
.sc_services_modern .sc_services_item_featured_left {
  text-align: left;
}
.sc_services_modern .sc_services_item_featured_right {
  text-align: right;
}
.sc_services_modern .sc_services_item_featured_left .sc_services_item_number,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_number {
  font-size: 3em;
  line-height: 1em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: -5px;
  left: 0;
}
.sc_services_modern .sc_services_item_featured_left .sc_services_item_icon,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_icon {
  font-size: 3.4em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
}
.sc_services_modern .sc_services_item_featured_right .sc_services_item_thumb,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_icon,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_pictogram,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_number {
  left: auto;
  right: 0;
}
.sc_services_modern .sc_services_item_featured_left.without_content .sc_services_item_icon,
.sc_services_modern .sc_services_item_featured_right.without_content .sc_services_item_icon {
  font-size: 1.5em;
}
.sc_services_modern .sc_services_item_featured_left .sc_services_item_pictogram,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_pictogram {
  font-size: 3.4em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: 3.4em;
  height: auto;
}
.sc_services_modern .sc_services_item_featured_left.without_content .sc_services_item_pictogram,
.sc_services_modern .sc_services_item_featured_right.without_content .sc_services_item_pictogram {
  font-size: 1.5em;
}
.sc_services_modern .sc_services_item_featured_left .sc_services_item_thumb,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_thumb {
  width: 30%;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
}
.sc_services_modern .sc_services_item_featured_left .sc_services_item_content,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_content {
  min-height: 0;
}
.sc_services_modern .sc_services_item_featured_left .sc_services_item_info {
  text-align: left;
  padding: 0;
  margin-left: 5em;
}
.sc_services_modern .sc_services_item_featured_left.with_image .sc_services_item_info {
  padding-left: 2em;
  margin-left: 30%;
}
.sc_services_modern .sc_services_item_featured_right .sc_services_item_thumb,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_icon,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_pictogram,
.sc_services_modern .sc_services_item_featured_right .sc_services_item_number {
  left: auto;
  right: 0;
}
.sc_services_modern .sc_services_item_featured_right .sc_services_item_info {
  text-align: right;
  padding: 0;
  margin-right: 5em;
}
.sc_services_modern .sc_services_item_featured_right.with_image .sc_services_item_info {
  padding-right: 2em;
  margin-right: 30%;
}
.sc_services_modern .trx_addons_hover_content .trx_addons_hover_title {
  font-size: 1.3333em;
}
.sc_services_modern .sc_services_item .sc_button_arrow {
  position: relative;
  display: inline-block;
  width: 2.8em;
  height: 2.8em;
  line-height: 2.85em;
  text-align: center;
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-text_dark_008);
  border: none;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, box-shadow 0.3s ease-out;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, box-shadow 0.3s ease-out;
  transition: color 0.3s ease, background-color 0.3s ease, box-shadow 0.3s ease-out;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_services_modern .sc_services_item .sc_button_arrow:before {
  content: '\E9A4';
  font-family: "fontello";
  letter-spacing: 1px;
  font-size: 12px;
  font-weight: 400;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.sc_services_modern .sc_services_item:hover .sc_button_arrow,
.sc_services_modern .sc_services_item .sc_button_arrow:hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
  -webkit-box-shadow: 0 5px 16px var(--theme-color-text_link_02);
  -ms-box-shadow: 0 5px 16px var(--theme-color-text_link_02);
  box-shadow: 0 5px 16px var(--theme-color-text_link_02);
}
.sc_services_modern.color_style_link2 .sc_services_item:hover .sc_button_arrow, .sc_services_modern.color_style_link2 .sc_services_item .sc_button_arrow:hover {
  background-color: var(--theme-color-text_link2);
  -webkit-box-shadow: 0 5px 16px var(--theme-color-text_link2_02);
  -ms-box-shadow: 0 5px 16px var(--theme-color-text_link2_02);
  box-shadow: 0 5px 16px var(--theme-color-text_link2_02);
}
.sc_services_modern.color_style_link2 .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_modern.color_style_link3 .sc_services_item:hover .sc_button_arrow, .sc_services_modern.color_style_link3 .sc_services_item .sc_button_arrow:hover {
  background-color: var(--theme-color-text_link3);
  -webkit-box-shadow: 0 5px 16px var(--theme-color-text_link3_02);
  -ms-box-shadow: 0 5px 16px var(--theme-color-text_link3_02);
  box-shadow: 0 5px 16px var(--theme-color-text_link3_02);
}
.sc_services_modern.color_style_link3 .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_modern.color_style_dark .sc_services_item:hover .sc_button_arrow, .sc_services_modern.color_style_dark .sc_services_item .sc_button_arrow:hover {
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-text_dark);
  -webkit-box-shadow: 0 5px 16px var(--theme-color-text_dark_02);
  -ms-box-shadow: 0 5px 16px var(--theme-color-text_dark_02);
  box-shadow: 0 5px 16px var(--theme-color-text_dark_02);
}
.sc_services_modern.color_style_dark .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}

/* Style 'Breezy'
+++++++++++++++++++++++ */
.sc_services_breezy .sc_services_item {
  position: relative;
  z-index: 1;
  text-align: center;
}
.sc_services_breezy .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 98%;
  display: inline-block;
}
.sc_services_breezy .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_breezy .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  opacity: .6;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_breezy .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: 0;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content:after {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background-color: var(--theme-color-text_link);
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_breezy .sc_services_item.with_image:hover .sc_services_item_content:after {
  opacity: .7;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image:before,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image:after {
  display: none;
}
.sc_services_breezy .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2.6em 2em;
}
.sc_services_breezy .trx_addons_column-1_5 .sc_services_item_content_inner,
.sc_services_breezy .trx_addons_column-1_6 .sc_services_item_content_inner,
.sc_services_breezy .trx_addons_column-1_7 .sc_services_item_content_inner,
.sc_services_breezy .trx_addons_column-1_8 .sc_services_item_content_inner {
  padding: 1em;
}
.sc_services_breezy .trx_addons_column-1_5 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_breezy .trx_addons_column-1_6 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_breezy .trx_addons_column-1_7 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_breezy .trx_addons_column-1_8 .sc_services_item_content_inner .sc_services_item_title {
  font-size: 1.1em;
}
.sc_services_breezy .sc_services_item_icon,
.sc_services_breezy .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
}
.sc_services_breezy .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_breezy .sc_services_item_number {
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
  font-weight: 400;
}
.sc_services_breezy .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0.4em 0 0;
}
.sc_services_breezy .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_breezy .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.2em;
}
.sc_services_breezy .sc_services_item_title + .sc_services_item_text,
.sc_services_breezy .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.4em;
}
.sc_services_breezy .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_breezy .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
  max-height: 4.8em;
  overflow: hidden;
}
.sc_services_breezy .sc_services_item_content p {
  margin: 0;
}
.sc_services_breezy .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_breezy .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_breezy .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_breezy .sc_services_item_price,
.sc_services_breezy .sc_services_item_price .amount,
.sc_services_breezy .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_breezy .sc_services_item_title,
.sc_services_breezy .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_breezy .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_breezy .sc_services_item_subtitle,
.sc_services_breezy .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_breezy .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_breezy .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_breezy .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_breezy [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_breezy .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_breezy [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_breezy .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_breezy [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_breezy .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_breezy .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_breezy.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_breezy.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_breezy.color_style_link2 .sc_services_item_title a:hover, .sc_services_breezy.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_breezy.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_breezy.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_breezy.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_breezy.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy.color_style_link2 .sc_services_item.with_image .sc_services_item_content:after {
  background-color: var(--theme-color-text_link2);
}
.sc_services_breezy.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_breezy.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_breezy.color_style_link3 .sc_services_item_title a:hover, .sc_services_breezy.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_breezy.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_breezy.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_breezy.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_breezy.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_breezy.color_style_link3 .sc_services_item.with_image .sc_services_item_content:after {
  background-color: var(--theme-color-text_link3);
}
.sc_services_breezy.color_style_dark .sc_services_item.with_image .sc_services_item_content:after {
  background-color: #000000;
}
.sc_services_breezy.color_style_dark .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_breezy.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}

/* Style 'Cool'
+++++++++++++++++++++++ */
.sc_services_cool .trx_addons_columns_wrap {
  margin-left: 0;
  margin-right: -4px;
}
.sc_services_cool .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 4px;
}
.sc_services_cool .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_services_cool .trx_addons_columns_wrap > [class*="trx_addons_column-"].columns_padding_bottom {
  padding-bottom: 4px;
}
.sc_services_cool .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_services_cool .sc_services_item {
  position: relative;
  z-index: 1;
  text-align: left;
}
.sc_services_cool .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 115%;
  display: inline-block;
}
.sc_services_cool .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_cool .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  opacity: .6;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_cool .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: 0;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content:after {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background-color: var(--theme-color-text_link);
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_cool .sc_services_item.with_image:hover .sc_services_item_content:after {
  opacity: .7;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image:before,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image:after {
  display: none;
}
.sc_services_cool .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 3em 2.2em;
}
.sc_services_cool .trx_addons_column-1_5 .sc_services_item_content_inner,
.sc_services_cool .trx_addons_column-1_6 .sc_services_item_content_inner,
.sc_services_cool .trx_addons_column-1_7 .sc_services_item_content_inner,
.sc_services_cool .trx_addons_column-1_8 .sc_services_item_content_inner {
  padding: 1.8em;
}
.sc_services_cool .trx_addons_column-1_5 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_cool .trx_addons_column-1_6 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_cool .trx_addons_column-1_7 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_cool .trx_addons_column-1_8 .sc_services_item_content_inner .sc_services_item_title {
  font-size: 1.5em;
}
.sc_services_cool .sc_services_item_content_inner_bottom {
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  position: relative;
  z-index: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_cool .sc_services_item .sc_services_item_content_inner_top {
  -webkit-transform: translateY(-15px);
  -ms-transform: translateY(-15px);
  transform: translateY(-15px);
  opacity: 0;
  will-change: transform, opacity;
  -webkit-transition: -webkit-transform 0.3s ease-out, opacity 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out, opacity 0.3s ease-out;
  transition: transform 0.3s ease-out, opacity 0.3s ease-out;
}
.sc_services_cool .sc_services_item:hover .sc_services_item_content_inner_top {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  opacity: 1;
}
.sc_services_cool .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(45px);
  -ms-transform: translateY(45px);
  transform: translateY(45px);
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_services_cool .sc_services_item.with_more:not(.no_links):hover .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.sc_services_cool .sc_services_item_icon,
.sc_services_cool .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 3em;
  line-height: 1em;
}
.sc_services_cool .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_cool .sc_services_item_number {
  display: inline-block;
  font-size: 1.333em;
  line-height: 1em;
  font-weight: 400;
  letter-spacing: 0;
}
.sc_services_cool .sc_services_item_title {
  font-size: 1.944em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0.4em 0 0;
}
.sc_services_cool .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_cool .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.5em;
}
.sc_services_cool .sc_services_item_title + .sc_services_item_text {
  margin-top: 0.55em;
}
.sc_services_cool .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.8em;
}
.sc_services_cool .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_cool .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
  max-height: 4.8em;
  overflow: hidden;
}
.sc_services_cool .sc_services_item_content p {
  margin: 0;
}
.sc_services_cool .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_cool .sc_services_item_button {
  margin-top: 1.2em;
}
.sc_services_cool .sc_services_item.with_more:not(.no_links) .sc_services_item_button {
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_services_cool .sc_services_item.with_more:not(.no_links):hover .sc_services_item_button {
  opacity: 1;
}
.sc_services_cool .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #ffffff !important;
  z-index: 1;
  overflow: hidden;
}
.sc_services_cool .sc_services_item:hover .sc_services_item_more_link,
.sc_services_cool .sc_services_item .sc_services_item_more_link:hover {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_cool .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_cool .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_cool .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_services_cool .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 13px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_cool .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool .sc_services_item_price,
.sc_services_cool .sc_services_item_price .amount,
.sc_services_cool .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item_title,
.sc_services_cool .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item_subtitle,
.sc_services_cool .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_cool .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_cool [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_cool .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_cool [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_cool .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_cool [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_cool .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_cool .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image:hover .sc_services_item_more_link,
.sc_services_cool .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool.color_style_link2 .sc_services_item_title a:hover, .sc_services_cool.color_style_link2 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_cool.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_cool.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_cool.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_cool.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link2 .sc_services_item.with_image .sc_services_item_content:after {
  background-color: var(--theme-color-text_link2);
}
.sc_services_cool.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool.color_style_link3 .sc_services_item_title a:hover, .sc_services_cool.color_style_link3 .sc_services_item_subtitle a:hover {
  color: #ffffff;
}
.sc_services_cool.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_cool.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_cool.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_cool.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_cool.color_style_link3 .sc_services_item.with_image .sc_services_item_content:after {
  background-color: var(--theme-color-text_link3);
}
.sc_services_cool.color_style_dark .sc_services_item.with_image .sc_services_item_content:after {
  background-color: #000000;
}
.sc_services_cool.color_style_dark .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_cool.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}

/* Style 'Extra'
+++++++++++++++++++++++ */
.sc_services_extra .sc_services_item {
  position: relative;
  z-index: 1;
  text-align: center;
}
.sc_services_extra .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 115%;
  display: inline-block;
}
.sc_services_extra .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_extra .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  opacity: .6;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_extra .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: 0;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content:after {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background-color: var(--theme-color-text_link);
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_extra .sc_services_item.with_image:hover .sc_services_item_content:after {
  opacity: .7;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image:before,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image:after {
  display: none;
}
.sc_services_extra .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 3em 2.2em;
}
.sc_services_extra .trx_addons_column-1_5 .sc_services_item_content_inner,
.sc_services_extra .trx_addons_column-1_6 .sc_services_item_content_inner,
.sc_services_extra .trx_addons_column-1_7 .sc_services_item_content_inner,
.sc_services_extra .trx_addons_column-1_8 .sc_services_item_content_inner {
  padding: 1.8em;
}
.sc_services_extra .trx_addons_column-1_5 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_extra .trx_addons_column-1_6 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_extra .trx_addons_column-1_7 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_extra .trx_addons_column-1_8 .sc_services_item_content_inner .sc_services_item_title {
  font-size: 1.5em;
}
.sc_services_extra .sc_services_item_content_inner_bottom {
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  position: relative;
  z-index: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_extra .sc_services_item .sc_services_item_content_inner_top {
  -webkit-transform: translateY(-15px);
  -ms-transform: translateY(-15px);
  transform: translateY(-15px);
  opacity: 0;
  will-change: transform, opacity;
  -webkit-transition: -webkit-transform 0.3s ease-out, opacity 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out, opacity 0.3s ease-out;
  transition: transform 0.3s ease-out, opacity 0.3s ease-out;
}
.sc_services_extra .sc_services_item:hover .sc_services_item_content_inner_top {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  opacity: 1;
}
.sc_services_extra .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(45px);
  -ms-transform: translateY(45px);
  transform: translateY(45px);
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_services_extra .sc_services_item.with_more:not(.no_links):hover .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.sc_services_extra .sc_services_item_icon,
.sc_services_extra .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 3em;
  line-height: 1em;
}
.sc_services_extra .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_extra .sc_services_item_number {
  display: inline-block;
  font-size: 1.556em;
  line-height: 1em;
  font-weight: 400;
  letter-spacing: 0;
}
.sc_services_extra .sc_services_item_title {
  font-size: 1.944em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0.4em 0 0;
}
.sc_services_extra .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_extra .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.5em;
}
.sc_services_extra .sc_services_item_title + .sc_services_item_text {
  margin-top: 0.55em;
}
.sc_services_extra .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.8em;
}
.sc_services_extra .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_extra .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
  max-height: 4.8em;
  overflow: hidden;
}
.sc_services_extra .sc_services_item_content p {
  margin: 0;
}
.sc_services_extra .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_extra .sc_services_item_button {
  margin-top: 1.2em;
}
.sc_services_extra .sc_services_item.with_more:not(.no_links) .sc_services_item_button {
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_services_extra .sc_services_item.with_more:not(.no_links):hover .sc_services_item_button {
  opacity: 1;
}
.sc_services_extra .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #ffffff !important;
  z-index: 1;
  overflow: hidden;
}
.sc_services_extra .sc_services_item:hover .sc_services_item_more_link,
.sc_services_extra .sc_services_item .sc_services_item_more_link:hover {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_extra .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_extra .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_extra .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_services_extra .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 13px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_extra .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra .sc_services_item_price,
.sc_services_extra .sc_services_item_price .amount,
.sc_services_extra .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item_title,
.sc_services_extra .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item_subtitle,
.sc_services_extra .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_extra .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_extra [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_extra .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_extra [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_extra .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_extra [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_extra .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_extra .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image:hover .sc_services_item_more_link,
.sc_services_extra .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra.color_style_link2 .sc_services_item_title a:hover, .sc_services_extra.color_style_link2 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_extra.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_extra.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_extra.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_extra.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link2 .sc_services_item.with_image .sc_services_item_content:after {
  background-color: var(--theme-color-text_link2);
}
.sc_services_extra.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra.color_style_link3 .sc_services_item_title a:hover, .sc_services_extra.color_style_link3 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_extra.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_extra.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_extra.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_extra.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_extra.color_style_link3 .sc_services_item.with_image .sc_services_item_content:after {
  background-color: var(--theme-color-text_link3);
}
.sc_services_extra.color_style_dark .sc_services_item.with_image .sc_services_item_content:after {
  background-color: #000000;
}
.sc_services_extra.color_style_dark .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_extra.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}

/* Style 'Strong'
+++++++++++++++++++++++ */
.sc_services_strong .sc_services_item {
  position: relative;
  z-index: 1;
  text-align: left;
}
.sc_services_strong .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 115%;
  display: inline-block;
}
.sc_services_strong .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_strong .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  opacity: .6;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_strong .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: 0;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content:after {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background: #000;
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_strong .sc_services_item.with_image:hover .sc_services_item_content:after {
  opacity: .6;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image:before,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image:after {
  display: none;
}
.sc_services_strong .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2em 2.2em 2.4em;
}
.sc_services_strong .trx_addons_column-1_5 .sc_services_item_content_inner,
.sc_services_strong .trx_addons_column-1_6 .sc_services_item_content_inner,
.sc_services_strong .trx_addons_column-1_7 .sc_services_item_content_inner,
.sc_services_strong .trx_addons_column-1_8 .sc_services_item_content_inner {
  padding: 1.8em;
}
.sc_services_strong .trx_addons_column-1_5 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_strong .trx_addons_column-1_6 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_strong .trx_addons_column-1_7 .sc_services_item_content_inner .sc_services_item_title,
.sc_services_strong .trx_addons_column-1_8 .sc_services_item_content_inner .sc_services_item_title {
  font-size: 1.3em;
}
.sc_services_strong .sc_services_item_content_inner_bottom {
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  position: relative;
  z-index: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_strong .sc_services_item .sc_services_item_content_inner_top {
  opacity: 1;
}
.sc_services_strong .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(40px);
  -ms-transform: translateY(40px);
  transform: translateY(40px);
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_services_strong .sc_services_item.with_more:not(.no_links):hover .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.sc_services_strong .sc_services_item_icon,
.sc_services_strong .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 3em;
  line-height: 1em;
}
.sc_services_strong .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_strong .sc_services_item_number {
  display: inline-block;
  font-size: 1.333em;
  line-height: 1em;
  font-weight: 400;
  letter-spacing: 0;
}
.sc_services_strong .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0.4em 0 0;
}
.sc_services_strong .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_strong .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.5em;
}
.sc_services_strong .sc_services_item_title + .sc_services_item_text {
  margin-top: 0.55em;
}
.sc_services_strong .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.8em;
}
.sc_services_strong .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_strong .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
  max-height: 4.8em;
  overflow: hidden;
}
.sc_services_strong .sc_services_item_content p {
  margin: 0;
}
.sc_services_strong .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_strong .sc_services_item_button {
  margin-top: 1.2em;
}
.sc_services_strong .sc_services_item.with_more:not(.no_links) .sc_services_item_button {
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_services_strong .sc_services_item.with_more:not(.no_links):hover .sc_services_item_button {
  opacity: 1;
}
.sc_services_strong .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #ffffff !important;
  z-index: 1;
  overflow: hidden;
}
.sc_services_strong .sc_services_item:hover .sc_services_item_more_link,
.sc_services_strong .sc_services_item .sc_services_item_more_link:hover {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_strong .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_strong .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_strong .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_services_strong .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_strong .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong .sc_services_item_price,
.sc_services_strong .sc_services_item_price .amount,
.sc_services_strong .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item_title,
.sc_services_strong .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item_subtitle,
.sc_services_strong .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_strong .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_strong [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_strong .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_strong [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_strong .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_strong [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_strong .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_strong .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image:hover .sc_services_item_more_link,
.sc_services_strong .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong.color_style_link2 .sc_services_item_title a:hover, .sc_services_strong.color_style_link2 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_strong.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_strong.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_strong.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_strong.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong.color_style_link3 .sc_services_item_title a:hover, .sc_services_strong.color_style_link3 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_strong.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_strong.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_strong.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_strong.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_strong.color_style_dark .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_strong.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}

/* Style 'Minimal'
+++++++++++++++++++++++ */
.sc_services_minimal {
  /* Column 1_4 */
}
.elementor-section-full_width .sc_services_minimal .sc_services_item:before {
  padding-top: 71%;
}
.sc_services_minimal .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: center;
  overflow: hidden;
}
.sc_services_minimal .sc_services_item:before {
  content: '';
  width: 0;
  height: 0;
  padding-top: 95%;
  display: inline-block;
}
.sc_services_minimal .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_minimal .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  width: 100%;
  height: 100%;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_featured_image {
  position: absolute;
  z-index: -1;
  top: -1px;
  right: -1px;
  bottom: -1px;
  left: -1px;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  will-change: transform;
  -webkit-transition: -webkit-transform 0.4s ease-out;
  -ms-transition: -ms-transform 0.4s ease-out;
  transition: transform 0.4s ease-out;
  -webkit-backface-visibility: hidden;
  -ms-backface-visibility: hidden;
  backface-visibility: hidden;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_featured_image:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background: #0C0F16;
  opacity: .45;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  will-change: opacity;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_featured_image:hover:before {
  opacity: .77;
}
.sc_services_minimal .sc_services_item:hover .sc_services_item_featured_image {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_featured_image.without_image:before {
  display: none;
}
.sc_services_minimal .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 3em 2em;
}
.sc_services_minimal .sc_services_item_content_inner_bottom {
  display: block;
  position: relative;
  z-index: 1;
  line-height: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_minimal .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_services_minimal .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  padding-top: 5.7em;
}
.sc_services_minimal .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_services_minimal .sc_services_item.with_more:not(.no_links):hover .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(-1em);
  -ms-transform: translateY(-1em);
  transform: translateY(-1em);
}
.sc_services_minimal .sc_services_item_icon,
.sc_services_minimal .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 3em;
  line-height: 1em;
}
.sc_services_minimal .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_minimal .sc_services_item_number {
  display: inline-block;
  font-size: 1.333em;
  line-height: 1em;
  font-weight: 400;
  letter-spacing: 0;
}
.sc_services_minimal .sc_services_item_title {
  font-size: 1.944em;
  line-height: 1.3em;
  font-weight: 700;
  letter-spacing: -0.8px;
  margin: 0.4em 0 0;
}
.sc_services_minimal .sc_services_item_subtitle {
  font-size: 14px;
  line-height: 1.5em;
  font-weight: 500;
  letter-spacing: 1.7px;
  text-transform: uppercase;
  opacity: .9;
}
.sc_services_minimal .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_minimal .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.5em;
}
.sc_services_minimal .sc_services_item_title + .sc_services_item_text {
  margin-top: 0.55em;
}
.sc_services_minimal .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.8em;
}
.sc_services_minimal .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_minimal .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
}
.sc_services_minimal .sc_services_item_content p {
  margin: 0;
}
.sc_services_minimal .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_minimal .sc_services_item.with_more:not(.no_links) .sc_services_item_button {
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_services_minimal .sc_services_item.with_more:not(.no_links):hover .sc_services_item_button {
  opacity: 1;
}
.sc_services_minimal .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #ffffff !important;
  z-index: 1;
  overflow: hidden;
}
.sc_services_minimal .sc_services_item:hover .sc_services_item_more_link,
.sc_services_minimal .sc_services_item .sc_services_item_more_link:hover {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_minimal .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_minimal .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_minimal .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_services_minimal .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 16px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_minimal .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal .sc_services_item_price,
.sc_services_minimal .sc_services_item_price .amount,
.sc_services_minimal .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item_title,
.sc_services_minimal .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item_subtitle,
.sc_services_minimal .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_minimal .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_minimal [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_minimal .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_minimal [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_minimal .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_minimal [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_minimal .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_minimal .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image:hover .sc_services_item_more_link,
.sc_services_minimal .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal.color_style_link2 .sc_services_item_title a:hover, .sc_services_minimal.color_style_link2 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_minimal.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_minimal.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_minimal.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_minimal.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal.color_style_link3 .sc_services_item_title a:hover, .sc_services_minimal.color_style_link3 .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_minimal.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_minimal.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_minimal.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_minimal.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_minimal.color_style_dark .sc_services_item .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: #ffffff;
}
.sc_services_minimal .trx_addons_column-1_4 .sc_services_item_content_inner {
  padding: 1.6em;
}
.sc_services_minimal .trx_addons_column-1_4 .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  padding-top: 2em;
}
.sc_services_minimal .trx_addons_column-1_4 .sc_services_item_title {
  font-size: 1.4em;
}
.sc_services_minimal .trx_addons_column-1_4 .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 14px;
}

/* Style 'Creative'
+++++++++++++++++++++++ */
.sc_services_creative {
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.sc_services_creative .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: left;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  perspective: none;
}
.sc_services_creative .sc_services_item:hover {
  z-index: 10;
}
.sc_services_creative .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 110%;
  display: inline-block;
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  -webkit-transition: background 0.3s ease;
  -ms-transition: background 0.3s ease;
  transition: background 0.3s ease;
  opacity: .6;
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image:before {
  display: none;
}
.sc_services_creative .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  -webkit-transform: translateZ(60px);
  -ms-transform: translateZ(60px);
  transform: translateZ(60px);
}
.sc_services_creative .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  width: 100%;
  height: 100%;
}
.sc_services_creative .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2.8em 2.6em;
  -webkit-transform: translateZ(60px);
  -ms-transform: translateZ(60px);
  transform: translateZ(60px);
}
.sc_services_creative .sc_services_item_content_inner_top {
  margin-bottom: 20px;
}
.sc_services_creative .sc_services_item_content_inner_bottom {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  width: 100%;
}
.sc_services_creative .sc_services_item_icon,
.sc_services_creative .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
}
.sc_services_creative .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_creative .sc_services_item_number {
  display: inline-block;
  font-size: 1.667em;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: 0;
}
.sc_services_creative .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0;
}
.sc_services_creative .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.2em;
}
.sc_services_creative .sc_services_item_text + .sc_services_item_title {
  margin-top: 0.25em;
}
.sc_services_creative .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  text-shadow: none;
  margin-bottom: 0.5em;
}
.sc_services_creative .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
}
.sc_services_creative .sc_services_item_content p {
  margin: 0;
}
.sc_services_creative .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_creative .sc_services_item_price,
.sc_services_creative .sc_services_item_price .amount,
.sc_services_creative .sc_services_item_icon,
.sc_services_creative .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_creative .sc_services_item_title,
.sc_services_creative .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_creative .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_creative .sc_services_item_subtitle,
.sc_services_creative .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_creative .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_creative .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_creative .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8);
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2) !important;
}
.sc_services_creative.color_style_link2 .sc_services_item_title a:hover, .sc_services_creative.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_creative.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3) !important;
}
.sc_services_creative.color_style_link3 .sc_services_item_title a:hover, .sc_services_creative.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_creative [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_creative .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_creative [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_creative .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_creative [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_creative .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_creative.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_creative.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_creative.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_creative.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_creative .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_creative.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_creative.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_creative.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}

/* Style 'Shine'
+++++++++++++++++++++++ */
.sc_services_shine .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: left;
}
.sc_services_shine .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 80%;
  display: inline-block;
}
.sc_services_shine .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_shine .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  background-color: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  width: 100%;
  max-height: 100%;
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background-color: var(--theme-color-alter_bg_color);
  opacity: 1;
  -webkit-transition: background-color 0.3s ease, opacity 0.3s ease;
  -ms-transition: background-color 0.3s ease, opacity 0.3s ease;
  transition: background-color 0.3s ease, opacity 0.3s ease;
  will-change: background-color, opacity;
}
.sc_services_shine .sc_services_item.with_image:hover .sc_services_item_content:before {
  background-color: var(--theme-color-text_link);
  opacity: .7;
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image:before {
  display: none;
}
.sc_services_shine .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 4em 2.8em;
}
.sc_services_shine .sc_services_item_icon,
.sc_services_shine .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4.2em;
  line-height: 1em;
}
.sc_services_shine .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_shine .sc_services_item_number {
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
  font-weight: 400;
}
.sc_services_shine .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 1.1em 0 0;
}
.sc_services_shine .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_shine .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.4em;
}
.sc_services_shine .sc_services_item_title + .sc_services_item_text,
.sc_services_shine .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.8em;
}
.sc_services_shine .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_shine .sc_services_item_text {
  font-size: 15px;
  line-height: 1.65em;
}
.sc_services_shine .sc_services_item_content p {
  margin: 0;
}
.sc_services_shine .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_shine .sc_services_item .sc_services_item_button {
  margin-top: 1.5em;
}
.sc_services_shine .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-alter_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_shine .sc_services_item:hover .sc_services_item_more_link,
.sc_services_shine .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-inverse_link);
}
.sc_services_shine .sc_services_item .sc_services_item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_shine .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_shine .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_shine .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_services_shine .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_shine .sc_services_item .sc_services_item_price,
.sc_services_shine .sc_services_item .sc_services_item_price .amount,
.sc_services_shine .sc_services_item .sc_services_item_number {
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_services_shine .sc_services_item:hover .sc_services_item_price,
.sc_services_shine .sc_services_item:hover .sc_services_item_price .amount,
.sc_services_shine .sc_services_item:hover .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_shine .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_shine .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_shine .sc_services_item_price,
.sc_services_shine .sc_services_item_price .amount,
.sc_services_shine .sc_services_item_number {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_shine .sc_services_item_title,
.sc_services_shine .sc_services_item_title a {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_shine .sc_services_item:hover .sc_services_item_title,
.sc_services_shine .sc_services_item:hover .sc_services_item_title a,
.sc_services_shine .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_shine .sc_services_item_subtitle,
.sc_services_shine .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text) !important;
}
.sc_services_shine .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_shine .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_shine .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_shine .sc_services_item_content {
  color: var(--theme-color-alter_text) !important;
}
.sc_services_shine .sc_services_item_text {
  color: var(--theme-color-alter_dark_08) !important;
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}
.sc_services_shine .sc_services_item:hover .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_shine [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_shine .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_shine [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_shine .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_shine [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_shine .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_shine .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_shine .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_more_link,
.sc_services_shine .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content:before {
  background-color: var(--theme-color-text_link2);
}
.sc_services_shine.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_shine.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_shine.color_style_link2 .sc_services_item_title a:hover, .sc_services_shine.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_shine.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_shine.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_shine.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_shine.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content:before {
  background-color: var(--theme-color-text_link3);
}
.sc_services_shine.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_shine.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_shine.color_style_link3 .sc_services_item_title a:hover, .sc_services_shine.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_shine.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_shine.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_shine.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_shine.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_shine.color_style_dark .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-text_dark);
}
.sc_services_shine.color_style_dark .sc_services_item .sc_services_item_price, .sc_services_shine.color_style_dark .sc_services_item .sc_services_item_price .amount, .sc_services_shine.color_style_dark .sc_services_item .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_price, .sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_price .amount, .sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_services_shine.color_style_dark .sc_services_item_title, .sc_services_shine.color_style_dark .sc_services_item_title a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_title, .sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_title a, .sc_services_shine.color_style_dark .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item_subtitle, .sc_services_shine.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_shine.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_shine.color_style_dark .sc_services_item .sc_services_item_more_link {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_shine.color_style_dark .sc_services_item:hover .sc_services_item_more_link, .sc_services_shine.color_style_dark .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-inverse_hover) !important;
}

/* Style 'Motley'
+++++++++++++++++++++++ */
.elementor-section-full_width .sc_services_motley .sc_services_item:before {
  padding-top: 74%;
}
.sc_services_motley .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: left;
}
.sc_services_motley .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 95%;
  display: inline-block;
}
.sc_services_motley .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_motley .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  background-color: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  width: 100%;
  max-height: 100%;
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background-color: var(--theme-color-alter_bg_color);
  opacity: 1;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_link);
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image:hover .sc_services_item_content:before,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: .8;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price,
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount,
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title,
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle,
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_dark);
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image:hover .sc_services_item_content:before,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: .8;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price,
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount,
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_number,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title,
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle,
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_text,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image:before {
  display: none;
}
.sc_services_motley .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 3.5em 2.8em;
}
.sc_services_motley .sc_services_item_content_inner_wrap {
  position: relative;
  z-index: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_motley .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_wrap {
  -webkit-transform: translateY(50px);
  -ms-transform: translateY(50px);
  transform: translateY(50px);
  will-change: translate;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_services_motley .sc_services_item.with_more:not(.no_links):hover .sc_services_item_content_inner_wrap {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.sc_services_motley .sc_services_item_icon,
.sc_services_motley .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4.2em;
  line-height: 1em;
}
.sc_services_motley .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_motley .sc_services_item_number {
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
  font-weight: 400;
}
.sc_services_motley .sc_services_item_title {
  font-size: 1.944em;
  line-height: 1.3em;
  font-weight: 700;
  letter-spacing: -0.8px;
  margin: 0.8em 0 0;
}
.sc_services_motley .sc_services_item_featured_none .sc_services_item_title {
  margin-top: 0;
}
.sc_services_motley .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.25em;
}
.sc_services_motley .sc_services_item_title + .sc_services_item_text,
.sc_services_motley .sc_services_item_subtitle + .sc_services_item_text {
  margin-top: 0.5em;
}
.sc_services_motley .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  margin-top: 0.6em;
}
.sc_services_motley .sc_services_item_text {
  font-size: 15px;
  line-height: 1.65em;
  max-height: 4.8em;
  overflow: hidden;
}
.sc_services_motley .sc_services_item_content p {
  margin: 0;
}
.sc_services_motley .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_motley .sc_services_item .sc_services_item_button {
  margin-top: 1.2em;
}
.sc_services_motley .sc_services_item.with_more:not(.no_links) .sc_services_item_button {
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_services_motley .sc_services_item.with_more:not(.no_links):hover .sc_services_item_button {
  opacity: 1;
}
.sc_services_motley .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-alter_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_motley .sc_services_item:hover .sc_services_item_more_link,
.sc_services_motley .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_motley .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_motley .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_motley .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_motley .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_services_motley .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 13px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9B2';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_motley .sc_services_item .sc_services_item_price,
.sc_services_motley .sc_services_item .sc_services_item_price .amount,
.sc_services_motley .sc_services_item .sc_services_item_number {
  color: var(--theme-color-alter_dark) !important;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_services_motley .sc_services_item:hover .sc_services_item_price,
.sc_services_motley .sc_services_item:hover .sc_services_item_price .amount,
.sc_services_motley .sc_services_item:hover .sc_services_item_number {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_motley .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_motley .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_motley .sc_services_item_title,
.sc_services_motley .sc_services_item_title a {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_motley .sc_services_item:hover .sc_services_item_title,
.sc_services_motley .sc_services_item:hover .sc_services_item_title a,
.sc_services_motley .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_motley .sc_services_item_subtitle,
.sc_services_motley .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text) !important;
}
.sc_services_motley .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_motley .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_motley .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text) !important;
}
.sc_services_motley .sc_services_item_content {
  color: var(--theme-color-alter_text) !important;
}
.sc_services_motley .sc_services_item_text {
  color: var(--theme-color-alter_dark_08) !important;
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}
.sc_services_motley .sc_services_item:hover .sc_services_item_text {
  color: var(--theme-color-alter_dark_08) !important;
}
.sc_services_motley [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_motley .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_motley [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_motley .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_motley [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_motley .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_motley .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_motley .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_more_link,
.sc_services_motley .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content:before {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_services_motley.color_style_link2 .sc_services_item .sc_services_item_price, .sc_services_motley.color_style_link2 .sc_services_item .sc_services_item_price .amount, .sc_services_motley.color_style_link2 .sc_services_item .sc_services_item_number {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_motley.color_style_link2 .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-alter_link2);
}
.sc_services_motley.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_link2);
}
.sc_services_motley.color_style_link2 .sc_services_item_title a:hover, .sc_services_motley.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_link2);
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_dark);
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_number, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_text, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_motley.color_style_link2 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link, .sc_services_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_motley.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_motley.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_motley.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content:before {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_services_motley.color_style_link3 .sc_services_item .sc_services_item_price, .sc_services_motley.color_style_link3 .sc_services_item .sc_services_item_price .amount, .sc_services_motley.color_style_link3 .sc_services_item .sc_services_item_number {
  color: var(--theme-color-alter_dark) !important;
}
.sc_services_motley.color_style_link3 .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-alter_link3);
}
.sc_services_motley.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_link3);
}
.sc_services_motley.color_style_link3 .sc_services_item_title a:hover, .sc_services_motley.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_link3);
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_dark);
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_number, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_text, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_motley.color_style_link3 [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link, .sc_services_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_motley.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_motley.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_motley.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_motley.color_style_dark .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_dark);
}
.sc_services_motley.color_style_dark .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: .8;
}
.sc_services_motley.color_style_dark .sc_services_item .sc_services_item_price, .sc_services_motley.color_style_dark .sc_services_item .sc_services_item_price .amount, .sc_services_motley.color_style_dark .sc_services_item .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_price, .sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_price .amount, .sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item .sc_services_item_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_services_motley.color_style_dark .sc_services_item_title, .sc_services_motley.color_style_dark .sc_services_item_title a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_title, .sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_title a, .sc_services_motley.color_style_dark .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item_subtitle, .sc_services_motley.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_motley.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_motley.color_style_dark .sc_services_item .sc_services_item_more_link {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark .sc_services_item:hover .sc_services_item_more_link, .sc_services_motley.color_style_dark .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_link);
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content:before {
  background-color: var(--theme-color-alter_link2);
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_number, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_text, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_motley.color_style_dark [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link, .sc_services_motley.color_style_dark .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_more_link {
  color: var(--theme-color-inverse_link) !important;
}

/* Style 'Classic'
+++++++++++++++++++++++ */
.sc_services_classic .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: left;
}
.sc_services_classic .sc_services_item:hover {
  z-index: 10;
}
.sc_services_classic .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 95%;
  display: inline-block;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  opacity: .6;
}
.sc_services_classic .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content:after {
  content: ' ';
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: #1f242e;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  opacity: 0;
}
.sc_services_classic .sc_services_item.with_image:hover .sc_services_item_content:after {
  opacity: 0.9;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image:before {
  display: none;
}
.sc_services_classic .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_classic .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  background-color: #05080d;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
}
.sc_services_classic .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2em 2.2em;
}
.sc_services_classic .sc_services_item .sc_services_item_content_inner_top {
  -webkit-transform: translateY(-15px);
  -ms-transform: translateY(-15px);
  transform: translateY(-15px);
  opacity: 0;
  will-change: transform, opacity;
  -webkit-transition: -webkit-transform 0.3s ease-out, opacity 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out, opacity 0.3s ease-out;
  transition: transform 0.3s ease-out, opacity 0.3s ease-out;
}
.sc_services_classic .sc_services_item:hover .sc_services_item_content_inner_top {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  opacity: 1;
}
.sc_services_classic .sc_services_item_content_inner_bottom {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  width: 100%;
}
.sc_services_classic .sc_services_item_info_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_services_classic .sc_services_item_info_wrap + .sc_services_item_text {
  margin-top: 0.5em;
}
.sc_services_classic .sc_services_item_icon,
.sc_services_classic .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
}
.sc_services_classic .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_classic .sc_services_item_number {
  margin-top: 0;
  display: inline-block;
  font-size: 1.556em;
  line-height: 1em;
  font-weight: 500;
  letter-spacing: 0;
}
.sc_services_classic .sc_services_item_title_wrap {
  max-width: 75%;
}
.sc_services_classic .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.2em;
  font-weight: 700;
  margin: 0;
}
.sc_services_classic .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.4em;
}
.sc_services_classic .sc_services_item_text + .sc_services_item_title {
  margin-top: 0.25em;
}
.sc_services_classic .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  text-shadow: none;
  margin-bottom: 0.5em;
}
.sc_services_classic .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
  max-height: 4.8em;
  overflow: hidden;
}
.sc_services_classic .sc_services_item_content p {
  margin: 0;
}
.sc_services_classic .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_classic .sc_services_item .sc_services_item_more_link {
  padding: 1px;
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #ffffff;
  z-index: 1;
  overflow: hidden;
}
.sc_services_classic .sc_services_item:hover .sc_services_item_more_link,
.sc_services_classic .sc_services_item .sc_services_item_more_link:hover {
  color: #ffffff;
}
.sc_services_classic .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_classic .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_classic .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_classic .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  text-align: center;
  border: 1px solid #707070;
  width: 3.1em;
  height: 3.1em;
  line-height: 3.1em;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-box-sizing: content-box;
  -ms-box-sizing: content-box;
  box-sizing: content-box;
  -webkit-transition: border-color 0.3s ease;
  -ms-transition: border-color 0.3s ease;
  transition: border-color 0.3s ease;
}
.sc_services_classic .sc_services_item:hover .sc_services_item_more_link .link_icon {
  border-color: #ffffff;
}
.sc_services_classic .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_classic .sc_services_item_price,
.sc_services_classic .sc_services_item_price .amount,
.sc_services_classic .sc_services_item_icon,
.sc_services_classic .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_classic .sc_services_item_title,
.sc_services_classic .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_classic .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_classic .sc_services_item_subtitle,
.sc_services_classic .sc_services_item_subtitle a {
  color: #ffffff !important;
}
.sc_services_classic .sc_services_item_subtitle a:hover {
  color: #ffffff !important;
}
.sc_services_classic .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_classic .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8);
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2) !important;
}
.sc_services_classic.color_style_link2 .sc_services_item_title a:hover, .sc_services_classic.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_classic.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3) !important;
}
.sc_services_classic.color_style_link3 .sc_services_item_title a:hover, .sc_services_classic.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_classic [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_classic .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_classic [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_classic .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_classic [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_classic .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image:after {
  display: none;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_more_link .link_icon {
  border-color: var(--theme-color-bd_color) !important;
}
.sc_services_classic .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_more_link .link_icon {
  border-color: var(--theme-color-text_dark) !important;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
  opacity: 1;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_classic.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_classic.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_classic.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_classic.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_classic .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_classic.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_classic.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_classic.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}

/* Style 'Fashion'
+++++++++++++++++++++++ */
.sc_services_fashion .sc_services_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: relative;
  z-index: 1;
  text-align: left;
}
.sc_services_fashion .sc_services_item:before {
  content: ' ';
  width: 0;
  height: 0;
  padding-top: 151%;
  display: inline-block;
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content:before {
  content: ' ';
  position: absolute;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.3);
  -webkit-transition: opacity 0.3s ease-out, background-color 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out, background-color 0.3s ease-out;
  transition: opacity 0.3s ease-out, background-color 0.3s ease-out;
}
.sc_services_fashion .sc_services_item.with_image:hover .sc_services_item_content:before {
  opacity: .9;
  background: var(--theme-color-text_link);
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image:before {
  display: none;
}
.sc_services_fashion .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_fashion .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #05080d;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  width: 100%;
  height: 100%;
}
.sc_services_fashion .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2.3em 2.3em;
}
.sc_services_fashion .sc_services_item .sc_services_item_content_inner_top {
  margin-bottom: 20px;
  -webkit-transform: translateY(-15px);
  -ms-transform: translateY(-15px);
  transform: translateY(-15px);
  opacity: 0;
  will-change: transform, opacity;
  -webkit-transition: -webkit-transform 0.3s ease-out, opacity 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out, opacity 0.3s ease-out;
  transition: transform 0.3s ease-out, opacity 0.3s ease-out;
}
.sc_services_fashion .sc_services_item:hover .sc_services_item_content_inner_top {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  opacity: 1;
}
.sc_services_fashion .sc_services_item_content_inner_bottom {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  width: 100%;
}
.sc_services_fashion .sc_services_item.with_subtitle .sc_services_item_content_inner_bottom {
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  -webkit-transform: translateY(30px);
  -ms-transform: translateY(30px);
  transform: translateY(30px);
}
.sc_services_fashion .sc_services_item.with_subtitle:hover .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.sc_services_fashion .sc_services_item_icon,
.sc_services_fashion .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 2.8em;
  line-height: 1em;
}
.sc_services_fashion .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_fashion .sc_services_item_number {
  display: inline-block;
  font-size: 24px;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: 0;
}
.sc_services_fashion .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0;
}
.sc_services_fashion .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.3em;
}
.sc_services_fashion .sc_services_item_subtitle {
  opacity: 0;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_services_fashion .sc_services_item:hover .sc_services_item_subtitle {
  opacity: 1;
}
.sc_services_fashion .sc_services_item_price {
  font-size: 1.5em;
  font-weight: 500;
  text-shadow: none;
  margin-bottom: 0.5em;
}
.sc_services_fashion .sc_services_item_text {
  font-size: 15px;
  line-height: 1.5em;
}
.sc_services_fashion .sc_services_item_text + .sc_services_item_title,
.sc_services_fashion .sc_services_item_text + .sc_services_item_subtitle {
  margin-top: 0.3em;
}
.sc_services_fashion .sc_services_item_content p {
  margin: 0;
}
.sc_services_fashion .sc_services_item_content p + p {
  margin-top: 0.2em;
}
.sc_services_fashion .sc_services_item_price,
.sc_services_fashion .sc_services_item_price .amount,
.sc_services_fashion .sc_services_item_icon,
.sc_services_fashion .sc_services_item_number {
  color: #ffffff !important;
}
.sc_services_fashion .sc_services_item_title,
.sc_services_fashion .sc_services_item_title a {
  color: #ffffff !important;
}
.sc_services_fashion .sc_services_item_title a:hover {
  color: #ffffff !important;
}
.sc_services_fashion .sc_services_item_subtitle,
.sc_services_fashion .sc_services_item_subtitle a {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_fashion .sc_services_item_subtitle a:hover {
  color: rgba(255, 255, 255, 0.8) !important;
}
.sc_services_fashion .sc_services_item_content {
  color: #ffffff !important;
}
.sc_services_fashion .sc_services_item_text {
  color: rgba(255, 255, 255, 0.8);
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_text {
  color: var(--theme-color-text) !important;
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price,
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_price .amount {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion [class*="column-"] .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_fashion .slider-slide .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link_007);
}
.sc_services_fashion [class*="column-"]:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_fashion .slider-slide:nth-child(3n-1) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link2_007);
}
.sc_services_fashion [class*="column-"]:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image,
.sc_services_fashion .slider-slide:nth-child(3n) .sc_services_item.with_image .sc_services_item_content.without_image {
  background-color: var(--theme-color-text_link3_007);
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_icon,
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_number {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle,
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a,
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title,
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a,
.sc_services_fashion .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content:before {
  background: var(--theme-color-text_link2) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_price, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_title, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_title, .sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_title a, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_subtitle, .sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_subtitle a, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_link2 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_fashion.color_style_link2 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content:before {
  background: var(--theme-color-text_link3) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_price, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_title, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_title, .sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_title a, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_link) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_subtitle, .sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_subtitle a, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_link_08) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_title a, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_link3 .sc_services_item.with_image:hover .sc_services_item_content.without_image .sc_services_item_subtitle a, .sc_services_fashion.color_style_link3 .sc_services_item.with_image .sc_services_item_content.without_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image:hover .sc_services_item_content:before {
  background: var(--theme-color-text_dark) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_price, .sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_price .amount, .sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_number {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_icon {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_title, .sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_title a {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image:hover .sc_services_item_title, .sc_services_fashion.color_style_dark .sc_services_item.with_image:hover .sc_services_item_title a, .sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_hover) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_subtitle, .sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_subtitle a {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image:hover .sc_services_item_subtitle, .sc_services_fashion.color_style_dark .sc_services_item.with_image:hover .sc_services_item_subtitle a, .sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_hover_08) !important;
}
.sc_services_fashion.color_style_dark .sc_services_item.with_image .sc_services_item_text {
  color: var(--theme-color-inverse_hover_08) !important;
}

/* Style 'Backward' */
.sc_services_backward .trx_addons_columns_wrap.columns_padding_bottom:not(.columns_in_single_row) .sc_services_item {
  padding-bottom: var(--theme-var-grid_gap);
}
.sc_services_backward .sc_services_item {
  color: var(--theme-color-text);
  background-color: transparent;
  overflow: hidden;
}
.sc_services_backward .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_backward .sc_services_item_info {
  padding: 4px 0 0 0;
  text-align: left;
}
.sc_services_backward .sc_services_item_info + .sc_services_item_thumb {
  margin-top: 3.5em;
}
.sc_services_backward .sc_services_item_content {
  font-size: 15px;
  line-height: 1.868em;
  margin-top: 1.25em;
}
.sc_services_backward .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_backward .sc_services_item_thumb {
  margin-bottom: 0;
}
.sc_services_backward .sc_services_item_number {
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
  font-weight: 400;
  margin-top: 0.3em;
  color: var(--theme-color-text_dark);
}
.sc_services_backward .sc_services_item_icon,
.sc_services_backward .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4.4em;
  width: auto;
  height: auto;
  line-height: 1em;
  margin-top: 0.3em;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.sc_services_backward .sc_services_item_title {
  margin: 0;
  font-size: 2.333em;
  line-height: 1.214em;
}
.sc_services_backward .sc_services_item_subtitle,
.sc_services_backward .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_backward .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_backward .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_backward .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_backward .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_backward .sc_services_item .sc_services_item_title,
.sc_services_backward .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_services_backward .sc_services_item:hover .sc_services_item_title,
.sc_services_backward .sc_services_item:hover .sc_services_item_title a,
.sc_services_backward .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_backward .sc_services_item .sc_services_item_button {
  margin: 1.7em 0 0;
}
.sc_services_backward .sc_services_item .sc_services_item_more_link {
  position: relative;
  z-index: 1;
  display: inline-block;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  overflow: hidden;
}
.sc_services_backward .sc_services_item:hover .sc_services_item_more_link,
.sc_services_backward .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_backward .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_backward .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_backward .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 5px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_backward .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_backward .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_backward .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_backward .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_backward.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_backward.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_backward.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_backward.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_backward.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_backward.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_backward.color_style_link2 .sc_services_item_subtitle, .sc_services_backward.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_backward.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_backward.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_backward.color_style_link2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_backward.color_style_link3 .sc_services_item_subtitle, .sc_services_backward.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_backward.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_backward.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_backward.color_style_link3 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_backward.color_style_dark .sc_services_item_subtitle, .sc_services_backward.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_backward.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_backward.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_backward.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}

/* Style 'Accent' */
.sc_services_accent .sc_services_item {
  padding: 5.5em 3.2em 3.6em;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
  will-change: color, background-color;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease;
}
.sc_services_accent .sc_services_item:not(.with_image):hover {
  color: var(--theme-color-inverse_link_08);
  background-color: var(--theme-color-alter_link);
}
.sc_services_accent .sc_services_item.with_image {
  padding: 2.6em;
}
.sc_services_accent .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_accent .sc_services_item_content {
  font-size: 15px;
  line-height: 1.65em;
  margin-top: 0.8em;
  color: var(--theme-color-alter_text);
  will-change: color;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_content {
  color: var(--theme-color-inverse_link_08);
}
.sc_services_accent .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_accent .sc_services_item_number {
  display: inline-block;
  font-size: 4em;
  line-height: 1em;
  font-weight: 400;
  margin-top: 0;
  color: var(--theme-color-alter_dark);
  will-change: color;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_number {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent .sc_services_item_featured_left .sc_services_item_number,
.sc_services_accent .sc_services_item_featured_right .sc_services_item_number {
  font-size: 3em;
  line-height: 1em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: -5px;
  left: 0;
}
.sc_services_accent .sc_services_item_featured_left .sc_services_item_icon,
.sc_services_accent .sc_services_item_featured_right .sc_services_item_icon {
  font-size: 3.4em;
  margin-top: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
}
.sc_services_accent .sc_services_item_featured_right .sc_services_item_thumb,
.sc_services_accent .sc_services_item_featured_right .sc_services_item_icon,
.sc_services_accent .sc_services_item_featured_right .sc_services_item_pictogram,
.sc_services_accent .sc_services_item_featured_right .sc_services_item_number {
  left: auto;
  right: 0;
}
.sc_services_accent .sc_services_item_featured_right .sc_services_item_info {
  margin-right: 5em;
}
.sc_services_accent .sc_services_item_icon,
.sc_services_accent .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 5.1em;
  width: auto;
  height: auto;
  line-height: 1em;
  margin: 0;
}
.sc_services_accent .sc_services_item_number + .sc_services_item_info,
.sc_services_accent .sc_services_item_icon + .sc_services_item_info,
.sc_services_accent .sc_services_item_pictogram + .sc_services_item_info {
  margin-top: 2.4em;
}
.sc_services_accent .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.214em;
  margin: 0;
}
.sc_services_accent .sc_services_item_subtitle,
.sc_services_accent .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_accent .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_accent .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_accent .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_subtitle,
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_subtitle a,
.sc_services_accent .sc_services_item:not(.with_image) .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_accent .sc_services_item .sc_services_item_title,
.sc_services_accent .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_services_accent .sc_services_item:hover .sc_services_item_title,
.sc_services_accent .sc_services_item:hover .sc_services_item_title a,
.sc_services_accent .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_title,
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_title a,
.sc_services_accent .sc_services_item:not(.with_image) .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_services_accent .sc_services_item .sc_services_item_button {
  margin: 1.85em 0 0;
}
.sc_services_accent .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-alter_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_accent .sc_services_item:hover .sc_services_item_more_link,
.sc_services_accent .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-alter_dark);
}
.sc_services_accent .sc_services_item:not(.with_image):hover .sc_services_item_more_link,
.sc_services_accent .sc_services_item:not(.with_image) .sc_services_item_more_link:hover {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_accent .sc_services_item.with_image .sc_services_item_more_link .link_text {
  display: inline-block;
}
.sc_services_accent .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_accent .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_accent .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_accent .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_accent .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_accent .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_hover);
}
.sc_services_accent.color_style_link2 .sc_services_item:not(.with_image):hover {
  background-color: var(--theme-color-alter_link2);
}
.sc_services_accent.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-alter_link2);
}
.sc_services_accent.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent.color_style_link2 .sc_services_item_subtitle, .sc_services_accent.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_accent.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_accent.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_accent.color_style_link2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_accent.color_style_link2 .sc_services_item:not(.with_image):hover .sc_services_item_subtitle, .sc_services_accent.color_style_link2 .sc_services_item:not(.with_image):hover .sc_services_item_subtitle a, .sc_services_accent.color_style_link2 .sc_services_item:not(.with_image) .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent.color_style_link3 .sc_services_item:not(.with_image):hover {
  background-color: var(--theme-color-alter_link3);
}
.sc_services_accent.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-alter_link3);
}
.sc_services_accent.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_hover3);
}
.sc_services_accent.color_style_link3 .sc_services_item_subtitle, .sc_services_accent.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_accent.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_accent.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_accent.color_style_link3 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_accent.color_style_link3 .sc_services_item:not(.with_image):hover .sc_services_item_subtitle, .sc_services_accent.color_style_link3 .sc_services_item:not(.with_image):hover .sc_services_item_subtitle a, .sc_services_accent.color_style_link3 .sc_services_item:not(.with_image) .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover {
  color: var(--theme-color-inverse_hover_08);
  background-color: var(--theme-color-alter_dark);
}
.sc_services_accent.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-alter_dark);
}
.sc_services_accent.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-alter_link);
}
.sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_content {
  color: var(--theme-color-inverse_hover_08);
}
.sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_more_link, .sc_services_accent.color_style_dark .sc_services_item:not(.with_image) .sc_services_item_more_link:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_title, .sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_title a, .sc_services_accent.color_style_dark .sc_services_item:not(.with_image) .sc_services_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_services_accent.color_style_dark .sc_services_item_subtitle, .sc_services_accent.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-alter_text);
}
.sc_services_accent.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_accent.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_accent.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-alter_text);
}
.sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_subtitle, .sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_subtitle a, .sc_services_accent.color_style_dark .sc_services_item:not(.with_image) .sc_services_item_subtitle a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_services_accent.color_style_dark .sc_services_item:not(.with_image):hover .sc_services_item_number {
  color: var(--theme-color-inverse_hover);
}

/* Style 'Unusual' */
.sc_services_unusual .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_unusual .sc_services_item_thumb {
  margin-bottom: 1.6em;
}
.sc_services_unusual .sc_services_item_info {
  overflow: hidden;
}
.sc_services_unusual .sc_services_item_header {
  padding-bottom: 1.5em;
  position: relative;
  z-index: 1;
}
.sc_services_unusual .sc_services_item_header:before,
.sc_services_unusual .sc_services_item_header:after {
  content: '';
  display: block;
  height: 1px;
  width: 100%;
  position: absolute;
  z-index: 1;
  bottom: 0;
  left: 0;
  background-color: var(--theme-color-bd_color);
}
.sc_services_unusual .sc_services_item_header:after {
  width: 0;
  background-color: var(--theme-color-text_dark);
  will-change: width;
  -webkit-transition: width 0.4s ease;
  -ms-transition: width 0.4s ease;
  transition: width 0.4s ease;
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_header:after {
  width: 100%;
}
.sc_services_unusual .sc_services_item_title_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_services_unusual .sc_services_item_title_wrap + .sc_services_item_subtitle,
.sc_services_unusual .sc_services_item_title_wrap + .sc_services_item_price {
  margin-top: 0.5em;
}
.sc_services_unusual .sc_services_item_subtitle + .sc_services_item_price {
  margin-top: 0.5em;
}
.sc_services_unusual .sc_services_item_content {
  font-size: 15px;
  line-height: 1.65em;
  margin-top: 1em;
}
.sc_services_unusual .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_unusual .sc_services_item_title {
  margin: 0;
  font-size: 1.556em;
  line-height: 1.214em;
  -ms-text-overflow: ellipsis;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
}
.sc_services_unusual .sc_services_item_title,
.sc_services_unusual .sc_services_item_title a {
  width: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_services_unusual .sc_services_item_title_text {
  padding: 1px 0;
  width: 100%;
  display: inline-block;
  -ms-text-overflow: ellipsis;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
}
.sc_services_unusual .sc_services_item_price {
  font-size: 1.2em;
  line-height: 1.3em;
  font-weight: 500;
  color: var(--theme-color-text_dark);
}
.sc_services_unusual .sc_services_item_number {
  padding: 1px 0;
  margin-right: 0;
  display: inline-block;
  font-size: inherit;
  line-height: inherit;
  font-weight: inherit;
  color: inherit;
  opacity: 0;
  text-indent: -50px;
  white-space: nowrap;
  will-change: text-indent, opacity, margin-right;
  -webkit-transition: text-indent 0.4s ease-out, opacity 0.4s ease-out, margin-right 0.2s ease-out;
  -ms-transition: text-indent 0.4s ease-out, opacity 0.4s ease-out, margin-right 0.2s ease-out;
  transition: text-indent 0.4s ease-out, opacity 0.4s ease-out, margin-right 0.2s ease-out;
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_number {
  opacity: 1;
  text-indent: 0;
  margin-right: 0.45em;
}
.sc_services_unusual .sc_services_item_icon,
.sc_services_unusual .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  width: auto;
  height: auto;
  line-height: 1em;
}
.sc_services_unusual .sc_services_item_icon + .sc_services_item_info,
.sc_services_unusual .sc_services_item_pictogram + .sc_services_item_info {
  margin-top: 1.2em;
}
.sc_services_unusual .sc_services_item_subtitle,
.sc_services_unusual .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_unusual .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_unusual .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_unusual .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_unusual .sc_services_item .sc_services_item_title,
.sc_services_unusual .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_title,
.sc_services_unusual .sc_services_item:hover .sc_services_item_title a,
.sc_services_unusual .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual .sc_services_item .sc_services_item_button {
  width: 25%;
  text-align: right;
}
.sc_services_unusual .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_more_link,
.sc_services_unusual .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual .sc_services_item .sc_services_item_more_link .link_text {
  display: none;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_unusual .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_unusual .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2.3em;
  height: 2.3em;
  line-height: 2.3em;
  text-align: center;
  border: 1px solid var(--theme-color-bd_color);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  will-change: border-color;
  -webkit-transition: border-color 0.3s 0.1s ease-out;
  -ms-transition: border-color 0.3s 0.1s ease-out;
  transition: border-color 0.3s 0.1s ease-out;
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_more_link .link_icon {
  border-color: var(--theme-color-text_dark);
}
.sc_services_unusual .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_unusual .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_unusual .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_unusual.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_unusual.color_style_link2 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_unusual.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_unusual.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_unusual.color_style_link3 .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_unusual.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_unusual.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_unusual.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_unusual.color_style_dark .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}

/* Style 'Price' */
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_4 .sc_services_item_title_wrap,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_5 .sc_services_item_title_wrap,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_6 .sc_services_item_title_wrap {
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_4 .sc_services_item_title_wrap .sc_services_item_price_dots,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_5 .sc_services_item_title_wrap .sc_services_item_price_dots,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_6 .sc_services_item_title_wrap .sc_services_item_price_dots {
  margin: 10px 0 20px;
}
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_4 .sc_services_item_title_wrap .sc_services_item_title,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_5 .sc_services_item_title_wrap .sc_services_item_title,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_6 .sc_services_item_title_wrap .sc_services_item_title {
  min-width: inherit !important;
  max-width: none !important;
}
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_4 .sc_services_item_title_wrap .sc_services_item_price,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_5 .sc_services_item_title_wrap .sc_services_item_price,
.sc_services_price .trx_addons_columns_wrap .trx_addons_column-1_6 .sc_services_item_title_wrap .sc_services_item_price {
  max-width: none !important;
}
.sc_services_price .trx_addons_columns_wrap {
  margin-right: -50px;
}
.sc_services_price .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 50px;
}
.sc_services_price .trx_addons_columns_wrap.columns_padding_bottom:not(.columns_in_single_row) {
  margin-bottom: -50px;
}
.sc_services_price .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_services_price .trx_addons_columns_wrap > [class*="trx_addons_column-"].columns_padding_bottom {
  padding-bottom: 50px;
}
.sc_services_price .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_services_price .sc_services_item + .sc_services_item {
  margin-top: var(--theme-var-grid_gap);
}
.sc_services_price .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_price .sc_services_item_content {
  font-size: 15px;
  line-height: 1.65em;
  margin-top: 0.6em;
}
.sc_services_price .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_price .sc_services_item_number {
  display: inline-block;
  font-size: 3.5em;
  line-height: 1em;
  font-weight: 400;
  color: var(--theme-color-text_dark);
}
.sc_services_price .sc_services_item_icon,
.sc_services_price .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  width: auto;
  height: auto;
  line-height: 1em;
}
.sc_services_price .sc_services_item_number + .sc_services_item_info,
.sc_services_price .sc_services_item_icon + .sc_services_item_info,
.sc_services_price .sc_services_item_pictogram + .sc_services_item_info {
  margin-top: 1.5em;
}
.sc_services_price .sc_services_item_title_wrap {
  width: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_services_price .sc_item_columns_4 .sc_services_item_title_wrap,
.sc_services_price .sc_item_columns_5 .sc_services_item_title_wrap,
.sc_services_price .sc_item_columns_6 .sc_services_item_title_wrap {
  flex-wrap: wrap;
}
.sc_services_price .sc_item_columns_4 .sc_services_item_price_dots,
.sc_services_price .sc_item_columns_5 .sc_services_item_price_dots,
.sc_services_price .sc_item_columns_6 .sc_services_item_price_dots {
  margin: 0 0 10px;
}
.sc_services_price .sc_services_item_title_wrap + .sc_services_item_subtitle {
  margin-top: 0.6em;
}
.sc_services_price .sc_services_item_price_dots {
  display: block;
  margin: 0 20px;
  position: relative;
  z-index: 1;
  line-height: 1;
  width: 100%;
  min-width: 20px;
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_price .sc_services_item_price_dots:after {
  content: '. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .';
  display: block;
  font-size: 20px;
  color: var(--theme-color-text_light);
}
.sc_services_price .sc_services_item_price {
  font-size: 1.389em;
  line-height: 1em;
  font-weight: 500;
  color: var(--theme-color-text_link);
  flex-shrink: 0;
  max-width: 110px;
}
.sc_services_price .sc_services_item_title {
  font-size: 1.333em;
  line-height: 1.214em;
  margin: 0;
  flex-shrink: 0;
  min-width: 15%;
  max-width: 60%;
}
.sc_services_price .sc_services_item_subtitle,
.sc_services_price .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_price .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_price .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_price .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_price .sc_services_item .sc_services_item_title,
.sc_services_price .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_services_price .sc_services_item:hover .sc_services_item_title,
.sc_services_price .sc_services_item:hover .sc_services_item_title a,
.sc_services_price .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_price .sc_services_item .sc_services_item_button {
  margin: 1.1em 0 0;
}
.sc_services_price .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_price .sc_services_item:hover .sc_services_item_more_link,
.sc_services_price .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_price .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_price .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_price .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_price .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2.3em;
  height: 2.3em;
  line-height: 2.3em;
  text-align: center;
  border: 1px solid var(--theme-color-text_dark_02);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_services_price .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_price .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_price .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_price.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price.color_style_link2 .sc_services_item_price {
  color: var(--theme-color-text_link2);
}
.sc_services_price.color_style_link2 .sc_services_item_subtitle, .sc_services_price.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_price.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_price.color_style_link2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_price.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_price.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price.color_style_link3 .sc_services_item_price {
  color: var(--theme-color-text_link3);
}
.sc_services_price.color_style_link3 .sc_services_item_subtitle, .sc_services_price.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_price.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_price.color_style_link3 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_price.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_price.color_style_dark .sc_services_item_price {
  color: var(--theme-color-text_dark);
}
.sc_services_price.color_style_dark.sc_services_item_subtitle, .sc_services_price.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_price.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_price.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}

/* Style 'Price 2' */
.sc_services_price2 .trx_addons_columns_wrap.columns_padding_bottom:not(.columns_in_single_row) {
  margin-bottom: calc(-1 * var(--theme-var-grid_gap));
}
.sc_services_price2 .sc_services_item {
  position: relative;
  z-index: 1;
}
.sc_services_price2 .sc_services_item_divider {
  margin-top: 0.7em;
  display: block;
  position: relative;
  z-index: 1;
  width: 100%;
  line-height: 1;
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_price2 .sc_services_item_divider:after {
  content: '. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .';
  font-size: 20px;
  display: block;
  color: var(--theme-color-text_light);
}
.sc_services_price2 .sc_services_item + .sc_services_item {
  margin-top: var(--theme-var-grid_gap);
}
.sc_services_price2 .sc_services_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_services_price2 .sc_services_item_content {
  font-size: 15px;
  line-height: 1.65em;
  margin-top: 0.5em;
}
.sc_services_price2 .sc_services_item_content p:last-child {
  margin-bottom: 0;
}
.sc_services_price2 .sc_services_item_number {
  display: inline-block;
  font-size: 3.5em;
  line-height: 1em;
  font-weight: 400;
  color: var(--theme-color-text_dark);
}
.sc_services_price2 .sc_services_item_icon,
.sc_services_price2 .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 4em;
  width: auto;
  height: auto;
  line-height: 1em;
}
.sc_services_price2 .sc_services_item_number + .sc_services_item_info,
.sc_services_price2 .sc_services_item_icon + .sc_services_item_info,
.sc_services_price2 .sc_services_item_pictogram + .sc_services_item_info {
  margin-top: 1.5em;
}
.sc_services_price2 .sc_services_item_title_wrap {
  width: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_services_price2 .sc_services_item_title_wrap + .sc_services_item_subtitle {
  margin-top: 0.6em;
}
.sc_services_price2 .sc_services_item_price {
  font-size: 1.389em;
  line-height: 1em;
  font-weight: 400;
  color: var(--theme-color-text_link);
  flex-shrink: 0;
}
.sc_services_price2 .sc_services_item_title {
  font-size: 1.333em;
  line-height: 1.214em;
  margin: 0;
  flex-shrink: 0;
  max-width: 75%;
}
.sc_services_price2 .sc_services_item_subtitle,
.sc_services_price2 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price2 .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_price2 .sc_services_item:hover .sc_services_item_subtitle a,
.sc_services_price2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_price2 .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.45em;
}
.sc_services_price2 .sc_services_item .sc_services_item_title,
.sc_services_price2 .sc_services_item .sc_services_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_services_price2 .sc_services_item:hover .sc_services_item_title,
.sc_services_price2 .sc_services_item:hover .sc_services_item_title a,
.sc_services_price2 .sc_services_item .sc_services_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_price2 .sc_services_item .sc_services_item_button {
  margin: 1.1em 0 0;
}
.sc_services_price2 .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_services_price2 .sc_services_item:hover .sc_services_item_more_link,
.sc_services_price2 .sc_services_item .sc_services_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_services_price2 .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_price2 .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_price2 .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_price2 .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 2.3em;
  height: 2.3em;
  line-height: 2.3em;
  text-align: center;
  border: 1px solid var(--theme-color-text_dark_02);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_services_price2 .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_price2 .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_price2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price2.color_style_link2 .sc_services_item_icon {
  color: var(--theme-color-text_link2);
}
.sc_services_price2.color_style_link2 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price2.color_style_link2 .sc_services_item_price {
  color: var(--theme-color-text_link2);
}
.sc_services_price2.color_style_link2 .sc_services_item_subtitle, .sc_services_price2.color_style_link2 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price2.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_price2.color_style_link2 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_price2.color_style_link2 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_price2.color_style_link3 .sc_services_item_icon {
  color: var(--theme-color-text_link3);
}
.sc_services_price2.color_style_link3 .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price2.color_style_link3 .sc_services_item_price {
  color: var(--theme-color-text_link3);
}
.sc_services_price2.color_style_link3 .sc_services_item_subtitle, .sc_services_price2.color_style_link3 .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price2.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle, .sc_services_price2.color_style_link3 .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_price2.color_style_link3 .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}
.sc_services_price2.color_style_dark .sc_services_item_icon {
  color: var(--theme-color-text_dark);
}
.sc_services_price2.color_style_dark .sc_services_item:hover .sc_services_item_icon {
  color: var(--theme-color-text_link);
}
.sc_services_price2.color_style_dark .sc_services_item_price {
  color: var(--theme-color-text_dark);
}
.sc_services_price2.color_style_dark.sc_services_item_subtitle, .sc_services_price2.color_style_dark .sc_services_item_subtitle a {
  color: var(--theme-color-text);
}
.sc_services_price2.color_style_dark .sc_services_item:hover .sc_services_item_subtitle, .sc_services_price2.color_style_dark .sc_services_item:hover .sc_services_item_subtitle a, .sc_services_price2.color_style_dark .sc_services_item .sc_services_item_subtitle a:hover {
  color: var(--theme-color-text);
}

/* Style Panel
++++++++++++++++*/
.sc_services_panel .sc_services_content .sc_services_item + .sc_services_item {
  border: none;
  border-top: 1px solid rgba(255, 255, 255, 0.3);
}
.sc_services_panel .sc_services_columns_wrap {
  overflow: hidden;
}
.sc_services_panel .sc_services_columns_wrap [class*="trx_addons_column-"] {
  position: relative;
}
.sc_services_panel .sc_services_columns_wrap [class*="trx_addons_column-"] .sc_services_item {
  border: none !important;
}
.sc_services_panel .sc_services_columns_wrap [class*="trx_addons_column-"]:before {
  content: "";
  display: block;
  position: absolute;
  z-index: 1;
  top: -1px;
  right: 0;
  bottom: 0;
  left: -1px;
  border-top: 1px solid;
  border-left: 1px solid;
  border-color: rgba(255, 255, 255, 0.3);
}
.sc_services_panel .sc_services_columns_wrap [class*="trx_addons_column-"],
.sc_services_panel .sc_item_posts_container [class*="trx_addons_column-"] {
  padding: 0 !important;
}
.sc_services_panel .sc_services_item .sc_services_item_content {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  height: 100%;
  width: 100%;
  margin-top: 0;
}
.sc_services_panel .sc_services_item_content_inner {
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: stretch;
  -ms-flex-pack: stretch;
  justify-content: stretch;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 2em 2.2em 2.4em;
}
.sc_services_panel .sc_services_item .sc_services_item_content_inner_top {
  -webkit-transform: translateY(-15px);
  -ms-transform: translateY(-15px);
  transform: translateY(-15px);
  opacity: 0;
  will-change: transform, opacity;
  -webkit-transition: -webkit-transform 0.3s ease-out, opacity 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out, opacity 0.3s ease-out;
  transition: transform 0.3s ease-out, opacity 0.3s ease-out;
}
.sc_services_panel .sc_services_item:hover .sc_services_item_content_inner_top {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  opacity: 1;
}
.sc_services_panel .sc_services_item_content_inner_bottom {
  -webkit-flex-grow: 1;
  -ms-flex-grow: 1;
  flex-grow: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  position: relative;
  z-index: 1;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_panel .sc_services_item.with_more:not(.no_links) .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(50px);
  -ms-transform: translateY(50px);
  transform: translateY(50px);
  will-change: transform;
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
.sc_services_panel .sc_services_item.with_more:not(.no_links):hover .sc_services_item_content_inner_bottom {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.sc_services_panel .sc_services_item {
  position: relative;
  padding: 0;
}
.sc_services_panel .sc_services_item .sc_services_item_thumb {
  margin: 0;
  width: 4em;
  height: 4em;
  line-height: 4em;
  text-align: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  border: 1px solid rgba(255, 255, 255, 0.2);
}
.sc_services_panel .sc_services_item .sc_services_item_number {
  display: inline-block;
  font-size: 24px;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: 0;
  color: #fcfcfc;
}
.sc_services_panel .sc_services_item .sc_services_item_icon,
.sc_services_panel .sc_services_item .sc_services_item_pictogram {
  position: relative;
  display: inline-block;
  font-size: 2.8em;
  line-height: 1em;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  width: auto;
  height: auto;
}
.sc_services_panel .sc_services_item .sc_services_item_icon {
  color: #fcfcfc;
}
.sc_services_panel .sc_services_item .sc_services_item_icon.sc_icon_type_svg svg {
  width: 1em;
  height: 1em;
}
.sc_services_panel .sc_services_item .sc_services_item_title {
  font-size: 1.556em;
  line-height: 1.3em;
  font-weight: 700;
  margin: 0;
}
.sc_services_panel .sc_services_item .sc_services_item_title,
.sc_services_panel .sc_services_item .sc_services_item_title a {
  color: #fcfcfc;
}
.sc_services_panel .sc_services_item .sc_services_item_title + .sc_services_item_subtitle {
  margin-top: 0.3em;
}
.sc_services_panel .sc_services_item .sc_services_item_text {
  font-size: 15px;
  line-height: 1.65em;
  max-height: 4.8em;
  overflow: hidden;
  color: rgba(255, 255, 255, 0.8);
}
.sc_services_panel .sc_services_item .sc_services_item_text p:last-child {
  margin-bottom: 0;
}
.sc_services_panel .sc_services_item .sc_services_item_header + .sc_services_item_text {
  margin-top: 0.6em;
}
.sc_services_panel .sc_services_item .sc_services_item_price {
  font-size: 1.2em;
  font-weight: 500;
  text-shadow: none;
  margin-bottom: 0.5em;
}
.sc_services_panel .sc_services_item .sc_services_item_button {
  margin-top: 1em;
  opacity: 0;
  -webkit-transition: opacity 0.3s ease-out !important;
  -ms-transition: opacity 0.3s ease-out !important;
  transition: opacity 0.3s ease-out !important;
}
.sc_services_panel .sc_services_item:hover .sc_services_item_button {
  opacity: 1;
}
.sc_services_panel .sc_services_item .sc_services_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #fcfcfc;
  z-index: 1;
  overflow: hidden;
}
.sc_services_panel .sc_services_item .sc_services_item_more_link .link_text {
  display: inline-block;
  position: relative;
  margin-right: 0;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_services_panel .sc_services_item .sc_services_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_services_panel .sc_services_item .sc_services_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_services_panel .sc_services_item:hover .sc_services_item_more_link,
.sc_services_panel .sc_services_item .sc_services_item_more_link:hover {
  color: #fcfcfc;
}
.sc_services_panel .sc_services_item .sc_services_item_more_link .link_text, .sc_services_panel .sc_services_item:hover .sc_services_item_more_link .link_text,
.sc_services_panel .sc_services_item .sc_services_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 10px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_services_panel .sc_services_item .sc_services_item_thumb, .sc_services_panel .sc_services_item:hover .sc_services_item_thumb,
.sc_services_panel .sc_services_item .sc_services_item_pictogram, .sc_services_panel .sc_services_item:hover .sc_services_item_pictogram,
.sc_services_panel .sc_services_item .sc_services_item_icon, .sc_services_panel .sc_services_item:hover .sc_services_item_icon,
.sc_services_panel .sc_services_item .sc_services_item_number, .sc_services_panel .sc_services_item:hover .sc_services_item_number,
.sc_services_panel .sc_services_item .sc_services_item_title, .sc_services_panel .sc_services_item:hover .sc_services_item_title,
.sc_services_panel .sc_services_item .sc_services_item_subtitle, .sc_services_panel .sc_services_item:hover .sc_services_item_subtitle,
.sc_services_panel .sc_services_item .sc_services_item_meta, .sc_services_panel .sc_services_item:hover .sc_services_item_meta,
.sc_services_panel .sc_services_item .sc_services_item_content, .sc_services_panel .sc_services_item:hover .sc_services_item_content,
.sc_services_panel .sc_services_item .sc_services_item_button, .sc_services_panel .sc_services_item:hover .sc_services_item_button {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  -webkit-transition: none;
  -ms-transition: none;
  transition: none;
}
.sc_services_panel .sc_services_item:before {
  content: '';
  width: 0;
  height: 0;
  padding-top: 114%;
  display: inline-block;
}
.sc_services_panel .sc_services_item:after {
  content: '';
  display: block;
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  background-color: var(--theme-color-inverse_dark);
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
  opacity: 0;
}
.sc_services_panel .sc_services_panel_thumbs {
  background-color: #000;
}
.sc_services_panel .sc_services_panel_thumbs:before {
  background: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, black 100%);
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, black 100%);
  opacity: .7;
}
.sc_services_panel .sc_services_item_link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}

/* Socials */
.socials_wrap:not(.socials_type_list) .social_item .social_icon {
  background-color: var(--theme-color-alter_bg_color);
}

.socials_wrap:not(.socials_type_list) .social_item .social_icon,
.socials_wrap:not(.socials_type_list) .social_item .social_icon i {
  color: var(--theme-color-alter_dark);
}

.socials_wrap:not(.socials_type_list) .social_item:hover .social_icon {
  background-color: var(--theme-color-alter_bg_color);
}

.socials_wrap:not(.socials_type_list) .social_item:hover .social_icon,
.socials_wrap:not(.socials_type_list) .social_item:hover .social_icon i {
  color: var(--theme-color-alter_link);
}

[class*="scheme_"].sidebar .socials_wrap:not(.socials_type_list) .social_item .social_icon {
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-bg_color);
}

[class*="scheme_"].sidebar .socials_wrap:not(.socials_type_list) .social_item:hover .social_icon {
  color: var(--theme-color-alter_hover);
  background-color: var(--theme-color-bg_color);
}

[class*="scheme_"].sidebar .sc_layouts_row_type_compact .socials_wrap .social_item .social_icon,
[class*="scheme_"].footer_wrap .sc_layouts_row_type_compact .socials_wrap .social_item .social_icon {
  color: var(--theme-color-text_dark);
  background-color: transparent !important;
}

[class*="scheme_"].sidebar .sc_layouts_row_type_compact .socials_wrap .social_item:hover .social_icon,
[class*="scheme_"].footer_wrap .sc_layouts_row_type_compact .socials_wrap .social_item:hover .social_icon {
  color: var(--theme-color-text_link);
  background-color: transparent !important;
}

/* Super Title */
.sc_supertitle_no_icon {
  background-color: var(--theme-color-text_link);
}

/* Testimonials */
.sc_testimonials_item_content:before {
  content: '\e8b6';
  font-family: "fontello";
}

.sc_testimonials_item_author_subtitle {
  color: var(--theme-color-text_light);
}

.sc_testimonials_simple .sc_testimonials_item_author_data:before {
  background-color: var(--theme-color-text_light);
}

.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author_data {
  border-color: var(--theme-color-text_light);
}

.sc_testimonials_rating_stars_default,
.sc_testimonials_rating_stars_hover {
  color: var(--theme-color-text_hover);
}

[class*="scheme_"].sidebar .sc_testimonials_rating_stars_default,
[class*="scheme_"].sidebar .sc_testimonials_rating_stars_hover {
  color: var(--theme-color-alter_hover);
}

.color_style_link2 .sc_testimonials_rating_stars_default,
.color_style_link2 .sc_testimonials_rating_stars_hover {
  color: var(--theme-color-text_hover2);
}

.color_style_link3 .sc_testimonials_rating_stars_default,
.color_style_link3 .sc_testimonials_rating_stars_hover {
  color: var(--theme-color-text_hover3);
}

.color_style_dark .sc_testimonials_rating_stars_default,
.color_style_dark .sc_testimonials_rating_stars_hover {
  color: var(--theme-color-text_dark);
}

/* Utils
--------------------------------------------------- */
/* Loading mask */
.sc_blogger .trx_addons_loading {
  background-color: var(--theme-color-bg_color_02);
}

ul.sc_layouts_submenu .sc_blogger .trx_addons_loading {
  background-color: var(--theme-color-extra_bg_color_05);
}

/* Mouse helper */
.trx_addons_mouse_helper {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_active {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_active.trx_addons_mouse_helper_with_text {
  box-shadow: 0px 10px 30px 0px rgba(0, 0, 0, 0.02);
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_active.trx_addons_mouse_helper_with_text .trx_addons_mouse_helper_text {
  font-size: 12px;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 1.6px;
}

/* Scroll to top */
.menu_side_right .scroll_to_top_style_default {
  left: 2em;
  right: auto;
}

/* Scroll to top */
.trx_addons_scroll_to_top {
  z-index: 7999;
}

.scroll_to_top_style_default {
  width: 2.9em;
  height: 2.9em;
  line-height: 2.9em;
  text-align: center;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-inverse_hover);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-text_dark);
}
.scroll_to_top_style_default:before {
  position: relative;
  top: -1px;
  font-size: 11px;
  font-weight: 400;
  font-family: "fontello";
  content: '\EA08';
}
.scroll_to_top_style_default:hover {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Scroll to Top Style "Modern" */
.scroll_to_top_style_modern {
  bottom: 0;
  right: 60px;
  width: 110px;
  height: 30px;
  line-height: 20px;
  text-align: left;
  white-space: nowrap;
  -webkit-transform-origin: 100% 50%;
  -ms-transform-origin: 100% 50%;
  transform-origin: 100% 50%;
  -webkit-transform: rotate(-90deg) translate(100%, -50%);
  -ms-transform: rotate(-90deg) translate(100%, -50%);
  transform: rotate(-90deg) translate(100%, -50%);
  color: var(--theme-color-text_dark);
  background-color: transparent;
  border-color: transparent;
  will-change: color, opacity, bottom;
  -webkit-transition: color 0.3s ease, opacity 0.3s ease-out, bottom 0.3s ease-out;
  -ms-transition: color 0.3s ease, opacity 0.3s ease-out, bottom 0.3s ease-out;
  transition: color 0.3s ease, opacity 0.3s ease-out, bottom 0.3s ease-out;
  opacity: 0;
}
.scroll_to_top_style_modern:hover {
  color: var(--theme-color-text_link);
  background-color: transparent;
  border-color: transparent;
}
.scroll_to_top_style_modern.show {
  bottom: 60px;
  opacity: 1;
}
.scroll_to_top_style_modern .scroll_to_top_text,
.scroll_to_top_style_modern .scroll_to_top_icon {
  display: inline-block;
  vertical-align: middle;
}
.scroll_to_top_style_modern .scroll_to_top_text {
  font-size: 13px;
  font-weight: 700;
}
.scroll_to_top_style_modern .scroll_to_top_icon {
  margin-left: 15px;
  position: relative;
  overflow: hidden;
}
.scroll_to_top_style_modern .scroll_to_top_icon:after {
  margin-left: -15px;
  display: inline-block;
  vertical-align: middle;
  font-size: 12px;
  font-family: "fontello";
  content: '\E9E2';
  color: currentColor;
  will-change: margin-left;
  -webkit-transition: margin-left 0.3s ease-out;
  -ms-transition: margin-left 0.3s ease-out;
  transition: margin-left 0.3s ease-out;
}
.scroll_to_top_style_modern:hover .scroll_to_top_icon:after {
  margin-left: 0;
}

/* Scroll progress */
.scroll_progress_wrap .scroll_progress_status {
  background-color: var(--theme-color-text_dark);
}

/* Magnific Popup */
.mfp-content .sc_layouts_popup {
  max-height: 80vh;
  max-width: 80vw;
}

/* Login, Register and custom popups and panels from Layouts Builder */
.sc_layouts_panel {
  -webkit-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.03);
  -ms-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.03);
  box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.03);
}

.sc_layouts_popup {
  -webkit-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.15);
  -ms-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.15);
  box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.15);
}

.trx_addons_popup, [class*="scheme_"].trx_addons_popup,
.sc_layouts_popup, [class*="scheme_"].sc_layouts_popup,
.sc_layouts_panel_inner, [class*="scheme_"].sc_layouts_panel_inner {
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bd_color);
  color: var(--theme-color-alter_text);
}

.trx_addons_popup button.mfp-close {
  background-color: var(--theme-color-alter_bg_hover);
  border-color: var(--theme-color-alter_bd_hover);
  color: var(--theme-color-alter_text);
}

.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title {
  background-color: var(--theme-color-alter_bg_hover);
  border-color: var(--theme-color-alter_bd_hover);
}

.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title.ui-tabs-active {
  background-color: var(--theme-color-alter_bg_color);
  border-bottom-color: transparent;
}

.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title a,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title a > i {
  color: var(--theme-color-alter_text);
}

.trx_addons_popup li.trx_addons_tabs_title a:hover,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title a:hover > i {
  color: var(--theme-color-alter_link);
}

.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title[data-disabled="true"] a,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title[data-disabled="true"] a > i,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title[data-disabled="true"] a:hover,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title[data-disabled="true"] a:hover > i {
  color: var(--theme-color-alter_light);
}

.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title.ui-tabs-active a,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title.ui-tabs-active a > i,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title.ui-tabs-active a:hover,
.trx_addons_popup .trx_addons_tabs_titles li.trx_addons_tabs_title.ui-tabs-active a:hover > i {
  color: var(--theme-color-alter_dark);
}

/* Profiler */
.trx_addons_profiler {
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bd_hover);
}

.trx_addons_profiler_title {
  color: var(--theme-color-alter_dark);
}

.trx_addons_profiler table td,
.trx_addons_profiler table th {
  border-color: var(--theme-color-alter_bd_color);
}

.trx_addons_profiler table td {
  color: var(--theme-color-alter_text);
}

.trx_addons_profiler table th {
  background-color: var(--theme-color-alter_bg_hover);
  color: var(--theme-color-alter_dark);
}

/* Range slider */
.trx_addons_range_slider_label_min {
  color: var(--theme-color-alter_text);
}

.trx_addons_range_slider_label_max {
  color: var(--theme-color-alter_text);
}

div.ui-slider {
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bd_color);
}

div.ui-slider .ui-slider-handle {
  border-color: var(--theme-color-alter_bd_hover);
  background-color: var(--theme-color-alter_bg_hover);
}

div.ui-slider .ui-slider-range {
  background-color: var(--theme-color-alter_bg_hover);
}

/* Layout Title Link */
.sc_layouts_title_link {
  margin: 2.5em 0 0.5em;
}

/* Title */
h1.sc_item_title {
  line-height: 1em;
}

h2.sc_item_title {
  line-height: 1.021em;
}

h3.sc_item_title {
  line-height: 1.086em;
}

h4.sc_item_title {
  line-height: 1.214em;
}

h5.sc_item_title {
  line-height: 1.417em;
}

h6.sc_item_title {
  line-height: 1.474em;
}

.sc_item_title i {
  font-family: inherit;
}

.sc_item_subtitle {
  font-size: 12px;
  line-height: 18px;
  font-weight: 700;
  font-style: normal;
  text-transform: uppercase;
  letter-spacing: 1.6px;
}

.sc_item_subtitle_above {
  margin-bottom: 1.6em;
}

.sc_item_descr {
  margin-bottom: 0;
  font-size: 1rem;
}
.sc_item_descr p {
  margin: 0;
}
.sc_item_descr p + p {
  margin-top: 1em;
}

.sc_item_title.sc_item_title_style_accent i {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  justify-content: center;
  flex-direction: revert;
  align-items: center;
}

h1.sc_item_title_tag:not(.sc_align_center) {
  margin-left: -1px;
}

h1.sc_item_title_tag.sc_align_right:not(.sc_align_center) {
  margin-right: -1px;
}

h2.sc_item_title_tag:not(.sc_align_center) {
  margin-left: -1px;
}

h2.sc_item_title_tag.sc_align_right:not(.sc_align_center) {
  margin-right: -1px;
}

.slider-slide h1.sc_item_title_tag {
  margin-left: 0 !important;
}

h1.sc_item_title_tag + .sc_item_descr, h1.sc_item_title_tag + .sc_item_slider, h1.sc_item_title_tag + .sc_item_columns, h1.sc_item_title_tag + .sc_item_content {
  margin-top: 1.4em;
}

h2.sc_item_title_tag + .sc_item_descr, h2.sc_item_title_tag + .sc_item_slider, h2.sc_item_title_tag + .sc_item_columns, h2.sc_item_title_tag + .sc_item_content {
  margin-top: 1.35em;
}

.sc_title_default h5.sc_item_title_tag + .sc_title_subtitle {
  text-transform: none;
  font-size: 1rem;
  font-weight: 400;
  letter-spacing: 0;
  color: var(--theme-color-text);
}

.sc_item_title + .sc_item_button, .sc_item_title + .sc_item_button_image, .sc_item_subtitle + .sc_item_button, .sc_item_subtitle + .sc_item_button_image, .sc_item_descr + .sc_item_button, .sc_item_descr + .sc_item_button_image, .sc_item_content + .sc_item_button, .sc_item_content + .sc_item_button_image, .sc_item_slider + .sc_item_button, .sc_item_slider + .sc_item_button_image, .sc_item_columns + .sc_item_button, .sc_item_columns + .sc_item_button_image, .sc_item_pagination + .sc_item_button, .sc_item_pagination + .sc_item_button_image {
  margin-top: 2.1em;
}

.sc_item_subtitle.sc_item_title_style_shadow + .sc_item_title {
  position: relative;
  z-index: 1;
}

.sc_item_title_style_gradient .trx_addons_text_gradient,
.sc_item_title_style_gradient .sc_item_title_text {
  padding-bottom: 8px;
}

.sc_item_title[data-mouse-helper*="highlight"] {
  padding-bottom: 8px;
  margin-bottom: -8px;
}

.sc_item_title_style_gradient[data-mouse-helper*="highlight"] .trx_addons_text_gradient {
  opacity: 0.7;
}

.sc_title .sc_button.sc_button.sc_button_simple {
  overflow: visible;
}

/* accent */
.sc_title_accent .sc_button_wrap {
  position: relative;
  z-index: 1;
}

.sc_title_accent .sc_item_subtitle {
  position: relative;
  display: inline-block;
  padding-left: 70px;
}
.sc_title_accent .sc_item_subtitle:before {
  content: "";
  display: block;
  width: 50px;
  height: 2px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 0;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  top: 47%;
  margin-top: 1px;
  background-color: var(--theme-color-text_link);
}
.sc_title_accent .sc_item_subtitle.sc_align_center {
  padding: 10px 0 0 0;
  width: 100%;
}
.sc_title_accent .sc_item_subtitle.sc_align_center:before {
  left: auto;
  right: auto;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
}
.sc_title_accent .sc_item_subtitle.sc_align_right {
  padding: 0 70px 0 0;
  width: 100%;
}
.sc_title_accent .sc_item_subtitle.sc_align_right:before {
  left: auto;
  right: 0;
}

/* icon */
.sc_item_subtitle.sc_item_title_style_icon {
  position: relative;
}
.sc_item_subtitle.sc_item_title_style_icon:before {
  color: var(--theme-color-text_dark);
  content: '\e9a7';
  display: block;
  font-family: "fontello";
  font-size: 18px;
  margin-bottom: 20px;
  font-weight: 400;
}

/* icon bottom */
.sc_item_title_style_icon_bottom.sc_item_title {
  position: relative;
}
.sc_item_title_style_icon_bottom.sc_item_title:after {
  color: var(--theme-color-text_dark);
  content: '\e9a7';
  display: block;
  font-family: "fontello";
  font-size: 18px;
  line-height: 20px;
  margin-top: 30px;
  font-weight: 400;
}

/* Price */
.sc_price_item {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-alter_bd_color);
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}

.sc_price_item .sc_price_item_icon {
  color: var(--theme-color-alter_dark);
}

.sc_price_item .sc_price_item_label {
  font-size: 11px;
  font-weight: 500;
  letter-spacing: 1px;
  z-index: 9;
  background-color: var(--theme-color-extra_link);
  color: var(--theme-color-inverse_link);
}

.sc_price_item .sc_price_item_subtitle {
  color: var(--theme-color-alter_text);
}

.sc_price_item .sc_price_item_title,
.sc_price_item .sc_price_item_title a {
  color: var(--theme-color-alter_dark);
}

.sc_price_item .sc_price_item_price {
  color: var(--theme-color-alter_dark);
}

.sc_price_item .sc_price_item_description,
.sc_price_item .sc_price_item_details {
  color: var(--theme-color-alter_text);
}

.sc_price_slider .sc_price_item, .sc_price_columns_wrap .sc_price_item {
  height: auto;
}

/* Color style */
.sc_price_item .sc_price_item_link {
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-text_dark);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_item .sc_price_item_link:hover,
.sc_price_item .sc_price_item_link:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover);
  background-color: var(--theme-color-text_hover);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

.sc_price_item:hover .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

.sc_price_item.sc_price_active .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

/* Button color for Default and Metro - if selected Color style */
.color_style_link2 .sc_price_item .sc_price_item_link {
  color: var(--theme-color-inverse_link);
}
.color_style_link3 .sc_price_item .sc_price_item_link {
  color: var(--theme-color-inverse_link);
}

.sc_price .sc_price_item .sc_price_item_link.sc_price_item_link_over {
  opacity: 0 !important;
  background: none !important;
  margin: 0;
}

/* Price Default */
.sc_price_default .sc_price_item .sc_price_item_inner {
  padding: 0;
}
.sc_price_default .sc_price_item_image + .sc_price_item_info {
  padding-top: 40px;
  padding-bottom: 40px;
}
.sc_price_default .with_bg_color .sc_price_item_image + .sc_price_item_info {
  padding-top: 33px;
  padding-bottom: 20px;
}
.sc_price_default .sc_price_item.sc_price_active {
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  z-index: 9;
}
.sc_price_default .sc_price_item_info {
  padding: 4em 2em 4.4em;
}
.sc_price_default .sc_price_item_icon {
  margin-top: 3em;
}
.sc_price_default .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_default .sc_price_item_icon + .sc_price_item_info {
  padding-top: 1.5em;
  padding-bottom: 2.8em;
}
.sc_price_default .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_default .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_default .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_default .sc_price_item_description,
.sc_price_default .sc_price_item_details {
  font-size: 15px;
  line-height: 1.6em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.65em 0;
}
.sc_price_default .sc_price_item_description ul,
.sc_price_default .sc_price_item_details ul {
  padding: 0;
  list-style-type: none;
}
.sc_price_default .sc_price_item_description ul li + li,
.sc_price_default .sc_price_item_details ul li + li {
  margin-top: 8px;
}
.sc_price_default .sc_price_item_price {
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: 0;
}
.sc_price_default .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 700;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_default .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  color: var(--theme-color-alter_text);
}
.sc_price_default .sc_price_item_price + .sc_price_item_details {
  margin-top: 30px;
}
.sc_price_default .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_default .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_default .sc_price_item_subtitle + .sc_price_item_link,
.sc_price_default .sc_price_item_title + .sc_price_item_link,
.sc_price_default .sc_price_item_description + .sc_price_item_link,
.sc_price_default .sc_price_item_details + .sc_price_item_link {
  margin-top: 24px;
}
.sc_price_default .sc_price_item_default.with_image .sc_price_item_icon,
.sc_price_default .sc_price_item_default.with_image .sc_price_item_title,
.sc_price_default .sc_price_item_default.with_image .sc_price_item_price,
.sc_price_default .sc_price_item_default.with_image .sc_price_item_price_after,
.sc_price_default .sc_price_item_default.with_image .sc_price_item_subtitle {
  color: var(--theme-color-inverse_link);
}
.sc_price_default .sc_price_item_default.with_image .sc_price_item_description,
.sc_price_default .sc_price_item_default.with_image .sc_price_item_details {
  color: #ccc;
}

/* Price Light */
.sc_price_light .trx_addons_columns_wrap {
  margin: 0 !important;
}
.sc_price_light .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding: 0 !important;
  margin: 0 !important;
}
.sc_price_light .sc_price_item_inner,
.sc_price_light .sc_price_item.with_image .sc_price_item_inner {
  padding: 50px;
}
.sc_price_light .sc_price_item {
  z-index: 1;
}
.sc_price_light .sc_price_item.sc_price_active {
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  z-index: 9;
}
.sc_price_light .sc_price_item_info {
  padding: 0;
}
.sc_price_light .sc_price_item_image {
  margin-top: 1.5em;
}
.sc_price_light .sc_price_item_icon {
  margin-top: 1.5em;
}
.sc_price_light .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_light .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_light .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_light .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_light .sc_price_item_description,
.sc_price_light .sc_price_item_details {
  font-size: 15px;
  line-height: 1.6em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.65em 0;
}
.sc_price_light .sc_price_item_description ul,
.sc_price_light .sc_price_item_details ul {
  padding: 0;
  list-style-type: none;
}
.sc_price_light .sc_price_item_description ul li:after,
.sc_price_light .sc_price_item_details ul li:after {
  content: '\e9a2';
  font-family: "fontello";
  font-size: 11px;
  margin-left: 12px;
  position: relative;
  top: -1px;
  color: var(--theme-color-alter_link);
}
.sc_price_light .sc_price_item_description ul li + li,
.sc_price_light .sc_price_item_details ul li + li {
  margin-top: 8px;
}
.sc_price_light .sc_price_item_details {
  padding-top: 48px;
  border-top: 1px solid var(--theme-color-alter_bd_color);
}
.sc_price_light .sc_price_active .sc_price_item_price {
  color: var(--theme-color-alter_link);
}
.sc_price_light .sc_price_item_price {
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: 0;
  margin-top: 15px;
}
.sc_price_light .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 500;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_light .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  display: block;
  margin-top: 16px;
  color: var(--theme-color-alter_light);
}
.sc_price_light .sc_price_item_price + .sc_price_item_details {
  margin-top: 48px;
}
.sc_price_light .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_light .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_light .sc_price_item_subtitle + .sc_price_item_link,
.sc_price_light .sc_price_item_title + .sc_price_item_link,
.sc_price_light .sc_price_item_description + .sc_price_item_link,
.sc_price_light .sc_price_item_details + .sc_price_item_link {
  margin-top: 32px;
}
.sc_price_light .sc_price_item.sc_price_active .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_light .sc_price_item:hover .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_light .sc_price_item .sc_price_item_link {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_light .sc_price_item .sc_price_item_link:hover,
.sc_price_light .sc_price_item .sc_price_item_link:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover) !important;
  background-color: var(--theme-color-text_hover) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

/* Price Simple */
.sc_price_simple .sc_price_item_inner,
.sc_price_simple .sc_price_item.with_image .sc_price_item_inner {
  padding: 50px 30px;
}
.sc_price_simple .sc_price_item.sc_price_active {
  -webkit-box-shadow: 0 12px 40px rgba(0, 0, 0, 0.03);
  -ms-box-shadow: 0 12px 40px rgba(0, 0, 0, 0.03);
  box-shadow: 0 12px 40px rgba(0, 0, 0, 0.03);
  z-index: 9;
}
.sc_price_simple .sc_price_item_info {
  padding: 0;
}
.sc_price_simple .sc_price_item_image {
  margin-top: 1.5em;
}
.sc_price_simple .sc_price_item_icon {
  margin-top: 1.5em;
}
.sc_price_simple .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_simple .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_simple .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_simple .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_simple .sc_price_item_description,
.sc_price_simple .sc_price_item_details {
  font-size: 15px;
  line-height: 1.9em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.75em 0;
  color: var(--theme-color-alter_dark);
}
.sc_price_simple .sc_price_item_description ul,
.sc_price_simple .sc_price_item_details ul {
  padding: 0;
  list-style-type: none;
}
.sc_price_simple .sc_price_item_description ul li:after,
.sc_price_simple .sc_price_item_details ul li:after {
  content: '\e9a2';
  font-family: "fontello";
  font-size: 11px;
  margin-left: 12px;
  position: relative;
  top: -1px;
  color: var(--theme-color-alter_link);
}
.sc_price_simple .sc_price_item_description ul li + li,
.sc_price_simple .sc_price_item_details ul li + li {
  margin-top: 8px;
}
.sc_price_simple .sc_price_item_info > .sc_price_item_details:last-child {
  margin-bottom: 0;
}
.sc_price_simple .sc_price_active .sc_price_item_price {
  color: var(--theme-color-alter_link);
}
.sc_price_simple .sc_price_item_price {
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: -1.7px;
  margin-top: 26px;
}
.sc_price_simple .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 500;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_simple .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  letter-spacing: 0;
  display: block;
  margin-top: 13px;
  color: var(--theme-color-alter_light);
}
.sc_price_simple .sc_price_item_price + .sc_price_item_details {
  margin-top: 39px;
}
.sc_price_simple .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_simple .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_simple .sc_price_item_subtitle + .sc_price_item_link,
.sc_price_simple .sc_price_item_title + .sc_price_item_link,
.sc_price_simple .sc_price_item_description + .sc_price_item_link,
.sc_price_simple .sc_price_item_details + .sc_price_item_link {
  margin-top: 28px;
}
.sc_price_simple .sc_price_item.sc_price_active .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
}
.sc_price_simple .sc_price_item:hover .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
}
.sc_price_simple .sc_price_item .sc_price_item_link {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_simple .sc_price_item .sc_price_item_link:hover,
.sc_price_simple .sc_price_item .sc_price_item_link:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover) !important;
  background-color: var(--theme-color-text_hover) !important;
}

/* Price Simple + shadow */
.sc_price_simple_shadow .sc_price_item_inner,
.sc_price_simple_shadow .sc_price_item.with_image .sc_price_item_inner {
  padding: 60px 30px 70px;
}
.sc_price_simple_shadow .sc_price_item {
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  z-index: 1;
}
.sc_price_simple_shadow .sc_price_item.sc_price_active {
  z-index: 9;
}
.sc_price_simple_shadow .sc_price_item_info {
  padding: 0;
}
.sc_price_simple_shadow .sc_price_item_image {
  margin-top: 1.5em;
}
.sc_price_simple_shadow .sc_price_item_icon {
  margin-top: 1.5em;
}
.sc_price_simple_shadow .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_simple_shadow .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_simple_shadow .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_simple_shadow .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_simple_shadow .sc_price_item_description,
.sc_price_simple_shadow .sc_price_item_details {
  font-size: 15px;
  line-height: 1.6em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.65em 0;
  color: var(--theme-color-alter_text);
}
.sc_price_simple_shadow .sc_price_item_description ul,
.sc_price_simple_shadow .sc_price_item_details ul {
  padding: 0;
  list-style-type: none;
}
.sc_price_simple_shadow .sc_price_item_description ul li:after,
.sc_price_simple_shadow .sc_price_item_details ul li:after {
  content: '\e9a2';
  font-family: "fontello";
  font-size: 11px;
  margin-left: 12px;
  position: relative;
  top: -1px;
  color: var(--theme-color-alter_link);
}
.sc_price_simple_shadow .sc_price_item_description ul li + li,
.sc_price_simple_shadow .sc_price_item_details ul li + li {
  margin-top: 8px;
}
.sc_price_simple_shadow .sc_price_item_info > .sc_price_item_details:last-child {
  margin-bottom: 0;
}
.sc_price_simple_shadow .sc_price_item:hover .sc_price_item_price {
  color: var(--theme-color-alter_link);
}
.sc_price_simple_shadow .sc_price_item_price {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: 0;
  margin-top: 22px;
}
.sc_price_simple_shadow .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 500;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_simple_shadow .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  display: block;
  margin-top: 16px;
  color: var(--theme-color-alter_light);
}
.sc_price_simple_shadow .sc_price_item_price + .sc_price_item_details {
  margin-top: 39px;
}
.sc_price_simple_shadow .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_simple_shadow .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_simple_shadow .sc_price_item_subtitle + .sc_price_item_link,
.sc_price_simple_shadow .sc_price_item_title + .sc_price_item_link,
.sc_price_simple_shadow .sc_price_item_description + .sc_price_item_link,
.sc_price_simple_shadow .sc_price_item_details + .sc_price_item_link {
  margin-top: 28px;
}
.sc_price_simple_shadow .sc_price_item.sc_price_active .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_simple_shadow .sc_price_item:hover .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_simple_shadow .sc_price_item .sc_price_item_link {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_simple_shadow .sc_price_item .sc_price_item_link:hover,
.sc_price_simple_shadow .sc_price_item .sc_price_item_link:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover) !important;
  background-color: var(--theme-color-text_hover) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner {
  position: relative;
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner:before {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: var(--theme-color-text_link2);
  opacity: 0.9;
  z-index: -1;
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_description ul li:after,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_details ul li:after {
  color: var(--theme-color-inverse_link);
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_description,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_details,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_subtitle,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_price .sc_price_item_price_after,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_price,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_icon > span,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_info,
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_title {
  color: var(--theme-color-inverse_link);
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_link {
  color: var(--theme-color-inverse_link) !important;
  border-color: var(--theme-color-inverse_link) !important;
  background-color: transparent !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color) .sc_price_item_inner .sc_price_item_link:hover {
  color: var(--theme-color-inverse_dark) !important;
  border-color: var(--theme-color-inverse_link) !important;
  background-color: var(--theme-color-inverse_link) !important;
}
.sc_price_simple_shadow .sc_price_item.with_image:not(.with_bg_color):hover .sc_price_item_link {
  color: var(--theme-color-inverse_link) !important;
  border-color: var(--theme-color-inverse_link) !important;
  background-color: transparent !important;
}

/* Price Plain */
.sc_price_plain .sc_price_item_inner,
.sc_price_plain .sc_price_item.with_image .sc_price_item_inner {
  padding: 66px 60px 75px;
}
.sc_price_plain .sc_price_item {
  text-align: left;
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  z-index: 1;
}
.sc_price_plain .sc_price_item.sc_price_active {
  z-index: 9;
}
.sc_price_plain .sc_price_item_info {
  padding: 0;
}
.sc_price_plain .sc_price_item_image {
  margin-top: 1.5em;
}
.sc_price_plain .sc_price_item_icon {
  margin-top: 1.5em;
}
.sc_price_plain .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_plain .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_plain .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_plain .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_plain .sc_price_item_description,
.sc_price_plain .sc_price_item_details {
  font-size: 15px;
  line-height: 1.6em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.65em 0;
  color: var(--theme-color-alter_text);
}
.sc_price_plain .sc_price_item_description ul,
.sc_price_plain .sc_price_item_details ul {
  padding: 0;
  list-style-type: none;
}
.sc_price_plain .sc_price_item_description ul li:after,
.sc_price_plain .sc_price_item_details ul li:after {
  content: '\e9a2';
  font-family: "fontello";
  font-size: 11px;
  margin-left: 12px;
  position: relative;
  top: -1px;
  color: var(--theme-color-alter_link);
}
.sc_price_plain .sc_price_item_description ul li + li,
.sc_price_plain .sc_price_item_details ul li + li {
  margin-top: 8px;
}
.sc_price_plain .sc_price_item_info > .sc_price_item_details:last-child {
  margin-bottom: 0;
}
.sc_price_plain .sc_price_item:hover .sc_price_item_price {
  color: var(--theme-color-alter_link);
}
.sc_price_plain .sc_price_item_price {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: 0;
  margin-top: 22px;
}
.sc_price_plain .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 500;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_plain .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  display: block;
  margin-top: 16px;
  color: var(--theme-color-alter_light);
}
.sc_price_plain .sc_price_item_price + .sc_price_item_details {
  margin-top: 30px;
}
.sc_price_plain .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_plain .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_plain .sc_price_item_subtitle + .sc_price_item_link,
.sc_price_plain .sc_price_item_title + .sc_price_item_link,
.sc_price_plain .sc_price_item_description + .sc_price_item_link,
.sc_price_plain .sc_price_item_details + .sc_price_item_link {
  margin-top: 24px;
}
.sc_price_plain .sc_price_item.sc_price_active .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_plain .sc_price_item:not(.sc_price_active) .sc_price_item_link {
  padding-left: 40px;
  padding-right: 40px;
}
.sc_price_plain .sc_price_item .sc_price_item_link {
  padding-left: 57px;
  padding-right: 57px;
}
.sc_price_plain .sc_price_item:hover .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_plain .sc_price_item .sc_price_item_link {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_plain .sc_price_item .sc_price_item_link:hover,
.sc_price_plain .sc_price_item .sc_price_item_link:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover) !important;
  background-color: var(--theme-color-text_hover) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_plain .sc_price_item_label {
  width: 12em;
  height: 2em;
  line-height: 2em;
  left: auto;
  right: -3em;
  top: 2em;
  -webkit-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}

/* Price Focus */
.sc_price_focus .trx_addons_columns_wrap {
  margin: 0 !important;
}
.sc_price_focus .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding: 0 !important;
  margin: 0 !important;
}
.sc_price_focus .sc_price_item_inner,
.sc_price_focus .sc_price_item.with_image .sc_price_item_inner {
  padding: 55px 45px 64px;
}
.sc_price_focus .sc_price_item {
  -webkit-box-shadow: 0 23px 40px rgba(0, 0, 0, 0.03);
  -ms-box-shadow: 0 23px 40px rgba(0, 0, 0, 0.03);
  box-shadow: 0 23px 40px rgba(0, 0, 0, 0.03);
  z-index: 1;
}
.sc_price_focus .sc_price_item.sc_price_active {
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  z-index: 9;
  margin: -20px 0 0;
  padding: 20px 0;
}
.sc_price_focus .sc_price_item_info {
  padding: 0;
}
.sc_price_focus .sc_price_item_image {
  margin-top: 1.5em;
}
.sc_price_focus .sc_price_item_icon {
  margin-top: 1.5em;
}
.sc_price_focus .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_focus .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_focus .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_focus .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_focus .sc_price_item_description,
.sc_price_focus .sc_price_item_details {
  font-size: 15px;
  line-height: 1.6em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.65em 0;
}
.sc_price_focus .sc_price_item_description ul,
.sc_price_focus .sc_price_item_details ul {
  padding: 0;
  list-style-type: none;
}
.sc_price_focus .sc_price_item_description ul li:after,
.sc_price_focus .sc_price_item_details ul li:after {
  content: '\e9a2';
  font-family: "fontello";
  font-size: 11px;
  margin-left: 12px;
  position: relative;
  top: -1px;
  color: var(--theme-color-alter_link);
}
.sc_price_focus .sc_price_item_description ul li + li,
.sc_price_focus .sc_price_item_details ul li + li {
  margin-top: 8px;
}
.sc_price_focus .sc_price_item_details {
  padding-top: 40px;
  border-top: 1px solid var(--theme-color-alter_bd_color);
}
.sc_price_focus .sc_price_item_price {
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: 0;
  margin-top: 15px;
}
.sc_price_focus .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 500;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_focus .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  display: block;
  margin-top: 20px;
  color: var(--theme-color-alter_light);
}
.sc_price_focus .sc_price_item_price + .sc_price_item_details {
  margin-top: 46px;
}
.sc_price_focus .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_focus .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_focus .sc_price_item_subtitle + .sc_price_item_link,
.sc_price_focus .sc_price_item_title + .sc_price_item_link,
.sc_price_focus .sc_price_item_description + .sc_price_item_link,
.sc_price_focus .sc_price_item_details + .sc_price_item_link {
  margin-top: 32px;
}
.sc_price_focus .sc_price_item.sc_price_active .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_focus .sc_price_item:hover .sc_price_item_link {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link) !important;
  background-color: var(--theme-color-text_link) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_price_focus .sc_price_item .sc_price_item_link {
  color: var(--theme-color-text_dark);
  border-color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  padding-left: 56px;
  padding-right: 56px;
}
.sc_price_focus .sc_price_item .sc_price_item_link:hover,
.sc_price_focus .sc_price_item .sc_price_item_link:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover) !important;
  background-color: var(--theme-color-text_hover) !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}

/* Price Metro */
.sc_price_metro .sc_price_item_inner,
.sc_price_metro .sc_price_item.with_image .sc_price_item_inner {
  padding: 65px 50px;
}
.sc_price_metro .sc_price_item {
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.04);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.04);
  z-index: 1;
}
.sc_price_metro .sc_price_item.sc_price_active {
  -webkit-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  box-shadow: 0 23px 90px rgba(0, 0, 0, 0.05);
  z-index: 9;
}
.sc_price_metro .sc_price_item_info {
  padding: 0;
}
.sc_price_metro .sc_price_item_image {
  margin-top: 1.5em;
}
.sc_price_metro .sc_price_item_icon {
  margin-top: 1.5em;
}
.sc_price_metro .sc_price_item_icon > span {
  font-size: 3em;
  line-height: 1em;
  font-weight: 400;
}
.sc_price_metro .sc_price_item_title {
  font-size: 21px;
  line-height: 1.25em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_metro .sc_price_item_title + .sc_price_item_subtitle {
  margin-top: 8px;
}
.sc_price_metro .sc_price_item_subtitle {
  font-size: 15px;
  line-height: 1.3em;
  font-weight: 400;
  text-transform: none;
  letter-spacing: 0;
  margin: 0;
}
.sc_price_metro .sc_price_item_description,
.sc_price_metro .sc_price_item_details {
  font-size: 15px;
  line-height: 1.6em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  margin: 0.65em 0;
}
.sc_price_metro .sc_price_item_description ul,
.sc_price_metro .sc_price_item_details ul {
  padding: 0 0 0 17px;
  list-style-type: none;
}
.sc_price_metro .sc_price_item_description ul li,
.sc_price_metro .sc_price_item_details ul li {
  position: relative;
}
.sc_price_metro .sc_price_item_description ul li:before,
.sc_price_metro .sc_price_item_details ul li:before {
  font-size: 22px;
  left: -16px;
  top: 1px;
  display: inline-block !important;
  position: absolute;
  content: '\e83c';
  font-family: "fontello";
  color: var(--theme-color-alter_dark);
}
.sc_price_metro .sc_price_item_description ul li + li,
.sc_price_metro .sc_price_item_details ul li + li {
  margin-top: 10px;
}
.sc_price_metro .sc_price_item_details {
  padding-top: 44px;
  text-align: left;
  border-top: 1px solid var(--theme-color-alter_bd_color);
}
.sc_price_metro .sc_price_item_price {
  font-size: 52px;
  line-height: 1;
  font-weight: 700;
  letter-spacing: 0;
  margin-top: 15px;
}
.sc_price_metro .sc_price_item_price .sc_price_item_price_before {
  font-size: 20px;
  font-weight: 500;
  vertical-align: top;
  line-height: 2.4em;
  margin-right: 4px;
}
.sc_price_metro .sc_price_item_price .sc_price_item_price_after {
  font-size: 15px;
  font-weight: 400;
  display: block;
  margin-top: 20px;
  color: var(--theme-color-alter_light);
}
.sc_price_metro .sc_price_item_price + .sc_price_item_details {
  margin-top: 38px;
}
.sc_price_metro .sc_price_item_subtitle + .sc_price_item_price,
.sc_price_metro .sc_price_item_title + .sc_price_item_price {
  margin-top: 20px;
}
.sc_price_metro .sc_price_item .sc_price_item_link {
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
  -webkit-border-radius: 0 !important;
  -ms-border-radius: 0 !important;
  border-radius: 0 !important;
  width: 100%;
  display: block;
  border: none;
  margin: 0;
  padding-left: 10px;
  padding-right: 10px;
}
.sc_price_metro .sc_price_item .sc_price_item_link:not(.sc_price_item_link_over) {
  margin-top: -20px;
  z-index: 9;
  position: relative;
}

/* Countdown */
.sc_countdown.sc_countdown_circle,
.sc_countdown.sc_countdown_default {
  margin-bottom: 0 !important;
}

.sc_countdown_default .sc_countdown_digits span {
  color: var(--theme-color-text_dark);
  background: none;
}

.sc_countdown_circle .sc_countdown_digits {
  color: var(--theme-color-alter_link);
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bg_color);
}

/* default */
.sc_countdown_default .sc_countdown_inner {
  display: inline-flex;
  flex-direction: row;
  align-items: center;
  align-content: center;
  flex-wrap: wrap;
}
.sc_countdown_default .sc_countdown_inner .sc_countdown_item {
  float: none;
}
.sc_countdown_default .sc_countdown_digits,
.sc_countdown_default .sc_countdown_separator {
  line-height: 1em;
  height: 1em;
  font-weight: 700;
  overflow: visible;
  float: none;
  color: var(--theme-color-text_dark);
}
.sc_countdown_default .sc_countdown_separator {
  font-weight: 400;
  margin: 0 40px;
  font-size: 50px;
}
.sc_countdown_default.aligncenter .sc_countdown_separator {
  margin: 0 48px;
}
.sc_countdown_default .sc_countdown_digits {
  margin-bottom: 21px;
  font-size: 57px;
}
.sc_countdown_default .sc_countdown_digits span {
  width: 0.7em;
}
.sc_countdown_default .sc_countdown_digits span + span {
  margin: 0;
}
.sc_countdown_default .sc_countdown_label {
  font-weight: 700;
  font-size: 17px;
  line-height: 1.1em;
  padding-top: 22px;
  position: relative;
  display: inline-block;
  color: var(--theme-color-text_dark);
}
.sc_countdown_default .sc_countdown_label:before {
  width: 31px;
  height: 2px;
  background: var(--theme-color-text_dark_02);
  content: "";
  display: block;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
}

/* Messages */
form .trx_addons_message_box {
  min-width: auto;
  max-width: 90%;
}

.trx_addons_message_box {
  width: auto;
  min-width: auto;
  max-width: 50%;
  border: none;
  padding: 18px 30px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 5px;
  -ms-border-radius: 5px;
  border-radius: 5px;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  position: fixed;
  z-index: 999999;
  top: auto;
  left: auto;
  bottom: 30px;
  right: 30px;
  font-size: 14px;
  line-height: 18px;
  font-weight: 400;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  color: #000000;
  background-color: #ffffff;
  -webkit-box-shadow: 0 3px 21px rgba(0, 0, 0, 0.05) !important;
  -ms-box-shadow: 0 3px 21px rgba(0, 0, 0, 0.05) !important;
  box-shadow: 0 3px 21px rgba(0, 0, 0, 0.05) !important;
}
.trx_addons_message_box.trx_addons_message_box_error {
  color: #ffffff;
  background-color: #FF5B4A;
}
.trx_addons_message_box.trx_addons_message_box_success {
  color: #ffffff;
  background-color: #89D86B;
}
.trx_addons_message_box .trx_addons_error_item {
  margin-bottom: 0 !important;
}
.fixed_blocks_sticky .sidebar .trx_addons_message_box, [class*="elementor"].animated .trx_addons_message_box {
  position: relative;
  bottom: auto;
  right: auto;
  max-width: 100%;
  margin-top: 1.5em;
}

/* Skills */
.sc_skills_digits .sc_skills_unit {
  margin-left: 0;
}

.sc_skills_counter_style_odometer .sc_skills_digits .sc_skills_digit {
  padding: 0 1px;
}

.sc_skills_counter_modern.sc_skills_counter_style_odometer .sc_skills_digits .sc_skills_digit,
.extra-size-skills .sc_skills_counter_style_odometer .sc_skills_digits .sc_skills_digit {
  padding: 0 3px;
}

/* counters */
.sc_skills_counter.sc_align_left {
  text-align: left;
}

.sc_skills_counter.sc_align_center {
  text-align: center;
}

.sc_skills_counter.sc_align_right {
  text-align: right;
}

.sc_skills_counter .sc_skills_icon {
  font-size: 4em;
  line-height: 1em;
  text-align: inherit;
  color: var(--theme-color-text_light);
}

.sc_skills_counter .sc_skills_total {
  font-size: 4.444em;
  line-height: 1em;
  font-weight: 700;
  text-align: inherit;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter .sc_skills_item_title {
  font-size: 15px;
  line-height: 1.65em;
  font-weight: 400;
  font-style: normal;
  text-align: inherit;
}

.sc_skills_counter .sc_skills_image + .sc_skills_total,
.sc_skills_counter .sc_skills_icon + .sc_skills_total {
  margin-top: 0.3em;
}

.sc_skills_counter .sc_skills_item + .sc_skills_item_title {
  margin-top: 0.8em;
}

.sc_skills_counter .sc_skills_column + .sc_skills_column:before {
  background-color: var(--theme-color-bd_color);
}

/* counters alter */
.sc_skills_counter_alter.sc_align_left {
  text-align: left;
}

.sc_skills_counter_alter.sc_align_center {
  text-align: center;
}

.sc_skills_counter_alter.sc_align_right {
  text-align: right;
}

.sc_skills_counter_alter.with_divider .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  content: '';
  display: block;
  height: 45px;
  width: 1px;
  position: absolute;
  right: 0;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-text_dark_05);
}

.sc_skills_counter_alter.with_divider .sc_skills_columns .sc_skills_column:last-child .sc_skills_item_wrap:after {
  display: none;
}

.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_2:nth-child(2n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_3:nth-child(3n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_4:nth-child(4n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_5:nth-child(5n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_6:nth-child(6n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_7:nth-child(7n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_8:nth-child(8n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_9:nth-child(9n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_10:nth-child(10n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_11:nth-child(11n) .sc_skills_item_wrap:after,
.sc_skills_counter_alter.with_divider .sc_skills_columns .trx_addons_column-1_12:nth-child(12n) .sc_skills_item_wrap:after {
  display: none;
}

.sc_skills_counter_alter.with_divider.sc_align_left .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  right: 0;
}

.sc_skills_counter_alter.with_divider.sc_align_center .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  right: calc(-1 * var(--theme-var-grid_gap) / 2);
}

.sc_skills_counter_alter.with_divider.sc_align_right .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  right: calc(-1 * var(--theme-var-grid_gap));
}

.sc_skills_counter_alter .sc_skills_item_wrap {
  max-width: none;
  position: relative;
}

.sc_skills_counter_alter .sc_skills_icon {
  position: relative;
  display: block;
  font-size: 3.8em;
  line-height: 1em;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_alter .sc_skills_total {
  display: block;
  margin: 0;
  font-size: 3.611em;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: -0.1px;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_alter .sc_skills_item_title {
  font-size: 19px;
  line-height: 1.65em;
  font-weight: 700;
  font-style: normal;
  text-transform: none;
  letter-spacing: 0;
  color: var(--theme-color-text_dark_08);
}

.sc_skills_counter_alter .sc_skills_image + .sc_skills_total,
.sc_skills_counter_alter .sc_skills_icon + .sc_skills_total {
  margin-top: 0.25em;
}

.sc_skills_counter_alter .sc_skills_item + .sc_skills_item_title {
  margin-top: 0.45em;
}

/* counters alter */
.sc_skills_counter_alter .sc_skills_image {
  text-align: center;
}
.sc_skills_counter_alter .sc_skills_image img {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  width: 4.83em;
  height: 4.83em;
  line-height: 4.83em;
  text-align: center;
}

.sc_skills_counter_alter .sc_skills_icon.sc_skills_char {
  text-align: center;
}
.sc_skills_counter_alter .sc_skills_icon.sc_skills_char:before, .sc_skills_counter_alter .sc_skills_icon.sc_skills_char > span:before {
  content: attr(data-char);
  font-weight: 700;
}
.sc_skills_counter_alter .sc_skills_icon.sc_skills_char > span {
  display: inline-block;
  opacity: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: auto;
}

.sc_skills_counter_alter .sc_icon_type_svg svg,
.sc_skills_counter_alter .sc_icon_type_svg object {
  width: 1em;
  height: 1em;
}

/* counters extra */
.sc_skills_counter_extra .sc_skills_item_wrap {
  max-width: none;
}

.sc_skills_counter_extra.sc_align_left {
  text-align: left;
}

.sc_skills_counter_extra.sc_align_center {
  text-align: center;
}

.sc_skills_counter_extra.sc_align_right {
  text-align: right;
}

.sc_skills_counter_extra .sc_skills_icon {
  position: relative;
  display: block;
  font-size: 3.8em;
  line-height: 1em;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_extra .sc_skills_total {
  display: block;
  margin: 0;
  font-size: 3.611em;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: -0.1px;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_extra .sc_skills_item_title {
  font-size: 19px;
  line-height: 1.4em;
  font-weight: 700;
  font-style: normal;
  text-transform: none;
  letter-spacing: 0;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_extra .sc_skills_image + .sc_skills_total,
.sc_skills_counter_extra .sc_skills_icon + .sc_skills_total {
  margin-top: 0.1em;
}

.sc_skills_counter_extra .sc_skills_item_title + .sc_skills_item {
  margin-top: 0.5em;
}

.sc_skills_counter_extra.sc_skills_counter_style_odometer.sc_align_left .sc_skills_digits {
  margin-left: -5px;
}

.sc_skills_counter_extra .sc_skills_image {
  text-align: center;
}
.sc_skills_counter_extra .sc_skills_image img {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  width: 4.83em;
  height: 4.83em;
  line-height: 4.83em;
  text-align: center;
}

.sc_skills_counter_extra .sc_skills_icon.sc_skills_char {
  text-align: center;
}
.sc_skills_counter_extra .sc_skills_icon.sc_skills_char:before, .sc_skills_counter_extra .sc_skills_icon.sc_skills_char > span:before {
  content: attr(data-char);
  font-weight: 700;
}
.sc_skills_counter_extra .sc_skills_icon.sc_skills_char > span {
  display: inline-block;
  opacity: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: auto;
}

.sc_skills_counter_extra .sc_icon_type_svg svg,
.sc_skills_counter_extra .sc_icon_type_svg object {
  width: 1em;
  height: 1em;
}

/* counters modern */
.sc_skills_counter_modern .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  content: '';
  display: block;
  height: 60px;
  width: 1px;
  position: absolute;
  right: calc( -1 * var(--theme-var-grid_gap) / 2 );
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-bd_color);
}

.sc_skills_counter_modern .sc_skills_columns .sc_skills_column:last-child .sc_skills_item_wrap:after {
  display: none;
}

.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_2:nth-child(2n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_3:nth-child(3n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_4:nth-child(4n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_5:nth-child(5n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_6:nth-child(6n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_7:nth-child(7n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_8:nth-child(8n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_9:nth-child(9n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_10:nth-child(10n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_11:nth-child(11n) .sc_skills_item_wrap:after,
.sc_skills_counter_modern .sc_skills_columns .trx_addons_column-1_12:nth-child(12n) .sc_skills_item_wrap:after {
  display: none;
}

.sc_skills_counter_modern .sc_skills_item_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  min-height: 8.2em;
  max-width: none;
  position: relative;
}

.sc_skills_counter_modern .sc_skills_icon {
  margin-bottom: 0.2em;
  position: relative;
  z-index: 1;
  display: block;
  text-align: center;
  font-size: 3.8em;
  line-height: 1em;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_modern .sc_skills_total {
  display: block;
  position: absolute;
  top: calc(50% - 15px);
  left: 50%;
  z-index: 0;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  text-align: center;
  margin: 0;
  font-size: 12em;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: 0;
  color: var(--theme-color-text_dark_003);
  opacity: 1;
  white-space: nowrap;
}

.sc_skills_counter_modern .sc_skills_item_title {
  position: relative;
  z-index: 1;
  text-align: center;
  font-size: 24px;
  line-height: 1.4em;
  font-weight: 700;
  font-style: normal;
  text-transform: none;
  letter-spacing: 0;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_modern .sc_skills_image {
  margin-bottom: 0.2em;
  text-align: center;
}
.sc_skills_counter_modern .sc_skills_image img {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  width: 4.83em;
  height: 4.83em;
  line-height: 4.83em;
  text-align: center;
}

.sc_skills_counter_modern .sc_skills_icon.sc_skills_char {
  text-align: center;
}
.sc_skills_counter_modern .sc_skills_icon.sc_skills_char:before, .sc_skills_counter_modern .sc_skills_icon.sc_skills_char > span:before {
  content: attr(data-char);
  font-weight: 700;
}
.sc_skills_counter_modern .sc_skills_icon.sc_skills_char > span {
  display: inline-block;
  opacity: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: auto;
}

.sc_skills_counter_modern .sc_icon_type_svg svg,
.sc_skills_counter_modern .sc_icon_type_svg object {
  width: 1em;
  height: 1em;
}

/* counters simple */
.sc_skills_counter_simple.with_divider .sc_skills_item_wrap {
  min-height: 123px;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

.sc_skills_counter_simple.with_divider .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  content: '';
  display: block;
  height: 123px;
  width: 1px;
  position: absolute;
  right: 0;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-bd_color);
}

.sc_skills_counter_simple.with_divider .sc_skills_columns .sc_skills_column:last-child .sc_skills_item_wrap:after {
  display: none;
}

.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_2:nth-child(2n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_3:nth-child(3n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_4:nth-child(4n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_5:nth-child(5n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_6:nth-child(6n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_7:nth-child(7n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_8:nth-child(8n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_9:nth-child(9n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_10:nth-child(10n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_11:nth-child(11n) .sc_skills_item_wrap:after,
.sc_skills_counter_simple.with_divider .sc_skills_columns .trx_addons_column-1_12:nth-child(12n) .sc_skills_item_wrap:after {
  display: none;
}

.sc_skills_counter_simple.with_divider.sc_align_left .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  right: 0;
}

.sc_skills_counter_simple.with_divider.sc_align_center .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  right: calc(-1 * var(--theme-var-grid_gap) / 2);
}

.sc_skills_counter_simple.with_divider.sc_align_right .sc_skills_columns .sc_skills_column .sc_skills_item_wrap:after {
  right: calc(-1 * var(--theme-var-grid_gap));
}

.sc_skills_counter_simple .sc_skills_item_wrap {
  max-width: none;
  position: relative;
}

.sc_skills_counter_simple.sc_align_left {
  text-align: left;
}

.sc_skills_counter_simple.sc_align_center {
  text-align: center;
}

.sc_skills_counter_simple.sc_align_right {
  text-align: right;
}

.sc_skills_counter_simple .sc_skills_icon {
  font-size: 4em;
  line-height: 1em;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_simple .sc_skills_total {
  font-size: 3.611em;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: -0.3px;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_simple .sc_skills_item_title {
  font-size: 19px;
  line-height: 1.65em;
  font-weight: 400;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
  color: var(--theme-color-text_dark);
}

.sc_skills_counter_simple .sc_skills_image + .sc_skills_total,
.sc_skills_counter_simple .sc_skills_icon + .sc_skills_total {
  margin-top: 0.25em;
}

.sc_skills_counter_simple .sc_skills_item + .sc_skills_item_title {
  margin-top: 0.25em;
}

.sc_skills_counter_simple .sc_skills_image {
  text-align: center;
}
.sc_skills_counter_simple .sc_skills_image img {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  width: 4.83em;
  height: 4.83em;
  line-height: 4.83em;
  text-align: center;
}

.sc_skills_counter_simple .sc_skills_icon.sc_skills_char {
  text-align: center;
}
.sc_skills_counter_simple .sc_skills_icon.sc_skills_char:before, .sc_skills_counter_simple .sc_skills_icon.sc_skills_char > span:before {
  content: attr(data-char);
  font-weight: 700;
}
.sc_skills_counter_simple .sc_skills_icon.sc_skills_char > span {
  display: inline-block;
  opacity: 0;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: auto;
}

.sc_skills_counter_simple .sc_icon_type_svg svg,
.sc_skills_counter_simple .sc_icon_type_svg object {
  width: 1em;
  height: 1em;
}

/* pie */
.sc_skills_pie.sc_skills_compact_off .sc_skills_item_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.sc_skills_pie.sc_skills_compact_off .sc_skills_item {
  position: relative;
  width: 50%;
  line-height: 0;
}

.sc_skills_pie.sc_skills_compact_off .sc_skills_total {
  font-size: 1.556em;
  line-height: 1.1em;
  font-weight: 700;
  color: var(--theme-color-text_dark);
}

.sc_skills_pie.sc_skills_compact_off .sc_skills_item_title {
  margin-top: 0;
  width: 50%;
  font-size: 1.333em;
  line-height: 1.18em;
  font-weight: 700;
  letter-spacing: 0;
  text-align: left;
  color: var(--theme-color-text_dark);
}

.sc_skills_pie.sc_skills_compact_off .sc_skills_item + .sc_skills_item_title {
  margin-left: 0.7em;
}

/* Icons */
.footer_wrap .sc_icons .sc_icons_icon + .sc_icons_item_title {
  margin-top: 1em;
  margin-bottom: 2em;
}

[class*="scheme_"].footer_wrap .sc_icons .sc_icons_item_title {
  color: var(--theme-color-text_dark);
}

[class*="scheme_"].footer_wrap .sc_icons .sc_icons_item_description {
  color: var(--theme-color-text);
}

.sc_icons .sc_icons_item + .sc_icons_item {
  margin-top: var(--theme-var-grid_gap);
}
.sc_icons .sc_icons_item_linked:hover .sc_icons_icon > span {
  -webkit-animation: none;
  -ms-animation: none;
  animation: none;
}
.sc_icons .sc_icons_item_linked .sc_icons_icon > svg,
.sc_icons .sc_icons_item_linked:hover .sc_icons_icon > svg {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.sc_icons .sc_icons_image img {
  max-width: 100%;
}
.sc_icons .sc_icons_item_linked .sc_icons_image img,
.sc_icons .sc_icons_item_linked:hover .sc_icons_image img {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.sc_icons .sc_icons_item .sc_icons_item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_icons .sc_icons_item .sc_icons_item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, opacity;
}
.sc_icons .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}
.sc_icons .sc_icons_item .sc_icons_item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_icons .sc_icons_item .sc_icons_item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_icons .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.7em;
}
.sc_icons .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  display: block;
  position: absolute;
  z-index: -1;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
.sc_icons .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons .sc_icons_icon:before,
.sc_icons .sc_icons_icon > span:before {
  font-size: 4em;
}
.sc_icons .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons .sc_icons_icon + .sc_icons_item_details,
.sc_icons .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.3em;
}
.sc_icons.color_style_link2 .sc_icons_icon {
  color: var(--theme-color-text_link2);
}
.sc_icons.color_style_link3 .sc_icons_icon {
  color: var(--theme-color-text_link3);
}
.sc_icons.color_style_dark .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons .sc_icons_item_title,
.sc_icons .sc_icons_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_icons .sc_icons_item_title[style*="color"] > a:active,
.sc_icons .sc_icons_item_title[style*="color"] > a:hover,
.sc_icons .sc_icons_item_title[style*="color"] > a {
  color: inherit !important;
}
.sc_icons .sc_icons_item:hover .sc_icons_item_title,
.sc_icons .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons.color_style_link2 .sc_icons_item:hover .sc_icons_item_title, .sc_icons.color_style_link2 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons.color_style_link3 .sc_icons_item:hover .sc_icons_item_title, .sc_icons.color_style_link3 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons.color_style_dark .sc_icons_item:hover .sc_icons_item_title, .sc_icons.color_style_dark .sc_icons_item:hover .sc_icons_item_title a, .sc_icons.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-text_dark);
}

.sc_icons_item_title {
  font-size: 1.556em;
  line-height: 1.2em;
  font-weight: 700;
  text-transform: none;
  letter-spacing: 0;
}

.sc_icons_item_description {
  font-size: 15px;
  line-height: 1.6em;
  color: var(--theme-color-text);
}

.sc_icons_item_description ul {
  list-style-type: none;
  padding-left: 0;
}

.sc_icons_item_description ul > li {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  position: relative;
  margin: 8px 0;
}

.sc_align_center .sc_icons_item_description ul > li {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

.sc_align_right .sc_icons_item_description ul > li {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

.sc_icons_item_description ul > li:first-child {
  margin-top: 0;
}

.sc_icons_item_description ul > li:last-child {
  margin-bottom: 0;
}

.sc_icons_item_description ul > li:before {
  margin-right: 10px;
  font-size: 27px;
  line-height: inherit;
  font-weight: 400;
  font-family: "fontello";
  content: '\E83C';
  display: inline-block;
  position: relative;
  z-index: 1;
  color: var(--theme-color-text_link);
}

.sc_icons_item_description p:last-child,
.sc_icons_item_description ul:last-child {
  margin-bottom: 0;
}

.sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.9em;
}

.sc_icons_item_description a {
  color: var(--theme-color-text);
}

.sc_icons_item_description a:hover {
  color: var(--theme-color-text_dark);
}

.sc_icon_type_svg svg,
.sc_icon_type_svg object {
  width: 4em;
  height: 4em;
  vertical-align: middle;
}

.sc_icons_size_small .sc_icons_icon:before,
.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 3em;
}

.sc_icons_size_small .sc_icon_type_svg svg,
.sc_icons_size_small .sc_icon_type_svg object {
  width: 3em;
  height: 3em;
}

.sc_icons_size_large .sc_icons_icon:before,
.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5em;
}

.sc_icons_size_large .sc_icon_type_svg svg,
.sc_icons_size_large .sc_icon_type_svg object {
  width: 5em;
  height: 5em;
}

/* Style 'Partners' */
.sc_icons_partners .sc_icons_item .sc_icons_image img {
  max-width: 37%;
  opacity: .2;
  will-change: opacity;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_icons_partners .sc_icons_item:hover .sc_icons_image img {
  opacity: 1;
}
.sc_icons_partners .sc_icons_item_linked:hover .sc_icons_image img {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}

/* Style 'Modern' */
.sc_icons_modern .sc_icons_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_icons_modern .sc_icons_item + .sc_icons_item {
  margin-top: 42px;
}
.sc_icons_modern .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_modern.sc_icons_size_large .sc_icons_item_details, .sc_icons_modern.sc_icons_size_small .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_modern.sc_align_right .sc_icons_item_details, .sc_icons_modern.sc_icons_size_small.sc_align_right .sc_icons_item_details, .sc_icons_modern.sc_icons_size_large.sc_align_right .sc_icons_item_details {
  padding-left: 0;
  padding-right: 0;
}
.sc_icons_modern .sc_icons_icon, .sc_icons_modern .sc_icons_image {
  position: relative;
  top: auto;
  left: auto;
  display: inline-block;
  width: 6.4em;
  height: 6.4em;
  line-height: 6.4em;
  text-align: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  flex: 0 0 auto;
}
.sc_icons_modern .sc_icons_image {
  max-width: none;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  background-color: var(--theme-color-alter_bg_hover);
}
.sc_icons_modern .sc_icons_image img {
  max-width: 60%;
  height: auto;
}
.sc_icons_modern .sc_icons_icon > span {
  display: inline-block;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: 6.4em;
  height: 6.4em;
  line-height: 6.4em;
  text-align: center;
}
.sc_icons_modern .sc_icons_icon:before,
.sc_icons_modern .sc_icons_icon > span:before {
  line-height: inherit !important;
}
.sc_icons_modern .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.9em;
}
.sc_icons_modern .sc_icons_icon + .sc_icons_item_details,
.sc_icons_modern .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.8em;
  margin-top: 1em;
}
.sc_icons_modern.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_modern.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 1.8em;
}
.sc_icons_modern.sc_icons_size_small .sc_icons_icon, .sc_icons_modern.sc_icons_size_small .sc_icons_image {
  width: 5.4em;
  height: 5.4em;
  line-height: 5.4em;
  text-align: center;
  max-width: 5.4em;
}
.sc_icons_modern.sc_icons_size_small .sc_icons_icon > span {
  width: 5.4em;
  height: 5.4em;
  line-height: 5.4em;
  text-align: center;
}
.sc_icons_modern.sc_icons_size_small .sc_icons_icon:before, .sc_icons_modern.sc_icons_size_small .sc_icons_icon > span:before {
  line-height: inherit !important;
}
.sc_icons_modern.sc_icons_size_large .sc_icons_icon, .sc_icons_modern.sc_icons_size_large .sc_icons_image {
  width: 7.4em;
  height: 7.4em;
  line-height: 7.4em;
  text-align: center;
}
.sc_icons_modern.sc_icons_size_large .sc_icons_icon > span {
  width: 7.4em;
  height: 7.4em;
  line-height: 7.4em;
  text-align: center;
}
.sc_icons_modern.sc_icons_size_large .sc_icons_icon:before, .sc_icons_modern.sc_icons_size_large .sc_icons_icon > span:before {
  line-height: inherit !important;
}
.sc_icons_modern.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_modern.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_modern.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_modern.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_modern.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_modern .sc_icons_icon {
  color: var(--theme-color-alter_link);
  background-color: var(--theme-color-alter_bg_hover);
}
.sc_icons_modern.color_style_link2 .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_modern.color_style_link3 .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_modern.color_style_dark .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}

/* Style 'Light' */
.sc_icons_light .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_light .sc_icons_icon + .sc_icons_item_details,
.sc_icons_light .sc_icons_image + .sc_icons_item_details {
  margin-top: 2em;
}
.sc_icons_light .sc_icons_icon:before,
.sc_icons_light .sc_icons_icon > span:before {
  font-size: 3.2em;
}
.sc_icons_light .sc_icon_type_svg svg,
.sc_icons_light .sc_icon_type_svg object {
  width: 3.2em;
  height: 3.2em;
}
.sc_icons_light.sc_icons_size_small .sc_icons_icon:before, .sc_icons_light.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.2em;
}
.sc_icons_light.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_light.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.2em;
  height: 2.2em;
}
.sc_icons_light.sc_icons_size_large .sc_icons_icon:before, .sc_icons_light.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4.4em;
}
.sc_icons_light.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_light.sc_icons_size_large .sc_icon_type_svg object {
  width: 4.4em;
  height: 4.4em;
}

/* Style 'Alter' */
.sc_icons_alter .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.2em;
}
.sc_icons_alter .sc_icons_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_icons_alter .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_alter .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.2em;
}
.sc_icons_alter .sc_icons_item_details {
  padding-right: 3%;
  padding-left: 0;
  min-height: auto;
}
.sc_icons_alter.sc_icons_size_large .sc_icons_item_details, .sc_icons_alter.sc_icons_size_small .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_alter.sc_align_center .sc_icons_item_details, .sc_icons_alter.sc_icons_size_small.sc_align_center .sc_icons_item_details, .sc_icons_alter.sc_icons_size_large.sc_align_center .sc_icons_item_details {
  padding-right: 0;
}
.sc_icons_alter.sc_align_right .sc_icons_item_details, .sc_icons_alter.sc_icons_size_small.sc_align_right .sc_icons_item_details, .sc_icons_alter.sc_icons_size_large.sc_align_right .sc_icons_item_details {
  padding-left: 3%;
  padding-right: 0;
}
.sc_icons_alter .sc_icons_image img {
  max-width: 3.6em;
}
.sc_icons_alter .sc_icons_icon + .sc_icons_item_details,
.sc_icons_alter .sc_icons_image + .sc_icons_item_details {
  margin-left: 1em;
  margin-top: 1.2em;
}
.sc_icons_alter.sc_icons_size_small .sc_icons_icon + .sc_icons_item_details, .sc_icons_alter.sc_icons_size_small .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.4em;
  margin-top: 0;
}
.sc_icons_alter.sc_icons_size_large .sc_icons_icon + .sc_icons_item_details, .sc_icons_alter.sc_icons_size_large .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.8em;
  margin-top: 1.3em;
}
.sc_icons_alter .sc_icons_item_title, .sc_icons_alter.sc_icons_size_small .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_alter.sc_icons_size_large .sc_icons_item_title {
  font-size: 1.556em;
  line-height: 1.2em;
}
.sc_icons_alter.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_alter.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 1em;
}
.sc_icons_alter.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_alter.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_alter.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_alter.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_alter.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_alter .sc_icons_icon:before,
.sc_icons_alter .sc_icons_icon > span:before {
  font-size: 3.6em;
}
.sc_icons_alter .sc_icon_type_svg svg,
.sc_icons_alter .sc_icon_type_svg object {
  width: 3.6em;
  height: 3.6em;
}
.sc_icons_alter.sc_icons_size_small .sc_icons_icon:before, .sc_icons_alter.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.8em;
}
.sc_icons_alter.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_alter.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.8em;
  height: 2.8em;
}
.sc_icons_alter.sc_icons_size_large .sc_icons_icon:before, .sc_icons_alter.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4em;
}
.sc_icons_alter.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_alter.sc_icons_size_large .sc_icon_type_svg object {
  width: 4em;
  height: 4em;
}

/* Style 'Hover' */
.sc_icons_hover {
  margin: 0 -1.6em;
}
.sc_icons_hover .sc_icons_item {
  padding: 2em 1.6em;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  -webkit-transition: box-shadow 0.3s ease-out;
  -ms-transition: box-shadow 0.3s ease-out;
  transition: box-shadow 0.3s ease-out;
  will-change: box-shadow;
}
.sc_icons_hover .sc_icons_item:hover {
  -webkit-box-shadow: 0 3px 30px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 30px rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 30px rgba(0, 0, 0, 0.05);
}
.sc_icons_hover .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.8em;
}
.sc_icons_hover .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_hover .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.4em;
}
.sc_icons_hover .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_hover .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_hover.sc_icons_size_large .sc_icons_item_details, .sc_icons_hover.sc_icons_size_small .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_hover.sc_align_right .sc_icons_item_details, .sc_icons_hover.sc_icons_size_small.sc_align_right .sc_icons_item_details, .sc_icons_hover.sc_icons_size_large.sc_align_right .sc_icons_item_details {
  padding-left: 0;
  padding-right: 0;
}
.sc_icons_hover .sc_icons_image img {
  max-width: 4.2em;
}
.sc_icons_hover .sc_icons_icon + .sc_icons_item_details,
.sc_icons_hover .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.8em;
  margin-top: 0.7em;
}
.sc_icons_hover.sc_icons_size_small .sc_icons_icon + .sc_icons_item_details, .sc_icons_hover.sc_icons_size_small .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.4em;
  margin-top: 0;
}
.sc_icons_hover.sc_icons_size_small .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_hover.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_hover.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 1.8em;
}
.sc_icons_hover.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_hover.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_hover.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_hover.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_hover.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_hover .sc_icons_icon:before,
.sc_icons_hover .sc_icons_icon > span:before {
  font-size: 4.2em;
}
.sc_icons_hover .sc_icon_type_svg svg,
.sc_icons_hover .sc_icon_type_svg object {
  width: 4.2em;
  height: 4.2em;
}
.sc_icons_hover.sc_icons_size_small .sc_icons_icon:before, .sc_icons_hover.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.8em;
}
.sc_icons_hover.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_hover.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.8em;
  height: 2.8em;
}
.sc_icons_hover.sc_icons_size_large .sc_icons_icon:before, .sc_icons_hover.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5.2em;
}
.sc_icons_hover.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_hover.sc_icons_size_large .sc_icon_type_svg object {
  width: 5.2em;
  height: 5.2em;
}
.sc_icons_hover .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_hover.color_style_link2 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link2);
}
.sc_icons_hover.color_style_link2 .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons_hover.color_style_link3 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link3);
}
.sc_icons_hover.color_style_link3 .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons_hover.color_style_dark .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_hover.color_style_dark .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}

/* Style 'Hover 2' */
.sc_icons_hover2 .sc_icons_item {
  padding: 2.5em 1.6em 3em;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: box-shadow 0.3s ease-out;
  -ms-transition: box-shadow 0.3s ease-out;
  transition: box-shadow 0.3s ease-out;
  will-change: box-shadow;
}
.sc_icons_hover2 .sc_icons_item:hover {
  -webkit-box-shadow: 0 10px 20px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 10px 20px rgba(0, 0, 0, 0.05);
  box-shadow: 0 10px 20px rgba(0, 0, 0, 0.05);
}
.sc_icons_hover2 .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.8em;
}
.sc_icons_hover2 .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_hover2 .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.4em;
}
.sc_icons_hover2 .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_hover2 .sc_icons_item_details {
  padding-right: 3%;
  padding-left: 0;
  min-height: auto;
}
.sc_icons_hover2.sc_icons_size_large .sc_icons_item_details, .sc_icons_hover2.sc_icons_size_small .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_hover2.sc_align_center .sc_icons_item_details, .sc_icons_hover2.sc_icons_size_small.sc_align_center .sc_icons_item_details, .sc_icons_hover2.sc_icons_size_large.sc_align_center .sc_icons_item_details {
  padding-right: 0;
}
.sc_icons_hover2.sc_align_right .sc_icons_item_details, .sc_icons_hover2.sc_icons_size_small.sc_align_right .sc_icons_item_details, .sc_icons_hover2.sc_icons_size_large.sc_align_right .sc_icons_item_details {
  padding-left: 3%;
  padding-right: 0;
}
.sc_icons_hover2 .sc_icons_image img {
  max-width: 3.8em;
}
.sc_icons_hover2 .sc_icons_icon + .sc_icons_item_details,
.sc_icons_hover2 .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.4em;
  margin-top: 0.7em;
}
.sc_icons_hover2.sc_icons_size_small .sc_icons_icon + .sc_icons_item_details, .sc_icons_hover2.sc_icons_size_small .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.4em;
  margin-top: 0;
}
.sc_icons_hover2.sc_icons_size_small .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_hover2.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_hover2.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 1.4em;
}
.sc_icons_hover2.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_hover2.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_hover2.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_hover2.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_hover2.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_hover2 .sc_icons_icon:before,
.sc_icons_hover2 .sc_icons_icon > span:before {
  font-size: 3.8em;
}
.sc_icons_hover2 .sc_icon_type_svg svg,
.sc_icons_hover2 .sc_icon_type_svg object {
  width: 3.8em;
  height: 3.8em;
}
.sc_icons_hover2.sc_icons_size_small .sc_icons_icon:before, .sc_icons_hover2.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.8em;
}
.sc_icons_hover2.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_hover2.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.8em;
  height: 2.8em;
}
.sc_icons_hover2.sc_icons_size_large .sc_icons_icon:before, .sc_icons_hover2.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5.8em;
}
.sc_icons_hover2.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_hover2.sc_icons_size_large .sc_icon_type_svg object {
  width: 5.8em;
  height: 5.8em;
}
.sc_icons_hover2 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_hover2.color_style_link2 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link2);
}
.sc_icons_hover2.color_style_link2 .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons_hover2.color_style_link3 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link3);
}
.sc_icons_hover2.color_style_link3 .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons_hover2.color_style_dark .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_hover2.color_style_dark .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}

/* Style 'Simple' */
.sc_icons_simple .sc_icons_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_icons_simple .sc_icons_item + .sc_icons_item {
  margin-top: 1.2em;
}
.sc_icons_simple .sc_icons_item .sc_icons_item_more_link .link_text,
.sc_icons_simple .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons_simple .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 0;
  visibility: visible;
  -webkit-transition: initial;
  -ms-transition: initial;
  transition: initial;
  will-change: initial;
}
.sc_icons_simple .sc_icons_item .sc_icons_item_more_link .link_icon {
  display: none;
}
.sc_icons_simple .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_simple .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 0.5em;
}
.sc_icons_simple .sc_icons_icon,
.sc_icons_simple .sc_icons_image {
  flex: 0 0 auto;
  width: 1.8em;
  height: 1.8em;
  line-height: 1.8em;
  text-align: center;
}
.sc_icons_simple .sc_icons_icon > span {
  width: 1.8em;
  height: 1.8em;
  line-height: 1.8em;
  text-align: center;
}
.sc_icons_simple .sc_icons_icon:before,
.sc_icons_simple .sc_icons_icon > span:before {
  font-size: 1.8em;
  line-height: inherit !important;
}
.sc_icons_simple .sc_icon_type_svg svg,
.sc_icons_simple .sc_icon_type_svg object {
  width: 1.8em;
  height: 1.8em;
}
.sc_icons_simple .sc_icons_item_details {
  line-height: 1;
}
.sc_icons_simple .sc_icons_icon + .sc_icons_item_details,
.sc_icons_simple .sc_icons_image + .sc_icons_item_details {
  margin-left: 0.8em;
  margin-top: 0;
}
.sc_icons_simple .sc_icons_item_description {
  font-size: 15px;
  line-height: 1.868em;
}
.sc_icons_simple.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_simple.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 0.8em;
}
.sc_icons_simple.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_simple.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_simple.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_simple.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_simple.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_simple.sc_icons_size_small .sc_icons_icon, .sc_icons_simple.sc_icons_size_small .sc_icons_image {
  width: 1.6em;
  height: 1.6em;
  line-height: 1.6em;
  text-align: center;
}
.sc_icons_simple.sc_icons_size_small .sc_icons_icon + .sc_icons_item_details, .sc_icons_simple.sc_icons_size_small .sc_icons_image + .sc_icons_item_details {
  margin-top: 0;
}
.sc_icons_simple.sc_icons_size_small .sc_icons_icon > span {
  width: 1.6em;
  height: 1.6em;
  line-height: 1.6em;
  text-align: center;
}
.sc_icons_simple.sc_icons_size_small .sc_icons_icon:before, .sc_icons_simple.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 1.3em;
  line-height: inherit !important;
}
.sc_icons_simple.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_simple.sc_icons_size_small .sc_icon_type_svg object {
  width: 1.3em;
  height: 1.3em;
}
.sc_icons_simple.sc_icons_size_large .sc_icons_icon, .sc_icons_simple.sc_icons_size_large .sc_icons_image {
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}
.sc_icons_simple.sc_icons_size_large .sc_icons_icon + .sc_icons_item_details, .sc_icons_simple.sc_icons_size_large .sc_icons_image + .sc_icons_item_details {
  margin-top: 3px;
}
.sc_icons_simple.sc_icons_size_large .sc_icons_icon > span {
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}
.sc_icons_simple.sc_icons_size_large .sc_icons_icon:before, .sc_icons_simple.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 2em;
  line-height: inherit !important;
}
.sc_icons_simple.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_simple.sc_icons_size_large .sc_icon_type_svg object {
  width: 2em;
  height: 2em;
}
.sc_icons_simple .sc_icons_item .sc_icons_item_more_link {
  font-size: 20px;
  line-height: 24px;
  letter-spacing: -0.3px;
}

/* Style 'Bordered' */
.sc_icons_bordered .sc_icons_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_icons_bordered .sc_icons_item .sc_icons_item_more_link .link_text,
.sc_icons_bordered .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons_bordered .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 0;
  visibility: visible;
  -webkit-transition: initial;
  -ms-transition: initial;
  transition: initial;
  will-change: initial;
}
.sc_icons_bordered .sc_icons_item .sc_icons_item_more_link .link_icon {
  display: none;
}
.sc_icons_bordered .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_bordered .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.2em;
}
.sc_icons_bordered .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_bordered .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_bordered .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_bordered.color_style_link2 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_bordered.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_bordered.color_style_link3 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_bordered.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_bordered.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_bordered.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_bordered .sc_icons_icon,
.sc_icons_bordered .sc_icons_image {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  flex: 0 0 auto;
  width: 4.2em;
  height: 4.2em;
  line-height: 4.2em;
  text-align: center;
  border: 1px solid var(--theme-color-bd_color);
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_icons_bordered .sc_icons_image img {
  max-width: 50%;
}
.sc_icons_bordered .sc_icons_icon > span {
  width: 4.2em;
  height: 4.2em;
  line-height: 4.2em;
  text-align: center;
}
.sc_icons_bordered .sc_icons_icon:before,
.sc_icons_bordered .sc_icons_icon > span:before {
  font-size: 1.8em;
  line-height: inherit !important;
}
.sc_icons_bordered .sc_icon_type_svg svg,
.sc_icons_bordered .sc_icon_type_svg object {
  width: 1.8em;
  height: 1.8em;
}
.sc_icons_bordered .sc_icons_item_details {
  line-height: 1;
}
.sc_icons_bordered .sc_icons_icon + .sc_icons_item_details,
.sc_icons_bordered .sc_icons_image + .sc_icons_item_details {
  margin-left: 1em;
  margin-top: 1em;
}
.sc_icons_bordered .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_bordered .sc_icons_item_description {
  font-size: 15px;
  line-height: 1.7em;
}
.sc_icons_bordered .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.8em;
}
.sc_icons_bordered.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_bordered.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 1em;
}
.sc_icons_bordered.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_bordered.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_bordered.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_bordered.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_bordered.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_bordered.sc_icons_size_small .sc_icons_icon, .sc_icons_bordered.sc_icons_size_small .sc_icons_image {
  width: 3.2em;
  height: 3.2em;
  line-height: 3.2em;
  text-align: center;
}
.sc_icons_bordered.sc_icons_size_small .sc_icons_icon + .sc_icons_item_details, .sc_icons_bordered.sc_icons_size_small .sc_icons_image + .sc_icons_item_details {
  margin-top: 0.8em;
}
.sc_icons_bordered.sc_icons_size_small .sc_icons_icon > span {
  width: 3.2em;
  height: 3.2em;
  line-height: 3.2em;
  text-align: center;
}
.sc_icons_bordered.sc_icons_size_small .sc_icons_icon:before, .sc_icons_bordered.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 1.3em;
  line-height: inherit !important;
}
.sc_icons_bordered.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_bordered.sc_icons_size_small .sc_icon_type_svg object {
  width: 1.3em;
  height: 1.3em;
}
.sc_icons_bordered.sc_icons_size_large .sc_icons_icon, .sc_icons_bordered.sc_icons_size_large .sc_icons_image {
  width: 5.2em;
  height: 5.2em;
  line-height: 5.2em;
  text-align: center;
}
.sc_icons_bordered.sc_icons_size_large .sc_icons_icon + .sc_icons_item_details, .sc_icons_bordered.sc_icons_size_large .sc_icons_image + .sc_icons_item_details {
  margin-top: 1em;
}
.sc_icons_bordered.sc_icons_size_large .sc_icons_icon > span {
  width: 5.2em;
  height: 5.2em;
  line-height: 5.2em;
  text-align: center;
}
.sc_icons_bordered.sc_icons_size_large .sc_icons_icon:before, .sc_icons_bordered.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 2em;
  line-height: inherit !important;
}
.sc_icons_bordered.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_bordered.sc_icons_size_large .sc_icon_type_svg object {
  width: 2em;
  height: 2em;
}
.sc_icons_bordered .sc_icons_item .sc_icons_item_more_link {
  font-size: 18px;
  line-height: 24px;
  letter-spacing: -0.3px;
}

/* Style 'Plate' */
.sc_icons_plate .sc_icons_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  padding: 2em;
  background-color: var(--theme-color-text_link_007);
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  will-change: transform;
}
.sc_icons_plate .sc_icons_item:hover {
  -webkit-transform: translateY(-8px);
  -ms-transform: translateY(-8px);
  transform: translateY(-8px);
}
.sc_icons_plate .sc_icons_item:nth-child(3n-1),
.sc_icons_plate .slider-slide:nth-child(3n-1) .sc_icons_item,
.sc_icons_plate [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item {
  background-color: var(--theme-color-text_link2_007);
}
.sc_icons_plate .sc_icons_item:nth-child(3n),
.sc_icons_plate .slider-slide:nth-child(3n) .sc_icons_item,
.sc_icons_plate [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item {
  background-color: var(--theme-color-text_link3_007);
}
.sc_icons_plate .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_plate .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_plate .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_plate.color_style_link2 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_plate.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_plate.color_style_link3 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_plate.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_plate.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_plate.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_plate .sc_icons_item .sc_icons_item_more_link {
  font-size: 18px;
  line-height: 26px;
  font-weight: 400;
  z-index: 11;
}
.sc_icons_plate .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_plate .sc_icons_item .sc_icons_item_more_link .link_text,
.sc_icons_plate .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons_plate .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 0;
  visibility: visible;
  -webkit-transition: initial;
  -ms-transition: initial;
  transition: initial;
  will-change: initial;
}
.sc_icons_plate .sc_icons_item .sc_icons_item_more_link .link_icon {
  display: none;
}
.sc_icons_plate .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_plate .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 0.1em;
}
.sc_icons_plate .sc_icons_icon + .sc_icons_item_details,
.sc_icons_plate .sc_icons_image + .sc_icons_item_details {
  margin-top: 2em;
}
.sc_icons_plate .sc_icons_icon,
.sc_icons_plate .sc_icons_image {
  width: 3em;
  height: 3em;
  line-height: 3em;
  text-align: center;
}
.sc_icons_plate .sc_icons_icon > span {
  width: 3em;
  height: 3em;
  line-height: 3em;
  text-align: center;
}
.sc_icons_plate .sc_icons_icon:before,
.sc_icons_plate .sc_icons_icon > span:before {
  font-size: 3em;
  line-height: inherit !important;
}
.sc_icons_plate .sc_icon_type_svg svg,
.sc_icons_plate .sc_icon_type_svg object {
  width: 3em;
  height: 3em;
}
.sc_icons_plate.sc_icons_size_small .sc_icons_icon, .sc_icons_plate.sc_icons_size_small .sc_icons_image {
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}
.sc_icons_plate.sc_icons_size_small .sc_icons_icon > span {
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}
.sc_icons_plate.sc_icons_size_small .sc_icons_icon:before, .sc_icons_plate.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2em;
  line-height: inherit !important;
}
.sc_icons_plate.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_plate.sc_icons_size_small .sc_icon_type_svg object {
  width: 2em;
  height: 2em;
}
.sc_icons_plate.sc_icons_size_large .sc_icons_icon, .sc_icons_plate.sc_icons_size_large .sc_icons_image {
  width: 4em;
  height: 4em;
  line-height: 4em;
  text-align: center;
}
.sc_icons_plate.sc_icons_size_large .sc_icons_icon > span {
  width: 4em;
  height: 4em;
  line-height: 4em;
  text-align: center;
}
.sc_icons_plate.sc_icons_size_large .sc_icons_icon:before, .sc_icons_plate.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4em;
  line-height: inherit !important;
}
.sc_icons_plate.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_plate.sc_icons_size_large .sc_icon_type_svg object {
  width: 4em;
  height: 4em;
}
.sc_icons_plate .sc_icons_item_title {
  font-size: 19px;
  line-height: 28px;
  font-weight: 700;
}
.sc_icons_plate .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.3em;
}
.sc_icons_plate.sc_align_center .sc_icons_item {
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_icons_plate.sc_align_right .sc_icons_item {
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}

/* Style 'Extra' */
.sc_icons_extra .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_extra .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1em;
}
.sc_icons_extra .sc_icons_item .sc_icons_item_more_link .link_icon {
  border: 1px solid var(--theme-color-bd_color);
  text-align: center;
  width: 2.2em;
  height: 2.2em;
  line-height: 2.15em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.ua_firefox .sc_icons_extra .sc_icons_item .sc_icons_item_more_link .link_icon {
  line-height: 2.07em;
}
.sc_icons_extra .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons_extra .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  margin-right: 8px;
}
.sc_icons_extra .sc_icons_item .sc_icons_item_more_link .link_icon:before {
  font-size: 9px;
  line-height: inherit;
  font-weight: 400;
}
.sc_icons_extra .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_extra .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_extra .sc_icons_item:hover .sc_icons_icon,
.sc_icons_extra .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_extra.color_style_link2 .sc_icons_item:hover .sc_icons_icon, .sc_icons_extra.color_style_link2 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link2);
}
.sc_icons_extra.color_style_link3 .sc_icons_item:hover .sc_icons_icon, .sc_icons_extra.color_style_link3 .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link3);
}
.sc_icons_extra.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_extra.color_style_dark .sc_icons_item:hover .sc_icons_icon, .sc_icons_extra.color_style_dark .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_extra .sc_icons_icon + .sc_icons_item_details,
.sc_icons_extra .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.3em;
}
.sc_icons_extra .sc_icons_icon:before,
.sc_icons_extra .sc_icons_icon > span:before {
  font-size: 5em;
}
.sc_icons_extra .sc_icon_type_svg svg,
.sc_icons_extra .sc_icon_type_svg object {
  width: 5em;
  height: 5em;
}
.sc_icons_extra.sc_icons_size_small .sc_icons_icon:before, .sc_icons_extra.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 3.2em;
}
.sc_icons_extra.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_extra.sc_icons_size_small .sc_icon_type_svg object {
  width: 3.2em;
  height: 3.2em;
}
.sc_icons_extra.sc_icons_size_large .sc_icons_icon:before, .sc_icons_extra.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 8em;
}
.sc_icons_extra.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_extra.sc_icons_size_large .sc_icon_type_svg object {
  width: 8em;
  height: 8em;
}

/* Style 'Plain' */
.sc_icons_plain .sc_icons_item .sc_icons_item_more_link {
  font-size: 15px;
  line-height: initial;
  font-weight: 400;
  color: var(--theme-color-text);
  padding-top: 1px;
  padding-bottom: 1px;
}
.sc_icons_plain .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_link);
}
.sc_icons_plain .sc_icons_item .sc_icons_item_more_link .link_text,
.sc_icons_plain .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons_plain .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 0;
  visibility: visible;
  -webkit-transition: initial;
  -ms-transition: initial;
  transition: initial;
  will-change: initial;
}
.sc_icons_plain .sc_icons_item .sc_icons_item_more_link .link_icon {
  display: none;
}
.sc_icons_plain .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_plain .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 0;
}
.sc_icons_plain .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-text_dark);
}
.sc_icons_plain .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_plain .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-text_link);
}
.sc_icons_plain.color_style_link2 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_plain.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_plain.color_style_link3 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_plain.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_plain.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_plain.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_plain .sc_icons_item_title {
  font-size: 1.6em;
  line-height: 1.2em;
}
.sc_icons_plain .sc_icons_item_description {
  font-size: 15px;
  line-height: 1.867em;
}
.sc_icons_plain .sc_icons_icon:before,
.sc_icons_plain .sc_icons_icon > span:before {
  font-size: 4.4em;
}
.sc_icons_plain .sc_icon_type_svg svg,
.sc_icons_plain .sc_icon_type_svg object {
  width: 4.4em;
  height: 4.4em;
}
.sc_icons_plain.sc_icons_size_small .sc_icons_icon:before, .sc_icons_plain.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 3.4em;
}
.sc_icons_plain.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_plain.sc_icons_size_small .sc_icon_type_svg object {
  width: 3.4em;
  height: 3.4em;
}
.sc_icons_plain.sc_icons_size_large .sc_icons_icon:before, .sc_icons_plain.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5.4em;
}
.sc_icons_plain.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_plain.sc_icons_size_large .sc_icon_type_svg object {
  width: 5.4em;
  height: 5.4em;
}
.sc_icons_plain .sc_icons_icon + .sc_icons_item_details {
  margin-top: 2.4em;
}

/* Style 'Card' */
.sc_icons_card .sc_icons_item {
  padding: 4.4em 2.4em 2.8em;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
  border: 1px solid var(--theme-color-alter_bd_color);
  -webkit-transition: box-shadow 0.3s ease-out;
  -ms-transition: box-shadow 0.3s ease-out;
  transition: box-shadow 0.3s ease-out;
  will-change: box-shadow;
}
.sc_icons_card .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_card .sc_icons_item:hover {
  -webkit-box-shadow: 0 5px 30px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 5px 30px rgba(0, 0, 0, 0.05);
  box-shadow: 0 5px 30px rgba(0, 0, 0, 0.05);
}
.sc_icons_card .sc_icons_item .sc_icons_item_more_link .link_text {
  display: none;
}
.sc_icons_card .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_card .sc_icons_item .sc_icons_item_title,
.sc_icons_card .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_card .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.7em;
}
.sc_icons_card .sc_icons_icon + .sc_icons_item_details,
.sc_icons_card .sc_icons_image + .sc_icons_item_details {
  margin-top: 2em;
}
.sc_icons_card .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-alter_link);
}
.sc_icons_card.color_style_link2 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_card.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_link2 .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_link2 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-alter_link2);
}
.sc_icons_card.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_link3 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_card.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_link3 .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_link3 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-alter_link3);
}
.sc_icons_card.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_card.color_style_dark .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-alter_link);
}
.sc_icons_card.color_style_dark .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-alter_dark);
}
.sc_icons_card.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-alter_dark);
}

/* Style 'Creative' */
.sc_icons_creative .sc_icons_item {
  padding: 0 2em;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_icons_creative .sc_icons_slider .sc_icons_item {
  padding-top: 3px;
  padding-bottom: 3px;
}
.sc_icons_creative .sc_icons_item:nth-child(3n-1) .sc_icons_decoration_bg svg,
.sc_icons_creative [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_decoration_bg svg {
  -webkit-transform: rotate(-60deg);
  -ms-transform: rotate(-60deg);
  transform: rotate(-60deg);
}
.sc_icons_creative .sc_icons_item:nth-child(3n) .sc_icons_decoration_bg svg,
.sc_icons_creative [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_decoration_bg svg {
  -webkit-transform: rotate(-120deg);
  -ms-transform: rotate(-120deg);
  transform: rotate(-120deg);
}
.sc_icons_creative.sc_align_center .sc_icons_item {
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  text-align: center;
}
.sc_icons_creative.sc_align_right .sc_icons_item {
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  text-align: right;
}
.sc_icons_creative .sc_icons_icon, .sc_icons_creative .sc_icons_image {
  position: relative;
  z-index: 2;
  width: 112px;
  height: 112px;
  line-height: 112px;
  text-align: center;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_icons_creative .sc_icons_icon {
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
  will-change: color;
}
.sc_icons_creative .sc_icons_image img {
  max-width: 60%;
}
.sc_icons_creative .sc_icons_icon + .sc_icons_item_details,
.sc_icons_creative .sc_icons_image + .sc_icons_item_details {
  margin-top: 2em;
}
.sc_icons_creative .sc_icons_decoration_bg {
  position: absolute;
  z-index: -1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  line-height: normal;
}
.sc_icons_creative .sc_icons_decoration_bg svg.decor-svg {
  width: 112px;
  height: 112px;
  -webkit-transition: fill 0.3s ease;
  -ms-transition: fill 0.3s ease;
  transition: fill 0.3s ease;
  will-change: fill;
}
.sc_icons_creative .sc_icons_item .sc_icons_decoration_bg svg.decor-svg {
  fill: var(--theme-color-alter_bg_hover) !important;
  stroke: none;
}
.sc_icons_creative .sc_icons_item:hover .sc_icons_decoration_bg svg.decor-svg {
  fill: var(--theme-color-alter_link) !important;
}
.sc_icons_creative .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_creative .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_creative.color_style_link2 .sc_icons_item:hover .sc_icons_decoration_bg svg.decor-svg {
  fill: var(--theme-color-alter_link2) !important;
}
.sc_icons_creative.color_style_link2 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_creative.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_creative.color_style_link3 .sc_icons_item:hover .sc_icons_decoration_bg svg.decor-svg {
  fill: var(--theme-color-alter_link3) !important;
}
.sc_icons_creative.color_style_link3 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_creative.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_creative.color_style_dark .sc_icons_item:hover .sc_icons_decoration_bg svg.decor-svg {
  fill: var(--theme-color-alter_dark) !important;
}
.sc_icons_creative.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}
.sc_icons_creative.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_creative .sc_icons_icon > span {
  width: 112px;
  height: 112px;
  line-height: 112px;
  text-align: center;
}
.sc_icons_creative .sc_icons_icon:before,
.sc_icons_creative .sc_icons_icon > span:before {
  font-size: 3.4em;
  line-height: inherit !important;
}
.sc_icons_creative .sc_icon_type_svg svg,
.sc_icons_creative .sc_icon_type_svg object {
  width: 3.4em;
  height: 3.4em;
}
.sc_icons_creative.sc_icons_size_small .sc_icons_icon, .sc_icons_creative.sc_icons_size_small .sc_icons_image {
  width: 100px;
  height: 100px;
  line-height: 100px;
  text-align: center;
}
.sc_icons_creative.sc_icons_size_small .sc_icons_icon > span {
  width: 100px;
  height: 100px;
  line-height: 100px;
  text-align: center;
}
.sc_icons_creative.sc_icons_size_small .sc_icons_decoration_bg svg {
  width: 100px;
  height: 100px;
}
.sc_icons_creative.sc_icons_size_small .sc_icons_icon:before, .sc_icons_creative.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.4em;
  line-height: inherit !important;
}
.sc_icons_creative.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_creative.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.4em;
  height: 2.4em;
}
.sc_icons_creative.sc_icons_size_small .sc_icons_icon + .sc_icons_item_details, .sc_icons_creative.sc_icons_size_small .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.5em;
}
.sc_icons_creative.sc_icons_size_large .sc_icons_icon:before, .sc_icons_creative.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4.4em;
  line-height: inherit !important;
}
.sc_icons_creative.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_creative.sc_icons_size_large .sc_icon_type_svg object {
  width: 4.4em;
  height: 4.4em;
}
.sc_icons_creative.sc_icons_size_large .sc_icons_icon, .sc_icons_creative.sc_icons_size_large .sc_icons_image {
  width: 130px;
  height: 130px;
  line-height: 130px;
  text-align: center;
}
.sc_icons_creative.sc_icons_size_large .sc_icons_icon > span {
  width: 130px;
  height: 130px;
  line-height: 130px;
  text-align: center;
}
.sc_icons_creative.sc_icons_size_large .sc_icons_decoration_bg svg {
  width: 130px;
  height: 130px;
}

/* Style 'Accent' */
.sc_icons_accent .sc_icons_columns_wrap {
  margin: 0;
}
.sc_icons_accent .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding: 0;
}
.sc_icons_accent .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_icons_accent .sc_icons_item {
  padding: 3.4em 2em;
  background-color: transparent;
  -webkit-transition: background-color 0.3s ease-out, box-shadow 0.3s ease-out;
  -ms-transition: background-color 0.3s ease-out, box-shadow 0.3s ease-out;
  transition: background-color 0.3s ease-out, box-shadow 0.3s ease-out;
  will-change: background-color, box-shadow;
}
.sc_icons_accent .sc_icons_item:hover {
  background-color: var(--theme-color-text_link);
  -webkit-box-shadow: 0 5px 30px var(--theme-color-text_link_03);
  -ms-box-shadow: 0 5px 30px var(--theme-color-text_link_03);
  box-shadow: 0 5px 30px var(--theme-color-text_link_03);
}
.sc_icons_accent .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_accent .sc_icons_item_title,
.sc_icons_accent .sc_icons_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_icons_accent .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_accent .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_accent .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent .sc_icons_item_description {
  color: var(--theme-color-text);
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}
.sc_icons_accent .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.8em;
}
.sc_icons_accent .sc_icons_icon + .sc_icons_item_details,
.sc_icons_accent .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.5em;
}
.sc_icons_accent .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_accent .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-text_dark);
}
.sc_icons_accent .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link2 .sc_icons_item:hover {
  background-color: var(--theme-color-text_link2);
  -webkit-box-shadow: 0 5px 30px var(--theme-color-text_link2_03);
  -ms-box-shadow: 0 5px 30px var(--theme-color-text_link2_03);
  box-shadow: 0 5px 30px var(--theme-color-text_link2_03);
}
.sc_icons_accent.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link2 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_accent.color_style_link2 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_accent.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link2 .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link2 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link3 .sc_icons_item:hover {
  background-color: var(--theme-color-text_link3);
  -webkit-box-shadow: 0 5px 30px var(--theme-color-text_link3_03);
  -ms-box-shadow: 0 5px 30px var(--theme-color-text_link3_03);
  box-shadow: 0 5px 30px var(--theme-color-text_link3_03);
}
.sc_icons_accent.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link3 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_accent.color_style_link3 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_accent.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link3 .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_link3 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent.color_style_dark .sc_icons_item:hover {
  background-color: var(--theme-color-text_dark);
  -webkit-box-shadow: 0 5px 30px var(--theme-color-text_dark_03);
  -ms-box-shadow: 0 5px 30px var(--theme-color-text_dark_03);
  box-shadow: 0 5px 30px var(--theme-color-text_dark_03);
}
.sc_icons_accent.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_accent.color_style_dark .sc_icons_item:hover .sc_icons_item_title, .sc_icons_accent.color_style_dark .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_accent.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_accent.color_style_dark .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_accent.color_style_dark .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}

/* Style 'Accent 2' */
.sc_icons_accent2 .sc_icons_item {
  padding: 2.4em 2.2em;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 3px 30px rgba(0, 0, 0, 0.03);
  -ms-box-shadow: 0 3px 30px rgba(0, 0, 0, 0.03);
  box-shadow: 0 3px 30px rgba(0, 0, 0, 0.03);
  -webkit-transition: background-color 0.3s ease-out, box-shadow 0.3s ease-out;
  -ms-transition: background-color 0.3s ease-out, box-shadow 0.3s ease-out;
  transition: background-color 0.3s ease-out, box-shadow 0.3s ease-out;
  will-change: background-color, box-shadow;
}
.sc_icons_accent2 .sc_icons_item:hover {
  background-color: var(--theme-color-alter_link);
  -webkit-box-shadow: 0 3px 30px rgba(0, 0, 0, 0);
  -ms-box-shadow: 0 3px 30px rgba(0, 0, 0, 0);
  box-shadow: 0 3px 30px rgba(0, 0, 0, 0);
}
.sc_icons_accent2 .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_accent2 .sc_icons_item_title,
.sc_icons_accent2 .sc_icons_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_icons_accent2 .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_accent2 .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_accent2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2 .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.3em;
}
.sc_icons_accent2 .sc_icons_item_description {
  color: var(--theme-color-alter_text);
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}
.sc_icons_accent2 .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2 .sc_icons_icon + .sc_icons_item_details,
.sc_icons_accent2 .sc_icons_image + .sc_icons_item_details {
  margin-top: 4.4em;
}
.sc_icons_accent2 .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_accent2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2 .sc_icons_icon:before,
.sc_icons_accent2 .sc_icons_icon > span:before {
  font-size: 3.6em;
}
.sc_icons_accent2 .sc_icon_type_svg svg,
.sc_icons_accent2 .sc_icon_type_svg object {
  width: 3.6em;
  height: 3.6em;
}
.sc_icons_accent2.sc_icons_size_small .sc_icons_icon:before, .sc_icons_accent2.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.6em;
}
.sc_icons_accent2.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_accent2.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.6em;
  height: 2.6em;
}
.sc_icons_accent2.sc_icons_size_large .sc_icons_icon:before, .sc_icons_accent2.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4.6em;
}
.sc_icons_accent2.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_accent2.sc_icons_size_large .sc_icon_type_svg object {
  width: 4.6em;
  height: 4.6em;
}
.sc_icons_accent2 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link2 .sc_icons_item:hover {
  background-color: var(--theme-color-alter_link2);
}
.sc_icons_accent2.color_style_link2 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link2 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_accent2.color_style_link2 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_accent2.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link2 .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link2 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link3 .sc_icons_item:hover {
  background-color: var(--theme-color-alter_link3);
}
.sc_icons_accent2.color_style_link3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link3 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_accent2.color_style_link3 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_accent2.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link3 .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_link3 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_accent2.color_style_dark .sc_icons_item:hover {
  background-color: var(--theme-color-alter_dark);
}
.sc_icons_accent2.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_accent2.color_style_dark .sc_icons_item:hover .sc_icons_item_title, .sc_icons_accent2.color_style_dark .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_accent2.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_accent2.color_style_dark .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_accent2.color_style_dark .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}

/* Style 'Motley' */
.sc_icons_motley .sc_icons_item {
  padding: 5.2em 2.4em;
  background-color: var(--theme-color-alter_link);
  -webkit-box-shadow: 0 12px 20px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 12px 20px rgba(0, 0, 0, 0.05);
  box-shadow: 0 12px 20px rgba(0, 0, 0, 0.05);
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  will-change: transform;
}
.sc_icons_motley .sc_icons_item:hover {
  -webkit-transform: translateY(-8px);
  -ms-transform: translateY(-8px);
  transform: translateY(-8px);
}
.sc_icons_motley .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley .sc_icons_item .sc_icons_item_title,
.sc_icons_motley .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_motley .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_motley .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_link_08);
}
.sc_icons_motley .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_motley .sc_icons_item:nth-child(3n-1),
.sc_icons_motley .slider-slide:nth-child(3n-1) .sc_icons_item,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item {
  background-color: var(--theme-color-alter_dark);
}
.sc_icons_motley .sc_icons_item:nth-child(3n-1) .sc_icons_icon,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley .slider-slide:nth-child(3n-1) .sc_icons_item .sc_icons_item_title,
.sc_icons_motley .slider-slide:nth-child(3n-1) .sc_icons_item .sc_icons_item_title a,
.sc_icons_motley .sc_icons_item:nth-child(3n-1) .sc_icons_item .sc_icons_item_title,
.sc_icons_motley .sc_icons_item:nth-child(3n-1) .sc_icons_item .sc_icons_item_title a,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_item_title,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley .slider-slide:hover:nth-child(3n-1) .sc_icons_item_title,
.sc_icons_motley .slider-slide:hover:nth-child(3n-1) .sc_icons_item_title a,
.sc_icons_motley .slider-slide:nth-child(3n-1) .sc_icons_item_title a:hover,
.sc_icons_motley .sc_icons_item:hover:nth-child(3n-1) .sc_icons_item_title,
.sc_icons_motley .sc_icons_item:hover:nth-child(3n-1) .sc_icons_item_title a,
.sc_icons_motley .sc_icons_item:nth-child(3n-1) .sc_icons_item_title a:hover,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley .sc_icons_item:nth-child(3n-1) .sc_icons_item .sc_icons_item_description,
.sc_icons_motley .slider-slide:nth-child(3n-1) .sc_icons_item .sc_icons_item_description,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_hover_08);
}
.sc_icons_motley .sc_icons_item:nth-child(3n-1) .sc_icons_item .sc_icons_item_more_link,
.sc_icons_motley .slider-slide:nth-child(3n-1) .sc_icons_item .sc_icons_item_more_link,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n-1) .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley .sc_icons_item:nth-child(3n),
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_icons_motley .sc_icons_item:nth-child(3n) .sc_icons_icon,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_icon,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link);
}
.sc_icons_motley .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_title,
.sc_icons_motley .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_title a,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_title,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_title a,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_title,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_icons_motley .sc_icons_item:hover:nth-child(3n) .sc_icons_item_title,
.sc_icons_motley .sc_icons_item:hover:nth-child(3n) .sc_icons_item_title a,
.sc_icons_motley .sc_icons_item:nth-child(3n) .sc_icons_item_title a:hover,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_title a:hover,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_icons_motley .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_description,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_description,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-alter_text);
}
.sc_icons_motley .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_more_link,
.sc_icons_motley .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_more_link,
.sc_icons_motley [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-alter_dark);
}
.sc_icons_motley.color_style_link2 .sc_icons_item {
  background-color: var(--theme-color-alter_link2);
}
.sc_icons_motley.color_style_link2 .sc_icons_item:nth-child(3n) .sc_icons_icon, .sc_icons_motley.color_style_link2 .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_icon, .sc_icons_motley.color_style_link2 [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_motley.color_style_link2 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_motley.color_style_link2 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_motley.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley.color_style_link3 .sc_icons_item {
  background-color: var(--theme-color-alter_link3);
}
.sc_icons_motley.color_style_link3 .sc_icons_item:nth-child(3n) .sc_icons_icon, .sc_icons_motley.color_style_link3 .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_icon, .sc_icons_motley.color_style_link3 [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_motley.color_style_link3 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_motley.color_style_link3 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_motley.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_motley.color_style_dark .sc_icons_item {
  background-color: var(--theme-color-alter_dark);
}
.sc_icons_motley.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley.color_style_dark .sc_icons_item .sc_icons_item_title, .sc_icons_motley.color_style_dark .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley.color_style_dark .sc_icons_item:hover .sc_icons_item_title, .sc_icons_motley.color_style_dark .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_motley.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley.color_style_dark .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_hover_08);
}
.sc_icons_motley.color_style_dark .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley.color_style_dark .sc_icons_item:nth-child(3n), .sc_icons_motley.color_style_dark .slider-slide:nth-child(3n) .sc_icons_item, .sc_icons_motley.color_style_dark [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item {
  background-color: var(--theme-color-alter_dark);
}
.sc_icons_motley.color_style_dark .sc_icons_item:nth-child(3n) .sc_icons_icon, .sc_icons_motley.color_style_dark .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_icon, .sc_icons_motley.color_style_dark [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley.color_style_dark .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_title, .sc_icons_motley.color_style_dark .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_title a, .sc_icons_motley.color_style_dark .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_title, .sc_icons_motley.color_style_dark .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_title a, .sc_icons_motley.color_style_dark [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_title, .sc_icons_motley.color_style_dark [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_motley.color_style_dark .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_description, .sc_icons_motley.color_style_dark .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_description, .sc_icons_motley.color_style_dark [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_hover_08);
}
.sc_icons_motley.color_style_dark .sc_icons_item:nth-child(3n) .sc_icons_item .sc_icons_item_more_link, .sc_icons_motley.color_style_dark .slider-slide:nth-child(3n) .sc_icons_item .sc_icons_item_more_link, .sc_icons_motley.color_style_dark [class*="trx_addons_column-"]:nth-child(3n) .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}

/* Style 'Decoration' */
.sc_icons_decoration .sc_icons_item {
  padding: 3.2em 2em 1.2em;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: box-shadow 0.3s ease-out;
  -ms-transition: box-shadow 0.3s ease-out;
  transition: box-shadow 0.3s ease-out;
}
.sc_icons_decoration .sc_icons_item:hover {
  -webkit-box-shadow: 0 3px 30px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 30px rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 30px rgba(0, 0, 0, 0.05);
}
.sc_icons_decoration .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_decoration .sc_icons_item_title,
.sc_icons_decoration .sc_icons_item_title a {
  color: var(--theme-color-alter_dark);
}
.sc_icons_decoration .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.3em;
}
.sc_icons_decoration .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_decoration .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_icons_decoration .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_decoration .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-alter_dark);
}
.sc_icons_decoration .sc_icons_item .sc_icons_item_more_link .link_text {
  display: none;
}
.sc_icons_decoration .sc_icons_item .sc_icons_item_more_link .link_icon {
  width: 1.8em;
  height: 1.8em;
  line-height: 1.8em;
  text-align: center;
}
.sc_icons_decoration .sc_icons_item .sc_icons_item_more_link .link_icon:before {
  font-family: "fontello";
  content: '\E8CA';
  font-size: 28px;
  font-weight: 400;
  color: var(--theme-color-alter_dark_02);
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}
.sc_icons_decoration .sc_icons_item:hover .sc_icons_item_more_link .link_icon:before,
.sc_icons_decoration .sc_icons_item .sc_icons_item_more_link:hover .link_icon:before {
  color: var(--theme-color-alter_link);
}
.sc_icons_decoration .sc_icons_icon + .sc_icons_item_details,
.sc_icons_decoration .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.5em;
}
.sc_icons_decoration .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_decoration .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1em;
}
.sc_icons_decoration .sc_icons_icon:before,
.sc_icons_decoration .sc_icons_icon > span:before {
  font-size: 3.8em;
}
.sc_icons_decoration .sc_icon_type_svg svg,
.sc_icons_decoration .sc_icon_type_svg object {
  width: 3.8em;
  height: 3.8em;
}
.sc_icons_decoration.sc_icons_size_small .sc_icons_icon:before, .sc_icons_decoration.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.8em;
}
.sc_icons_decoration.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_decoration.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.8em;
  height: 2.8em;
}
.sc_icons_decoration.sc_icons_size_large .sc_icons_icon:before, .sc_icons_decoration.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4.8em;
}
.sc_icons_decoration.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_decoration.sc_icons_size_large .sc_icon_type_svg object {
  width: 4.8em;
  height: 4.8em;
}
.sc_icons_decoration.color_style_link2 .sc_icons_item:hover .sc_icons_item_more_link .link_icon:before, .sc_icons_decoration.color_style_link2 .sc_icons_item .sc_icons_item_more_link:hover .link_icon:before {
  color: var(--theme-color-alter_link2);
}
.sc_icons_decoration.color_style_link3 .sc_icons_item:hover .sc_icons_item_more_link .link_icon:before, .sc_icons_decoration.color_style_link3 .sc_icons_item .sc_icons_item_more_link:hover .link_icon:before {
  color: var(--theme-color-alter_link3);
}
.sc_icons_decoration.color_style_dark .sc_icons_item:hover .sc_icons_item_more_link .link_icon:before, .sc_icons_decoration.color_style_dark .sc_icons_item .sc_icons_item_more_link:hover .link_icon:before {
  color: var(--theme-color-alter_dark);
}

/* Style 'Figure' */
.sc_icons_figure .sc_icons_item {
  padding: 3.2em 2em 2em;
  -webkit-transition: box-shadow 0.3s ease-out;
  -ms-transition: box-shadow 0.3s ease-out;
  transition: box-shadow 0.3s ease-out;
}
.sc_icons_figure .sc_icons_item:hover {
  -webkit-box-shadow: 0 7px 30px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 7px 30px rgba(0, 0, 0, 0.05);
  box-shadow: 0 7px 30px rgba(0, 0, 0, 0.05);
}
.sc_icons_figure .sc_icons_icon {
  position: relative;
}
.sc_icons_figure .sc_icons_icon:after {
  content: '';
  display: block;
  width: 74px;
  height: 74px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  position: absolute;
  z-index: 0;
  top: -20%;
  right: -40%;
  background-color: var(--theme-color-text_dark);
  opacity: .03;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_icons_figure .sc_icons_icon.sc_icons_char:after {
  position: absolute;
  z-index: 0;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.sc_icons_figure .sc_icons_item:hover .sc_icons_image:after,
.sc_icons_figure .sc_icons_item:hover .sc_icons_icon:after {
  opacity: .04;
}
.sc_icons_figure .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_figure .sc_icons_item_title,
.sc_icons_figure .sc_icons_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_icons_figure .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.3em;
}
.sc_icons_figure .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_figure .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_icons_figure .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_figure .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-text_dark);
}
.sc_icons_figure .sc_icons_item:hover .sc_icons_item_more_link,
.sc_icons_figure .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_link);
}
.sc_icons_figure .sc_icons_item .sc_icons_item_more_link .link_text {
  display: none;
}
.sc_icons_figure .sc_icons_icon + .sc_icons_item_details,
.sc_icons_figure .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.8em;
}
.sc_icons_figure.color_style_link2 .sc_icons_item:hover .sc_icons_item_more_link, .sc_icons_figure.color_style_link2 .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_link2);
}
.sc_icons_figure.color_style_link3 .sc_icons_item:hover .sc_icons_item_more_link, .sc_icons_figure.color_style_link3 .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_link3);
}
.sc_icons_figure.color_style_dark .sc_icons_item:hover .sc_icons_item_more_link, .sc_icons_figure.color_style_dark .sc_icons_item .sc_icons_item_more_link:hover {
  color: var(--theme-color-text_dark);
}

/* Style 'Number' */
.sc_icons_number {
  /* add special hover */
}
.sc_icons_number .sc_icons_item_number {
  font-size: 8em;
  line-height: 1em;
  font-weight: 500;
  position: absolute;
  z-index: 1;
  top: -0.4em;
  left: -10px;
  color: var(--theme-color-text_dark);
  opacity: .03;
  -webkit-transition: opacity 0.3s ease-out;
  -ms-transition: opacity 0.3s ease-out;
  transition: opacity 0.3s ease-out;
}
.sc_icons_number .sc_icons_item {
  min-height: 6em;
  line-height: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}
.sc_icons_number .sc_icons_item:hover .sc_icons_item_number {
  opacity: .04;
}
.sc_icons_number .sc_icons_item_header {
  width: 100%;
  min-height: 3.4em;
  position: relative;
  z-index: 1;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_icons_number .sc_icons_item_details {
  width: 100%;
}
.sc_icons_number .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title,
.sc_icons_number .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title,
.sc_icons_number .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked .sc_icons_image + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked .sc_icons_image img {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_icons_number .sc_icons_item_linked:hover .sc_icons_icon + .sc_icons_item_title,
.sc_icons_number .sc_icons_item_linked:hover .sc_icons_image + .sc_icons_item_title,
.sc_icons_number .sc_icons_item_linked:hover .sc_icons_icon + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked:hover .sc_icons_icon + .sc_icons_item_title + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked:hover .sc_icons_image + .sc_icons_item_description,
.sc_icons_number .sc_icons_item_linked:hover .sc_icons_image + .sc_icons_item_title + .sc_icons_item_description {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.sc_icons_number .sc_icons_item_linked .sc_icons_icon + .sc_icons_item_title,
.sc_icons_number .sc_icons_item_linked .sc_icons_image + .sc_icons_item_title {
  -webkit-transform-origin: initial;
  -ms-transform-origin: initial;
  transform-origin: initial;
}
.sc_icons_number .sc_icons_item_header + .sc_icons_item_details {
  margin-top: 0.5em;
}
.sc_icons_number .sc_icons_image + .sc_icons_item_title,
.sc_icons_number .sc_icons_icon + .sc_icons_item_title {
  margin-left: 0.8em;
}
.sc_icons_number .sc_icons_image img {
  max-width: 100px;
}
.sc_icons_number .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.6em;
}
.sc_icons_number .sc_icons_item .sc_icons_item_more_link .link_icon {
  border: 1px solid var(--theme-color-bd_color);
  width: 2.3em;
  height: 2.3em;
  line-height: 2.2em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_icons_number .sc_icons_item .sc_icons_item_more_link .link_icon:before {
  font-size: 9px;
}
.sc_icons_number .sc_icons_item:hover .sc_icons_item_more_link .link_text,
.sc_icons_number .sc_icons_item .sc_icons_item_more_link:hover .link_text {
  margin-right: 10px;
}
.sc_icons_number .sc_icons_icon:before,
.sc_icons_number .sc_icons_icon > span:before {
  font-size: 4.4em;
}
.sc_icons_number .sc_icon_type_svg svg,
.sc_icons_number .sc_icon_type_svg object {
  width: 4.4em;
  height: 4.4em;
}
.sc_icons_number.sc_icons_size_small .sc_icons_icon:before, .sc_icons_number.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 3.4em;
}
.sc_icons_number.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_number.sc_icons_size_small .sc_icon_type_svg object {
  width: 3.4em;
  height: 3.4em;
}
.sc_icons_number.sc_icons_size_large .sc_icons_icon:before, .sc_icons_number.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5.4em;
}
.sc_icons_number.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_number.sc_icons_size_large .sc_icon_type_svg object {
  width: 5.4em;
  height: 5.4em;
}
.sc_icons_number.sc_align_center .sc_icons_item {
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_icons_number.sc_align_center .sc_icons_item_header {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_number.sc_align_center .sc_icons_item_number {
  position: absolute;
  z-index: 1;
  top: -0.4em;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
}
.sc_icons_number.sc_align_right .sc_icons_item {
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}
.sc_icons_number.sc_align_right .sc_icons_item_header {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_number.sc_align_right .sc_icons_item_number {
  position: absolute;
  z-index: 1;
  top: -0.4em;
  right: 0;
}
.extra_hover .sc_icons_number .sc_icons_item:hover .sc_icons_item_title a, .extra_hover .sc_icons_number .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-text_link2) !important;
}

/* Style 'Rounded' */
.sc_icons_rounded .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_rounded .sc_icons_icon, .sc_icons_rounded .sc_icons_image {
  position: relative;
  top: auto;
  left: auto;
  display: inline-block;
  width: 7em;
  height: 7em;
  line-height: 7em;
  text-align: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 6px 30px rgba(0, 0, 0, 0.03);
  -ms-box-shadow: 0 6px 30px rgba(0, 0, 0, 0.03);
  box-shadow: 0 6px 30px rgba(0, 0, 0, 0.03);
  -webkit-transition: -webkit-transform 0.3s ease-out, box-shadow 0.3s ease, color 0.3s ease, background-color 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease-out, box-shadow 0.3s ease, color 0.3s ease, background-color 0.3s ease;
  transition: transform 0.3s ease-out, box-shadow 0.3s ease, color 0.3s ease, background-color 0.3s ease;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.sc_icons_rounded .sc_icons_item:hover .sc_icons_icon,
.sc_icons_rounded .sc_icons_item:hover .sc_icons_image {
  -webkit-transform: translate3d(0, -8px, 0);
  -ms-transform: translate3d(0, -8px, 0);
  transform: translate3d(0, -8px, 0);
  -webkit-box-shadow: 0 6px 30px rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 6px 30px rgba(0, 0, 0, 0.04);
  box-shadow: 0 6px 30px rgba(0, 0, 0, 0.04);
}
.sc_icons_rounded .sc_icons_item_linked:hover .sc_icons_icon {
  -webkit-box-shadow: 0 6px 30px rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 6px 30px rgba(0, 0, 0, 0.04);
  box-shadow: 0 6px 30px rgba(0, 0, 0, 0.04);
}
.sc_icons_rounded .sc_icons_image img {
  max-width: 60%;
  vertical-align: middle;
}
.sc_icons_rounded .sc_icons_icon > span {
  display: inline-block;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: 7em;
  height: 7em;
  line-height: 7em;
  text-align: center;
}
.sc_icons_rounded .sc_icons_icon:before,
.sc_icons_rounded .sc_icons_icon > span:before {
  font-size: 3.4em;
  line-height: inherit !important;
}
.sc_icons_rounded .sc_icon_type_svg svg,
.sc_icons_rounded .sc_icon_type_svg object {
  width: 3.4em;
  height: 3.4em;
  margin: -0.25em 0 0 0;
}
.sc_icons_rounded .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.8em;
}
.sc_icons_rounded .sc_icons_icon + .sc_icons_item_details,
.sc_icons_rounded .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.8em;
}
.sc_icons_rounded .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_rounded .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.5em;
}
.sc_icons_rounded.sc_icons_size_small .sc_icons_icon, .sc_icons_rounded.sc_icons_size_small .sc_icons_image {
  width: 6em;
  height: 6em;
  line-height: 6em;
  text-align: center;
}
.sc_icons_rounded.sc_icons_size_small .sc_icons_icon > span {
  width: 6em;
  height: 6em;
  line-height: 6em;
  text-align: center;
}
.sc_icons_rounded.sc_icons_size_small .sc_icons_icon:before, .sc_icons_rounded.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.4em;
  line-height: inherit !important;
}
.sc_icons_rounded.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_rounded.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.4em;
  height: 2.4em;
}
.sc_icons_rounded.sc_icons_size_large .sc_icons_icon, .sc_icons_rounded.sc_icons_size_large .sc_icons_image {
  width: 8em;
  height: 8em;
  line-height: 8em;
  text-align: center;
}
.sc_icons_rounded.sc_icons_size_large .sc_icons_icon > span {
  width: 8em;
  height: 8em;
  line-height: 8em;
  text-align: center;
}
.sc_icons_rounded.sc_icons_size_large .sc_icons_icon:before, .sc_icons_rounded.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4.4em;
  line-height: inherit !important;
}
.sc_icons_rounded.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_rounded.sc_icons_size_large .sc_icon_type_svg object {
  width: 4.4em;
  height: 4.4em;
}
.sc_icons_rounded .sc_icons_icon {
  color: var(--theme-color-alter_link);
  background-color: var(--theme-color-alter_bg_hover);
}
.sc_icons_rounded.color_style_link2 .sc_icons_icon {
  color: var(--theme-color-alter_link2);
}
.sc_icons_rounded.color_style_link3 .sc_icons_icon {
  color: var(--theme-color-alter_link3);
}
.sc_icons_rounded.color_style_dark .sc_icons_icon {
  color: var(--theme-color-alter_dark);
}

/* Style 'Common' */
.sc_icons_common .sc_icons_item .sc_icons_image,
.sc_icons_common .sc_icons_item .sc_icons_icon {
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
  -webkit-transition: -webkit-transform 0.3s ease-out, color 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease-out, color 0.3s ease;
  transition: transform 0.3s ease-out, color 0.3s ease;
  will-change: transform, color;
}
.sc_icons_common .sc_icons_item:hover .sc_icons_image,
.sc_icons_common .sc_icons_item:hover .sc_icons_icon {
  -webkit-transform: translateY(-8px);
  -ms-transform: translateY(-8px);
  transform: translateY(-8px);
}
.sc_icons_common .sc_icons_icon + .sc_icons_item_details,
.sc_icons_common .sc_icons_image + .sc_icons_item_details {
  margin-top: 2em;
}
.sc_icons_common .sc_icons_image img {
  max-width: 100%;
}
.sc_icons_common .sc_icons_item_linked:hover .sc_icons_image img {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.sc_icons_common.color_style_link2 .sc_icons_item_description ul > li:before {
  color: var(--theme-color-text_link2);
}
.sc_icons_common.color_style_link3 .sc_icons_item_description ul > li:before {
  color: var(--theme-color-text_link3);
}
.sc_icons_common.color_style_dark .sc_icons_item_description ul > li:before {
  color: var(--theme-color-text_dark);
}

/* Style 'Divider' */
.sc_icons_divider .slider-wrapper .sc_icons_item,
.sc_icons_divider .sc_icons_columns_wrap .sc_icons_item {
  position: relative;
  padding: 15px 20px 15px 0;
}
.sc_icons_divider .slider-wrapper .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .sc_icons_item:after {
  content: '';
  display: block;
  height: 100%;
  width: 1px;
  position: absolute;
  right: 0;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-bd_color);
}
.sc_icons_divider .slider-wrapper .sc_icons_item:after {
  right: -1px;
}
.sc_icons_divider .slider-wrapper .swiper-slide-prev .sc_icons_item:after {
  right: 0;
}
.sc_icons_divider.sc_align_center .slider-wrapper .sc_icons_item, .sc_icons_divider.sc_align_center .sc_icons_columns_wrap .sc_icons_item {
  padding: 15px 20px;
}
.sc_icons_divider.sc_align_center .sc_icons_columns_wrap .sc_icons_item:after {
  right: -25px;
}
.sc_icons_divider.sc_align_right .slider-wrapper .sc_icons_item, .sc_icons_divider.sc_align_right .sc_icons_columns_wrap .sc_icons_item {
  padding: 15px 0 15px 20px;
}
.sc_icons_divider.sc_align_right .sc_icons_columns_wrap .sc_icons_item:after {
  right: -50px;
}
.sc_icons_divider .sc_icons_columns_wrap.trx_addons_columns_wrap {
  margin-right: -50px;
  margin-bottom: -50px;
}
.sc_icons_divider .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 50px;
}
.sc_icons_divider .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_icons_divider .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"].columns_padding_bottom {
  padding-bottom: 50px;
}
.sc_icons_divider .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row {
  margin-bottom: 0;
}
.sc_icons_divider .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_icons_divider .sc_icons_columns_wrap [class*="trx_addons_column-"]:last-child .sc_icons_item:after {
  display: none;
}
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_2:nth-child(2n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_3:nth-child(3n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_4:nth-child(4n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_5:nth-child(5n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_6:nth-child(6n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_7:nth-child(7n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_8:nth-child(8n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_9:nth-child(9n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_10:nth-child(10n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_11:nth-child(11n) .sc_icons_item:after,
.sc_icons_divider .sc_icons_columns_wrap .trx_addons_column-1_12:nth-child(12n) .sc_icons_item:after {
  display: none;
}
.sc_icons_divider .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_divider .sc_icons_icon + .sc_icons_item_details,
.sc_icons_divider .sc_icons_image + .sc_icons_item_details {
  margin-top: 2.35em;
}
.sc_icons_divider .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_divider .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 3.2em;
}
.sc_icons_divider .sc_icons_icon:before,
.sc_icons_divider .sc_icons_icon > span:before {
  font-size: 4.4em;
}
.sc_icons_divider .sc_icon_type_svg svg,
.sc_icons_divider .sc_icon_type_svg object {
  width: 4.4em;
  height: 4.4em;
}
.sc_icons_divider.sc_icons_size_small .sc_icons_icon:before, .sc_icons_divider.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 3.4em;
}
.sc_icons_divider.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_divider.sc_icons_size_small .sc_icon_type_svg object {
  width: 3.4em;
  height: 3.4em;
}
.sc_icons_divider.sc_icons_size_large .sc_icons_icon:before, .sc_icons_divider.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5.4em;
}
.sc_icons_divider.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_divider.sc_icons_size_large .sc_icon_type_svg object {
  width: 5.4em;
  height: 5.4em;
}

/* Style 'Divider 2' */
.sc_icons_divider2 {
  padding: 4.4em 0;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 3px 60px rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 3px 60px rgba(0, 0, 0, 0.04);
  box-shadow: 0 3px 60px rgba(0, 0, 0, 0.04);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_icons_divider2 .slider-wrapper .sc_icons_item,
.sc_icons_divider2 .sc_icons_columns_wrap .sc_icons_item {
  position: relative;
  padding: 0 2em;
}
.sc_icons_divider2 .slider-wrapper .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .sc_icons_item:after {
  content: '';
  display: block;
  height: 96%;
  width: 1px;
  position: absolute;
  right: 0;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-alter_bd_color);
}
.sc_icons_divider2 .slider-wrapper .sc_icons_item:after {
  right: -1px;
}
.sc_icons_divider2 .slider-wrapper .swiper-slide-prev .sc_icons_item:after {
  right: 0;
}
.sc_icons_divider2.sc_align_center .sc_icons_columns_wrap .sc_icons_item:after {
  right: -25px;
}
.sc_icons_divider2.sc_align_right .sc_icons_columns_wrap .sc_icons_item:after {
  right: -50px;
}
.sc_icons_divider2 .sc_icons_columns_wrap.trx_addons_columns_wrap {
  margin-right: -50px;
  margin-bottom: -50px;
}
.sc_icons_divider2 .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 50px;
}
.sc_icons_divider2 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_icons_divider2 .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"].columns_padding_bottom {
  padding-bottom: 50px;
}
.sc_icons_divider2 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row {
  margin-bottom: 0;
}
.sc_icons_divider2 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_icons_divider2 .sc_icons_columns_wrap [class*="trx_addons_column-"]:last-child .sc_icons_item:after {
  display: none;
}
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_2:nth-child(2n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_3:nth-child(3n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_4:nth-child(4n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_5:nth-child(5n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_6:nth-child(6n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_7:nth-child(7n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_8:nth-child(8n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_9:nth-child(9n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_10:nth-child(10n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_11:nth-child(11n) .sc_icons_item:after,
.sc_icons_divider2 .sc_icons_columns_wrap .trx_addons_column-1_12:nth-child(12n) .sc_icons_item:after {
  display: none;
}
.sc_icons_divider2 .sc_icons_item_title {
  font-size: 1.556em;
  line-height: 1.2em;
}
.sc_icons_divider2 .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.8em;
}
.sc_icons_divider2 .sc_icons_icon + .sc_icons_item_details,
.sc_icons_divider2 .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.8em;
}
.sc_icons_divider2 .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_divider2 .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 2em;
}
.sc_icons_divider2 .sc_icons_icon:before,
.sc_icons_divider2 .sc_icons_icon > span:before {
  font-size: 4.7em;
}
.sc_icons_divider2 .sc_icon_type_svg svg,
.sc_icons_divider2 .sc_icon_type_svg object {
  width: 4.7em;
  height: 4.7em;
}
.sc_icons_divider2.sc_icons_size_small .sc_icons_icon:before, .sc_icons_divider2.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 3.7em;
}
.sc_icons_divider2.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_divider2.sc_icons_size_small .sc_icon_type_svg object {
  width: 3.7em;
  height: 3.7em;
}
.sc_icons_divider2.sc_icons_size_large .sc_icons_icon:before, .sc_icons_divider2.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 5.7em;
}
.sc_icons_divider2.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_divider2.sc_icons_size_large .sc_icon_type_svg object {
  width: 5.7em;
  height: 5.7em;
}

/* Style 'Divider 3' */
.sc_icons_divider3 .sc_icons_item_wrap + .sc_icons_item_wrap {
  margin-top: var(--theme-var-grid_gap);
}
.sc_icons_divider3 .slider-wrapper .sc_icons_item_wrap,
.sc_icons_divider3 .sc_icons_columns_wrap .sc_icons_item_wrap {
  position: relative;
  padding: 0 2.2em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_icons_divider3 .slider-wrapper .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .sc_icons_item_wrap:after {
  content: '';
  display: block;
  height: 150px;
  width: 1px;
  position: absolute;
  right: -25px;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-bd_color);
}
.sc_icons_divider3 .slider-wrapper .sc_icons_item_wrap:after {
  right: -1px;
}
.sc_icons_divider3 .slider-wrapper .swiper-slide-prev .sc_icons_item_wrap:after {
  right: 0;
}
.sc_icons_divider3 .sc_icons_item {
  position: relative;
  padding: 3.8em 2em 3em;
  background-color: transparent;
  will-change: background-color;
  -webkit-transition: background-color 0.3s ease;
  -ms-transition: background-color 0.3s ease;
  transition: background-color 0.3s ease;
}
.sc_icons_divider3 .sc_icons_item:hover {
  background-color: var(--theme-color-text_link);
}
.sc_icons_divider3 .sc_icons_columns_wrap.trx_addons_columns_wrap {
  margin-right: -50px;
  margin-bottom: -50px;
}
.sc_icons_divider3 .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 50px;
}
.sc_icons_divider3 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_icons_divider3 .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"].columns_padding_bottom {
  padding-bottom: 50px;
}
.sc_icons_divider3 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row {
  margin-bottom: 0;
}
.sc_icons_divider3 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_icons_divider3 .sc_icons_columns_wrap [class*="trx_addons_column-"]:last-child .sc_icons_item_wrap:after {
  display: none;
}
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_2:nth-child(2n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_3:nth-child(3n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_4:nth-child(4n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_5:nth-child(5n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_6:nth-child(6n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_7:nth-child(7n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_8:nth-child(8n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_9:nth-child(9n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_10:nth-child(10n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_11:nth-child(11n) .sc_icons_item_wrap:after,
.sc_icons_divider3 .sc_icons_columns_wrap .trx_addons_column-1_12:nth-child(12n) .sc_icons_item_wrap:after {
  display: none;
}
.sc_icons_divider3 .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_divider3 .sc_icons_item_title {
  font-size: 1.333em;
  line-height: 1.2em;
}
.sc_icons_divider3 .sc_icons_item .sc_icons_item_title,
.sc_icons_divider3 .sc_icons_item .sc_icons_item_title span {
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_icons_divider3 .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_divider3 .sc_icons_item:hover .sc_icons_item_title span,
.sc_icons_divider3 .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_divider3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_divider3 .sc_icons_icon + .sc_icons_item_details,
.sc_icons_divider3 .sc_icons_image + .sc_icons_item_details {
  margin-top: 1.5em;
}
.sc_icons_divider3 .sc_icons_item .sc_icons_item_description {
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_icons_divider3 .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_link);
}
.sc_icons_divider3 .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.7em;
}
.sc_icons_divider3 .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_divider3 .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_divider3 .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 2em;
}
.sc_icons_divider3 .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_divider3 .sc_icons_icon:before,
.sc_icons_divider3 .sc_icons_icon > span:before {
  font-size: 3.8em;
}
.sc_icons_divider3 .sc_icon_type_svg svg,
.sc_icons_divider3 .sc_icon_type_svg object {
  width: 3.8em;
  height: 3.8em;
}
.sc_icons_divider3.sc_icons_size_small .sc_icons_icon:before, .sc_icons_divider3.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2.8em;
}
.sc_icons_divider3.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_divider3.sc_icons_size_small .sc_icon_type_svg object {
  width: 2.8em;
  height: 2.8em;
}
.sc_icons_divider3.sc_icons_size_large .sc_icons_icon:before, .sc_icons_divider3.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 4.8em;
}
.sc_icons_divider3.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_divider3.sc_icons_size_large .sc_icon_type_svg object {
  width: 4.8em;
  height: 4.8em;
}
.sc_icons_divider3.color_style_link2 .sc_icons_item:hover {
  background-color: var(--theme-color-text_link2);
}
.sc_icons_divider3.color_style_link2 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_divider3.color_style_link2 .sc_icons_item:hover .sc_icons_item_title span, .sc_icons_divider3.color_style_link2 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_divider3.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_divider3.color_style_link3 .sc_icons_item:hover {
  background-color: var(--theme-color-text_link3);
}
.sc_icons_divider3.color_style_link3 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_divider3.color_style_link3 .sc_icons_item:hover .sc_icons_item_title span, .sc_icons_divider3.color_style_link3 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_divider3.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_divider3.color_style_dark .sc_icons_item:hover {
  background-color: var(--theme-color-text_dark);
}
.sc_icons_divider3.color_style_dark .sc_icons_item:hover .sc_icons_item_title, .sc_icons_divider3.color_style_dark .sc_icons_item:hover .sc_icons_item_title span, .sc_icons_divider3.color_style_dark .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_divider3.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_divider3.color_style_dark .sc_icons_item:hover .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_divider3.color_style_dark .sc_icons_item:hover .sc_icons_item_description {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_divider3.color_style_dark .sc_icons_item:hover .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}

/* Style 'Divider 4' */
.sc_icons_divider4 .slider-wrapper .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .sc_icons_item:after {
  content: '';
  display: block;
  height: 100%;
  width: 1px;
  position: absolute;
  right: 0;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  background-color: var(--theme-color-bd_color);
}
.sc_icons_divider4 .slider-wrapper .sc_icons_item:after {
  right: -1px;
}
.sc_icons_divider4 .slider-wrapper .swiper-slide-prev .sc_icons_item:after {
  right: 0;
}
.sc_icons_divider4.sc_align_center .sc_icons_columns_wrap .sc_icons_item:after {
  right: calc( -1 * var(--theme-var-grid_gap) );
}
.sc_icons_divider4.sc_align_right .sc_icons_columns_wrap .sc_icons_item:after {
  right: calc( -1 * var(--theme-var-grid_gap) );
}
.sc_icons_divider4 .sc_icons_columns_wrap.trx_addons_columns_wrap {
  margin-right: calc( -2 * var(--theme-var-grid_gap) );
  margin-bottom: calc( -2 * var(--theme-var-grid_gap) );
}
.sc_icons_divider4 .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: calc( 2 * var(--theme-var-grid_gap) );
}
.sc_icons_divider4 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_icons_divider4 .sc_icons_columns_wrap.trx_addons_columns_wrap > [class*="trx_addons_column-"].columns_padding_bottom {
  padding-bottom: calc( 2 * var(--theme-var-grid_gap) );
}
.sc_icons_divider4 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row {
  margin-bottom: 0;
}
.sc_icons_divider4 .sc_icons_columns_wrap.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}
.sc_icons_divider4 .sc_icons_columns_wrap [class*="trx_addons_column-"]:last-child .sc_icons_item:after {
  display: none;
}
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_2:nth-child(2n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_3:nth-child(3n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_4:nth-child(4n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_5:nth-child(5n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_6:nth-child(6n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_7:nth-child(7n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_8:nth-child(8n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_9:nth-child(9n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_10:nth-child(10n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_11:nth-child(11n) .sc_icons_item:after,
.sc_icons_divider4 .sc_icons_columns_wrap .trx_addons_column-1_12:nth-child(12n) .sc_icons_item:after {
  display: none;
}
.sc_icons_divider4 .sc_icons_item {
  padding: 13px 0;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_icons_divider4 .sc_icons_icon,
.sc_icons_divider4 .sc_icons_image {
  width: 3.4em;
  height: 3.4em;
  line-height: 3.4em;
  text-align: center;
}
.sc_icons_divider4 .sc_icons_icon > span {
  width: 3.4em;
  height: 3.4em;
  line-height: 3.4em;
  text-align: center;
}
.sc_icons_divider4 .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_divider4 .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.2em;
}
.sc_icons_divider4 .sc_icons_item_details {
  padding-left: 0;
  padding-right: 5%;
  min-height: auto;
}
.sc_icons_divider4.sc_icons_size_large .sc_icons_item_details, .sc_icons_divider4.sc_icons_size_small .sc_icons_item_details {
  padding-left: 0;
  min-height: auto;
}
.sc_icons_divider4.sc_align_right .sc_icons_item_details, .sc_icons_divider4.sc_icons_size_small.sc_align_right .sc_icons_item_details, .sc_icons_divider4.sc_icons_size_large.sc_align_right .sc_icons_item_details {
  padding-left: 5%;
  padding-right: 0;
}
.sc_icons_divider4 .sc_icons_icon + .sc_icons_item_details,
.sc_icons_divider4 .sc_icons_image + .sc_icons_item_details {
  margin-left: 0.8em;
  margin-top: 0.6em;
}
.sc_icons_divider4.sc_icons_size_large .sc_icons_icon + .sc_icons_item_details, .sc_icons_divider4.sc_icons_size_large .sc_icons_image + .sc_icons_item_details {
  margin-left: 1.2em;
  margin-top: 0.8em;
}
.sc_icons_divider4 .sc_icons_item_title {
  font-size: 1.056em;
  line-height: 1.2em;
}
.sc_icons_divider4 .sc_icons_item_details .sc_icons_item_description {
  font-size: 15px;
  line-height: 1.4em;
}
.sc_icons_divider4 .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 0.5em;
}
.sc_icons_divider4.sc_align_right .sc_icons_icon + .sc_icons_item_details, .sc_icons_divider4.sc_align_right .sc_icons_image + .sc_icons_item_details {
  margin-left: 0;
  margin-right: 1.8em;
}
.sc_icons_divider4.sc_align_center .sc_icons_item {
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}
.sc_icons_divider4.sc_align_right .sc_icons_item {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_icons_divider4.sc_align_right .sc_icons_item .sc_icons_item_details {
  order: 1;
}
.sc_icons_divider4.sc_align_right .sc_icons_item .sc_icons_icon, .sc_icons_divider4.sc_align_right .sc_icons_item .sc_icons_image {
  order: 2;
}
.sc_icons_divider4 .sc_icons_icon:before,
.sc_icons_divider4 .sc_icons_icon > span:before {
  font-size: 2.6em;
}
.sc_icons_divider4 .sc_icon_type_svg svg,
.sc_icons_divider4 .sc_icon_type_svg object {
  width: 2.6em;
  height: 2.6em;
}
.sc_icons_divider4.sc_icons_size_small .sc_icons_icon:before, .sc_icons_divider4.sc_icons_size_small .sc_icons_icon > span:before {
  font-size: 2em;
}
.sc_icons_divider4.sc_icons_size_small .sc_icon_type_svg svg, .sc_icons_divider4.sc_icons_size_small .sc_icon_type_svg object {
  width: 2em;
  height: 2em;
}
.sc_icons_divider4.sc_icons_size_large .sc_icons_icon:before, .sc_icons_divider4.sc_icons_size_large .sc_icons_icon > span:before {
  font-size: 3em;
}
.sc_icons_divider4.sc_icons_size_large .sc_icon_type_svg svg, .sc_icons_divider4.sc_icons_size_large .sc_icon_type_svg object {
  width: 3em;
  height: 3em;
}

/* Style Fill */
.sc_icons_fill .sc_icons_item {
  padding: 3.5em 3.4em;
  background-color: var(--theme-color-alter_link);
}
.sc_icons_fill .sc_icons_item_title + .sc_icons_item_description {
  margin-top: 1em;
}
.sc_icons_fill .sc_icons_icon + .sc_icons_item_details,
.sc_icons_fill .sc_icons_image + .sc_icons_item_details {
  margin-top: 2.7em;
}
.sc_icons_fill .sc_icons_item .sc_icons_item_title + .sc_icons_item_more_link,
.sc_icons_fill .sc_icons_item .sc_icons_item_description + .sc_icons_item_more_link {
  margin-top: 1.85em;
}
.sc_icons_fill .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill .sc_icons_item_linked:hover .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill .sc_icons_item .sc_icons_item_title,
.sc_icons_fill .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill .sc_icons_item:hover .sc_icons_item_title,
.sc_icons_fill .sc_icons_item:hover .sc_icons_item_title a,
.sc_icons_fill .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill .sc_icons_item .sc_icons_item_description {
  font-size: 15px;
  line-height: 1.65em;
  color: var(--theme-color-inverse_link_08);
}
.sc_icons_fill .sc_icons_item .sc_icons_item_more_link {
  margin-top: 19px;
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill .sc_icons_item .sc_icons_item_more_link .link_text {
  display: none;
}
.sc_icons_fill .sc_icons_item .sc_icons_item_more_link .link_icon {
  display: inline-block;
  width: 17px;
  height: 20px;
  line-height: 20px;
  overflow: hidden;
  position: relative;
  will-change: transform;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_icons_fill .sc_icons_item .sc_icons_item_more_link .link_icon:before {
  display: block;
  font-family: "fontello";
  content: '\e9e2';
  position: absolute;
  z-index: 1;
  top: 0;
  right: 1px;
  font-size: 11px;
  line-height: 20px;
  font-weight: 400;
  color: currentColor;
}
.sc_icons_fill .sc_icons_item:hover .sc_icons_item_more_link .link_icon {
  width: 38px;
}
.sc_icons_fill .sc_icons_item.sc_icons_item_linked.with_more .sc_icons_item_link {
  z-index: 10;
}
.sc_icons_fill.color_style_link2 .sc_icons_item {
  background-color: var(--theme-color-alter_link2);
}
.sc_icons_fill.color_style_link2 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link2 .sc_icons_item .sc_icons_item_title, .sc_icons_fill.color_style_link2 .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link2 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_fill.color_style_link2 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_fill.color_style_link2 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link2 .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_link_08);
}
.sc_icons_fill.color_style_link2 .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link3 .sc_icons_item {
  background-color: var(--theme-color-alter_link3);
}
.sc_icons_fill.color_style_link3 .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link3 .sc_icons_item .sc_icons_item_title, .sc_icons_fill.color_style_link3 .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link3 .sc_icons_item:hover .sc_icons_item_title, .sc_icons_fill.color_style_link3 .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_fill.color_style_link3 .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_link3 .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_link_08);
}
.sc_icons_fill.color_style_link3 .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_icons_fill.color_style_dark .sc_icons_item {
  background-color: var(--theme-color-alter_dark);
}
.sc_icons_fill.color_style_dark .sc_icons_item .sc_icons_icon {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_fill.color_style_dark .sc_icons_item .sc_icons_item_title, .sc_icons_fill.color_style_dark .sc_icons_item .sc_icons_item_title a {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_fill.color_style_dark .sc_icons_item:hover .sc_icons_item_title, .sc_icons_fill.color_style_dark .sc_icons_item:hover .sc_icons_item_title a, .sc_icons_fill.color_style_dark .sc_icons_item .sc_icons_item_title a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_icons_fill.color_style_dark .sc_icons_item .sc_icons_item_description {
  color: var(--theme-color-inverse_hover_08);
}
.sc_icons_fill.color_style_dark .sc_icons_item .sc_icons_item_more_link {
  color: var(--theme-color-inverse_hover);
}

/* Team */
.sc_team .sc_item_posts_container > .sc_team_item + .sc_team_item {
  margin-top: 1.8em;
}

.sc_team_default .sc_team_item {
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}

.sc_team .sc_team_item_thumb .sc_team_item_title a:hover {
  color: var(--theme-color-alter_link);
}

.sc_team.color_style_link2 .sc_team_item_thumb .sc_team_item_title a:hover {
  color: var(--theme-color-alter_link2);
}

.sc_team.color_style_link3 .sc_team_item_thumb .sc_team_item_title a:hover {
  color: var(--theme-color-alter_link3);
}

.sc_team_default .sc_team_item_subtitle {
  color: var(--theme-color-alter_link);
}

.sc_team_default.color_style_link2 .sc_team_item_subtitle {
  color: var(--theme-color-alter_link2);
}

.sc_team_default.color_style_link3 .sc_team_item_subtitle {
  color: var(--theme-color-alter_link3);
}

.sc_team_default.color_style_dark .sc_team_item_subtitle {
  color: var(--theme-color-alter_dark);
}

.sc_team_default .sc_team_item_socials .social_item .social_icon,
.team_member_page .team_member_socials .social_item .social_icon {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_link);
}

.sc_team_default.color_style_link2 .sc_team_item_socials .social_item .social_icon {
  background-color: var(--theme-color-alter_link2);
}

.sc_team_default.color_style_link3 .sc_team_item_socials .social_item .social_icon {
  background-color: var(--theme-color-alter_link3);
}

.sc_team_default.color_style_dark .sc_team_item_socials .social_item .social_icon {
  background-color: var(--theme-color-alter_dark);
}

.sc_team_default .sc_team_item_socials .social_item:hover .social_icon,
.team_member_page .team_member_socials .social_item:hover .social_icon {
  color: var(--theme-color-alter_bg_color);
  background-color: var(--theme-color-alter_dark);
}

.sc_team_default.color_style_link2 .sc_team_item_socials .social_item:hover .social_icon {
  background-color: var(--theme-color-alter_hover2);
}

.sc_team_default.color_style_link3 .sc_team_item_socials .social_item:hover .social_icon {
  background-color: var(--theme-color-alter_hover3);
}

.sc_team_default.color_style_dark .sc_team_item_socials .social_item:hover .social_icon {
  background-color: var(--theme-color-alter_link);
}

.sc_team.slider_container .swiper-pagination-bullet {
  border-color: var(--theme-color-text_light);
}

.team_member_projects {
  border-color: var(--theme-color-bd_color);
}

/* Single Teams */
.team_member_page > .team_member_content,
.team_member_page > .team_member_featured {
  margin-bottom: 1.2em;
}
.team_member_page:after {
  content: "";
  display: block;
  clear: both;
  width: 100%;
  height: 0;
  display: block;
  margin-bottom: -1.2em;
}
.team_member_page .team_member_description {
  overflow: visible;
  margin: 0 0 2.8em 0;
}
.team_member_page .team_member_position {
  font-size: 15px;
  line-height: 18px;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 0.5px;
  color: var(--theme-color-text_dark);
}
.team_member_page .team_member_position + .team_member_title {
  margin-top: 16px;
}
.team_member_page .team_member_title {
  margin: 0;
  font-size: 57px;
  line-height: 1.1em;
  color: var(--theme-color-text_dark);
}
.team_member_page .team_member_featured {
  float: left;
  width: 53%;
  padding: 0 50px 0 0;
}
.team_member_page .team_member_featured .post_featured {
  overflow: hidden;
  position: relative;
  margin-bottom: 55px;
}
.team_member_page .team_member_featured .team_member_description_socials {
  z-index: 99;
  position: relative;
}
.team_member_page .team_member_featured .team_member_description_socials .team_member_socials {
  margin: 0;
}
.team_member_page .team_member_description_socials .team_member_socials .social_item {
  display: inline-block;
  vertical-align: top;
  line-height: 1;
  margin: 0 7px 7px 0;
}
.team_member_page .team_member_description_socials .team_member_socials .social_item .social_icon {
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  border: none;
  font-size: 16px;
  width: 45px;
  height: 45px;
  line-height: 45px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  margin: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.team_member_page .team_member_description_socials .team_member_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-alter_bg_color);
  margin-top: -8px;
}

.team_member_projects .team_member_projects_title,
.team_page_related .related_wrap_title {
  margin: 0 0 0.85em 0;
  font-size: 47px;
}

.sidebar_show .team_page_wrap_info .team_page_wrap_info_over {
  padding-top: 0 !important;
}

.sidebar_show .team_page_wrap_info:after {
  display: none;
}

.single-cpt_team .page_content_wrap {
  overflow: hidden;
}

body:not(.remove_margins) .team_page_wrap_info.comments_close {
  margin-bottom: -7.4em;
}

.team_page_wrap_info {
  position: relative;
  margin-top: 6.5em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
}
.team_page_wrap_info .team_page_wrap_info_over {
  position: relative;
  padding: 100px 0 120px;
  overflow: hidden;
}
.team_page_wrap_info:before {
  content: "";
  display: block;
  position: absolute;
  top: 0;
  left: -400%;
  width: 1000%;
  height: 100%;
  background-color: var(--theme-color-alter_bg_color);
  z-index: 0;
}
.team_page_wrap_info .team_member_details {
  float: left;
  width: 43%;
  padding: 0 7% 0 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.team_page_wrap_info .team_member_details .team_member_brief_info_text {
  font-size: 15px;
  line-height: 1.64em;
}
.team_page_wrap_info .team_member_details:last-child {
  padding: 0;
  width: 100%;
  float: none;
}
.team_page_wrap_info .section_title {
  margin: 0 0 0.85em 0;
  font-size: 47px;
}
.team_page_wrap_info .page_contact_form {
  margin: 0 !important;
  padding: 0 !important;
  border: none !important;
  overflow: visible;
  float: right;
  width: 57%;
}
.team_page_wrap_info .page_contact_form div.wpcf7 .form-style-5 {
  margin-top: -10px;
}
.team_page_wrap_info .page_contact_form div.wpcf7 .form-style-5 .wpcf7-submit-style {
  margin-top: 15px;
}
.team_page_wrap_info .page_contact_form div.wpcf7 .form-style-5 .trx_addons_message_box.wpcf7-response-output,
.team_page_wrap_info .page_contact_form div.wpcf7 .form-style-5 div.wpcf7-response-output {
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
}
.team_page_wrap_info .page_contact_form:first-child {
  width: 100%;
  float: none;
}
.team_page_wrap_info .page_contact_form:first-child .wpcf7 .wpcf7-submit {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.team_page_wrap_info .page_contact_form .wpcf7 .trx_addons_message_box {
  -webkit-box-shadow: none !important;
  -ms-box-shadow: none !important;
  box-shadow: none !important;
}
.team_page_wrap_info .team_member_brief_info_details {
  font-size: 1rem;
  margin-left: -3px;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_value a:hover,
.team_page_wrap_info .team_member_brief_info_details .team_member_details_value a,
.team_page_wrap_info .team_member_brief_info_details .team_member_details_value {
  color: var(--theme-color-alter_text);
}
.team_page_wrap_info .team_member_brief_info_details > div {
  margin-top: 15px;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_label {
  width: 1.3em;
  height: 1.3em;
  line-height: 1.3em;
  text-align: center;
  text-indent: -300px;
  font-size: 23px;
  overflow: hidden;
  flex-shrink: 0;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_label:before {
  display: block;
  text-indent: 0;
  font-family: "fontello";
  color: var(--theme-color-text_link2);
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_label + .team_member_details_value {
  margin-left: 10px;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_email .team_member_details_label:before {
  content: '\e9fc';
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_email .team_member_details_value > a {
  position: relative;
  padding-bottom: 8px;
  margin-bottom: -8px;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_email .team_member_details_value > a:after {
  content: '';
  display: block;
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 1px;
  background: currentColor;
  -webkit-transform-origin: center center;
  -ms-transform-origin: center center;
  transform-origin: center center;
  -webkit-transform: scale3d(0, 1, 1);
  -ms-transform: scale3d(0, 1, 1);
  transform: scale3d(0, 1, 1);
  -webkit-transition: -webkit-transform 0.25s cubic-bezier(0.25, 0.8, 0.25, 1);
  -ms-transition: -ms-transform 0.25s cubic-bezier(0.25, 0.8, 0.25, 1);
  transition: transform 0.25s cubic-bezier(0.25, 0.8, 0.25, 1);
  will-change: transform;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_email .team_member_details_value > a:hover {
  color: var(--theme-color-text_dark);
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_email .team_member_details_value > a:hover:after {
  -webkit-transform-origin: center center;
  -ms-transform-origin: center center;
  transform-origin: center center;
  -webkit-transform: scale3d(1, 1, 1);
  -ms-transform: scale3d(1, 1, 1);
  transform: scale3d(1, 1, 1);
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_phone .team_member_details_value {
  font-size: 18px;
  font-weight: 700;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_phone .team_member_details_value a:hover,
.team_page_wrap_info .team_member_brief_info_details .team_member_details_phone .team_member_details_value a {
  color: var(--theme-color-text_dark);
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_phone .team_member_details_label:before {
  content: '\e9cf';
  text-indent: -1px;
}
.team_page_wrap_info .team_member_brief_info_details .team_member_details_address .team_member_details_label:before {
  content: '\e9d2';
}
.team_page_wrap_info .team_member_brief_info_details .sc_icons_item_details {
  line-height: 1;
}

.team_member_page:not(.has-post-thumbnail) + .team_page_wrap_info .team_member_description_socials {
  margin-top: 20px;
}
.team_member_page:not(.has-post-thumbnail) + .team_page_wrap_info .socials_wrap:not(.socials_type_list) .social_item .social_icon {
  font-size: 16px;
  width: 45px;
  height: 45px;
  line-height: 45px;
  background-color: var(--theme-color-bg_color);
}

.related_wrap.team_page_related .sc_team_posts_item .post_categories {
  text-transform: uppercase;
}
.related_wrap.team_page_related .sc_team_posts_item .sc_team_posts_item_title {
  font-size: 24px;
  line-height: 1.2em;
  font-weight: 500;
}
.related_wrap.team_page_related .sc_team_posts_item .post_meta {
  margin: 0.8em 0 0 0;
}
.related_wrap.team_page_related .sc_team_posts_item .sc_team_posts_item_content {
  display: none;
  margin-top: 0.6em;
}
.related_wrap.team_page_related .sc_team_posts_item .post_featured {
  margin-bottom: 1.3em;
}

/* Default */
.sc_team_default .sc_team_item {
  text-align: center;
  display: block;
}
.sc_team_default .sc_team_item .sc_team_item_content {
  display: none;
}

.sc_team_default .sc_team_item_info {
  padding: 2em;
  text-align: center;
}
.sc_team_default .sc_team_item_info .sc_team_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_default .sc_team_item_info .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 11px;
  color: var(--theme-color-alter_text);
}
.sc_team_default .sc_team_item_info .sc_team_item_content {
  margin-top: 1em;
  margin-bottom: 1em;
}
.sc_team_default .sc_team_item_info .sc_team_item_content + .sc_team_item_socials {
  margin-top: 1em;
}
.sc_team_default .sc_team_item_info .sc_team_item_socials {
  margin-left: -2px;
  margin-top: 15px;
}
.sc_team_default .sc_team_item_info .sc_team_item_socials .social_item {
  will-change: transform;
  position: relative;
  margin: 3px 5px 3px 0;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_default .sc_team_item_info .sc_team_item_socials .social_item .social_icon {
  top: 0;
  position: relative;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  color: var(--theme-color-text_dark);
  border: 1px solid var(--theme-color-alter_bd_color);
  font-size: 16px;
  width: 45px;
  height: 45px;
  line-height: 43px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  text-align: center;
  background-color: transparent !important;
}
.sc_team_default .sc_team_item_info .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link) !important;
  top: -7px;
}

/* Featured */
.sc_team_featured .no_post_thumbnail {
  align-content: center;
  background-color: var(--theme-color-alter_bg_color);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 10px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: center;
}
.sc_team_featured .no_post_thumbnail h5 {
  margin: 0;
}
.sc_team_featured .no_post_thumbnail h5 a {
  display: inline;
}
.sc_team_featured .post_featured .trx_addons_hover_mask {
  background-color: #fff;
}
.sc_team_featured .post_featured:hover .trx_addons_hover_mask {
  opacity: 1;
}
.sc_team_featured .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_featured .post_featured:hover img {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}
.sc_team_featured .trx_addons_hover_team {
  padding: 15px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  text-align: center;
  z-index: 99;
}
.sc_team_featured .trx_addons_hover:hover .trx_addons_hover_title,
.sc_team_featured .trx_addons_hover:hover .trx_addons_hover_info {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_team_featured .trx_addons_hover_team .sc_team_item_title {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  position: relative;
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
}
.sc_team_featured .trx_addons_hover_team .sc_team_item_title,
.sc_team_featured .trx_addons_hover_team .sc_team_item_title a:hover,
.sc_team_featured .trx_addons_hover_team .sc_team_item_title a {
  color: #0C0F26;
}
.sc_team_featured .trx_addons_hover_team .sc_team_item_subtitle {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  position: relative;
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  color: #797C7F;
  margin-top: 8px;
}
.sc_team_featured .trx_addons_hover_team .sc_team_item_socials {
  margin: 11px 0 0 0;
}
.sc_team_featured .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .4s;
  top: 15px;
  position: relative;
  margin: 6px !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_featured .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: #000000;
  border: none;
  background: none;
  font-size: 16px;
  width: 2em;
  height: 2em;
  line-height: 2em;
}
.sc_team_featured .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link);
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_title {
  opacity: 1;
  top: 0;
  transition-delay: 0.2s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_subtitle {
  opacity: 1;
  top: 0;
  transition-delay: 0.3s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.4s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.45s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.5s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.55s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.6s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.65s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.7s;
}
.sc_team_featured .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 0.75s;
}

/* Short */
.sc_team_short .sc_team_slider .sc_team_item {
  padding-bottom: 4px;
}
.sc_team_short .sc_team_item_thumb {
  border: none;
}
.sc_team_short .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_short .post_featured:hover img {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_team_short .sc_team_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
}
.sc_team_short .sc_team_item_title a:hover,
.sc_team_short .sc_team_item_title a {
  color: var(--theme-color-text_dark);
  display: inline;
}
.sc_team_short .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 11px;
  color: var(--theme-color-alter_text);
}
.sc_team_short .sc_team_item_thumb + .sc_team_item_info {
  margin-top: 24px;
}
.sc_team_short .trx_addons_hover_team {
  padding: 15px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  text-align: center;
  z-index: 99;
}
.sc_team_short .trx_addons_hover_team .sc_team_item_socials {
  margin: 0;
}
.sc_team_short .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 20px;
  position: relative;
  margin: 3px !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_short .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: #000000;
  background-color: #FFFFFF;
  border: none;
  font-size: 16px;
  width: 45px;
  height: 45px;
  line-height: 45px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_team_short .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.1s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.15s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.2s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.25s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.3s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.35s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.4s;
}
.sc_team_short .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 0.45s;
}

/* Alter */
.sc_team_alter .sc_team_slider .sc_team_item {
  padding-bottom: 4px;
}
.sc_team_alter .sc_team_item_thumb {
  border: none;
}
.sc_team_alter .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_alter .post_featured:hover img {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_team_alter .sc_team_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_alter .sc_team_item_title a:hover,
.sc_team_alter .sc_team_item_title a {
  color: var(--theme-color-text_dark);
  display: inline;
}
.sc_team_alter .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 7px;
  color: var(--theme-color-alter_text);
}
.sc_team_alter .sc_team_item_thumb + .sc_team_item_info {
  margin-top: 24px;
}
.sc_team_alter .sc_team_item_thumb .sc_team_item_content + .sc_team_item_socials {
  margin-top: 1.5em;
}
.sc_team_alter .post_featured .trx_addons_hover_mask {
  background-color: var(--theme-color-inverse_dark);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_team_alter .post_featured:hover .trx_addons_hover_mask {
  opacity: 0.9;
}
.sc_team_alter .trx_addons_hover_team {
  padding: 15px 30px 35px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  text-align: left;
  z-index: 99;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  align-items: flex-start;
}
.sc_team_alter .trx_addons_hover_team .sc_team_item_socials {
  margin: 0;
  z-index: 9;
  position: relative;
}
.sc_team_alter .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 20px;
  position: relative;
  margin: 3px 6px 3px 0  !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_alter .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
  border: none;
  font-size: 16px;
  width: 36px;
  height: 36px;
  line-height: 36px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_team_alter .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon[class*="facebook"] {
  color: #ffffff;
  background-color: #515FC4;
}
.sc_team_alter .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon[class*="twitter"] {
  color: #ffffff;
  background-color: #48BDE9;
}
.sc_team_alter .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon[class*="dribble"], .sc_team_alter .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon[class*="dribbble"] {
  color: #ffffff;
  background-color: #EA4C89;
}
.sc_team_alter .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  color: #000000;
  background-color: #FFFFFF;
}
.sc_team_alter .sc_team_item_content {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 20px;
  position: relative;
  font-size: 15px;
}
.sc_team_alter .sc_team_item_content, .sc_team_alter .sc_team_item_content a {
  color: #ffffff;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_content {
  transition-delay: 0.1s;
  opacity: 1;
  top: 0;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.2s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.25s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.3s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.35s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.4s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.45s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.5s;
}
.sc_team_alter .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 0.55s;
}

/* 3D */
.sc_team_3d {
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.sc_team_3d .sc_team_slider .sc_team_item {
  padding-bottom: 4px;
}
.sc_team_3d .post_featured_bg:before {
  padding-top: 106%;
}
.sc_team_3d .post_featured_bg .post_thumb {
  display: block;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  background-repeat: no-repeat;
  background-size: cover;
  background-position: center;
}
.sc_team_3d .sc_team_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_3d .sc_team_item_title a:hover,
.sc_team_3d .sc_team_item_title a {
  color: var(--theme-color-text_dark);
  display: inline;
}
.sc_team_3d .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 11px;
  color: var(--theme-color-alter_text);
}
.sc_team_3d .sc_team_item_thumb + .sc_team_item_info {
  margin-top: 28px;
}
.sc_team_3d .trx_addons_hover_team {
  padding: 15px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  text-align: center;
  z-index: 99;
}
.sc_team_3d .trx_addons_hover_team .sc_team_item_socials {
  margin: 0;
}
.sc_team_3d .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 20px;
  position: relative;
  margin: 3px !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_3d .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: #000000;
  background-color: #FFFFFF;
  border: none;
  font-size: 16px;
  width: 45px;
  height: 45px;
  line-height: 45px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_team_3d .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.1s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.15s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.2s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.25s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.3s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.35s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.4s;
}
.sc_team_3d .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 0.45s;
}

/* Plain */
.sc_team_plain .post_featured_bg:before {
  padding-top: 140%;
}
.sc_team_plain .post_featured_bg .post_thumb {
  display: block;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  background-repeat: no-repeat;
  background-size: cover;
  background-position: center;
}
.sc_team_plain .no_post_thumbnail {
  align-content: center;
  background-color: var(--theme-color-alter_bg_color);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 10px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: center;
}
.sc_team_plain .no_post_thumbnail h5 {
  margin: 0;
}
.sc_team_plain .no_post_thumbnail h5 a {
  display: inline;
}
.sc_team_plain .post_featured .trx_addons_hover_mask {
  opacity: 0;
}
.sc_team_plain .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_plain .post_featured:hover img {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}
.sc_team_plain .trx_addons_hover_team {
  padding: 18px;
  position: absolute;
  bottom: 7px;
  left: 7px;
  right: 7px;
  width: calc(100% - 14px);
  z-index: 99;
  text-align: left;
  background-color: #ffffff;
  overflow: hidden;
}
.sc_team_plain .trx_addons_hover:hover .trx_addons_hover_title,
.sc_team_plain .trx_addons_hover:hover .trx_addons_hover_info {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_title {
  opacity: 1;
  position: relative;
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_title,
.sc_team_plain .trx_addons_hover_team .sc_team_item_title a:hover,
.sc_team_plain .trx_addons_hover_team .sc_team_item_title a {
  color: #0C0F26;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_subtitle {
  position: relative;
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  color: #797C7F;
  margin-top: 8px;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_socials {
  margin: 20px 0 -57px 0;
  padding-top: 10px;
  min-height: 40px;
  overflow: hidden;
  position: relative;
  -webkit-transition: all 0.5s ease;
  -ms-transition: all 0.5s ease;
  transition: all 0.5s ease;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_socials:before {
  content: '';
  display: block;
  height: 1px;
  background-color: #DDDDDD;
  width: 0;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  position: relative;
  top: -9px;
}
.sc_team_plain .sc_team_item:hover .trx_addons_hover_team .sc_team_item_socials {
  margin-bottom: -8px;
}
.sc_team_plain .sc_team_item:hover .trx_addons_hover_team .sc_team_item_socials:before {
  width: 100%;
  transition-delay: 0.2s;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 15px;
  position: relative;
  margin: 3px 15px 3px 0 !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
  will-change: transform;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_socials .social_item.social_item_type_names .social_name {
  font-size: 12px;
  line-height: 16px;
  font-weight: 700;
  color: #0F0F0F;
}
.sc_team_plain .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: #000000;
  border: none;
  background: none;
  font-size: 16px;
  width: 2em;
  height: 2em;
  line-height: 2em;
}
.sc_team_plain .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_name,
.sc_team_plain .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link);
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
  transition-delay: 1.4s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.3s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.4s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.5s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.6s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.7s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.8s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.9s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 1s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(9) {
  transition-delay: 1.1s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(10) {
  transition-delay: 1.2s;
}
.sc_team_plain .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(11) {
  transition-delay: 1.3s;
}

/* 3D Simple */
.sc_team_3d-simple {
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.sc_team_3d-simple .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_3d-simple .post_featured:hover img {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_team_3d-simple .sc_team_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_3d-simple .sc_team_item_title a:hover,
.sc_team_3d-simple .sc_team_item_title a {
  color: var(--theme-color-text_dark);
  display: inline;
}
.sc_team_3d-simple .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 11px;
  color: var(--theme-color-alter_text);
}
.sc_team_3d-simple .sc_team_item_thumb + .sc_team_item_info {
  margin-top: 32px;
}
.sc_team_3d-simple .trx_addons_hover_team {
  margin: 12px 0 0 0;
  padding: 0;
  width: 100%;
  text-align: left;
  z-index: 99;
  position: relative;
}
.sc_team_3d-simple .trx_addons_hover_team .sc_team_item_socials {
  margin: 0;
}
.sc_team_3d-simple .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 20px;
  will-change: transform;
  position: relative;
  margin: 7px 22px 7px 0 !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_3d-simple .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: var(--theme-color-text_dark);
  border: none;
  font-size: 16px;
  width: 20px;
  height: 30px;
  line-height: 30px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-align: left;
  background-color: transparent !important;
}
.sc_team_3d-simple .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link) !important;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.1s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.15s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.2s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.25s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.3s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.35s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.4s;
}
.sc_team_3d-simple .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 0.45s;
}

/* List */
.sc_team_list .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_list .post_featured:hover img {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_team_list .sc_team_item_title {
  font-size: 35px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_list .sc_team_item_title a {
  display: inline;
}
.sc_team_list .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 11px;
  color: var(--theme-color-text_light);
}
.sc_team_list .sc_team_item_content {
  margin: 17px 0 26px;
}
.sc_team_list .sc_team_item_content p {
  margin: 0;
}
.sc_team_list .sc_team_item_content p + p {
  margin-top: 0.7em;
}
.sc_team_list .sc_item_columns .sc_team_item_content {
  margin: 17px 0;
}
.sc_team_list .sc_item_columns .sc_team_item_title {
  font-size: 24px;
}
.sc_team_list .sc_team_item.has-post-thumbnail {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  align-items: center;
}
.sc_team_list .sc_team_item.has-post-thumbnail .post_featured {
  flex: 1 0 48%;
  max-width: 48%;
}
.sc_team_list .sc_team_item.has-post-thumbnail .sc_team_item_info {
  padding: 0 0 0 9%;
}
.sc_team_list .sc_team_item_content + .sc_team_item_socials {
  margin-top: 0 !important;
}
.sc_team_list .sc_team_item_socials {
  margin-left: -2px;
  margin-top: 15px;
}
.sc_team_list .sc_team_item .sc_team_item_socials .social_item {
  will-change: transform;
  position: relative;
  margin: 3px 24px 3px 0;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_list .sc_team_item .sc_team_item_socials .social_item .social_icon {
  color: var(--theme-color-text_dark);
  border: none;
  font-size: 16px;
  width: 20px;
  height: 20px;
  line-height: 20px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-align: center;
  background-color: transparent !important;
}
.sc_team_list .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link) !important;
}

/* Metro */
.sc_team_metro .sc_team_item {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_team_metro .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_metro .post_featured:hover img {
  -webkit-transform: scale(1.05, 1.05);
  -ms-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
}
.sc_team_metro .post_featured:before {
  padding-top: 100%;
}
.sc_team_metro .sc_team_item_title {
  font-size: 35px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_metro .sc_team_item_title a:hover,
.sc_team_metro .sc_team_item_title a {
  color: var(--theme-color-text_dark);
  display: inline;
}
.sc_team_metro .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 9px;
  color: var(--theme-color-text_light);
}
.sc_team_metro .sc_team_item_content {
  margin: 17px 0 26px;
  font-size: 15px;
  line-height: 1.65em;
}
.sc_team_metro .sc_team_item_content p {
  margin: 0;
}
.sc_team_metro .sc_team_item_content p + p {
  margin-top: 0.7em;
}
.sc_team_metro .sc_team_slider:not(.slider_outer_one) .sc_team_item_content,
.sc_team_metro .sc_item_columns .sc_team_item_content {
  margin: 17px 0;
}
.sc_team_metro .sc_team_slider:not(.slider_outer_one) .sc_team_item_title,
.sc_team_metro .sc_item_columns .sc_team_item_title {
  font-size: 24px;
}
.sc_team_metro .sc_team_item_info {
  padding: 20px 35px;
}
.sc_team_metro .sc_team_item.has-post-thumbnail {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  align-items: center;
}
.sc_team_metro .sc_team_item.has-post-thumbnail .post_featured {
  flex: 1 0 50%;
  max-width: 50%;
  height: 100%;
}
.sc_team_metro .trx_addons_column-1_2 .sc_team_item.has-post-thumbnail .sc_team_item_info {
  padding-top: 85px !important;
  padding-bottom: 60px !important;
}
.sc_team_metro .trx_addons_column-1_6 .sc_team_item.has-post-thumbnail .sc_team_item_info,
.sc_team_metro .trx_addons_column-1_5 .sc_team_item.has-post-thumbnail .sc_team_item_info,
.sc_team_metro .trx_addons_column-1_4 .sc_team_item.has-post-thumbnail .sc_team_item_info,
.sc_team_metro .trx_addons_column-1_3 .sc_team_item.has-post-thumbnail .sc_team_item_info {
  padding: 20px 25px;
}
.sc_team_metro .trx_addons_column-1_6 .sc_team_item_content + .sc_team_item_socials,
.sc_team_metro .trx_addons_column-1_5 .sc_team_item_content + .sc_team_item_socials,
.sc_team_metro .trx_addons_column-1_4 .sc_team_item_content + .sc_team_item_socials,
.sc_team_metro .trx_addons_column-1_3 .sc_team_item_content + .sc_team_item_socials {
  margin-top: 20px;
}
.sc_team_metro .trx_addons_column-1_6 .sc_team_item_socials .social_item .social_icon,
.sc_team_metro .trx_addons_column-1_5 .sc_team_item_socials .social_item .social_icon,
.sc_team_metro .trx_addons_column-1_4 .sc_team_item_socials .social_item .social_icon,
.sc_team_metro .trx_addons_column-1_3 .sc_team_item_socials .social_item .social_icon {
  font-size: 15px;
  width: 35px;
  height: 35px;
  line-height: 32px;
}
.sc_team_metro .sc_team_item_content + .sc_team_item_socials {
  margin-top: 30px;
}
.sc_team_metro .sc_team_item_socials {
  margin-left: -2px;
  margin-top: 15px;
}
.sc_team_metro .sc_team_item_socials .social_item {
  will-change: transform;
  position: relative;
  margin: 3px 5px 3px 0;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_metro .sc_team_item_socials .social_item .social_icon {
  top: 0;
  position: relative;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  color: var(--theme-color-text_dark);
  border: 1px solid var(--theme-color-alter_bd_color);
  font-size: 16px;
  width: 45px;
  height: 45px;
  line-height: 43px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  text-align: center;
  background-color: transparent !important;
}
.sc_team_metro .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link) !important;
  top: -7px;
}

/* Hover */
.sc_team_hover .no_post_thumbnail {
  align-content: center;
  background-color: var(--theme-color-alter_bg_color);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 10px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: center;
}
.sc_team_hover .no_post_thumbnail h5 {
  margin: 0;
}
.sc_team_hover .no_post_thumbnail h5 a {
  display: inline;
}
.sc_team_hover .post_featured .trx_addons_hover_mask {
  background: var(--theme-color-text_link2);
  background: -moz-linear-gradient(0deg, var(--theme-color-text_link2_08) 0%, rgba(0, 0, 0, 0) 100%);
  background: -webkit-linear-gradient(0deg, var(--theme-color-text_link2_08) 0%, rgba(0, 0, 0, 0) 100%);
  background: linear-gradient(0deg, var(--theme-color-text_link2_08) 0%, rgba(0, 0, 0, 0) 100%);
}
.sc_team_hover .post_featured:hover .trx_addons_hover_mask {
  opacity: 1;
}
.sc_team_hover .post_featured img {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_hover .post_featured:hover img {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}
.sc_team_hover .trx_addons_hover_team {
  padding: 35px;
  position: absolute;
  z-index: 1;
  bottom: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
  width: 100%;
  text-align: left;
  z-index: 99;
}
.sc_team_hover .trx_addons_hover:hover .trx_addons_hover_title,
.sc_team_hover .trx_addons_hover:hover .trx_addons_hover_info {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_team_hover .trx_addons_hover_team .sc_team_item_title {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  margin: 0;
  position: relative;
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
}
.sc_team_hover .trx_addons_hover_team .sc_team_item_title a:hover,
.sc_team_hover .trx_addons_hover_team .sc_team_item_title a {
  color: #ffffff;
}
.sc_team_hover .trx_addons_hover_team .sc_team_item_subtitle {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  position: relative;
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  color: #ffffff;
  margin-top: 8px;
}
.sc_team_hover .trx_addons_hover_team .sc_team_item_socials {
  margin: 18px 0 0 -4px;
}
.sc_team_hover .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .4s;
  top: 15px;
  position: relative;
  margin: 6px 23px 6px 0 !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_hover .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: #ffffff;
  border: none;
  background: none;
  font-size: 15px;
  width: 20px;
  height: 20px;
  line-height: 20px;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_team_hover .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  opacity: 0.7;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_title {
  opacity: 1;
  top: 0;
  transition-delay: 0.2s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_subtitle {
  opacity: 1;
  top: 0;
  transition-delay: 0.3s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
  transition-delay: 1.2s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.4s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.5s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.6s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.7s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.8s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.9s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 1s;
}
.sc_team_hover .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 1.1s;
}

/* Creative */
.sc_team_creative .sc_team_slider .trx_addons_hover_team {
  margin-bottom: 0;
}
.sc_team_creative .sc_team_item {
  text-align: center;
}
.sc_team_creative .sc_team_item_info {
  text-align: center;
}
.sc_team_creative .sc_team_item_title {
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
  margin: 0;
}
.sc_team_creative .sc_team_item_title a:hover,
.sc_team_creative .sc_team_item_title a {
  display: inline;
  color: var(--theme-color-text_dark);
}
.sc_team_creative .sc_team_item_subtitle {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  margin-top: 11px;
  color: var(--theme-color-alter_text);
}
.sc_team_creative .sc_team_item_thumb + .sc_team_item_info {
  margin-top: 32px;
}
.sc_team_creative .trx_addons_hover_team {
  margin: 22px 0 -20px 0;
  padding: 0;
  width: 100%;
  text-align: center;
  z-index: 99;
  position: relative;
}
.sc_team_creative .trx_addons_hover_team .sc_team_item_socials {
  margin: 0;
}
.sc_team_creative .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 20px;
  will-change: transform;
  position: relative;
  margin: 5px 11px !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_creative .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: var(--theme-color-text_dark);
  border: none;
  font-size: 16px;
  width: 20px;
  height: 30px;
  line-height: 30px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-align: center;
  background-color: transparent !important;
}
.sc_team_creative .sc_team_item_socials .social_item:hover .social_icon {
  color: var(--theme-color-text_link) !important;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.1s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.15s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.2s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.25s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.3s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.35s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 0.4s;
}
.sc_team_creative .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 0.45s;
}
.sc_team_creative .post_featured img {
  z-index: 2;
  position: relative;
}
.sc_team_creative .all-svg {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  z-index: 1;
}
.sc_team_creative .all-svg span {
  display: inline-block;
  line-height: 0;
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  will-change: transform;
}
.sc_team_creative .all-svg .svg-1 {
  position: absolute;
  top: 29%;
  right: 12%;
  margin: 15px 15px 0 0;
}
.sc_team_creative .all-svg .svg-1 svg {
  width: 130px;
  height: 130px;
  fill: var(--theme-color-text_link2);
  opacity: 0.11;
}
.sc_team_creative .all-svg .svg-2 {
  position: absolute;
  right: 1.5%;
  bottom: 18.5%;
  margin: 0 15px 0 0;
}
.sc_team_creative .all-svg .svg-2 svg {
  width: 97px;
  height: 97px;
  fill: transparent;
  stroke: var(--theme-color-text_dark);
  stroke-width: 21px;
}
.sc_team_creative .all-svg .svg-3 {
  position: absolute;
  left: 3.5%;
  top: 33.5%;
  margin: 15px 0 0 15px;
}
.sc_team_creative .all-svg .svg-3 svg {
  width: 137px;
  height: 137px;
  fill: transparent;
  stroke: var(--theme-color-text_link2);
  stroke-width: 21px;
}
.sc_team_creative .sc_team_item:hover .all-svg .svg-1 {
  opacity: 1;
  transition-delay: 0.1s;
  margin: 0;
}
.sc_team_creative .sc_team_item:hover .all-svg .svg-2 {
  opacity: 1;
  transition-delay: 0.2s;
  margin: 0;
}
.sc_team_creative .sc_team_item:hover .all-svg .svg-3 {
  opacity: 1;
  transition-delay: 0.15s;
  margin: 0;
}

/* Accent */
.sc_team_accent .no_post_thumbnail {
  align-content: center;
  background-color: var(--theme-color-alter_bg_color);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 10px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: center;
}
.sc_team_accent .no_post_thumbnail h5 {
  margin: 0;
}
.sc_team_accent .no_post_thumbnail h5 a {
  display: inline;
}
.sc_team_accent .post_featured_bg:before {
  padding-top: 100%;
}
.sc_team_accent .post_featured_bg .post_thumb {
  display: block;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  background-repeat: no-repeat;
  background-size: cover;
  background-position: center;
}
.sc_team_accent .post_featured .trx_addons_hover_mask {
  background-color: var(--theme-color-extra_bg_color);
}
.sc_team_accent .post_featured:hover .trx_addons_hover_mask {
  opacity: 0.8;
}
.sc_team_accent .post_featured .post_thumb {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_accent .post_featured:hover .post_thumb {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}
.sc_team_accent .trx_addons_hover_team {
  padding: 60px 20px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  text-align: center;
  z-index: 99;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-wrap: wrap;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_socials {
  position: absolute;
  z-index: 1;
  bottom: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
  width: 100%;
  bottom: 27px;
  z-index: 9;
}
.sc_team_accent .trx_addons_hover_team .center-all {
  align-self: center;
  text-align: center;
  width: 100%;
}
.sc_team_accent .trx_addons_hover:hover .trx_addons_hover_title,
.sc_team_accent .trx_addons_hover:hover .trx_addons_hover_info {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_title {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  margin: 0;
  position: relative;
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_title a:hover,
.sc_team_accent .trx_addons_hover_team .sc_team_item_title a {
  color: #ffffff;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_subtitle {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  position: relative;
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  color: #ffffff;
  margin-top: 8px;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_socials {
  margin: 0;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .4s;
  top: 15px;
  position: relative;
  margin: 6px 11px !important;
  display: inline-block;
  vertical-align: top;
  line-height: 1;
}
.sc_team_accent .trx_addons_hover_team .sc_team_item_socials .social_item .social_icon {
  color: #ffffff;
  border: none;
  background: none;
  font-size: 15px;
  width: 20px;
  height: 20px;
  line-height: 20px;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_team_accent .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  opacity: 0.7;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_title {
  opacity: 1;
  top: 0;
  transition-delay: 0.2s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_subtitle {
  opacity: 1;
  top: 0;
  transition-delay: 0.3s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item {
  opacity: 1;
  top: 0;
  transition-delay: 1.2s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.4s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.5s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.6s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.7s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.8s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.9s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 1s;
}
.sc_team_accent .trx_addons_hover_style_info_anim:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 1.1s;
}

/* Light */
.sc_team_light .no_post_thumbnail {
  align-content: center;
  background-color: var(--theme-color-alter_bg_color);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 10px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: center;
}
.sc_team_light .sc_team_item_title {
  margin: 0;
}
.sc_team_light .sc_team_item_title a {
  display: inline;
}
.sc_team_light .post_featured_bg:before {
  padding-top: 100%;
}
.sc_team_light .post_featured_bg .post_thumb {
  display: block;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  background-repeat: no-repeat;
  background-size: cover;
  background-position: center;
}
.sc_team_light .post_featured .trx_addons_hover_mask {
  background-color: var(--theme-color-inverse_dark);
}
.sc_team_light .post_featured:hover .trx_addons_hover_mask {
  opacity: 0.76;
}
.sc_team_light .post_featured .post_thumb {
  -webkit-transition: -webkit-transform 0.3s ease;
  -ms-transition: -ms-transform 0.3s ease;
  transition: transform 0.3s ease;
}
.sc_team_light .post_featured:hover .post_thumb {
  -webkit-transform: scale(1.1, 1.1);
  -ms-transform: scale(1.1, 1.1);
  transform: scale(1.1, 1.1);
}
.sc_team_light .trx_addons_hover_team {
  padding: 15px 55px 36px 28px;
  position: absolute;
  z-index: 1;
  bottom: 0;
  left: 50%;
  -webkit-transform: translateX(-50%);
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
  width: 100%;
  text-align: left;
  z-index: 99;
}
.sc_team_light .trx_addons_hover:hover .trx_addons_hover_title,
.sc_team_light .trx_addons_hover:hover .trx_addons_hover_info {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_team_light .trx_addons_hover_team .sc_team_item_title {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  margin: 0;
  position: relative;
  font-size: 24px;
  font-weight: 700;
  line-height: 1.2em;
}
.sc_team_light .trx_addons_hover_team .sc_team_item_title a:hover,
.sc_team_light .trx_addons_hover_team .sc_team_item_title a {
  color: #ffffff;
}
.sc_team_light .trx_addons_hover_team .sc_team_item_subtitle {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  top: 10px;
  position: relative;
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
  font-style: normal;
  color: #ffffff;
  margin-top: 6px;
}
.sc_team_light .sc_team_item_thumb .sc_team_item_socials {
  margin: 0;
  position: absolute;
  z-index: 1;
  top: 15px;
  right: 15px;
  bottom: 15px;
  height: auto;
  overflow: hidden;
  z-index: 99;
  width: 30px;
  text-align: right;
}
.sc_team_light .sc_team_item_thumb .sc_team_item_socials .social_item {
  opacity: 0;
  transition-property: all;
  transition-duration: .3s;
  right: -10px;
  display: block;
  float: none;
  position: relative;
  margin: 5px !important;
  vertical-align: top;
  line-height: 1;
}
.sc_team_light .sc_team_item_thumb .sc_team_item_socials .social_item .social_icon {
  color: #ffffff;
  border: none;
  background: none;
  font-size: 15px;
  width: 20px;
  height: 30px;
  line-height: 30px;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_team_light .sc_team_item_thumb .sc_team_item_socials .social_item:hover .social_icon {
  opacity: 0.7;
}
.sc_team_light .sc_team_item:hover .sc_team_item_title {
  opacity: 1;
  top: 0;
  transition-delay: 0.2s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_subtitle {
  opacity: 1;
  top: 0;
  transition-delay: 0.3s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item {
  opacity: 1;
  right: 0;
  transition-delay: 1.2s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(1) {
  transition-delay: 0.4s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(2) {
  transition-delay: 0.5s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(3) {
  transition-delay: 0.6s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(4) {
  transition-delay: 0.7s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(5) {
  transition-delay: 0.8s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(6) {
  transition-delay: 0.9s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(7) {
  transition-delay: 1s;
}
.sc_team_light .sc_team_item:hover .sc_team_item_socials .social_item:nth-child(8) {
  transition-delay: 1.1s;
}

/* Map Marker */
.map_marker {
  position: absolute;
  width: 18px;
  height: 18px;
  display: block;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-text_link2);
  will-change: transform;
}
.map_marker > div {
  background-color: var(--theme-color-text_link2_05);
  content: '';
  display: inline-block;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  opacity: 1;
}
.map_marker > div:first-child {
  -webkit-animation: markerWave 1.5s cubic-bezier(0.4, 0, 0.2, 1) infinite forwards;
  animation: markerWave 1.5s cubic-bezier(0.4, 0, 0.2, 1) infinite forwards;
}
.map_marker > div:first-child + div {
  -webkit-animation: markerWave 1.5s 0.45s cubic-bezier(0, 0, 0.2, 1) infinite forwards;
  animation: markerWave 1.5s 0.45s cubic-bezier(0, 0, 0.2, 1) infinite forwards;
}

@-webkit-keyframes markerWave {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
    opacity: 0.8;
  }
  20% {
    opacity: 0.8;
  }
  100% {
    -webkit-transform: scale(5.5);
    transform: scale(5.5);
    opacity: 0;
  }
}
@keyframes markerWave {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
    opacity: 0.8;
  }
  20% {
    opacity: 0.8;
  }
  100% {
    -webkit-transform: scale(5.5);
    transform: scale(5.5);
    opacity: 0;
  }
}
/* style 2 */
.map_marker_2 {
  position: absolute;
  width: 86px;
  height: 86px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #ffffff;
}
.map_marker_2:before {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  display: block;
  content: '\e9ce';
  font-family: "fontello";
  color: #000;
  font-size: 38px;
  margin: 2px 0 0 0;
}

/* custom pagination as thumb */
.swiper-pagination-custom .swiper-pagination-button {
  margin: 0 6px;
  width: 5em;
  height: 5em;
  border: none;
  opacity: 1;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: transparent;
  will-change: transform;
  -webkit-transform: scale3d(0.8, 0.8, 0.8);
  -ms-transform: scale3d(0.8, 0.8, 0.8);
  transform: scale3d(0.8, 0.8, 0.8);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  backface-visibility: hidden;
  -webkit-backface-visibility: hidden;
  cursor: pointer;
}

.swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active {
  -webkit-transform: scale3d(1, 1, 1);
  -ms-transform: scale3d(1, 1, 1);
  transform: scale3d(1, 1, 1);
  background-color: transparent;
}

.slider_container.slider_pagination_pos_bottom .swiper-pagination-custom,
.slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-custom,
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom {
  height: 5em;
  line-height: 5em;
}

.slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-custom,
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom {
  margin-top: 1.8em;
}

/* Testimonials */
.sc_testimonials:not(.sc_testimonials_plain) .sc_testimonials_content > .sc_testimonials_item + .sc_testimonials_item {
  margin-top: 2em;
}

.sc_testimonials_default .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_simple .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_classic .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_light .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_list .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_common .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_modern .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_creative .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_fashion .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_alter .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_alter2 .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_decoration .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"],
.sc_testimonials_extra .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"] {
  padding-bottom: 60px;
}

.sc_testimonials_default .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_simple .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_classic .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_light .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_list .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_common .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_modern .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_creative .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_fashion .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_alter .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_alter2 .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_decoration .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"],
.sc_testimonials_extra .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}

/* Classic */
.sc_testimonials_classic .slider_container.slider_controls_side .slider_controls_wrap > .slider_prev {
  opacity: 1;
  margin-left: 0 !important;
  left: 0 !important;
  text-align: left !important;
}
.sc_testimonials_classic .slider_container.slider_controls_side .slider_controls_wrap > .slider_next {
  opacity: 1;
  margin-right: 0 !important;
  right: 0 !important;
  text-align: right !important;
}
.sc_testimonials_classic .slider_container.slider_controls_side .slider_controls_wrap > a {
  width: 40px;
  height: 40px;
  line-height: 40px;
  background: none !important;
  color: var(--theme-color-text_dark) !important;
}
.sc_testimonials_classic .slider_container.slider_controls_side .slider_controls_wrap > a:before {
  font-size: 22px;
}
.sc_testimonials_classic .slider_container.slider_controls_side .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link) !important;
}
.sc_testimonials_classic .slider_outer.slider_outer_pagination_pos_bottom.slider_outer_pagination_custom .slider_controls_wrap > a {
  margin-top: 2em;
}
.sc_testimonials_classic .slider_container .sc_testimonials_item {
  padding: 0 15%;
}
.sc_testimonials_classic .sc_testimonials_item_author_title {
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
}
.sc_testimonials_classic .sc_testimonials_item_author_subtitle {
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_classic .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 10px;
}
.sc_testimonials_classic .sc_testimonials_item_author,
.sc_testimonials_classic [class*="column"] .sc_testimonials_item_author {
  text-align: center;
  margin: 30px 0 0 0;
  padding: 0;
}
.sc_testimonials_classic .sc_testimonials_item_content,
.sc_testimonials_classic [class*="column"] .sc_testimonials_item_content {
  font-size: 19px;
  line-height: 32px;
  font-weight: 400;
  text-align: center;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_classic .sc_testimonials_item_content:before {
  margin-bottom: 40px;
  font-size: 24px;
  line-height: 1.3em;
  content: '\e9ca';
  font-family: "fontello";
  will-change: color;
  color: var(--theme-color-text_dark);
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}

/* Default */
.sc_testimonials_default [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_default .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 32px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text);
}
.sc_testimonials_default [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_default .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_default .sc_testimonials_item_author {
  margin: 38px 0 1px;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_default .sc_testimonials_item_author_avatar {
  overflow: visible;
  margin: 0 20px 1px 0;
  width: 78px;
  height: 78px;
  position: relative;
}
.sc_testimonials_default .sc_testimonials_item_author_avatar:before {
  content: '\e9cb';
  font-family: "fontello";
  display: block;
  position: absolute;
  z-index: 1;
  bottom: -1px;
  right: -1px;
  width: 30px;
  height: 30px;
  line-height: 32px;
  overflow: hidden;
  font-size: 7px;
  font-weight: 400;
  text-align: center;
  text-indent: 1px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.sc_testimonials_default .sc_testimonials_item_author_avatar img {
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_default .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_default .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_default .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_default .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
}
.sc_testimonials_default .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}

/* Simple */
.sc_testimonials_simple .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_testimonials_simple .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 3.4em;
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_simple .sc_testimonials_item_content {
  text-align: center;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-input_text);
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_simple .sc_testimonials_item_content:before {
  font-size: 23px;
  line-height: 1.5em;
  color: var(--theme-color-text_link);
  content: '\e9de';
  font-family: "fontello";
  margin-bottom: 30px;
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_simple .sc_testimonials_item_author {
  margin: 34px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_simple .sc_testimonials_item_author_avatar {
  margin: 0 auto 27px;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  display: inline-block;
}
.sc_testimonials_simple .sc_testimonials_item_author_data:before {
  display: none;
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author_data,
.sc_testimonials_simple .sc_testimonials_item_author_data {
  border: none;
  padding: 0;
  max-width: 100%;
  text-align: center;
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title,
.sc_testimonials_simple .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_simple .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_simple .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-input_text);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_simple [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_simple .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_simple .slider_container .swiper-pagination-bullet,
.sc_testimonials_simple .slider_outer .swiper-pagination-bullet {
  width: 10px;
  border: 2px solid var(--theme-color-input_text);
  opacity: 1;
  height: 10px;
}
.sc_testimonials_simple .slider_container .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_testimonials_simple .slider_outer .swiper-pagination-bullet.swiper-pagination-bullet-active {
  border-color: var(--theme-color-text_link2);
  background-color: var(--theme-color-text_link2);
}
.sc_testimonials_simple .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_simple .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_simple .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
}

/* Plain */
body:not(.mobile_layout) .sc_testimonials_plain .sc_testimonials_slider {
  overflow: hidden;
  padding: 40px 0;
}

body:not(.mobile_layout) .sc_testimonials_plain .slider_container[data-slides-per-view="3"] {
  overflow: visible;
}

body:not(.mobile_layout) .sc_testimonials_plain .slider_container[data-slides-per-view="3"] .swiper-slide-duplicate-active + .swiper-slide-duplicate-next .sc_testimonials_item,
body:not(.mobile_layout) .sc_testimonials_plain .slider_container[data-slides-per-view="3"] .swiper-slide-active + .swiper-slide-next .sc_testimonials_item {
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 3px 40px 0 rgba(0, 0, 0, 0.06);
  -ms-box-shadow: 0 3px 40px 0 rgba(0, 0, 0, 0.06);
  box-shadow: 0 3px 40px 0 rgba(0, 0, 0, 0.06);
}

.sc_testimonials_plain .sc_item_slider.slider_outer_pagination_pos_bottom_outside .swiper-pagination,
.sc_testimonials_plain .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2.4em;
}
.sc_testimonials_plain .sc_testimonials_item {
  padding: 50px 60px 59px 107px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: transparent;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  position: relative;
  height: auto;
}
.sc_testimonials_plain .sc_testimonials_item:before {
  content: '\e9eb';
  font-family: "fontello";
  display: block;
  position: absolute;
  z-index: 1;
  top: 53px;
  left: 41px;
  width: 35px;
  height: 35px;
  line-height: 35px;
  font-size: 25px;
  font-weight: 400;
  text-align: center;
  color: var(--theme-color-text_link2);
}
.sc_testimonials_plain [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_plain .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_plain [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_plain .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_plain .sc_testimonials_item_author {
  margin: 25px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_plain .sc_testimonials_item_author_avatar {
  margin: 0 16px 0 0;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_plain .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_plain .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_plain .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_plain .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
}
.sc_testimonials_plain .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_plain .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_plain .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_plain .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: var(--theme-color-bd_color);
}
.sc_testimonials_plain .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_plain .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_plain .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_plain .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_plain .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_plain .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_plain .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Extra */
.sc_testimonials_extra .slider_container .sc_testimonials_item {
  padding: 15px 15px 0;
}

body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-duplicate-active + .swiper-slide-duplicate-next .sc_testimonials_item_content,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-active + .swiper-slide-next .sc_testimonials_item_content,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-next .sc_testimonials_item_content {
  will-change: background-color;
  background-color: var(--theme-color-text_link2);
  color: #ffffff;
}
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-duplicate-active + .swiper-slide-duplicate-next .sc_testimonials_item_content:before,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-active + .swiper-slide-next .sc_testimonials_item_content:before,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-next .sc_testimonials_item_content:before {
  color: #ffffff;
}
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-duplicate-active + .swiper-slide-duplicate-next .sc_testimonials_item_content:after,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-active + .swiper-slide-next .sc_testimonials_item_content:after,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-next .sc_testimonials_item_content:after {
  background-color: var(--theme-color-text_link2);
}
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-duplicate-active + .swiper-slide-duplicate-next .sc_testimonials_item_content > p,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-active + .swiper-slide-next .sc_testimonials_item_content > p,
body:not(.mobile_layout) .sc_testimonials_extra .slider_container[data-slides-per-view="3"] .swiper-slide-next .sc_testimonials_item_content > p {
  opacity: 0.8;
}

.sc_testimonials_extra .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2.2em;
}
.sc_testimonials_extra .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets {
  margin-top: 3em;
}
.sc_testimonials_extra .sc_testimonials_item .sc_testimonials_item_content {
  padding: 50px 40px 58px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  -webkit-box-shadow: 0 3px 15px 0 rgba(0, 0, 0, 0.02);
  -ms-box-shadow: 0 3px 15px 0 rgba(0, 0, 0, 0.02);
  box-shadow: 0 3px 15px 0 rgba(0, 0, 0, 0.02);
  background-color: var(--theme-color-alter_bg_color);
  text-align: center;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
  position: relative;
  overflow: visible;
}
.sc_testimonials_extra .sc_testimonials_item .sc_testimonials_item_content > p {
  opacity: 1;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
.sc_testimonials_extra .sc_testimonials_item .sc_testimonials_item_content:before {
  content: '\e9eb';
  font-family: "fontello";
  display: block;
  width: 100%;
  height: 35px;
  line-height: 35px;
  font-size: 22px;
  font-weight: 400;
  text-align: center;
  color: var(--theme-color-text_link2);
  margin-bottom: 18px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_extra .sc_testimonials_item .sc_testimonials_item_content:after {
  content: '';
  width: 22px;
  height: 22px;
  background-color: var(--theme-color-alter_bg_color);
  position: absolute;
  bottom: -6px;
  left: 50%;
  z-index: 1;
  -webkit-transform: translateX(-50%) rotate(125deg) skew(-20deg);
  -ms-transform: translateX(-50%) rotate(125deg) skew(-20deg);
  transform: translateX(-50%) rotate(125deg) skew(-20deg);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_extra [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_extra .sc_testimonials_item_author {
  margin: 40px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_extra .sc_testimonials_item_author_avatar {
  margin: 0;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  display: inline-block;
}
.sc_testimonials_extra .sc_testimonials_item_author_avatar + .sc_testimonials_item_author_data {
  margin-top: 28px;
}
.sc_testimonials_extra .sc_testimonials_item_author_data {
  max-width: 100%;
  width: 100%;
  text-align: center;
}
.sc_testimonials_extra .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_extra .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_extra .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_extra .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_extra .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_extra .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_extra .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: var(--theme-color-bd_color);
}
.sc_testimonials_extra .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active,
.sc_testimonials_extra .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active,
.sc_testimonials_extra .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover,
.sc_testimonials_extra .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_testimonials_extra .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_testimonials_extra .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover,
.sc_testimonials_extra .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Light */
.sc_testimonials_light .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  text-align: left;
  padding-left: 66px;
  margin-top: 5.3em;
}
.sc_testimonials_light .sc_testimonials_item {
  padding: 0 0 0 72px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: transparent;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  position: relative;
}
.sc_testimonials_light .sc_testimonials_item:before {
  content: '\e9de';
  font-family: "fontello";
  display: block;
  position: absolute;
  z-index: 1;
  top: 4px;
  left: 1px;
  width: 35px;
  height: 35px;
  line-height: 35px;
  font-size: 22px;
  font-weight: 400;
  text-align: left;
  color: var(--theme-color-text_link);
}
.sc_testimonials_light [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_light .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text);
}
.sc_testimonials_light [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_light .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_light .sc_testimonials_item_author {
  margin: 36px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_light .sc_testimonials_item_author_avatar {
  margin: 0 16px 0 0;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_light .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_light .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_light .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_light .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
}
.sc_testimonials_light .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_light .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_light .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_light .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: #E5E3E0;
}
.sc_testimonials_light .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_light .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_light .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_light .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_light .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_light .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_light .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* List */
.sc_testimonials_list .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  text-align: left;
  padding: 0;
  margin-left: -8px;
}
.sc_testimonials_list .sc_testimonials_item {
  padding: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: transparent;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_list .sc_testimonials_item:before {
  content: '\e9de';
  font-family: "fontello";
  display: block;
  width: 35px;
  height: 35px;
  line-height: 35px;
  font-size: 23px;
  font-weight: 400;
  text-align: left;
  margin-bottom: 30px;
  color: var(--theme-color-text_link);
}
.sc_testimonials_list [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_list .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text);
}
.sc_testimonials_list [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_list .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_list .sc_testimonials_item_author {
  margin: 32px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_list .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_list .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_list .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_list .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_list .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_list .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_list .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_list .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: #E5E3E0;
}
.sc_testimonials_list .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_list .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_list .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_list .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_list .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_list .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_list .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Common */
.sc_testimonials_common .sc_item_slider.slider_outer_pagination_pos_bottom {
  padding-bottom: 4.9em;
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_common .sc_testimonials_item_content {
  text-align: center;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text);
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_common .sc_testimonials_item_content:before {
  font-size: 23px;
  line-height: 1.5em;
  color: var(--theme-color-inverse_text);
  content: '\e9de';
  font-family: "fontello";
  margin-bottom: 30px;
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_common .sc_testimonials_item_author {
  margin: 32px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_author_data,
.sc_testimonials_common .sc_testimonials_item_author_data {
  border: none;
  padding: 0;
  max-width: 100%;
  text-align: center;
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title,
.sc_testimonials_common .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_common [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_common .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_common .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_common [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_common .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_common .slider_container .swiper-pagination-bullet,
.sc_testimonials_common .slider_outer .swiper-pagination-bullet {
  width: 10px;
  border: 2px solid var(--theme-color-text_dark);
  opacity: 1;
  height: 10px;
}
.sc_testimonials_common .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_common .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_common .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
}

/* Modern */
.sc_testimonials_modern .sc_item_slider.slider_outer_pagination_pos_bottom {
  padding-bottom: 6.7em !important;
}
.sc_testimonials_modern .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  text-align: left;
  padding-left: 66px;
}
.sc_testimonials_modern .sc_testimonials_item {
  padding: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: transparent;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_modern .sc_testimonials_item:before {
  margin-bottom: 42px;
  margin-left: 4px;
  font-size: 24px;
  line-height: 1.3em;
  content: '\e9ca';
  font-family: "fontello";
  display: block;
  position: relative;
  width: 100%;
  font-weight: 400;
  text-align: left;
  color: var(--theme-color-text_link);
}
.sc_testimonials_modern [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_modern .sc_testimonials_item_content {
  text-align: left;
  font-size: 16px;
  line-height: 26px;
  font-weight: var(--theme-font-p_font-weight);
  font-style: normal;
  color: var(--theme-color-text);
}
.sc_testimonials_modern [class*="column"] .sc_testimonials_item_content strong,
.sc_testimonials_modern .sc_testimonials_item_content strong {
  font-size: 20px;
  line-height: 1em;
  font-weight: 700;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_modern [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_modern .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_modern .sc_testimonials_item_author {
  margin: 36px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_modern .sc_testimonials_item_author_avatar {
  overflow: visible;
  margin: 0 15px 1px 0;
  width: 78px;
  height: 78px;
  position: relative;
}
.sc_testimonials_modern .sc_testimonials_item_author_avatar:before {
  content: '\e9cb';
  font-family: "fontello";
  display: block;
  position: absolute;
  z-index: 1;
  bottom: 0;
  right: 0;
  width: 30px;
  height: 30px;
  line-height: 32px;
  overflow: hidden;
  font-size: 7px;
  font-weight: 400;
  text-align: center;
  text-indent: 1px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.sc_testimonials_modern .sc_testimonials_item_author_avatar img {
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_modern .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_modern .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_modern .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_modern .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
}
.sc_testimonials_modern .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_modern .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_modern .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_modern .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: #E5E3E0;
}
.sc_testimonials_modern .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_modern .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_modern .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_modern .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_modern .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_modern .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_modern .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Hover */
.sc_testimonials_hover .sc_item_slider .sc_testimonials_item {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_testimonials_hover .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_testimonials_hover .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2.4em;
}
.sc_testimonials_hover .sc_testimonials_item {
  position: relative;
  -webkit-box-shadow: 0 3px 15px 0 rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 15px 0 rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 15px 0 rgba(0, 0, 0, 0.05);
  padding: 50px 50px 55px;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_hover .sc_testimonials_item:after {
  background-position: center !important;
  background-repeat: no-repeat !important;
  background-size: cover;
  content: "";
  display: block;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  z-index: 1;
  opacity: 0;
}
.sc_testimonials_hover .sc_testimonials_item:before {
  content: '\e9eb';
  font-family: "fontello";
  display: block;
  position: relative;
  width: 100%;
  height: 32px;
  line-height: 32px;
  font-size: 20px;
  font-weight: 400;
  text-align: left;
  color: var(--theme-color-text_link2);
  margin-bottom: 20px;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_hover .sc_testimonials_item:hover {
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-text_link2);
}
.sc_testimonials_hover .sc_testimonials_item:hover .sc_testimonials_item_content {
  color: #FCFCFC;
  opacity: 0.9;
}
.sc_testimonials_hover .sc_testimonials_item:hover:before {
  color: #ffffff;
}
.sc_testimonials_hover .sc_testimonials_item:hover:after {
  opacity: 1;
}
.sc_testimonials_hover .sc_testimonials_item:hover .sc_testimonials_item_author_title {
  color: #FCFCFC;
}
.sc_testimonials_hover .sc_testimonials_item:hover .sc_testimonials_item_author_subtitle {
  color: #FFFFFF !important;
  opacity: 0.8 !important;
}
.sc_testimonials_hover [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_hover .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_hover [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_hover .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_hover .sc_testimonials_item_author {
  margin: 26px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_hover .sc_testimonials_item_author_avatar {
  margin: 0 14px 0 0;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_hover .sc_testimonials_item_author_data {
  max-width: 100%;
  margin-bottom: 11px;
  margin-top: 11px;
}
.sc_testimonials_hover .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_hover .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_hover .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_hover .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_hover .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_hover .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_hover .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: var(--theme-color-bd_color);
}
.sc_testimonials_hover .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_hover .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_hover .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_hover .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_hover .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_hover .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_hover .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Accent */
.sc_testimonials_accent .sc_item_slider .sc_testimonials_item {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_testimonials_accent .sc_testimonials_item {
  position: relative;
  -webkit-box-shadow: 0 3px 30px 0 rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 3px 30px 0 rgba(0, 0, 0, 0.04);
  box-shadow: 0 3px 30px 0 rgba(0, 0, 0, 0.04);
  padding: 57px 50px 61px;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: -webkit-transform 0.2s ease-out, color 0.2s ease-out;
  -ms-transition: -ms-transform 0.2s ease-out, color 0.2s ease-out;
  transition: transform 0.2s ease-out, color 0.2s ease-out;
  margin: 8px 0 0 0;
  -webkit-transform: translate3d(0, 0, 0);
  -ms-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
  will-change: transform;
}
.sc_testimonials_accent .sc_testimonials_item:before {
  content: '\e9eb';
  font-family: "fontello";
  display: block;
  position: relative;
  width: 100%;
  height: 32px;
  line-height: 32px;
  font-size: 20px;
  font-weight: 400;
  text-align: left;
  color: var(--theme-color-text_link2);
  margin-bottom: 20px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_accent .sc_testimonials_item:hover {
  -webkit-transform: translate3d(0, -8px, 0);
  -ms-transform: translate3d(0, -8px, 0);
  transform: translate3d(0, -8px, 0);
}
.sc_testimonials_accent .sc_testimonials_item:hover:before {
  color: var(--theme-color-text_dark);
}
.sc_testimonials_accent [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_accent .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_accent [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_accent .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_accent .sc_testimonials_item_author {
  margin: 26px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_accent .sc_testimonials_item_author_avatar {
  margin: 0 14px 0 0;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_accent .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_accent .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_accent .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_accent .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_accent .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_accent .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_accent .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_accent .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: var(--theme-color-bd_color);
}
.sc_testimonials_accent .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_accent .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_accent .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_accent .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_accent .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_accent .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_accent .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

/* Accent 2 */
.sc_testimonials_accent2 .sc_item_slider .sc_testimonials_item {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_testimonials_accent2 .sc_testimonials_item {
  position: relative;
  -webkit-box-shadow: 0 3px 30px 0 rgba(0, 0, 0, 0.04);
  -ms-box-shadow: 0 3px 30px 0 rgba(0, 0, 0, 0.04);
  box-shadow: 0 3px 30px 0 rgba(0, 0, 0, 0.04);
  padding: 45px 45px 40px 50px;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: -webkit-transform 0.2s ease-out, color 0.2s ease-out;
  -ms-transition: -ms-transform 0.2s ease-out, color 0.2s ease-out;
  transition: transform 0.2s ease-out, color 0.2s ease-out;
  margin: 8px 0 0 0;
  will-change: transform;
  -webkit-transform: translate3d(0, 0, 0);
  -ms-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
}
.sc_testimonials_accent2 .sc_testimonials_item:before {
  content: '\e9eb';
  font-family: "fontello";
  display: block;
  position: relative;
  width: 100%;
  height: 32px;
  line-height: 32px;
  font-size: 24px;
  font-weight: 400;
  text-align: left;
  color: var(--theme-color-text_link2);
  margin-bottom: 29px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_accent2 .sc_testimonials_item:hover {
  -webkit-transform: translate3d(0, -8px, 0);
  -ms-transform: translate3d(0, -8px, 0);
  transform: translate3d(0, -8px, 0);
}
.sc_testimonials_accent2 .sc_testimonials_item:hover:before {
  color: var(--theme-color-text_dark);
}
.sc_testimonials_accent2 [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_accent2 .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_accent2 [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_accent2 .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_accent2 .sc_testimonials_item_author {
  margin: 26px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_accent2 .sc_testimonials_item_author_avatar {
  margin: 0 14px 0 0;
  width: 78px;
  height: 78px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_accent2 .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_accent2 .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_accent2 .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_accent2 .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_testimonials_accent2 .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_accent2 .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_accent2 .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_accent2 .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: var(--theme-color-bd_color);
}
.sc_testimonials_accent2 .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_accent2 .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_accent2 .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_accent2 .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_accent2 .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_accent2 .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_accent2 .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_testimonials_accent2 .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_testimonials_accent2 .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2em;
}

/* Creative */
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_creative .sc_testimonials_item_content {
  text-align: center;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_creative .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_creative .sc_testimonials_item_author {
  margin: 34px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author:before,
.sc_testimonials_creative .sc_testimonials_item_author:before {
  font-size: 21px;
  line-height: 1.5em;
  color: var(--theme-color-text_link);
  content: '\e9eb';
  font-family: "fontello";
  margin-bottom: 16px;
  display: inline-block;
  width: 100%;
  text-align: center;
}
.sc_testimonials_creative .sc_testimonials_item_top {
  height: 120px;
  text-align: center;
  margin: 0 0 45px 0;
}
.sc_testimonials_creative .sc_testimonials_item_top .sc_testimonials_item_author_avatar {
  margin: 0 auto;
  width: 120px;
  height: 120px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  display: inline-block;
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author_data,
.sc_testimonials_creative .sc_testimonials_item_author_data {
  border: none;
  padding: 0;
  max-width: 100%;
  text-align: center;
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title,
.sc_testimonials_creative .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_creative .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_creative .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 1;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_creative [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_creative .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_creative .slider_container .swiper-pagination-bullet,
.sc_testimonials_creative .slider_outer .swiper-pagination-bullet {
  width: 10px;
  border: 2px solid var(--theme-color-text_dark);
  opacity: 1;
  height: 10px;
}
.sc_testimonials_creative .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_creative .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_creative .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
}
.sc_testimonials_creative .slider_container.slider_controls_side .slider_controls_wrap > a.slider_prev {
  opacity: 1;
  margin-left: 0 !important;
  left: calc(50% - 152px) !important;
  text-align: left !important;
}
.sc_testimonials_creative .slider_container.slider_controls_side .slider_controls_wrap > a.slider_next {
  opacity: 1;
  margin-right: 0 !important;
  right: calc(50% - 152px) !important;
  text-align: right !important;
}
.sc_testimonials_creative .slider_container.slider_controls_side .slider_controls_wrap > a {
  width: 40px;
  height: 40px;
  line-height: 40px;
  background: none !important;
  color: var(--theme-color-text_light) !important;
  top: 40px;
  margin-top: 0;
}
.sc_testimonials_creative .slider_container.slider_controls_side .slider_controls_wrap > a:before {
  font-size: 16px;
}
.sc_testimonials_creative .slider_container.slider_controls_side .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link) !important;
}

/* Fashion */
.sc_testimonials_fashion .slider_container:not(.slider_controller_container):not(.slider_multi):not(.slider_type_images),
.sc_testimonials_fashion .slider_container:not(.slider_controller_container):not(.slider_multi):not(.slider_type_images) .slider-slide {
  min-height: auto !important;
}
.sc_testimonials_fashion .info_title {
  display: none;
}
.sc_testimonials_fashion .slider-pagination-button .img_wrap {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  overflow: hidden;
  display: block;
}
.sc_testimonials_fashion .slider_outer_controls_bottom.slider_outer_pagination_pos_bottom_outside > .slider_controls_wrap {
  display: inline-block;
  width: 100%;
  text-align: left;
}
.sc_testimonials_fashion .slider_outer_pagination_custom.slider_outer_pagination_pos_bottom_outside {
  padding-left: 35%;
}
.sc_testimonials_fashion .slider_outer_pagination_custom.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom {
  margin: 0;
  width: 35%;
  position: absolute;
  left: 0;
  top: 0;
  text-align: left;
}
.sc_testimonials_fashion .swiper-pagination-custom .swiper-pagination-button:hover img,
.sc_testimonials_fashion .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active img {
  opacity: 1 !important;
}
.sc_testimonials_fashion .swiper-pagination-custom .swiper-pagination-button:hover .img_wrap:before,
.sc_testimonials_fashion .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active .img_wrap:before {
  opacity: 1 !important;
}
.sc_testimonials_fashion .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active {
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
}
.sc_testimonials_fashion .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active .info_title {
  opacity: 1 !important;
}
.sc_testimonials_fashion .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom {
  min-height: 180px;
  height: auto;
  line-height: 1.2em;
  margin-top: 7px;
}
.sc_testimonials_fashion .slider_outer.slider_outer_pagination_pos_bottom_outside.slider_outer_pagination_custom {
  padding-bottom: 0 !important;
}
.sc_testimonials_fashion .slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom .slider-pagination-button {
  margin: 0 0 10px 0;
  width: 138px;
  padding-right: 5px;
  height: auto;
  border: none;
  vertical-align: top;
  display: inline-block;
  opacity: 1;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: transparent;
  will-change: transform;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  -webkit-transition: all 0.3s ease-out;
  -ms-transition: all 0.3s ease-out;
  transition: all 0.3s ease-out;
  backface-visibility: hidden;
  -webkit-backface-visibility: hidden;
}
.sc_testimonials_fashion .slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom .slider-pagination-button img {
  opacity: 0.5;
  display: block;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  overflow: hidden;
  height: 103px;
  width: 103px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_fashion .slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom .slider-pagination-button .img_wrap {
  position: relative;
  display: block;
  width: auto;
  float: left;
  overflow: visible;
}
.sc_testimonials_fashion .slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom .slider-pagination-button .img_wrap:before {
  content: '\e9cb';
  font-family: "fontello";
  display: block;
  position: absolute;
  z-index: 1;
  bottom: -1px;
  right: -3px;
  width: 30px;
  height: 30px;
  line-height: 32px;
  overflow: hidden;
  font-size: 7px;
  font-weight: 400;
  text-align: center;
  text-indent: 1px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
  opacity: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_fashion .slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom .slider-pagination-button .img_wrap + .info_title {
  padding-top: 27px;
  opacity: 0;
  width: 100%;
}
.sc_testimonials_fashion .slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom .slider-pagination-button .info_title {
  display: inline-block;
  width: 100%;
  text-align: left;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_fashion .slider_outer_controls_bottom > .slider_controls_wrap {
  margin-top: 3em;
}
.sc_testimonials_fashion .slider_prev + .slider_next,
.sc_testimonials_fashion .slider_prev + .slider_pagination_wrap,
.sc_testimonials_fashion .slider_next + .slider_pagination_wrap {
  margin-left: 0.5em;
}
.sc_testimonials_fashion .slider_controls_wrap > a.slider_next,
.sc_testimonials_fashion .slider_controls_wrap > a.slider_prev {
  border: 1px solid var(--theme-color-bd_color);
  height: 56px;
  width: 56px;
  line-height: 53px;
  padding: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: transparent !important;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_fashion .slider_controls_wrap > a.slider_next:before,
.sc_testimonials_fashion .slider_controls_wrap > a.slider_prev:before {
  font-size: 16px;
}
.sc_testimonials_fashion .slider_controls_wrap > a.slider_next:hover,
.sc_testimonials_fashion .slider_controls_wrap > a.slider_prev:hover {
  color: var(--theme-color-text_link);
}
.sc_testimonials_fashion .slider_container.slider_controls_side .slider_controls_wrap > .slider_prev {
  opacity: 1;
  margin-left: 0;
  left: 0;
  text-align: center;
}
.sc_testimonials_fashion .slider_container.slider_controls_side .slider_controls_wrap > .slider_next {
  opacity: 1;
  margin-right: 0;
  right: 0;
  text-align: center;
}
.sc_testimonials_fashion .sc_testimonials_item_author_title {
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
}
.sc_testimonials_fashion .sc_testimonials_item_author_subtitle {
  color: var(--theme-color-alter_text);
  opacity: 1;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
  display: block;
}
.sc_testimonials_fashion .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_fashion .sc_testimonials_item_author,
.sc_testimonials_fashion [class*="column"] .sc_testimonials_item_author {
  text-align: left;
  margin: 30px 0 0 0;
  padding: 0;
}
.sc_testimonials_fashion .sc_testimonials_item_content,
.sc_testimonials_fashion [class*="column"] .sc_testimonials_item_content {
  font-size: 19px;
  line-height: 32px;
  font-weight: 400;
  text-align: left;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_fashion .sc_testimonials_item_content p + p,
.sc_testimonials_fashion [class*="column"] .sc_testimonials_item_content p + p {
  margin-top: 1.5em;
}
.sc_testimonials_fashion .sc_testimonials_item_content:before {
  display: none;
}

/* Alter */
.sc_testimonials_alter .slider_container.slider_one .sc_testimonials_item {
  padding: 0 15%;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_alter .sc_testimonials_item_content {
  text-align: center;
  font-size: 19px;
  line-height: 32px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_alter .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_alter .sc_testimonials_item_author {
  margin: 32px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author:before,
.sc_testimonials_alter .sc_testimonials_item_author:before {
  font-size: 21px;
  line-height: 1.5em;
  color: var(--theme-color-text_link2);
  content: '\e9eb';
  font-family: "fontello";
  margin-bottom: 22px;
  display: inline-block;
  width: 100%;
  text-align: center;
}
.sc_testimonials_alter .sc_testimonials_item_top {
  height: 103px;
  text-align: center;
  margin: 0 0 38px 0;
}
.sc_testimonials_alter .sc_testimonials_item_top .sc_testimonials_item_author_avatar {
  margin: 0 auto;
  width: 103px;
  height: 103px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  display: inline-block;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author_data,
.sc_testimonials_alter .sc_testimonials_item_author_data {
  border: none;
  padding: 0;
  max-width: 100%;
  text-align: center;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title,
.sc_testimonials_alter .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 1;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_alter [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_alter .slider_container .swiper-pagination-bullet,
.sc_testimonials_alter .slider_outer .swiper-pagination-bullet {
  width: 10px;
  border: 2px solid var(--theme-color-text_dark);
  opacity: 1;
  height: 10px;
}
.sc_testimonials_alter .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_alter .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_alter .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
}
.sc_testimonials_alter .slider_container.slider_controls_side .slider_controls_wrap > .slider_prev {
  opacity: 1;
  margin-left: 0 !important;
  left: 0 !important;
  text-align: center !important;
}
.sc_testimonials_alter .slider_container.slider_controls_side .slider_controls_wrap > .slider_next {
  opacity: 1;
  margin-right: 0 !important;
  right: 0 !important;
  text-align: center !important;
}
.sc_testimonials_alter .slider_controls_wrap > a {
  text-align: center !important;
  width: 56px !important;
  height: 56px !important;
  line-height: 54px !important;
  background: none !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  border: 1px solid var(--theme-color-bd_color) !important;
  color: var(--theme-color-text_dark) !important;
}
.sc_testimonials_alter .slider_controls_wrap > a:before {
  font-size: 16px !important;
}
.sc_testimonials_alter .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link) !important;
}
.sc_testimonials_alter .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_alter .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_alter .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: #E5E3E0;
}
.sc_testimonials_alter .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_alter .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_alter .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_alter .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_alter .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_alter .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_alter .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_testimonials_alter .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_testimonials_alter .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2em;
}

/* Alter 2 */
.sc_testimonials_alter2 .slider_container.slider_one .sc_testimonials_item {
  padding: 0 15%;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_alter2 .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 30px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_alter2 .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_alter2 .sc_testimonials_item_author {
  margin: 13px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author:before,
.sc_testimonials_alter2 .sc_testimonials_item_author:before {
  font-size: 21px;
  line-height: 1.5em;
  color: var(--theme-color-text_link2);
  content: '\e9eb';
  font-family: "fontello";
  margin-bottom: 22px;
  display: inline-block;
  width: 100%;
  text-align: left;
  padding-left: 1px;
}
.sc_testimonials_alter2 .sc_testimonials_item_top {
  height: 100px;
  text-align: left;
  margin: 0 0 27px 0;
}
.sc_testimonials_alter2 .sc_testimonials_item_top .sc_testimonials_item_author_avatar {
  margin: 0 auto;
  width: 100px;
  height: 100px;
  position: relative;
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  display: inline-block;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author_data,
.sc_testimonials_alter2 .sc_testimonials_item_author_data {
  border: none;
  padding: 0;
  max-width: 100%;
  text-align: left;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title,
.sc_testimonials_alter2 .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter2 .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter2 .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  opacity: 1;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_alter2 [class*="column"] .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle,
.sc_testimonials_alter2 .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}
.sc_testimonials_alter2 .slider_container .swiper-pagination-bullet,
.sc_testimonials_alter2 .slider_outer .swiper-pagination-bullet {
  width: 10px;
  border: 2px solid var(--theme-color-text_dark);
  opacity: 1;
  height: 10px;
}
.sc_testimonials_alter2 .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_alter2 .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.sc_testimonials_alter2 .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
}
.sc_testimonials_alter2 .slider_container.slider_controls_side .slider_controls_wrap > .slider_prev {
  opacity: 1;
  margin-left: 0;
  left: 0;
  text-align: center;
}
.sc_testimonials_alter2 .slider_container.slider_controls_side .slider_controls_wrap > .slider_next {
  opacity: 1;
  margin-right: 0;
  right: 0;
  text-align: center;
}
.sc_testimonials_alter2 .slider_controls_wrap > a {
  text-align: center !important;
  width: 56px !important;
  height: 56px !important;
  line-height: 52px !important;
  background: none !important;
  -webkit-border-radius: 50% !important;
  -ms-border-radius: 50% !important;
  border-radius: 50% !important;
  border: 1px solid var(--theme-color-bd_color) !important;
  color: var(--theme-color-text_dark) !important;
}
.sc_testimonials_alter2 .slider_controls_wrap > a:before {
  font-size: 16px !important;
}
.sc_testimonials_alter2 .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link) !important;
}
.sc_testimonials_alter2 .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_alter2 .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_alter2 .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 8px;
  background: transparent;
  border-color: #E5E3E0;
}
.sc_testimonials_alter2 .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_alter2 .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_alter2 .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_alter2 .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_alter2 .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_alter2 .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_alter2 .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_testimonials_alter2 .sc_item_slider.slider_outer_pagination_pos_bottom {
  padding-bottom: 3.6em;
}

/* Decoration */
.sc_testimonials_decoration .slider_container.slider_controls_side .slider_controls_wrap > .slider_prev {
  opacity: 1;
  margin-left: 0 !important;
  left: 0 !important;
  text-align: left;
}
.sc_testimonials_decoration .slider_container.slider_controls_side .slider_controls_wrap > .slider_next {
  opacity: 1;
  margin-right: 0 !important;
  right: 0 !important;
  text-align: right;
}
.sc_testimonials_decoration .slider_container.slider_controls_side .slider_controls_wrap > a {
  width: 40px;
  height: 40px;
  line-height: 40px;
  background: none !important;
  color: var(--theme-color-text_dark) !important;
}
.sc_testimonials_decoration .slider_container.slider_controls_side .slider_controls_wrap > a:before {
  font-size: 22px;
}
.sc_testimonials_decoration .slider_container.slider_controls_side .slider_controls_wrap > a:hover {
  color: var(--theme-color-text_link) !important;
}
.sc_testimonials_decoration .slider_outer.slider_outer_pagination_pos_bottom.slider_outer_pagination_custom .slider_controls_wrap > a {
  margin-top: 2em;
}
.sc_testimonials_decoration .slider_container.slider_one .sc_testimonials_item {
  padding: 0 15%;
}
.sc_testimonials_decoration .sc_testimonials_item_author_title {
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
}
.sc_testimonials_decoration .sc_testimonials_item_author_subtitle {
  color: var(--theme-color-text_dark);
  opacity: 0.8;
  font-size: 15px;
  line-height: 20px;
  padding-bottom: 2px;
}
.sc_testimonials_decoration .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 7px;
}
.sc_testimonials_decoration .sc_testimonials_item_author,
.sc_testimonials_decoration [class*="column"] .sc_testimonials_item_author {
  text-align: center;
  margin: 34px 0 0 0;
  padding: 0;
}
.sc_testimonials_decoration .sc_testimonials_item_author .sc_testimonials_item_author_data,
.sc_testimonials_decoration [class*="column"] .sc_testimonials_item_author .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_decoration .sc_testimonials_item_content,
.sc_testimonials_decoration [class*="column"] .sc_testimonials_item_content {
  font-size: 19px;
  line-height: 32px;
  font-weight: 400;
  text-align: center;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_decoration .sc_testimonials_item_content:before {
  margin-bottom: 42px;
  font-size: 22px;
  line-height: 1.3em;
  content: '\E9DE';
  font-family: "fontello";
  will-change: color;
  color: var(--theme-color-text_link);
  -webkit-transition: color 0.3s ease-out;
  -ms-transition: color 0.3s ease-out;
  transition: color 0.3s ease-out;
}

/* Chit */
.sc_testimonials_chit .sc_testimonials_rating_stars_default, .sc_testimonials_chit .sc_testimonials_rating_stars_hover {
  color: #FFC107;
}
.sc_testimonials_chit .sc_testimonials_item_author_rating {
  line-height: 1;
}
.sc_testimonials_chit .sc_testimonials_item_author_rating .sc_testimonials_rating {
  height: 1em;
  font-size: 1.1em;
}
.sc_testimonials_chit .sc_testimonials_item_author_rating + .sc_testimonials_item_content {
  margin-top: 36px;
}
.sc_testimonials_chit .sc_testimonials_item {
  position: relative;
  padding: 74px 40px;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  margin-bottom: 0;
  margin-top: 0;
}
.sc_testimonials_chit .sc_testimonials_item:before {
  display: none;
}
.sc_testimonials_chit [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_chit .sc_testimonials_item_content {
  text-align: left;
  font-size: 17px;
  line-height: 27px;
  font-weight: inherit;
  font-style: normal;
  color: var(--theme-color-text);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_testimonials_chit [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_chit .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_chit .sc_testimonials_item_author {
  margin: 60px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: left;
}
.sc_testimonials_chit .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_chit .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_chit .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_chit .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-alter_text);
  font-size: 15px;
  line-height: 20px;
}
.sc_testimonials_chit .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 10px;
}
.sc_testimonials_chit .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_chit .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_testimonials_chit .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 6px;
  background-color: #E2E1E0;
  border-color: #E2E1E0;
  opacity: 1;
  width: 8px;
  height: 8px;
}
.sc_testimonials_chit .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_testimonials_chit .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_testimonials_chit .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_testimonials_chit .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_chit .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_testimonials_chit .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_testimonials_chit .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_testimonials_chit .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_testimonials_chit .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2.4em;
}

/* Bred */
.sc_testimonials_bred .sc_testimonials_item {
  padding: 61px 30px 55px;
  height: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 3px 40px 0 rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 40px 0 rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 40px 0 rgba(0, 0, 0, 0.05);
}
.sc_testimonials_bred .sc_item_slider .sc_testimonials_item {
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.sc_testimonials_bred [class*="column"] .sc_testimonials_item_content,
.sc_testimonials_bred .sc_testimonials_item_content {
  text-align: center;
  font-size: 16px;
  line-height: 27px;
  font-weight: 400;
  font-style: normal;
  color: var(--theme-color-text_dark);
}
.sc_testimonials_bred [class*="column"] .sc_testimonials_item_content:before,
.sc_testimonials_bred .sc_testimonials_item_content:before {
  display: none;
}
.sc_testimonials_bred [class*="column"] .sc_testimonials_item_author,
.sc_testimonials_bred .sc_testimonials_item_author {
  margin: 25px 0 0;
  max-width: none;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  text-align: center;
}
.sc_testimonials_bred .sc_testimonials_item_author_avatar {
  overflow: visible;
  margin: 0 auto 32px;
  width: 93px;
  height: 93px;
  position: relative;
  display: block;
}
.sc_testimonials_bred .sc_testimonials_item_author_avatar:before {
  content: '\e9cb';
  font-family: "fontello";
  display: block;
  position: absolute;
  z-index: 1;
  bottom: -1px;
  right: -1px;
  width: 30px;
  height: 30px;
  line-height: 32px;
  overflow: hidden;
  font-size: 7px;
  font-weight: 400;
  text-align: center;
  text-indent: 1px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.sc_testimonials_bred .sc_testimonials_item_author_avatar img {
  overflow: hidden;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_testimonials_bred .sc_testimonials_item_author_data {
  max-width: 100%;
}
.sc_testimonials_bred .sc_testimonials_item_author_data .sc_testimonials_item_author_title {
  margin: 0;
  color: var(--theme-color-text_dark);
  font-size: 17px;
  line-height: 22px;
  font-weight: 700;
  font-style: normal;
  letter-spacing: 0;
  text-transform: none;
}
.sc_testimonials_bred .sc_testimonials_item_author_data .sc_testimonials_item_author_subtitle,
.sc_testimonials_bred .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 0;
  color: var(--theme-color-text);
  opacity: 1;
  font-size: 15px;
  line-height: 20px;
}
.sc_testimonials_bred .sc_testimonials_item_author_data .sc_testimonials_item_author_title + .sc_testimonials_item_author_subtitle {
  margin-top: 6px;
}

/* --- Controls --- */
/* Bullets */
.sc_slider_controls.sc_slider_controls_default.slider_pagination_style_bullets .slider_pagination_bullet {
  margin: 0 8px;
  border-color: var(--theme-color-text_dark);
  background-color: transparent;
}
.sc_slider_controls.sc_slider_controls_default.slider_pagination_style_bullets .slider_pagination_bullet.slider_pagination_bullet_active, .sc_slider_controls.sc_slider_controls_default.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-button-active, .sc_slider_controls.sc_slider_controls_default.slider_pagination_style_bullets .slider_pagination_bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

.sc_slider_controls.sc_slider_controls_default.slider_pagination_style_bullets.sc_align_left .slider_controls_wrap:not(.with_prev):not(.with_next) .slider_pagination_wrap {
  text-align: left;
  justify-content: left;
  margin-left: -8px;
}
.sc_slider_controls.sc_slider_controls_default.slider_pagination_style_bullets .slider_controls_wrap:not(.with_prev):not(.with_next) .slider_pagination_wrap {
  height: 20px;
}

/* Default */
.sc_slider_controls.sc_slider_controls_default .slider_prev + .slider_next,
.sc_slider_controls.sc_slider_controls_default .slider_prev + .slider_pagination_wrap,
.sc_slider_controls.sc_slider_controls_default .slider_next + .slider_pagination_wrap {
  margin-left: 0.5em;
}
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_next,
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_prev {
  border: 1px solid var(--theme-color-bd_color);
  height: 56px;
  width: 56px;
  line-height: 53px;
  padding: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: transparent;
  color: var(--theme-color-text_dark);
  flex-shrink: 0;
}
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_next:before,
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_prev:before {
  font-size: 16px;
}
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_next.with_title,
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_prev.with_title {
  -webkit-border-radius: 5px;
  -ms-border-radius: 5px;
  border-radius: 5px;
  padding: 0 15px;
  width: auto;
}
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_next:hover,
.sc_slider_controls.sc_slider_controls_default .slider_controls_wrap > a.slider_prev:hover {
  color: var(--theme-color-text_link);
}

/* Light */
.sc_slider_controls.sc_slider_controls_light .slider_prev + .slider_next,
.sc_slider_controls.sc_slider_controls_light .slider_prev + .slider_pagination_wrap,
.sc_slider_controls.sc_slider_controls_light .slider_next + .slider_pagination_wrap {
  margin-left: 0.5em;
}
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_next:before {
  content: '\e9e6';
  letter-spacing: -3px;
}
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_prev:before {
  content: '\e9e5';
  letter-spacing: 2px;
}
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_next,
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_prev {
  border: 1px solid var(--theme-color-bd_color);
  height: 56px;
  width: 56px;
  min-width: 56px;
  line-height: 52px;
  padding: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: transparent;
  color: var(--theme-color-text_dark);
}
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_next:before,
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_prev:before {
  font-size: 14px;
}
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_next.with_title,
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_prev.with_title {
  -webkit-border-radius: 5px;
  -ms-border-radius: 5px;
  border-radius: 5px;
  padding: 0 15px;
  width: auto;
}
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_next:hover,
.sc_slider_controls.sc_slider_controls_light .slider_controls_wrap > a.slider_prev:hover {
  color: var(--theme-color-text_link);
}

/* Alter */
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap:not(.with_prev):not(.with_next) .slider_pagination_wrap {
  text-align: left;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}
.sc_slider_controls.sc_slider_controls_alter .slider_pagination_bullet {
  position: relative;
  z-index: 1;
  margin: 0 15px;
  border: none;
  background-color: var(--theme-color-alter_bg_color);
}
.sc_slider_controls.sc_slider_controls_alter .slider_pagination_bullet.swiper-pagination-bullet-active {
  background-color: var(--theme-color-alter_link);
}
.sc_slider_controls.sc_slider_controls_alter .slider_pagination_bullet.swiper-pagination-bullet-active:after {
  content: '';
  display: block;
  width: 20px;
  height: 20px;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: var(--theme-color-alter_link_02);
}
.sc_slider_controls.sc_slider_controls_alter .slider_pagination_bullet:first-child {
  margin-left: 0;
}
.sc_slider_controls.sc_slider_controls_alter .slider_pagination_bullet:last-child {
  margin-right: 0;
}
.sc_slider_controls.sc_slider_controls_alter .slider_prev + .slider_next,
.sc_slider_controls.sc_slider_controls_alter .slider_prev + .slider_pagination_wrap,
.sc_slider_controls.sc_slider_controls_alter .slider_next + .slider_pagination_wrap {
  margin-left: 15px;
}
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_next,
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_prev {
  border: none;
  height: 1.5em;
  width: 1.5em;
  line-height: 1.5em;
  padding: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: transparent;
  color: var(--theme-color-alter_dark);
}
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_next:before,
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_prev:before {
  font-size: 20px;
}
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_next.with_title,
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_prev.with_title {
  -webkit-border-radius: 5px;
  -ms-border-radius: 5px;
  border-radius: 5px;
  padding: 0 15px;
  width: auto;
}
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_next:hover,
.sc_slider_controls.sc_slider_controls_alter .slider_controls_wrap > a.slider_prev:hover {
  color: var(--theme-color-text_link);
}

/* Socials Default */
.sc_socials.sc_socials_default .socials_wrap {
  margin-bottom: -7px;
}
.sc_socials.sc_socials_default .socials_wrap .social_item {
  display: inline-block;
  vertical-align: top;
  line-height: inherit;
  text-align: center;
  margin: 0 7px 7px 0;
}
.sc_socials.sc_socials_default .socials_wrap .social_item .social_icon {
  position: relative;
  display: block;
  background-size: 100%;
  background-position: top center;
  overflow: hidden;
  width: 45px;
  height: 45px;
  line-height: 43px;
  font-size: 16px;
  text-align: center;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  border: 1px solid var(--theme-color-text_dark_015);
  color: var(--theme-color-text_dark);
  background-color: transparent;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon {
  background-color: transparent;
  color: var(--theme-color-text_link);
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="facebook"] {
  color: #3b5998 !important;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="twitter"] {
  color: #1da1f2 !important;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="dribble"], .sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="dribbble"] {
  color: #ea4c89 !important;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="instagram"] {
  color: #C862DC !important;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="youtube"] {
  color: #FF0000 !important;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="deviantart"] {
  color: #00E59B !important;
}
.sc_socials.sc_socials_default .socials_wrap .social_item:hover .social_icon[class*="discord"] {
  color: #5562EA !important;
}

/* Toggle filter */
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  flex-wrap: wrap;
  align-items: flex-start;
  width: var(--theme-var-page);
  margin-left: auto;
  margin-right: auto;
  margin-bottom: 1.7rem;
  opacity: 0;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.inited {
  opacity: 1;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.sc_item_filters_align_left .list_wrap .sc_item_filters_tabs {
  justify-content: flex-start;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.sc_item_filters_align_left .sc_item_filters_header {
  text-align: left;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.sc_item_filters_align_right .list_wrap .sc_item_filters_tabs {
  justify-content: flex-start;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.sc_item_filters_align_right .sc_item_filters_header {
  text-align: right;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.sc_item_filters_align_center .list_wrap .sc_item_filters_tabs {
  justify-content: flex-start;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters.sc_item_filters_align_center .sc_item_filters_header {
  text-align: center;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .sc_item_filters_header {
  flex-basis: 100%;
  order: 1;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .title_wrap {
  order: 2;
  font-size: 1rem;
  padding-right: 3.6rem;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .title_wrap .toggle_title {
  color: var(--theme-color-text_dark);
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .title_wrap .active_tab {
  text-transform: capitalize;
  cursor: pointer;
  color: var(--theme-color-text_link3);
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap {
  overflow: hidden;
  order: 3;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs {
  margin-bottom: 0 !important;
  transform: translateX(-100%);
  transition: transform 1s ease;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs li {
  padding: 0 15px;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs li a {
  text-transform: capitalize;
  color: var(--theme-color-text_dark);
  padding-bottom: 0;
  font-size: 1rem;
  border-bottom: none;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs li a:after {
  display: none;
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs li a:hover {
  color: var(--theme-color-text_link3);
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs li.sc_item_filters_tabs_active a {
  color: var(--theme-color-text_link3);
}
.sc_style_toggle .sc_blogger .sc_item_filters_wrap .sc_item_filters .list_wrap .sc_item_filters_tabs.active {
  transform: translateX(0);
  transition: transform 1s ease;
}

/* --- Portfolio --- */
/* Default filter */
.sc_blogger .sc_blogger_filters .sc_item_filters_tabs li a {
  display: inline-block;
}

.sc_blogger_lay_portfolio .sc_blogger_filters,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters {
  margin-bottom: 2.4em;
}
.sc_blogger_lay_portfolio .sc_blogger_filters.sc_item_filters_align_left, .sc_blogger_lay_portfolio .sc_blogger_filters.sc_item_filters_align_right,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters.sc_item_filters_align_left,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters.sc_item_filters_align_right {
  border-bottom: none;
  padding-bottom: 0;
}
.sc_blogger_lay_portfolio .sc_blogger_filters.sc_item_filters_align_right.sc_item_filters_no_title .sc_item_filters_tabs li:first-child,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters.sc_item_filters_align_right.sc_item_filters_no_title .sc_item_filters_tabs li:first-child {
  padding-left: 0;
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li {
  padding: 0 13px;
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li a,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li a {
  font-size: 1rem;
  color: var(--theme-color-alter_text);
  padding-bottom: 5px;
  position: relative;
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li a:after,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li a:after {
  content: '';
  position: absolute;
  bottom: 0;
  left: auto;
  right: 0;
  height: 2px;
  width: 0;
  background-color: var(--theme-color-alter_link);
  transition: all 0.3s;
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li a:hover,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li a:hover {
  color: var(--theme-color-alter_dark);
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li a:hover:after,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li a:hover:after {
  width: 100%;
  left: 0;
  right: auto;
  transition: all 0.3s;
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li.sc_item_filters_tabs_active a,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li.sc_item_filters_tabs_active a {
  border: none;
  color: var(--theme-color-alter_dark);
}
.sc_blogger_lay_portfolio .sc_blogger_filters .sc_item_filters_tabs li.sc_item_filters_tabs_active a:after,
.sc_blogger_lay_portfolio_grid .sc_blogger_filters .sc_item_filters_tabs li.sc_item_filters_tabs_active a:after {
  width: 100%;
  left: 0;
  right: auto;
  transition: all 0.3s;
}

/* Pagination ( Portfolio and Blogger Portfolio ) */
.sc_portfolio .slider_container .swiper-pagination-bullet,
.sc_portfolio .slider_outer .swiper-pagination-bullet,
.sc_blogger.sc_blogger_portfolio .slider_container .swiper-pagination-bullet,
.sc_blogger.sc_blogger_portfolio .slider_outer .swiper-pagination-bullet {
  width: 8px;
  height: 8px;
}
.sc_portfolio .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet,
.sc_portfolio .slider_container .slider_pagination_wrap .swiper-pagination-bullet,
.sc_portfolio .slider_outer .slider_pagination_wrap .swiper-pagination-bullet,
.sc_portfolio .swiper-pagination-custom .swiper-pagination-button,
.sc_blogger.sc_blogger_portfolio .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet,
.sc_blogger.sc_blogger_portfolio .slider_container .slider_pagination_wrap .swiper-pagination-bullet,
.sc_blogger.sc_blogger_portfolio .slider_outer .slider_pagination_wrap .swiper-pagination-bullet,
.sc_blogger.sc_blogger_portfolio .swiper-pagination-custom .swiper-pagination-button {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bd_color);
}
.sc_portfolio .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active,
.sc_portfolio .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_portfolio .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_portfolio .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-bullet-active,
.sc_blogger.sc_blogger_portfolio .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active,
.sc_blogger.sc_blogger_portfolio .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_blogger.sc_blogger_portfolio .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.sc_blogger.sc_blogger_portfolio .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-bullet-active {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_portfolio .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_blogger.sc_blogger_portfolio .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets {
  margin-top: 2.2em;
}

/* Default and Extra Portfolio Styles  */
.sc_blogger_excerpt_default .post_layout_excerpt {
  margin-bottom: 0 !important;
}

.sc_blogger_excerpt_default .sc_item_posts_container .post_layout_excerpt {
  margin-bottom: 0.4em !important;
}

.sc_portfolio_eclipse .sc_portfolio_content > .sc_portfolio_item + .sc_portfolio_item,
.sc_portfolio_extra .sc_portfolio_content > .sc_portfolio_item + .sc_portfolio_item,
.sc_portfolio_default .sc_portfolio_content > .sc_portfolio_item + .sc_portfolio_item,
.sc_blogger_portfolio_default > .sc_blogger_content > .column-1_1 + .column-1_1,
.sc_blogger_classic_default > .sc_blogger_content > .column-1_1 + .column-1_1 {
  margin-top: 1.5em;
}

.sc_blogger_portestate_default > .sc_blogger_content .sc_blogger_item_portestate_default + .sc_blogger_item_portestate_default,
.sc_blogger_lay_portfolio > .sc_blogger_content .sc_blogger_item_lay_portfolio + .sc_blogger_item_lay_portfolio {
  margin-top: 2em;
}

.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg {
  background-position: center center;
  background-size: cover;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg:before {
  padding-top: 15rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide:nth-child(odd) {
  width: 35% !important;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide:nth-child(even) {
  width: 65% !important;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_2 .swiper-slide .post_featured_bg:before {
  padding-top: 24.8rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_3 .swiper-slide .post_featured_bg:before {
  padding-top: 20rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_4 .swiper-slide .post_featured_bg:before {
  padding-top: 18rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_4 .sc_portfolio_item .post_featured .post_info, .slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_5 .sc_portfolio_item .post_featured .post_info, .slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_6 .sc_portfolio_item .post_featured .post_info {
  bottom: 20px;
  left: 0;
  padding: 13px 18px 11px;
}
.slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_4 .sc_portfolio_item .post_featured .post_info .post_title, .slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_5 .sc_portfolio_item .post_featured .post_info .post_title, .slider_width_auto .sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_6 .sc_portfolio_item .post_featured .post_info .post_title {
  font-size: 1.1rem;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg {
  background-position: center center;
  background-size: cover;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg:before {
  padding-top: 20rem;
}
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay:before {
  content: '';
  display: inline-block;
  width: 0;
  vertical-align: top;
  margin-left: -0.3em;
}
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay {
  position: absolute;
  z-index: 3;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay iframe {
  height: 100% !important;
  background-color: #000;
}
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .mejs-layers,
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .mejs-controls {
  display: none;
}
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay video {
  object-fit: cover;
  height: 100% !important;
}
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .with_video_autoplay,
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .video_frame,
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .wp-video,
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .mejs-container,
.sc_portfolio.sc_portfolio_default > div:not([class*="masonry"]) .post_featured.with_video_autoplay > .with_video_autoplay .mejs-mediaelement {
  height: 100% !important;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured {
  overflow: hidden;
  position: relative;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured > a {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  z-index: 1;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured.with_video_autoplay, .sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured.post_featured_bg {
  background-position: center center;
  background-size: cover;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured.with_video_autoplay:before, .sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured.post_featured_bg:before {
  padding-top: 20rem;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured .mask {
  display: none;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured .post_info {
  width: auto;
  max-width: calc(100% - 30px);
  height: auto;
  top: auto;
  right: auto;
  bottom: 27px;
  left: 0;
  padding: 23px 28px 21px;
  background-color: var(--theme-color-bg_color);
  -webkit-transform: translateX(-100%) translateZ(0);
  -ms-transform: translateX(-100%) translateZ(0);
  transform: translateX(-100%) translateZ(0);
  transition: all 0.3s;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured .post_info .post_title {
  font-size: 1.6rem;
  line-height: 1.2em;
  letter-spacing: 0;
  text-transform: none;
  font-weight: 700;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured .post_info .post_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured .post_info .post_meta .post_categories {
  font-size: 14px;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured .post_info .post_meta .post_categories a {
  color: var(--theme-color-alter_text) !important;
}
.sc_portfolio.sc_portfolio_default .sc_portfolio_item .post_featured:hover .post_info {
  -webkit-transform: translateX(0) translateZ(0);
  -ms-transform: translateX(0) translateZ(0);
  transform: translateX(0) translateZ(0);
  transition: all 0.7s;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg {
  background-position: center center;
  background-size: cover;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg:before {
  padding-top: 17rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide:nth-child(2n+1) {
  width: 35% !important;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide:nth-child(2n) {
  width: 65% !important;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_2 .swiper-slide .post_featured_bg:before {
  padding-top: 34.5rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_3 .post_featured_bg:before {
  padding-top: 22rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_4 .post_featured_bg:before {
  padding-top: 20rem;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_4 .sc_portfolio_item .post_featured .post_info, .slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_5 .sc_portfolio_item .post_featured .post_info, .slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_6 .sc_portfolio_item .post_featured .post_info {
  bottom: 10px;
  left: 10px;
}
.slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_4 .sc_portfolio_item .post_featured .post_info .post_title, .slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_5 .sc_portfolio_item .post_featured .post_info .post_title, .slider_width_auto .sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper.sc_item_columns_6 .sc_portfolio_item .post_featured .post_info .post_title {
  font-size: 1.1rem;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg {
  background-position: center center;
  background-size: cover;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_slider .slider_container .slider-wrapper .swiper-slide .sc_portfolio_item .post_featured_bg:before {
  padding-top: 24rem;
}
.sc_portfolio.sc_portfolio_extra .trx_addons_columns_wrap {
  margin-right: -16px;
}
.sc_portfolio.sc_portfolio_extra .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 16px;
}
.sc_portfolio.sc_portfolio_extra .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"] {
  padding-bottom: 16px;
}
.sc_portfolio.sc_portfolio_extra .trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
  padding-bottom: 16px;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured {
  overflow: hidden;
  position: relative;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured > a {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  z-index: 1;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured.post_featured_bg {
  background-position: center center;
  background-size: cover;
  margin: 0;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured.post_featured_bg:before {
  padding-top: 100%;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .mask {
  display: none;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .post_info {
  width: auto;
  max-width: calc(100% - 80px);
  height: auto;
  top: auto;
  right: auto;
  bottom: 40px;
  left: 40px;
  padding: 0;
  background-color: transparent;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .post_info .post_title {
  font-size: 1.6rem;
  line-height: 1.25em;
  letter-spacing: 0;
  font-weight: 700;
  padding: 11px 30px 11px 22px;
  background-color: #0F0F0F;
  transform: translateX(-101%);
  transition: all 0.3s;
  transition-duration: 0.3s;
  transition-delay: 0ms;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .post_info .post_title a {
  color: #ffffff !important;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .post_info .post_meta {
  margin-top: 5px;
  transform: translateX(-101%);
  transition: all 0.3s;
  transition-delay: 50ms;
  transition-duration: 0.3s;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .post_info .post_meta .post_categories {
  font-size: 14px;
  line-height: 1.4em;
  padding: 6px 20px;
  background-color: #1B1B1B;
  max-width: 100%;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured .post_info .post_meta .post_categories a {
  color: #ffffff !important;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured:hover .post_info .post_title {
  transform: translateX(0);
  transition: all 0.7s ease;
  transition-delay: 0ms;
  transition-duration: 0.5s;
}
.sc_portfolio.sc_portfolio_extra .sc_portfolio_item .post_featured:hover .post_info .post_meta {
  transform: translateX(0);
  transition: all 0.7s ease;
  transition-delay: 50ms;
  transition-duration: 0.5s;
}
.sc_portfolio.sc_portfolio_extra .trx_addons_column-1_5 .sc_portfolio_item .post_info,
.sc_portfolio.sc_portfolio_extra .trx_addons_column-1_6 .sc_portfolio_item .post_info,
.sc_portfolio.sc_portfolio_extra .trx_addons_column-1_3 .sc_portfolio_item .post_info,
.sc_portfolio.sc_portfolio_extra .trx_addons_column-1_4 .sc_portfolio_item .post_info {
  left: 30px;
  bottom: 30px;
  max-width: calc(100% - 60px);
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured {
  overflow: hidden;
  position: relative;
  margin-bottom: 0;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured > a {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 7;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .mask {
  display: block;
  background-color: var(--theme-color-inverse_dark);
  opacity: 0;
  transition-delay: 300ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .post_info {
  width: calc(100% - 40px);
  height: calc( 100% - 40px );
  top: 20px;
  right: 20px;
  bottom: 20px;
  left: 20px;
  padding: 0;
  background-color: transparent;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .post_info .post_title {
  font-size: 1.6rem;
  line-height: 1.208em;
  letter-spacing: 0;
  font-weight: 700;
  color: #ffffff !important;
  overflow: hidden;
  text-align: center;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .post_info .post_title a {
  transform: translateY(100%);
  transition-delay: 150ms;
  transition: 300ms;
  transition-duration: 400ms;
  color: #ffffff !important;
  margin-left: 0;
  overflow: hidden;
  padding-bottom: 2px;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .post_info .post_meta {
  overflow: hidden;
  margin-top: 0.55em;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .post_info .post_meta .post_categories {
  font-size: 14px;
  line-height: 1.4em;
  color: #ffffff !important;
  transform: translateY(100%);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 400ms;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured .post_info .post_meta .post_categories a {
  color: #ffffff !important;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured:hover .mask {
  transition: all 0.3s;
  opacity: 0.9;
  transition-duration: 300ms;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured:hover .post_info .post_title a {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_portfolio.sc_portfolio_eclipse .sc_portfolio_item .post_featured:hover .post_info .post_meta .post_categories {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
  align-items: stretch;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_featured {
  flex-basis: 49%;
  flex-shrink: 0;
  margin-bottom: 0;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap {
  box-sizing: border-box;
  padding: 2.2em 2.2em 1.9em;
  display: -webkit-flex;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-content: flex-start;
  align-self: center;
  flex-basis: 51%;
  max-width: 51%;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_title {
  margin-bottom: 27px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_title a:hover {
  color: var(--theme-color-text_dark) !important;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_description_content {
  margin-bottom: 15px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_meta + .post_title {
  margin-top: 12px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_meta .post_categories {
  width: 100%;
  font-size: 12px;
  line-height: 25px;
  font-weight: 700;
  letter-spacing: 1.6px;
  text-transform: uppercase;
  color: var(--theme-color-text_dark);
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .post_meta .post_categories a {
  color: var(--theme-color-text_dark) !important;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .theme_button {
  margin-top: 5%;
  margin-bottom: -5%;
  font-size: 16px;
  line-height: 21px;
  font-weight: 700;
  letter-spacing: 0;
  padding: 0;
  background-color: transparent !important;
  color: var(--theme-color-text_dark) !important;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .theme_button .hover-arrow {
  display: inline-block;
  width: 39px;
  height: 17px;
  line-height: 20px;
  overflow: hidden;
  position: relative;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  will-change: transform;
  margin-left: 15px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .theme_button .hover-arrow:before {
  top: -1px;
  right: 2px;
  position: absolute;
  display: block;
  font-family: "fontello";
  color: var(--theme-color-text_dark);
  font-size: 11px;
  font-weight: 400;
  line-height: 20px;
  content: '\EA04';
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .theme_button:hover .hover-arrow {
  width: 59px;
  margin-left: 35px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_item .post_content_wrap .theme_button:hover .hover-arrow:before {
  color: var(--theme-color-text_link);
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_content .sc_portfolio_item .post_content_wrap {
  padding: 3.2em 0 3.8em 3.9em;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_content .sc_portfolio_item + .sc_portfolio_item {
  margin-top: 30px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_content.no_margin .sc_portfolio_item + .sc_portfolio_item {
  margin-top: 0;
}
.content_wrap_fullscreen .elementor-section-full_width .sc_portfolio.sc_portfolio_band .sc_portfolio_content .sc_portfolio_item .post_content_wrap {
  margin-right: calc((100vw - var(--theme-var-page))/2);
}
.content_wrap_fullscreen .elementor-section-full_width .sc_portfolio.sc_portfolio_band .sc_portfolio_content .sc_portfolio_item .post_content_wrap .theme_button {
  margin-top: 27%;
  margin-bottom: -27%;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_columns_wrap [class*="trx_addons_column-"] .sc_portfolio_item .post_content_wrap {
  padding: 1.5em 1.5em;
  margin-right: 0;
  align-self: flex-start;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_columns_wrap [class*="trx_addons_column-"] .sc_portfolio_item .post_content_wrap .theme_button .hover-arrow {
  margin-left: 15px;
  width: 20px;
}
.sc_portfolio.sc_portfolio_band .sc_portfolio_columns_wrap [class*="trx_addons_column-"] .sc_portfolio_item .post_content_wrap .theme_button:hover .hover-arrow {
  margin-left: 15px;
  width: 38px;
}
.sc_portfolio.sc_portfolio_simple.related_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: flex-start;
}
.sc_portfolio.sc_portfolio_simple.related_wrap .related_wrap_title {
  margin-right: 20px;
  width: calc(34% - 20px);
  line-height: 1em;
  margin-top: -6px;
}
.sc_portfolio.sc_portfolio_simple.related_wrap .related_columns {
  width: 66%;
  padding-top: 3.1em;
  border-top: 1px solid var(--theme-color-text_dark);
}
.sc_portfolio.sc_portfolio_simple.related_wrap .related_columns .sc_portfolio_item {
  padding: 0 33px 34px 0;
  display: inline-block;
}
.sc_portfolio.sc_portfolio_simple.related_wrap .related_columns .sc_portfolio_item .post_title {
  font-size: 1.333em;
}
.sc_portfolio.sc_portfolio_simple.related_wrap .related_columns .sc_portfolio_item .post_meta {
  display: inline-block;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item {
  padding: 0 33px 18px 0;
  display: inline-block;
  width: auto;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item:last-child {
  padding-right: 0;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row-reverse;
  justify-content: flex-end;
  align-items: baseline;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap .post_title {
  font-size: 1.944em;
  margin-bottom: 0;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap .post_meta {
  color: var(--theme-color-alter_text);
  margin-top: 0;
  margin-bottom: 3px;
  display: none;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap .post_meta .post_categories {
  font-size: 14px;
  letter-spacing: 0;
  font-weight: inherit;
  color: var(--theme-color-alter_text);
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap .post_meta .post_categories a {
  color: var(--theme-color-alter_text) !important;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap .post_meta .post_categories a:hover {
  color: var(--theme-color-text_link) !important;
}
.sc_portfolio.sc_portfolio_simple .sc_portfolio_item .post_content_wrap .post_meta:before {
  content: '/';
  margin: 0 5px 0 9px;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured {
  overflow: hidden;
  position: relative;
  margin-bottom: 0;
  width: 100%;
  height: 100%;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured > a {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 7;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .mask {
  top: 10px;
  left: 10px;
  bottom: 10px;
  right: 10px;
  display: block;
  background: var(--theme-color-bg_color);
  opacity: 0;
  transition-delay: 300ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .post_info {
  width: calc(100% - 40px);
  height: calc(100% - 40px);
  padding: 0;
  background-color: transparent;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  text-align: center;
  top: 20px;
  left: 20px;
  right: 20px;
  bottom: 20px;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .post_info .post_title {
  font-size: 1.6rem;
  line-height: 1.25em;
  letter-spacing: 0;
  font-weight: 700;
  color: var(--theme-color-text_dark) !important;
  overflow: hidden;
  width: 100%;
  text-align: center;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .post_info .post_title a {
  transform: translateY(100%);
  transition-delay: 150ms;
  transition: 300ms;
  transition-duration: 400ms;
  color: var(--theme-color-text_dark) !important;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
  overflow: hidden;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .post_info .post_meta {
  overflow: hidden;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .post_info .post_meta .post_categories {
  font-size: 14px;
  line-height: 1.4em;
  color: var(--theme-color-text_light) !important;
  transform: translateY(100%);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 400ms;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured .post_info .post_meta .post_categories a {
  color: var(--theme-color-text_light) !important;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured:hover .mask {
  transition: all 0.3s;
  opacity: 1;
  transition-duration: 300ms;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured:hover .post_info .post_title a {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_portfolio.sc_portfolio_fill .sc_portfolio_item .post_featured:hover .post_info .post_meta .post_categories {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container {
  display: grid;
  gap: 30px 30px;
  grid-template: auto/repeat(4, 1fr);
  grid-auto-flow: dense;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container .sc_portfolio_item {
  min-height: 390px;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container[class*="grid_wrap_"] {
  margin: 0 !important;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_1 {
  grid-template-columns: 1fr !important;
  grid-template-rows: 500px !important;
  gap: 30px 30px;
  grid-template-areas: "md-1";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_1 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_1 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_1.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_2 {
  grid-template-columns: 1fr 1fr !important;
  grid-template-rows: 500px !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-2";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_2 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_2 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_2 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_2.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_3 {
  grid-template-columns: 1fr 1fr !important;
  grid-template-rows: 1fr 1fr 1fr 1fr 1fr !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-3" "md-1 md-3"  "md-1 md-3" "md-2 md-3"  "md-2 md-3";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_3 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_3 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_3 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_3 .sc_portfolio_item:nth-child(3) {
  grid-area: md-3;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_3.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4 {
  grid-template-columns: 1fr 1fr !important;
  grid-template-rows: 1fr 1fr 1fr 1fr 1fr !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-3" "md-1 md-3" "md-1 md-4" "md-2 md-4" "md-2 md-4";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4 .sc_portfolio_item:nth-child(3) {
  grid-area: md-3;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4 .sc_portfolio_item:nth-child(4) {
  grid-area: md-4;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_4.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 {
  grid-template-columns: 1fr 1fr 1fr !important;
  grid-template-rows: 1fr 1fr 1fr 1fr 1fr !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-3 md-5" "md-1 md-3 md-5" "md-1 md-4 md-5" "md-2 md-4 md-5" "md-2 md-4 md-5";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 .sc_portfolio_item:nth-child(3) {
  grid-area: md-3;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 .sc_portfolio_item:nth-child(4) {
  grid-area: md-4;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5 .sc_portfolio_item:nth-child(5) {
  grid-area: md-5;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_5.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 {
  grid-template-columns: 1fr 1fr 1fr !important;
  grid-template-rows: repeat(12, 1fr) !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-3 md-5"  "md-1 md-3 md-5"  "md-1 md-3 md-5"  "md-1 md-3 md-5"  "md-1 md-3 md-5"  "md-2 md-3 md-5"  "md-2 md-3 md-6"  "md-2 md-4 md-6"  "md-2 md-4 md-6"  "md-2 md-4 md-6"  "md-2 md-4 md-6"  "md-2 md-4 md-6";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item:nth-child(3) {
  grid-area: md-3;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item:nth-child(4) {
  grid-area: md-4;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item:nth-child(5) {
  grid-area: md-5;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6 .sc_portfolio_item:nth-child(6) {
  grid-area: md-6;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_6.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 {
  grid-template-columns: 1fr 1fr 1fr 1fr !important;
  grid-template-rows: repeat(12, 1fr) !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-2 md-3 md-5 md-7"  "md-2 md-3 md-6 md-7"  "md-2 md-4 md-6 md-7"  "md-2 md-4 md-6 md-7"  "md-2 md-4 md-6 md-7"  "md-2 md-4 md-6 md-7"  "md-2 md-4 md-6 md-7";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(3) {
  grid-area: md-3;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(4) {
  grid-area: md-4;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(5) {
  grid-area: md-5;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(6) {
  grid-area: md-6;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7 .sc_portfolio_item:nth-child(7) {
  grid-area: md-7;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_7.no_margin {
  gap: 0 0;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 {
  grid-template-columns: 1fr 1fr 1fr 1fr !important;
  grid-template-rows: repeat(12, 1fr) !important;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-1 md-3 md-5 md-7"  "md-2 md-3 md-5 md-7"  "md-2 md-3 md-6 md-7"  "md-2 md-4 md-6 md-7"  "md-2 md-4 md-6 md-8"  "md-2 md-4 md-6 md-8"  "md-2 md-4 md-6 md-8"  "md-2 md-4 md-6 md-8";
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item {
  min-height: unset;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(1) {
  grid-area: md-1;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(2) {
  grid-area: md-2;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(3) {
  grid-area: md-3;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(4) {
  grid-area: md-4;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(5) {
  grid-area: md-5;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(6) {
  grid-area: md-6;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(7) {
  grid-area: md-7;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8 .sc_portfolio_item:nth-child(8) {
  grid-area: md-8;
}
.sc_portfolio.sc_portfolio_fill .sc_item_posts_container.grid_wrap_8.no_margin {
  gap: 0 0;
}

.sc_portfolio .sc_portfolio_item .post_featured.with_thumb .post_video_hover {
  top: 20px;
  right: 20px;
  margin: 0;
  left: auto;
  width: 40px;
  height: 40px;
  line-height: 40px;
  font-size: 12px;
  letter-spacing: -4px;
}

.sc_blogger_lay_portfolio .sc_blogger_item .sc_blogger_item_body .post_featured.with_thumb .post_video_hover,
.sc_blogger_lay_portfolio_grid .sc_blogger_item .sc_blogger_item_body .post_featured.with_thumb .post_video_hover {
  top: 20px;
  right: 20px;
  margin: 0;
  left: auto;
  width: 40px;
  height: 40px;
  line-height: 40px;
  font-size: 12px;
  letter-spacing: -4px;
  z-index: 2001;
  -webkit-box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.05);
  box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.05);
}
.sc_blogger_lay_portfolio .sc_blogger_item .sc_blogger_item_body .post_video_play [class*="post_info_"],
.sc_blogger_lay_portfolio_grid .sc_blogger_item .sc_blogger_item_body .post_video_play [class*="post_info_"] {
  display: none !important;
}
.sc_blogger_lay_portfolio .sc_blogger_item .post_meta .post_sponsored,
.sc_blogger_lay_portfolio_grid .sc_blogger_item .post_meta .post_sponsored {
  display: none;
}

/* Style 1 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .post_featured {
  margin-bottom: 17px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content {
  margin-bottom: 20px;
  text-align: left;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta {
  margin: 3px 0 0 0;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-1 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta .post_categories {
  font-size: 14px;
}

/* Style 5 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  opacity: 0;
  transition: all 0.3s;
  transform: scale(0.8);
  bottom: 30px;
  left: 30px;
  padding: 18px 26px;
  background-color: var(--theme-color-bg_color);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.4rem;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 3px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  opacity: 1;
  transition: all 0.3s;
  transform: scale(1);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_5 .sc_blogger_item .post_featured_bg[data-ratio="10:9"]:before {
  padding-top: 94%;
}

/* Style 6 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc {
  transition: all 0.4s;
  transform: translateY(100%);
  bottom: 0;
  left: 0;
  right: 0;
  margin: 0 auto;
  padding: 21px 26px 17px;
  width: 70%;
  max-width: 70%;
  background-color: var(--theme-color-bg_color);
  opacity: 0;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title {
  font-size: 1.33rem;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta.post_meta_categories {
  margin-top: 6px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta.post_meta_categories .post_categories {
  font-size: 14px;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured.hover_link.with_thumb > .bg_in {
  transition: all 0.3s ease;
  transform: scale(1.009, 1.009);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured.hover_link.with_thumb:hover > .bg_in {
  transform: scale(1.04, 1.04);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc {
  transition: all 0.4s;
  transform: translateY(0);
  bottom: 38px;
  opacity: 1;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_6 .sc_blogger_item .post_featured_bg[data-ratio="10:9"]:before {
  padding-top: 94%;
}

/* Style 7 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  left: 15%;
  bottom: 10%;
  background-color: transparent;
  overflow: hidden;
  padding: 0;
  text-align: left;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.25em;
  letter-spacing: 0;
  font-weight: 700;
  padding: 11px 22px 11px 18px;
  background-color: #0F0F0F;
  transform: translateX(-105%);
  transition: all 0.3s;
  transition-duration: 0.3s;
  transition-delay: 0ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 5px;
  transform: translateX(-105%);
  transition: all 0.3s;
  transition-delay: 50ms;
  transition-duration: 0.3s;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
  line-height: 1.6em;
  padding: 6px 24px 6px 20px;
  background-color: #1B1B1B;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories a {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .sc_blogger_item_title {
  transform: translateX(0);
  transition: all 0.7s;
  transition-delay: 0ms;
  transition-duration: 0.5s;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .post_meta {
  transform: translateX(0);
  transition: all 0.7s;
  transition-delay: 50ms;
  transition-duration: 0.5s;
}

/* Style 8 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .post_featured {
  margin-bottom: 19px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .post_featured .mask {
  display: none;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content {
  margin-bottom: 10px;
  text-align: center;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .sc_blogger_item_title {
  font-size: 1.2rem;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta {
  margin: 5px 0 0 0;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .post_meta .post_categories {
  font-size: 14px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_columns_wrap .trx_addons_column-1_2 .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .sc_blogger_item_title {
  font-size: 1.867rem;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_content .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_content .sc_blogger_item_title {
  font-size: 1.867rem;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style-8 .sc_blogger_content .sc_blogger_item + .sc_blogger_item {
  padding-top: 30px;
}

/* Style 14 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .link {
  z-index: 10;
  display: block;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in {
  transform: scale(1.02, 1.02);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc {
  transition: all 0.3s;
  max-width: unset;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  text-align: center;
  bottom: 0;
  left: 0;
  right: 0;
  top: 0;
  padding: 20px;
  background-color: transparent;
  transform: none;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.4em;
  overflow: hidden;
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title a {
  transform: translateY(100%);
  transition-delay: 150ms;
  transition: 300ms;
  transition-duration: 400ms;
  color: #ffffff !important;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta {
  margin-top: 3px;
  overflow: hidden;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_categories {
  font-size: 14px;
  transform: translateY(100%);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 400ms;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc:before {
  content: '';
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  display: block;
  z-index: -1;
  background-color: var(--theme-color-inverse_dark);
  opacity: 0;
  transition-delay: 300ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc:before {
  transition: all 0.3s;
  opacity: 0.95;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc .sc_blogger_item_title a {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc .post_meta .post_categories {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .sc_blogger_item .post_featured_bg[data-ratio="10:7"]:before {
  padding-top: 72%;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .trx_addons_columns_wrap {
  margin-right: 0;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 0;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_14 .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}

/* Style 15 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .link {
  z-index: 10;
  display: block;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc {
  transition: all 0.3s;
  max-width: unset;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  text-align: center;
  bottom: 0;
  left: 0;
  right: 0;
  top: 0;
  padding: 20px;
  background-color: transparent;
  transform: none;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.4em;
  overflow: hidden;
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title a {
  transform: translateY(100%);
  transition-delay: 150ms;
  transition: 300ms;
  transition-duration: 400ms;
  color: #ffffff !important;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
  overflow: hidden;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta {
  margin-top: 3px;
  overflow: hidden;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_categories {
  font-size: 14px;
  transform: translateY(100%);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 400ms;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc:before {
  content: '';
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  display: block;
  z-index: -1;
  background-color: var(--theme-color-inverse_dark);
  opacity: 0;
  transition-delay: 300ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc:before {
  transition: all 0.3s;
  opacity: 0.95;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc .sc_blogger_item_title a {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc .post_meta .post_categories {
  transform: translateY(0);
  transition-duration: 500ms;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .trx_addons_columns_wrap {
  margin-right: 0;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding-right: 0;
  padding-bottom: 0 !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_15 .trx_addons_columns_wrap.columns_padding_bottom > [class*="trx_addons_column-"] {
  padding-bottom: 0;
}

/* Style 16 */
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .link {
  z-index: 10;
  display: block;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  opacity: 0;
  transition: all 0.3s;
  transform: scale(0.8);
  max-width: unset;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  bottom: 30px;
  left: 30px;
  right: 30px;
  top: 30px;
  padding: 20px 39px 30px;
  background-color: var(--theme-color-bg_color);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.3em;
  padding-bottom: 1px;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
  overflow: hidden;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 3px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  opacity: 1;
  transition: all 0.3s;
  transform: scale(1);
}
.sc_blogger_lay_portfolio.sc_blogger_lay_portfolio_style_16 .sc_blogger_item .post_featured_bg[data-ratio="10:9"]:before {
  padding-top: 96%;
}

/* Grid Portfolio */
.sc_blogger_lay_portfolio_grid {
  /* Grid style 3 */
  /* grid Style 4 */
  /* Grid style 5 */
  /* Grid style 7 */
  /* Grid style 8 */
  /* Grid style 9 */
  /* grid Style 13 */
}
.sc_blogger_lay_portfolio_grid .sc_item_featured [class*="post_info_"] {
  z-index: 2001 !important;
}
.sc_blogger_lay_portfolio_grid .sc_blogger_item .post_featured.without_thumb {
  height: 100%;
}
.sc_blogger_lay_portfolio_grid .sc_blogger_item .post_featured.without_thumb .slider-slide,
.sc_blogger_lay_portfolio_grid .sc_blogger_item .post_featured.without_thumb .slider_outer,
.sc_blogger_lay_portfolio_grid .sc_blogger_item .post_featured.without_thumb .slider_container {
  height: 100% !important;
  min-height: 200px !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured_bg {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  opacity: 0;
  transition: all 0.3s;
  transform: scale(0.8);
  bottom: 50px;
  left: 50px;
  padding: 20px 27px 17px;
  max-height: calc(100% - 100px);
  max-width: calc(100% - 100px);
  background-color: var(--theme-color-bg_color);
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.33rem;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 3px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  opacity: 1;
  transition: all 0.3s;
  transform: scale(1);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 323px 323px;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 323px 323px;
  gap: 0 0;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px;
  gap: 0 0;
  grid-template-areas: "md-3-1 md-3-1 md-3-2 md-3-2"  "md-3-1 md-3-1 md-3-3 md-3-3";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1" "lg-3-1 lg-3-1 sm-3-1 sm-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "lg-3-1 lg-3-1 sm-3-3 sm-3-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 md-3-2 md-3-2"  "md-3-3 md-3-4 lg-3-2 lg-3-2" "md-3-3 md-3-4 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: md-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "md-3-2 md-3-3 lg-3-2 lg-3-2" "md-3-2 md-3-3 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(5) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(7) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1" "lg-3-1 lg-3-1 sm-3-1 sm-3-2" "sm-3-3 md-3-2 lg-3-2 lg-3-2" "sm-3-4 md-3-2 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(5) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(7) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(8) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1" "lg-3-1 lg-3-1 sm-3-1 sm-3-2" "sm-3-3 md-3-2 lg-3-2 lg-3-2" "sm-3-4 md-3-3 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(5) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(7) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(8) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(9) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-4-1" "lg-3-1 lg-3-1 sm-3-1 sm-3-2" "sm-3-3 md-3-2 lg-3-2 lg-3-2" "sm-3-4 md-3-3 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(4) {
  grid-area: md-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(6) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(8) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(9) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(10) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "sm-3-3 md-3-2 lg-3-2 lg-3-2"  "sm-3-4 md-3-2 lg-3-2 lg-3-2" "lg-3-3 lg-3-3 md-3-3 md-3-4"  "lg-3-3 lg-3-3 md-3-3 md-3-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(9) {
  grid-area: lg-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(10) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(11) {
  grid-area: md-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 323px 323px 323px 323px 323px 323px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "sm-3-3 md-3-2 lg-3-2 lg-3-2"  "sm-3-4 md-3-2 lg-3-2 lg-3-2" "lg-3-3 lg-3-3 md-3-3 md-3-3"  "lg-3-3 lg-3-3 sm-3-5 sm-3-6";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(9) {
  grid-area: lg-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(10) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(11) {
  grid-area: sm-3-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_3 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(12) {
  grid-area: sm-3-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured_bg {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .link {
  z-index: 10;
  display: block;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  transition: all 0.3s;
  max-width: unset;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  text-align: center;
  bottom: 0;
  left: 0;
  right: 0;
  top: 0;
  padding: 20px;
  background-color: transparent;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.4em;
  transform: translateY(20px);
  opacity: 0;
  transition-delay: 50ms;
  transition: 400ms;
  transition-duration: 300ms;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 3px;
  transform: translateY(20px);
  opacity: 0;
  transition-delay: 0ms;
  transition: 400ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_excerpt {
  opacity: 0;
  transform: translateY(20px);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_button {
  opacity: 0;
  transform: translateY(20px);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_button .item_more_link,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_button .item_more_link:hover,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_button .item_more_link:focus {
  color: var(--theme-color-text_dark);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl:before {
  content: '';
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  display: block;
  z-index: -1;
  background-color: var(--theme-color-bg_color);
  opacity: 0;
  transition-delay: 300ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl:before {
  transition: all 0.3s;
  opacity: 1;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .sc_blogger_item_title {
  transform: translateY(0);
  transition-delay: 150ms;
  opacity: 1;
  transition-duration: 400ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .post_meta {
  transform: translateY(0);
  opacity: 1;
  transition-delay: 200ms;
  transition-duration: 400ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .sc_blogger_item_excerpt {
  opacity: 1;
  transform: translateY(0);
  transition-delay: 250ms;
  transition-duration: 400ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .sc_blogger_item_button {
  opacity: 1;
  transform: translateY(0);
  transition-delay: 300ms;
  transition-duration: 400ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-13-1 lg-13-1 md-13-1 md-13-1"  "lg-13-1 lg-13-1 md-13-2 md-13-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-4-1 sm-4-1 lg-4-1 lg-4-1"  "md-4-1 sm-4-2 lg-4-1 lg-4-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: md-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: sm-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: sm-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: lg-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-4-1 lg-4-1 sm-4-1 sm-4-2"  "lg-4-1 lg-4-1 sm-4-3 sm-4-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: lg-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: sm-4-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: sm-4-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-4-1 lg-4-1 md-4-1 md-4-1"  "lg-4-1 lg-4-1 md-4-2 md-4-2"  "md-4-3 md-4-4 lg-4-2 lg-4-2" "md-4-3 md-4-4 lg-4-2 lg-4-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: lg-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: md-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: md-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-4-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: md-4-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: lg-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1 sm-13-2"  "lg-13-1 lg-13-1 md-13-1 md-13-1"  "md-13-2 md-13-3 lg-13-2 lg-13-2" "md-13-2 md-13-3 lg-13-2 lg-13-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(5) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(7) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-4-1 lg-4-1 sm-4-1 sm-4-2"  "lg-4-1 lg-4-1 md-4-1 md-4-1"  "md-4-2 sm-4-3 lg-4-2 lg-4-2"  "md-4-2 sm-4-4 lg-4-2 lg-4-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(1) {
  grid-area: lg-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(2) {
  grid-area: sm-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(3) {
  grid-area: sm-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(4) {
  grid-area: md-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(5) {
  grid-area: lg-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(6) {
  grid-area: sm-4-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(7) {
  grid-area: sm-4-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(8) {
  grid-area: md-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-4-1 lg-4-1 sm-4-1 sm-4-2"  "lg-4-1 lg-4-1 sm-4-3 sm-4-4"  "md-4-2 sm-4-5 lg-4-2 lg-4-2"  "md-4-2 sm-4-6 lg-4-2 lg-4-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(1) {
  grid-area: lg-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(2) {
  grid-area: sm-4-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(3) {
  grid-area: sm-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(4) {
  grid-area: lg-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(5) {
  grid-area: md-4-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(6) {
  grid-area: sm-4-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(7) {
  grid-area: sm-4-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(8) {
  grid-area: sm-4-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(9) {
  grid-area: sm-4-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1 sm-13-2"  "lg-13-1 lg-13-1 sm-13-3 sm-13-4"  "sm-13-5 sm-13-6 lg-13-2 lg-13-2"  "sm-13-7 sm-13-8 lg-13-2 lg-13-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(4) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(5) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(6) {
  grid-area: sm-13-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(8) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(9) {
  grid-area: sm-13-7;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(10) {
  grid-area: sm-13-8;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: repeat(6, 480px);
  gap: 0 0;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1 sm-13-2"  "lg-13-1 lg-13-1 md-13-1 md-13-1"  "md-13-2 md-13-3 lg-13-2 lg-13-2"  "md-13-2 md-13-3 lg-13-2 lg-13-2"  "lg-13-3 lg-13-3 sm-13-3 sm-13-4" "lg-13-3 lg-13-3 md-13-4 md-13-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(5) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(7) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(8) {
  grid-area: lg-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(9) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(10) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(11) {
  grid-area: md-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: repeat(6, 480px);
  gap: 0 0;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1 sm-13-2"  "lg-13-1 lg-13-1 md-13-1 md-13-1"  "md-13-2 sm-13-3 lg-13-2 lg-13-2"  "md-13-2 sm-13-4 lg-13-2 lg-13-2"  "lg-13-3 lg-13-3 sm-13-5 sm-13-6" "lg-13-3 lg-13-3 md-13-3 md-13-3";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(5) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(6) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(8) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(9) {
  grid-area: lg-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(10) {
  grid-area: sm-13-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(11) {
  grid-area: sm-13-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_4 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(12) {
  grid-area: md-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .no_margin .sc_blogger_grid_wrap {
  gap: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .no_margin .sc_blogger_grid_wrap + .sc_blogger_grid_wrap {
  margin-top: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .no_margin .sc_blogger_grid_wrap .sc_blogger_item + .sc_blogger_item {
  margin-top: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured_bg {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  transition: all 0.3s;
  transform: translateX(-100%);
  bottom: 30px;
  max-width: calc( 100%  - 60px );
  left: 0;
  padding: 18px 26px;
  background-color: var(--theme-color-bg_color);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.33rem;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta.post_meta_categories {
  margin-top: 3px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta.post_meta_categories .post_categories {
  font-size: 14px;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta + .post_meta {
  margin-top: 5px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .item_more_link,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .item_more_link:hover,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .item_more_link:focus {
  color: var(--theme-color-text_dark);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  left: 30px;
  transition: all 0.3s;
  transform: translateX(0);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap + .sc_blogger_grid_wrap {
  margin-top: 30px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 19.4rem 19.4rem;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 19.4rem 19.4rem;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 19.4rem 19.4rem;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-1 sm-1 sm-1" "md-1 md-1 sm-2 sm-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: sm-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: sm-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 19.4rem 19.4rem 19.4rem 19.4rem;
  gap: 30px 30px;
  grid-template-areas: "md-5 sm-5-1" "md-5 sm-5-2" "lg-5 lg-5" "lg-5 lg-5";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: md-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: lg-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 19.4rem 19.4rem 19.4rem 19.4rem;
  gap: 30px 30px;
  grid-template-areas: "md-5-1 md-5-1 sm-5-1 sm-5-1"  "md-5-1 md-5-1 sm-5-2 sm-5-2"  "md-5-2 md-5-2 md-5-3 md-5-3" "md-5-2 md-5-2 md-5-3 md-5-3";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: md-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 19.4rem 19.4rem 19.4rem 19.4rem;
  gap: 30px 30px;
  grid-template-areas: "md-5-1 md-5-1 sm-5-1 sm-5-1" "md-5-1 md-5-1 sm-5-2 sm-5-2" "sm-5-3 sm-5-3 md-5-2 md-5-2" "sm-5-4 sm-5-4 md-5-2 md-5-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_5 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: sm-5-4;
}
.elementor-edit-area .sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .post_featured_bg.with_thumb[class*="hover_on_"] .trx_addons_image_effect_original_image {
  display: none;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item {
  position: relative;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured_bg {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured {
  overflow: visible;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in_wrap {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in_wrap .post_thumb {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in_wrap .bg_in {
  transition: all 0.5s ease;
  transform: scale(1, 1);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  width: max-content;
  height: auto;
  left: 30px;
  bottom: 30px;
  top: auto;
  right: auto;
  background-color: transparent;
  overflow: hidden;
  padding: 0;
  opacity: 0;
  will-change: scroll-position;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.6rem;
  line-height: 1.25em;
  letter-spacing: 0;
  font-weight: 700;
  padding: 11px 30px 11px 22px;
  background-color: #0F0F0F;
  width: 50%;
  transition: all 0s ease;
  transition-duration: 0s;
  transition-delay: 0ms;
  white-space: nowrap;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  width: 30%;
  margin-top: 5px;
  transition: all 0s ease;
  transition-delay: 0ms;
  transition-duration: 0s;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
  line-height: 1.4em;
  padding: 6px 20px;
  background-color: #1F232B;
  white-space: nowrap;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories > * {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .bg_in_wrap .post_thumb {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .bg_in_wrap .bg_in {
  transform: scale(1.07, 1.07);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  opacity: 1;
  width: auto;
  max-width: 100vw;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .sc_blogger_item_title {
  width: 100%;
  transition: all 0.4s ease;
  transition-delay: 0ms;
  transition-duration: 0.40s;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .post_meta {
  width: 100%;
  transition: all 0.4s ease;
  transition-delay: 0ms;
  transition-duration: 0.40s;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 md-3-2 md-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1" "lg-3-1 lg-3-1 sm-3-1 sm-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-7-1 lg-7-1 sm-7-1 sm-7-2" "lg-7-1 lg-7-1 sm-7-3 sm-7-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: lg-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-7-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: sm-7-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: sm-7-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 md-3-2 md-3-2" "md-3-3 md-3-4 lg-3-2 lg-3-2" "md-3-3 md-3-4 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: md-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "md-3-2 md-3-3 lg-3-2 lg-3-2" "md-3-2 md-3-3 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(5) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(7) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "sm-3-3 md-3-2 lg-3-2 lg-3-2"  "sm-3-4 md-3-2 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(5) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(7) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(8) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 sm-3-1 sm-3-2" "lg-3-1 lg-3-1 sm-3-3 sm-3-4" "md-3-1 sm-3-5 lg-3-2 lg-3-2" "md-3-1 sm-3-6 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(2) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(7) {
  grid-area: sm-3-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(8) {
  grid-area: sm-3-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(9) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "lg-3-1 lg-3-1 sm-3-3 sm-3-4"  "sm-3-5 sm-3-6 lg-3-2 lg-3-2"  "sm-3-7 sm-3-8 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(2) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(7) {
  grid-area: sm-3-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(8) {
  grid-area: sm-3-7;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(9) {
  grid-area: sm-3-8;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(10) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "sm-3-3 md-3-2 lg-3-2 lg-3-2"  "sm-3-4 md-3-2 lg-3-2 lg-3-2" "lg-3-3 lg-3-3 md-3-3 md-3-4"  "lg-3-3 lg-3-3 md-3-3 md-3-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(9) {
  grid-area: lg-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(10) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(11) {
  grid-area: md-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-1"  "lg-3-1 lg-3-1 sm-3-1 sm-3-2"  "sm-3-3 md-3-2 lg-3-2 lg-3-2"  "sm-3-4 md-3-2 lg-3-2 lg-3-2" "lg-3-3 lg-3-3 md-3-3 md-3-3"  "lg-3-3 lg-3-3 sm-3-5 sm-3-6";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(9) {
  grid-area: lg-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(10) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(11) {
  grid-area: sm-3-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_7 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(12) {
  grid-area: sm-3-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .link {
  z-index: 10;
  display: block;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc {
  transition: all 0.3s;
  max-width: unset;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  text-align: center;
  bottom: 0;
  left: 0;
  right: 0;
  top: 0;
  padding: 20px;
  background-color: transparent;
  transform: none;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title {
  font-size: 1.33rem;
  line-height: 1.4em;
  overflow: hidden;
  color: var(--theme-color-inverse_link) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .sc_blogger_item_title a {
  transform: translateY(100%);
  transition-delay: 150ms;
  transition: 300ms;
  transition-duration: 400ms;
  color: var(--theme-color-inverse_link) !important;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta {
  margin-top: 5px;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_meta_item {
  color: var(--theme-color-inverse_link) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc .post_meta .post_categories {
  font-size: 14px;
  transform: translateY(100%);
  transition-delay: 0ms;
  transition: 300ms;
  transition-duration: 400ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bc:before {
  content: '';
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  display: block;
  z-index: -1;
  background-color: var(--theme-color-text_link);
  opacity: 0;
  transition-delay: 300ms;
  transition: 300ms;
  transition-duration: 300ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc:before {
  transition: all 0.3s;
  opacity: 1;
  transition-duration: 300ms;
  transition-delay: 0ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc .sc_blogger_item_title a {
  transform: translateY(0);
  transition-duration: 500ms;
  transition-delay: 200ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bc .post_meta .post_categories {
  transform: translateY(0);
  transition-duration: 500ms;
  transition-delay: 200ms;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "md-1 md-1 sm-1 sm-1"  "md-1 md-1 sm-2 sm-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: sm-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: sm-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-8-1 lg-8-1 sm-8-1 sm-8-2"  "lg-8-1 lg-8-1 md-8-1 md-8-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: lg-8-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: sm-8-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: sm-8-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: md-8-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 sm-5-3 sm-5-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 md-5-1 md-5-1"  "lg-5-1 lg-5-1 md-5-2 md-5-2"  "md-5-3 md-5-3 lg-5-2 lg-5-2" "md-5-4 md-5-4 lg-5-2 lg-5-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: md-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 md-5-1 md-5-1"  "md-5-2 md-5-2 lg-5-2 lg-5-2"  "md-5-3 md-5-3 lg-5-2 lg-5-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(5) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(6) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(7) {
  grid-area: md-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 md-5-1 md-5-1"  "sm-5-3 sm-5-4 lg-5-2 lg-5-2"  "md-5-2 md-5-2 lg-5-2 lg-5-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(6) {
  grid-area: sm-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(7) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(8) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 md-5-1 md-5-1"  "sm-5-3 sm-5-4 lg-5-2 lg-5-2"  "sm-5-5 sm-5-6 lg-5-2 lg-5-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(6) {
  grid-area: sm-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(7) {
  grid-area: sm-5-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(8) {
  grid-area: sm-5-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(9) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 sm-5-3 sm-5-4"  "sm-5-5 sm-5-6 lg-5-2 lg-5-2"  "sm-5-7 sm-5-8 lg-5-2 lg-5-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(4) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(6) {
  grid-area: sm-5-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(7) {
  grid-area: sm-5-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(8) {
  grid-area: sm-5-7;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(9) {
  grid-area: sm-5-8;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(10) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 md-5-1 md-5-1"  "sm-5-3 sm-5-4 lg-5-2 lg-5-2"  "md-5-2 md-5-2 lg-5-2 lg-5-2" "lg-5-3 lg-5-3 md-5-3 md-5-4"  "lg-5-3 lg-5-3 md-5-3 md-5-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(6) {
  grid-area: sm-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(7) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(8) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(9) {
  grid-area: lg-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(10) {
  grid-area: md-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(11) {
  grid-area: md-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 480px 480px 480px 480px 480px 480px;
  gap: 0 0;
  grid-template-areas: "lg-5-1 lg-5-1 sm-5-1 sm-5-2"  "lg-5-1 lg-5-1 md-5-1 md-5-1"  "sm-5-3 sm-5-4 lg-5-2 lg-5-2"  "md-5-2 md-5-2 lg-5-2 lg-5-2" "lg-5-3 lg-5-3 sm-5-5 sm-5-6"  "lg-5-3 lg-5-3 md-5-3 md-5-3";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(1) {
  grid-area: lg-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(2) {
  grid-area: sm-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(3) {
  grid-area: sm-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(4) {
  grid-area: md-5-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(5) {
  grid-area: sm-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(6) {
  grid-area: sm-5-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(7) {
  grid-area: lg-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(8) {
  grid-area: md-5-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(9) {
  grid-area: lg-5-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(10) {
  grid-area: sm-5-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(11) {
  grid-area: sm-5-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_8 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(12) {
  grid-area: md-5-3;
}
.elementor-edit-area .sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .post_featured_bg.with_thumb[class*="hover_on_"] .trx_addons_image_effect_original_image {
  display: none;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .no_margin .sc_blogger_grid_wrap {
  gap: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .no_margin .sc_blogger_grid_wrap + .sc_blogger_grid_wrap {
  margin-top: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .no_margin .sc_blogger_grid_wrap .sc_blogger_item + .sc_blogger_item {
  margin-top: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item {
  position: relative;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured_bg {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured {
  overflow: visible;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in_wrap {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in_wrap .post_thumb {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .bg_in_wrap .bg_in {
  transition: all 0.5s ease;
  transform: scale(1, 1);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  width: max-content;
  left: 30px;
  right: auto;
  bottom: 30px;
  top: auto;
  background-color: transparent;
  overflow: hidden;
  padding: 0;
  opacity: 0;
  will-change: scroll-position;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  font-size: 1.6rem;
  line-height: 1.25em;
  letter-spacing: 0;
  font-weight: 700;
  padding: 11px 30px 10px 22px;
  background-color: #0F0F0F;
  width: 50%;
  transition: all 0s ease;
  transition-duration: 0s;
  transition-delay: 0ms;
  will-change: transform;
  white-space: nowrap;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 5px;
  transition: all 0s ease;
  transition-delay: 0ms;
  transition-duration: 0s;
  will-change: transform;
  width: 30%;
  overflow: hidden;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
  line-height: 1.4em;
  padding: 6px 20px;
  background-color: #1B1B1B;
  margin-right: 5px;
  white-space: nowrap;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories:last-child {
  margin-right: 0;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories > * {
  color: #ffffff !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .bg_in_wrap .post_thumb {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .bg_in_wrap .bg_in {
  transform: scale(1.07, 1.07);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  opacity: 1;
  width: auto;
  max-width: 100vw;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .sc_blogger_item_title {
  width: 100%;
  transition: all 0.40s ease;
  transition-delay: 0ms;
  transition-duration: 0.40s;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl .post_meta {
  width: 100%;
  transition: all 0.40s ease;
  transition-delay: 0ms;
  transition-duration: 0.40s;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap + .sc_blogger_grid_wrap {
  margin-top: 30px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 300px 300px;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-2"  "lg-3-1 lg-3-1 md-3-1 md-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-9-1 lg-9-1 md-9-1 sm-9-1" "lg-9-1 lg-9-1 md-9-1 sm-9-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: lg-9-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: md-9-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: sm-9-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: sm-9-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-7-1 lg-7-1 sm-7-1 sm-7-2" "lg-7-1 lg-7-1 sm-7-3 sm-7-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: lg-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-7-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: sm-7-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: sm-7-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 md-3-2"  "lg-3-1 lg-3-1 md-3-1 md-3-2"  "md-3-3 md-3-3 lg-3-2 lg-3-2"  "md-3-4 md-3-4 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: md-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-9-1 lg-9-1 md-9-1 sm-9-1" "lg-9-1 lg-9-1 md-9-1 sm-9-2" "md-9-2 md-9-2 lg-9-2 lg-9-2" "md-9-3 md-9-3 lg-9-2 lg-9-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(1) {
  grid-area: lg-9-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(2) {
  grid-area: md-9-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(3) {
  grid-area: sm-9-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(4) {
  grid-area: sm-9-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(5) {
  grid-area: lg-9-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(6) {
  grid-area: md-9-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(7) {
  grid-area: md-9-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 sm-3-1"  "lg-3-1 lg-3-1 md-3-1 sm-3-2"  "sm-3-3 sm-3-4 lg-3-2 lg-3-2"  "md-3-2 md-3-2 lg-3-2 lg-3-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-7-1 lg-7-1 sm-7-1 sm-7-2"  "lg-7-1 lg-7-1 sm-7-3 sm-7-4"  "sm-7-5 sm-7-6 lg-7-2 lg-7-2"  "md-7-1 md-7-1 lg-7-2 lg-7-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(1) {
  grid-area: lg-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(2) {
  grid-area: sm-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(3) {
  grid-area: sm-7-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(4) {
  grid-area: sm-7-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(5) {
  grid-area: sm-7-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(6) {
  grid-area: sm-7-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(7) {
  grid-area: sm-7-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(8) {
  grid-area: md-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(9) {
  grid-area: lg-7-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-7-1 lg-7-1 sm-7-1 sm-7-2"  "lg-7-1 lg-7-1 sm-7-3 sm-7-4"  "sm-7-5 sm-7-6 lg-7-2 lg-7-2"  "sm-7-7 sm-7-8 lg-7-2 lg-7-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(1) {
  grid-area: lg-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(2) {
  grid-area: sm-7-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(3) {
  grid-area: sm-7-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(4) {
  grid-area: sm-7-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(5) {
  grid-area: sm-7-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(6) {
  grid-area: sm-7-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(7) {
  grid-area: sm-7-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(8) {
  grid-area: sm-7-7;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(9) {
  grid-area: sm-7-8;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(10) {
  grid-area: lg-7-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 sm-3-1"  "lg-3-1 lg-3-1 md-3-1 sm-3-2" "md-3-2 md-3-2 lg-3-2 lg-3-2"  "md-3-3 md-3-3 lg-3-2 lg-3-2" "lg-3-3 lg-3-3 md-3-4 md-3-4"  "lg-3-3 lg-3-3 sm-3-3 sm-3-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(5) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(6) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(7) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(9) {
  grid-area: md-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(10) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(11) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 sm-3-1"  "lg-3-1 lg-3-1 md-3-1 sm-3-2" "sm-3-3 sm-3-4 lg-3-2 lg-3-2"  "md-3-2 md-3-2 lg-3-2 lg-3-2" "lg-3-3 lg-3-3 md-3-3 md-3-3"  "lg-3-3 lg-3-3 sm-3-5 sm-3-6";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(1) {
  grid-area: lg-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(2) {
  grid-area: md-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(3) {
  grid-area: sm-3-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(4) {
  grid-area: sm-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(5) {
  grid-area: sm-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(6) {
  grid-area: sm-3-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(7) {
  grid-area: md-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(8) {
  grid-area: lg-3-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(9) {
  grid-area: lg-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(10) {
  grid-area: md-3-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(11) {
  grid-area: sm-3-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_9 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(12) {
  grid-area: sm-3-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .no_margin .sc_blogger_grid_wrap {
  gap: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .no_margin .sc_blogger_grid_wrap + .sc_blogger_grid_wrap {
  margin-top: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .no_margin .sc_blogger_grid_wrap .sc_blogger_item + .sc_blogger_item {
  margin-top: 0 !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured_bg {
  width: 100%;
  height: 100%;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .link {
  z-index: 10;
  display: block;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl {
  opacity: 0;
  transition: all 0.3s;
  transform: scale(0.8);
  max-width: unset;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  bottom: 10px;
  left: 10px;
  right: 10px;
  top: 10px;
  padding: 20px 35px 26px;
  background-color: var(--theme-color-bg_color);
  will-change: transform;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title {
  line-height: 1.2em;
  font-size: 1.33rem;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 3;
  -moz-box-orient: vertical;
  line-clamp: 3;
  box-orient: vertical;
  padding-bottom: 2px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .sc_blogger_item_title a {
  color: var(--theme-color-text_dark) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta {
  margin-top: 1px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item a,
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_meta_item {
  color: var(--theme-color-alter_text) !important;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured .post_info_bl .post_meta .post_categories {
  font-size: 14px;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 100%;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -moz-box;
  -moz-line-clamp: 2;
  -moz-box-orient: vertical;
  line-clamp: 2;
  box-orient: vertical;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_item .sc_blogger_item_body .post_featured:hover .post_info_bl {
  opacity: 1;
  transition: all 0.3s;
  transform: scale(1);
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap + .sc_blogger_grid_wrap {
  margin-top: 30px;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 300px 300px;
  gap: 0 0;
  grid-template-areas: "md-1" "md-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_1 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_2 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-2" "md-1 md-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(1) {
  grid-area: md-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_2 .sc_blogger_item:nth-child(2) {
  grid-area: md-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1" "lg-13-1 lg-13-1 sm-13-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_3 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1" "lg-13-1 lg-13-1 md-13-1" "md-13-2 md-13-2 md-13-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(3) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_4 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "lg-13-1 lg-13-1 sm-13-1" "lg-13-1 lg-13-1 sm-13-2" "sm-13-3 md-13-1 md-13-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(4) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_5 .sc_blogger_item:nth-child(5) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-2 lg-13-1 lg-13-1 sm-13-1" "md-13-3 lg-13-1 lg-13-1 md-13-1" "md-13-3 md-13-2 md-13-2 md-13-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(3) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(5) {
  grid-area: md-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_6 .sc_blogger_item:nth-child(6) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-4 lg-13-1 lg-13-1 sm-13-1" "md-13-2 lg-13-1 lg-13-1 sm-13-2" "md-13-2 sm-13-3 md-13-1 md-13-1";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(5) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_7 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-4 lg-13-1 lg-13-1 sm-13-1" "sm-13-3 lg-13-1 lg-13-1 md-13-1" "lg-13-2 lg-13-2 sm-13-2 md-13-1" "lg-13-2 lg-13-2 md-13-2 md-13-2";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(3) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(5) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(6) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_8 .sc_blogger_item:nth-child(8) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-4 lg-13-1 lg-13-1 sm-13-1" "md-13-2 lg-13-1 lg-13-1 sm-13-2" "md-13-2 sm-13-3 md-13-1 md-13-1" "md-13-4 md-13-4 md-13-3 md-13-3";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(5) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(8) {
  grid-area: md-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_9 .sc_blogger_item:nth-child(9) {
  grid-area: md-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-4 lg-13-1 lg-13-1 sm-13-1" "md-13-2 lg-13-1 lg-13-1 sm-13-2" "md-13-2 sm-13-3 md-13-1 md-13-1" "lg-13-2 lg-13-2 md-13-3 md-13-4" "lg-13-2 lg-13-2 md-13-3 md-13-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(5) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(8) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(9) {
  grid-area: md-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_10 .sc_blogger_item:nth-child(10) {
  grid-area: md-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-4 lg-13-1 lg-13-1 sm-13-1"  "md-13-2 lg-13-1 lg-13-1 sm-13-2"  "md-13-2 sm-13-3 md-13-1 md-13-1"  "lg-13-2 lg-13-2 sm-13-5 md-13-4"  "lg-13-2 lg-13-2 sm-13-6 md-13-4";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(5) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(8) {
  grid-area: lg-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(9) {
  grid-area: md-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(10) {
  grid-area: sm-13-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_11 .sc_blogger_item:nth-child(11) {
  grid-area: sm-13-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 300px 300px 300px 300px 300px;
  gap: 30px 30px;
  grid-template-areas: "sm-13-4 lg-13-1 lg-13-1 sm-13-1"  "md-13-2 lg-13-1 lg-13-1 sm-13-2"  "md-13-2 sm-13-3 md-13-1 md-13-1"  "md-13-4 md-13-5 sm-13-5 md-13-6"  "md-13-4 md-13-5 sm-13-6 md-13-6";
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(1) {
  grid-area: lg-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(2) {
  grid-area: sm-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(3) {
  grid-area: sm-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(4) {
  grid-area: md-13-1;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(5) {
  grid-area: sm-13-3;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(6) {
  grid-area: md-13-2;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(7) {
  grid-area: sm-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(8) {
  grid-area: md-13-4;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(9) {
  grid-area: md-13-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(10) {
  grid-area: sm-13-5;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(11) {
  grid-area: sm-13-6;
}
.sc_blogger_lay_portfolio_grid.sc_blogger_lay_portfolio_grid_grid_style_13 .sc_blogger_grid_wrap.sc_blogger_grid_12 .sc_blogger_item:nth-child(12) {
  grid-area: md-13-6;
}

/* Over Image Portfolio */
html.portfolio_preview_opened {
  overflow-y: hidden !important;
  height: 100%;
}

.sc_blogger_portmodern {
  width: 100%;
  height: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  align-content: center;
  align-items: center;
  justify-content: center;
  padding-top: 10%;
  padding-bottom: 5%;
  min-height: 100vh;
}
.sc_blogger_portmodern .sc_item_filters_wrap {
  position: relative;
  z-index: 2;
}
.sc_blogger_portmodern .sc_item_filters_wrap .sc_item_filters {
  padding-bottom: 0;
  margin-bottom: 4rem;
  border-bottom: none;
}
.elementor-section-boxed .sc_blogger_portmodern .decor_image_wrap {
  left: -30px;
  width: calc(100% + 60px);
}
.sc_blogger_portmodern .decor_image_wrap {
  position: absolute;
  top: 0 !important;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 0;
  overflow: hidden;
}
.sc_blogger_portmodern .decor_image_wrap .image_item {
  position: absolute;
  top: 0;
  left: 0;
  background-size: cover;
  background-position: center;
  background-repeat: no-repeat;
  width: 100%;
  height: 100%;
  opacity: 0;
  transition: opacity 0.5s ease,  transform 4s ease;
}
.sc_blogger_portmodern .decor_image_wrap .image_item.active_image {
  opacity: 0.95;
  transform: scale(1.03);
}
.sc_blogger_portmodern .sc_blogger_content {
  max-width: var(--theme-var-page);
  margin: 0 auto;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item {
  display: inline-block;
  padding-right: 2rem;
  margin-right: 2rem;
  padding-bottom: 2rem;
  position: relative;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item:after {
  content: '/';
  position: absolute;
  right: -6px;
  bottom: 2.4rem;
  color: var(--theme-color-text_dark);
  font-size: 1.6rem;
  opacity: 1;
  transition: color 0.2s ease;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item:last-child {
  padding-right: 0;
  margin-right: 0;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item:last-child:after {
  display: none;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item .sc_blogger_item_title {
  font-size: 3em;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_title {
  transition: all 0.2s ease-in-out;
  will-change: color;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_title:hover {
  cursor: pointer;
}
.sc_blogger_portmodern .sc_blogger_content .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_title.anim_fade {
  opacity: 0;
}
.sc_blogger_portmodern .sc_blogger_content.active_items .sc_blogger_item:after {
  color: rgba(255, 255, 255, 0.4);
}
.sc_blogger_portmodern .sc_blogger_content.active_items .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_title {
  color: rgba(255, 255, 255, 0.4);
}
.sc_blogger_portmodern .sc_blogger_content.active_items .sc_blogger_item .sc_blogger_item_body .sc_blogger_item_title.active_item {
  color: var(--theme-color-text_link);
}
.sc_blogger_portmodern .portfolio_preview {
  display: none;
  position: fixed;
  top: 0;
  left: 0;
  z-index: 9999999 !important;
  width: 100vw;
  height: 100vh;
  background-color: var(--theme-color-bg_color);
  opacity: 0;
  will-change: opacity;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  width: 100%;
  height: 100%;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_image {
  width: 55%;
  height: 100%;
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  flex: 0 0 auto;
  z-index: 1;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .close {
  position: absolute;
  top: 3em;
  right: 4em;
  width: 41px;
  height: 41px;
  line-height: 1em;
  text-align: center;
  color: var(--theme-color-text_dark);
  transition: 0.3s ease;
  will-change: transform;
  opacity: 1;
  font-size: 21px;
  animation: transformAnimOutPort .4s ease-out both;
  padding: 10px;
  background-color: var(--theme-color-bg_color);
  border-radius: 50%;
  z-index: 2 !important;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .close:before {
  content: '\E9E1';
  font-family: "fontello";
  position: relative;
  opacity: 0.3;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .close:hover {
  cursor: pointer;
  animation: transformAnimInPort .4s ease-out both;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description {
  padding: 5rem 10% 2rem 7%;
  width: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  align-content: center;
  height: auto;
  z-index: 1;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details {
  overflow-y: auto;
  overflow-x: hidden;
  padding-right: 25px;
  display: block;
  height: 100%;
  scrollbar-width: thin;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details::-webkit-scrollbar {
  width: 6px;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details::-webkit-scrollbar-track {
  background: var(--theme-color-alter_bd_color);
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-text_dark);
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_title {
  margin-bottom: 40px;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item_title {
  color: var(--theme-color-text_dark);
  font-weight: 600;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item_value {
  color: var(--theme-color-text_light);
  font-weight: inherit;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item + .portfolio_page_details_item {
  margin-top: 10px;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share {
  margin-top: 1.8em;
  padding-top: 1.8em;
  border-top: 1px solid var(--theme-color-text_dark_015);
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .portfolio_page_details_item_title {
  color: var(--theme-color-text_dark);
  font-weight: 700;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .socials_share .social_items .social_item {
  margin: 0 2em 8px 0;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .socials_share .social_items .social_item:last-child {
  margin-right: 0 !important;
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .post_description_content {
  margin-top: 1.4em;
  color: var(--theme-color-text_dark);
}
.sc_blogger_portmodern .portfolio_preview .inner_preview .portfolio_description .post_details .post_description .post_readmore {
  margin-top: 3em;
  box-shadow: none;
}
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show {
  display: block;
  opacity: 1;
  animation: fadeInAnimPort .3s ease-out both;
}
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show + .sc_item_filters_wrap .sc_item_posts_container .sc_blogger_item:after,
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show + .sc_item_posts_container .sc_blogger_item:after {
  display: none;
}
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show .portfolio_description .post_details .post_title {
  animation: fadeInUpAnimPort .3s 100ms ease-out both;
}
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show .portfolio_description .post_details .post_description .portfolio_page_details {
  animation: fadeInUpAnimPort .3s 200ms ease-out both;
}
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show .portfolio_description .post_details .post_description .post_description_content {
  animation: fadeInUpAnimPort .3s 300ms ease-out both;
}
.sc_blogger_portmodern .portfolio_preview.portfolio_preview_show .portfolio_description .post_details .post_description .post_readmore {
  animation: fadeInUpAnimPort .3s 400ms ease-out both;
}

/* Portfolio Anim */
@-webkit-keyframes fadeInAnimPort {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@keyframes fadeInAnimPort {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-webkit-keyframes colorInAnimPort {
  0% {
    opacity: 0.1;
    color: var(--theme-color-text_dark);
  }
  100% {
    opacity: 1;
    color: var(--theme-color-text_link);
  }
}
@keyframes colorInAnimPort {
  0% {
    opacity: 0.1;
    color: var(--theme-color-text_dark);
  }
  100% {
    opacity: 1;
    color: var(--theme-color-text_link);
  }
}
@-webkit-keyframes fadeInUpAnimPort {
  0% {
    opacity: 0;
    -webkit-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@keyframes fadeInUpAnimPort {
  0% {
    opacity: 0;
    transform: translateY(20px);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
@-webkit-keyframes transformAnimInPort {
  0% {
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
  }
  100% {
    -webkit-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@keyframes transformAnimInPort {
  0% {
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
  }
  100% {
    -webkit-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@-webkit-keyframes transformAnimOutPort {
  0% {
    -webkit-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
  100% {
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
  }
}
@keyframes transformAnimOutPort {
  0% {
    -webkit-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
  100% {
    -webkit-transform: rotate(0);
    -ms-transform: rotate(0);
    transform: rotate(0);
  }
}
/* Portfolio Estate */
.sc_blogger_portestate .sc_blogger_filters {
  padding-bottom: 3em;
  margin-bottom: 0 !important;
  border-bottom: none;
}
.sc_blogger_portestate .sc_blogger_item {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_blogger_portestate .sc_blogger_item .post_featured {
  display: block;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content {
  padding: 1.5em 2.2em;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content > .sc_blogger_item_meta:last-child {
  margin-bottom: 0 !important;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .sc_blogger_item_meta {
  font-size: 14px;
  margin: 5px 0 16px 0;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .sc_blogger_item_meta .post_sponsored {
  display: none;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .sc_blogger_item_meta .post_categories {
  width: 100%;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .sc_blogger_item_meta .post_categories a {
  color: var(--theme-color-text_light);
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .portfolio_page_details .portfolio_page_details_item {
  font-size: 15px;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .portfolio_page_details .portfolio_page_details_item_title {
  color: var(--theme-color-text_dark);
  font-weight: 500;
  width: 40%;
  padding-right: 0.5em;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .portfolio_page_details .portfolio_page_details_item_value {
  color: var(--theme-color-alter_text);
  font-weight: 400;
  text-align: right;
  width: 60%;
}
.sc_blogger_portestate .sc_blogger_item .sc_blogger_item_content .portfolio_page_details .portfolio_page_details_item + .portfolio_page_details_item {
  margin-top: 8px;
  padding-top: 6px;
  border-top: 1px solid var(--theme-color-bd_color);
}

/* Single Portfolio */
.single-cpt_portfolio .portfolio_page_gallery .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet,
.single-cpt_portfolio .portfolio_page_gallery .slider_container .slider_pagination_wrap .swiper-pagination-bullet,
.single-cpt_portfolio .portfolio_page_gallery .slider_outer .slider_pagination_wrap .swiper-pagination-bullet,
.single-cpt_portfolio .portfolio_page_gallery .swiper-pagination-custom .swiper-pagination-button {
  border-color: var(--theme-color-alter_bd_color);
  background-color: var(--theme-color-alter_bd_color);
}
.single-cpt_portfolio .portfolio_page_gallery .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .single-cpt_portfolio .portfolio_page_gallery .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active,
.single-cpt_portfolio .portfolio_page_gallery .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover,
.single-cpt_portfolio .portfolio_page_gallery .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.single-cpt_portfolio .portfolio_page_gallery .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover,
.single-cpt_portfolio .portfolio_page_gallery .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active,
.single-cpt_portfolio .portfolio_page_gallery .swiper-pagination-custom .swiper-pagination-button:hover,
.single-cpt_portfolio .portfolio_page_gallery .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-bullet-active {
  border-color: var(--theme-color-alter_link);
  background-color: var(--theme-color-alter_link);
}
.single-cpt_portfolio .portfolio_page_gallery .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets {
  margin-top: 2.3rem;
}
.single-cpt_portfolio .portfolio_page_gallery .slider_container.slider_controls_side .slider_controls_wrap > a {
  background-color: var(--theme-color-bg_color);
  border-color: var(--theme-color-bg_color);
}
.single-cpt_portfolio .portfolio_page_gallery .slider_container.slider_controls_side .slider_controls_wrap > a.slider_prev {
  margin-left: 30px;
}
.single-cpt_portfolio .portfolio_page_gallery .slider_container.slider_controls_side .slider_controls_wrap > a.slider_next {
  margin-right: 30px;
}
.single-cpt_portfolio .portfolio_page_gallery .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_prev {
  margin-left: 30px;
}
.single-cpt_portfolio .portfolio_page_gallery .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_next {
  margin-right: 30px;
}

.portfolio_page .portfolio_page_title {
  max-width: 80%;
  margin-top: 0;
  margin-bottom: 1.2em;
}
.portfolio_page .portfolio_page_title + .portfolio_page_meta {
  display: none;
}
.portfolio_page .portfolio_page_video {
  margin-bottom: var(--theme-var-grid_gap);
}
.portfolio_page .portfolio_page_content {
  margin-bottom: 1.5em;
}
.portfolio_page .portfolio_page_content > h1:first-child,
.portfolio_page .portfolio_page_content > h2:first-child,
.portfolio_page .portfolio_page_content > h3:first-child,
.portfolio_page .portfolio_page_content > h4:first-child,
.portfolio_page .portfolio_page_content > h5:first-child,
.portfolio_page .portfolio_page_content > h6:first-child {
  margin-top: 0 !important;
}
.portfolio_page .portfolio_page_content p:last-child {
  margin-bottom: 0;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_subtitle {
  font-size: 1.94rem;
  line-height: 1.08em;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_description p:last-child {
  margin-bottom: 0;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title {
  font-size: 1.05rem;
  font-weight: 600;
  color: var(--theme-color-text_dark);
  width: 30%;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_value {
  font-size: 1.05rem;
  font-weight: 400;
  color: var(--theme-color-text);
  width: 70%;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share {
  padding-top: 0;
  border-top: none;
  margin-top: 1.9em !important;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .portfolio_page_details_item_title {
  display: none;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .portfolio_page_details_item_title + .portfolio_page_details_item_value {
  width: 100%;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .portfolio_page_details_item_value {
  width: 100%;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .socials_wrap {
  margin-right: 0;
  margin-bottom: -15px;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share .socials_wrap .social_item {
  margin: 0 35px 15px 0;
  font-size: 17px;
}
.portfolio_page .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item + .portfolio_page_details_item {
  margin-top: 11px;
}
.portfolio_page .portfolio_page_details_wrap.light_style .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title {
  font-weight: 400;
  color: var(--theme-color-text_light);
}
.portfolio_page .portfolio_page_details_wrap.light_style .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_value {
  color: var(--theme-color-text_dark);
}
.portfolio_page .portfolio_page_details_wrap.light_style .portfolio_page_details .portfolio_page_details_item + .portfolio_page_details_item {
  margin-top: 1px;
}
.portfolio_page .portfolio_page_details_wrap.light_style .portfolio_page_details + .portfolio_page_description {
  margin-top: 1.4em;
}
.portfolio_page .portfolio_page_details_wrap.light_style .socials_share {
  margin-top: 1.9em !important;
}
.portfolio_page .portfolio_page_details_wrap.light_style .socials_share .social_items .social_item {
  margin: 0 8px 8px 0;
  font-size: 17px;
  width: 42px;
  height: 42px;
  line-height: 42px;
  border: 1px solid var(--theme-color-bd_color);
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  color: var(--theme-color-text_dark);
}
.portfolio_page .portfolio_page_details_wrap.light_style .socials_share .social_items .social_item:hover {
  color: var(--theme-color-text_link);
}
.portfolio_page .portfolio_page_content_wrap .portfolio_page_featured + .portfolio_page_content {
  margin-top: 30px;
}
.portfolio_page .portfolio_page_content_wrap .portfolio_page_gallery:last-child {
  margin-bottom: 0;
}
.portfolio_page.portfolio_page_details_right .sc_column_fixed.portfolio_page_details_wrap, .portfolio_page.portfolio_page_details_left .sc_column_fixed.portfolio_page_details_wrap {
  top: 4em;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_details_wrap, .portfolio_page.portfolio_page_details_left .portfolio_page_details_wrap {
  width: 37%;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_details_wrap .portfolio_page_subtitle, .portfolio_page.portfolio_page_details_left .portfolio_page_details_wrap .portfolio_page_subtitle {
  margin-top: -4px;
  margin-bottom: 26px;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_details_wrap .portfolio_page_description + .portfolio_page_details, .portfolio_page.portfolio_page_details_left .portfolio_page_details_wrap .portfolio_page_description + .portfolio_page_details {
  padding-top: 35px;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_details_wrap.light_style, .portfolio_page.portfolio_page_details_left .portfolio_page_details_wrap.light_style {
  width: 34%;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_details_wrap.light_style .portfolio_page_subtitle, .portfolio_page.portfolio_page_details_left .portfolio_page_details_wrap.light_style .portfolio_page_subtitle {
  margin-top: 1px;
}
.portfolio_page.portfolio_page_details_right .light_style + .portfolio_page_content_wrap, .portfolio_page.portfolio_page_details_left .light_style + .portfolio_page_content_wrap {
  width: 66%;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_video,
.portfolio_page.portfolio_page_details_right .portfolio_page_gallery,
.portfolio_page.portfolio_page_details_right .portfolio_page_content_wrap, .portfolio_page.portfolio_page_details_left .portfolio_page_video,
.portfolio_page.portfolio_page_details_left .portfolio_page_gallery,
.portfolio_page.portfolio_page_details_left .portfolio_page_content_wrap {
  width: 63%;
}
.portfolio_page.portfolio_page_details_right .portfolio_page_content_wrap .portfolio_page_video,
.portfolio_page.portfolio_page_details_right .portfolio_page_content_wrap .portfolio_page_gallery, .portfolio_page.portfolio_page_details_left .portfolio_page_content_wrap .portfolio_page_video,
.portfolio_page.portfolio_page_details_left .portfolio_page_content_wrap .portfolio_page_gallery {
  width: 100%;
}
.portfolio_page.portfolio_page_details_left .portfolio_page_video,
.portfolio_page.portfolio_page_details_left .portfolio_page_gallery {
  margin-left: auto;
  margin-right: 0;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap {
  margin-bottom: 1.86em;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_subtitle, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_subtitle {
  margin-bottom: 26px;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_description, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_description {
  width: 74%;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_description + .portfolio_page_details, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_description + .portfolio_page_details {
  padding-left: 3em;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_details, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_details {
  width: 26%;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title {
  width: 40%;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_value, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_value {
  width: 60%;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item.portfolio_page_details_share {
  margin-top: 1.5em !important;
}
.portfolio_page.portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item + .portfolio_page_details_item, .portfolio_page.portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item + .portfolio_page_details_item {
  margin-top: 13px;
}

body.body_style_wide:not(.expand_content) .portfolio_page_details_left .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_value,
body.body_style_wide:not(.expand_content) .portfolio_page_details_left .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title,
body.body_style_wide:not(.expand_content) .portfolio_page_details_right .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_value,
body.body_style_wide:not(.expand_content) .portfolio_page_details_right .portfolio_page_details_wrap .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title {
  display: block;
  width: 100%;
  padding-right: 0;
}
body.body_style_wide:not(.expand_content) .portfolio_page_details_left .portfolio_page_details_wrap {
  padding-right: 2em;
}
body.body_style_wide:not(.expand_content) .portfolio_page_details_right .portfolio_page_details_wrap {
  padding-left: 2em;
}

body.body_style_wide:not(.expand_content) .portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_description,
body.body_style_wide:not(.expand_content) .portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_description {
  width: 100%;
}
body.body_style_wide:not(.expand_content) .portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_details,
body.body_style_wide:not(.expand_content) .portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_details {
  width: 100%;
}
body.body_style_wide:not(.expand_content) .portfolio_page_details_top .portfolio_page_details_wrap .portfolio_page_description + .portfolio_page_details,
body.body_style_wide:not(.expand_content) .portfolio_page_details_bottom .portfolio_page_details_wrap .portfolio_page_description + .portfolio_page_details {
  padding-left: 0;
  margin-top: 1.5em;
}
body.body_style_wide:not(.expand_content) .portfolio_page_details_top .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title,
body.body_style_wide:not(.expand_content) .portfolio_page_details_bottom .portfolio_page_details .portfolio_page_details_item .portfolio_page_details_item_title {
  width: 15%;
}

/* Portfolio single navigation */
.single-cpt_portfolio .post-navigation .nav-links {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
  margin-top: 5em;
}
.single-cpt_portfolio .post-navigation .nav-links .nav-next a,
.single-cpt_portfolio .post-navigation .nav-links .nav-previous a {
  font-size: 15px;
  font-weight: 700;
  letter-spacing: 0;
  color: var(--theme-color-text_dark);
}
.single-cpt_portfolio .post-navigation .nav-links .nav-next a:hover,
.single-cpt_portfolio .post-navigation .nav-links .nav-previous a:hover {
  color: var(--theme-color-text_link);
}
.single-cpt_portfolio .post-navigation .nav-links .nav-next a span:after, .single-cpt_portfolio .post-navigation .nav-links .nav-next a span:before,
.single-cpt_portfolio .post-navigation .nav-links .nav-previous a span:after,
.single-cpt_portfolio .post-navigation .nav-links .nav-previous a span:before {
  content: '';
  font-family: "fontello";
  font-size: 12px;
  font-weight: 400;
  position: relative;
  top: -1px;
}
.single-cpt_portfolio .post-navigation .nav-links .nav-previous a span:before {
  content: '\EA07';
  padding-right: 13px;
}
.single-cpt_portfolio .post-navigation .nav-links .nav-next a span:after {
  content: '\E9A4';
  padding-left: 13px;
}

/* Blogger */
.sidebar_inner .sc_blogger .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sidebar_inner .sc_blogger .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.5em;
}
.sidebar_inner .sc_blogger .sc_blogger_columns_wrap > div + div {
  margin-top: 1.5em;
}

/* more_link */
.sc_blogger .sc_blogger_item_button .item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_blogger .sc_blogger_item_button .item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_blogger .sc_blogger_item_button .item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_blogger .sc_blogger_item_button .item_more_link .link_text {
  position: relative;
  margin-top: -2px;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, color, opacity;
}
.sc_blogger .sc_blogger_item:hover .sc_blogger_item_button .item_more_link .link_text,
.sc_blogger .sc_blogger_item_body:hover .sc_blogger_item_button .item_more_link .link_text,
.sc_blogger .sc_blogger_item_button .item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 9px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}

.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_title,
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_title,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_title,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title {
  max-height: 4.9em;
  overflow: hidden;
  padding-bottom: 2px;
}

.sc_blogger .sc_blogger_item_featured .post_meta_label {
  display: inline-block;
}

/* blogger_default + masonry */
.sc_blogger.sc_blogger_default .masonry_wrap .sc_blogger_item_featured {
  margin-bottom: 0;
}

/* default -> classic */
.sc_blogger_default.sc_blogger_default_classic {
  /* bullets */
  /* title */
  /* meta */
  /* meta -> top cat */
}
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_default.sc_blogger_item_image_position_top .sc_blogger_item_featured {
  margin-bottom: 0;
}
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_default.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
  margin-top: 1em;
}
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_body:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_default.sc_blogger_default_classic .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_blogger_default.sc_blogger_default_classic .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_blogger_default.sc_blogger_default_classic .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 6px;
  background-color: #E2E1E0;
  border-color: #E2E1E0;
  opacity: 1;
  width: 8px;
  height: 8px;
}
.sc_blogger_default.sc_blogger_default_classic .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_blogger_default.sc_blogger_default_classic .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_blogger_default.sc_blogger_default_classic .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_blogger_default.sc_blogger_default_classic .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_blogger_default.sc_blogger_default_classic .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_blogger_default.sc_blogger_default_classic .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_blogger_default.sc_blogger_default_classic .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link2);
  background-color: var(--theme-color-text_link2);
}
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_title {
  font-size: 24px;
  line-height: 1.2em;
  font-weight: 700;
}
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic .sc_blogger_item_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_default.sc_blogger_default_classic .sc_item_columns_1 .sc_blogger_item_title,
.sc_blogger_default.sc_blogger_default_classic .sc_item_columns_2 .sc_blogger_item_title,
.sc_blogger_default.sc_blogger_default_classic .sc_item_columns_3 .sc_blogger_item_title {
  font-size: 26px;
}
.sc_blogger_default.sc_blogger_default_classic .slider_outer_centered .sc_blogger_item_title {
  font-size: 25px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_classic .slider_outer_centered .sc_blogger_item_default.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
  margin-top: 1.2em;
}
.sc_blogger_default.sc_blogger_default_classic .post_meta {
  margin-top: 0.9em;
}
.sc_blogger_default.sc_blogger_default_classic .post_meta_categories {
  margin: 0 0 0.9em;
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
}
.sc_blogger_default.sc_blogger_default_classic .post_meta_categories .post_meta_item,
.sc_blogger_default.sc_blogger_default_classic .post_meta_categories .post_meta_item a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic .post_meta_categories .post_meta_item a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_classic .post_meta_categories .post_sponsored .post_sponsored_label {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_classic .post_meta_categories .post_sponsored a.post_sponsored_label:hover {
  color: var(--theme-color-text_dark);
}

/* default -> classic_simple */
.sc_blogger_default.sc_blogger_default_classic_simple {
  /* title */
  /* meta */
  /* on plate  */
  /* link */
}
.sc_blogger_default.sc_blogger_default_classic_simple.sc_blogger_item_image_position_left .sc_blogger_item_content, .sc_blogger_default.sc_blogger_default_classic_simple.sc_blogger_item_image_position_alter.sc_blogger_item_odd .sc_blogger_item_content {
  padding-left: 2.2em;
}
.sc_blogger_default.sc_blogger_default_classic_simple.sc_blogger_item_image_position_right .sc_blogger_item_content {
  padding-right: 2.2em;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_content .sc_blogger_item_default + .sc_blogger_item_default {
  margin-top: 30px;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_body:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_title {
  font-size: 23px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_default.sc_blogger_default_classic_simple .post_meta {
  margin: 0 0 1.1em 0;
}
.sc_blogger_default.sc_blogger_default_classic_simple .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_simple .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_simple .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content {
  padding: 40px 50px;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.8em;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_meta + .sc_blogger_item_button,
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt + .sc_blogger_item_button {
  margin-top: 1em;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt:after {
  display: none;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top .sc_blogger_item_content {
  border: 1px solid var(--theme-color-alter_bd_color);
  -webkit-box-shadow: 0 3px 30px var(--theme-color-text_dark_003);
  -ms-box-shadow: 0 3px 30px var(--theme-color-text_dark_003);
  box-shadow: 0 3px 30px var(--theme-color-text_dark_003);
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
  border-top: none;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_button .item_more_link .link_text {
  display: none;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_button .item_more_link .link_icon {
  width: 17px;
  height: 20px;
  line-height: 20px;
  overflow: hidden;
  position: relative;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  will-change: transform;
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item_button .item_more_link .link_icon:before {
  top: 0;
  right: 1px;
  position: absolute;
  display: block;
  font-size: 11px;
  font-weight: 400;
  line-height: 20px;
  content: '\e9e2';
}
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item:hover .sc_blogger_item_button .item_more_link:hover .link_icon,
.sc_blogger_default.sc_blogger_default_classic_simple .sc_blogger_item:hover .sc_blogger_item_button .item_more_link .link_icon {
  width: 38px;
}

/* default -> classic_3 */
.sc_blogger_default.sc_blogger_default_classic_3 {
  /* title */
  /* meta */
  /* on plate  */
  /* link */
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_title {
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_default.sc_blogger_default_classic_3 .post_meta {
  margin: 0 0 1em 0;
}
.sc_blogger_default.sc_blogger_default_classic_3 .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_3 .post_meta .post_meta_item.post_categories a,
.sc_blogger_default.sc_blogger_default_classic_3 .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate {
  -webkit-box-shadow: 0 3px 20px var(--theme-color-text_dark_003);
  -ms-box-shadow: 0 3px 20px var(--theme-color-text_dark_003);
  box-shadow: 0 3px 20px var(--theme-color-text_dark_003);
  height: auto;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content {
  padding: 25px 32px;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.8em;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_meta + .sc_blogger_item_button,
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt + .sc_blogger_item_button {
  margin-top: 0.7em;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt:after {
  display: none;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top .sc_blogger_item_header {
  margin: 0;
  padding: 25px 32px;
  background-color: var(--theme-color-alter_bg_color);
  border-top: 2px solid var(--theme-color-alter_bg_color);
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top:hover .sc_blogger_item_header {
  border-color: var(--theme-color-alter_dark);
}
.sc_blogger_default.sc_blogger_default_classic_3 .sc_blogger_item_button .item_more_link {
  font-size: 15px;
}

/* default -> classic_time */
.sc_blogger_default.sc_blogger_default_classic_time {
  /* title */
  /* meta */
  /* date */
  /* on plate  */
  /* link */
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_title {
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta {
  margin: 0 0 0.9em 0;
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta.sc_blogger_item_meta.post_meta_date {
  padding: 0;
  font-size: 12px;
  line-height: 1em;
  font-weight: 700;
  text-transform: uppercase;
  display: inline-block;
  width: 100%;
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta.sc_blogger_item_meta.post_meta_date .post_date {
  width: auto;
  min-width: 67px;
  max-width: 100px;
  padding: 15px 15px 17px;
  text-align: center;
  display: inline-block;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-inverse_hover);
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta.sc_blogger_item_meta.post_meta_date b {
  margin-top: -7px;
  font-size: 35px;
  line-height: 1em;
  font-weight: 500;
  display: block;
  margin-bottom: 5px;
}
.sc_blogger_default.sc_blogger_default_classic_time .post_meta.sc_blogger_item_meta.post_meta_date a,
.sc_blogger_default.sc_blogger_default_classic_time .post_meta.sc_blogger_item_meta.post_meta_date a:hover {
  color: var(--theme-color-inverse_hover);
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate {
  -webkit-box-shadow: 0 3px 20px var(--theme-color-text_dark_003);
  -ms-box-shadow: 0 3px 20px var(--theme-color-text_dark_003);
  box-shadow: 0 3px 20px var(--theme-color-text_dark_003);
  height: auto;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_body:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content {
  padding: 42px 38px;
  position: relative;
  z-index: 9;
  -webkit-transform: translateZ(99px);
  -ms-transform: translateZ(99px);
  transform: translateZ(99px);
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.8em;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_meta + .sc_blogger_item_button,
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt + .sc_blogger_item_button {
  margin-top: 1em;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate .sc_blogger_item_content .sc_blogger_item_excerpt:after {
  display: none;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top {
  position: relative;
  z-index: 1;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_default.sc_blogger_item_on_plate.sc_blogger_item_image_position_top .post_meta.sc_blogger_item_meta.post_meta_date {
  margin: 0;
  text-align: right;
  position: absolute;
  right: 30px;
  top: -42px;
  width: auto;
  z-index: 9999;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_button .item_more_link .link_text {
  display: none;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_button .item_more_link .link_icon {
  width: 17px;
  height: 20px;
  line-height: 20px;
  overflow: hidden;
  position: relative;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  will-change: transform;
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item_button .item_more_link .link_icon:before {
  top: 0;
  right: 1px;
  position: absolute;
  display: block;
  font-size: 11px;
  font-weight: 400;
  line-height: 20px;
  content: '\e9e2';
}
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item:hover .sc_blogger_item_button .item_more_link:hover .link_icon,
.sc_blogger_default.sc_blogger_default_classic_time .sc_blogger_item:hover .sc_blogger_item_button .item_more_link .link_icon {
  width: 38px;
}

/* default -> classic_time_2 */
.sc_blogger_default.sc_blogger_default_classic_time_2 {
  /* post_info */
  /* cat */
  /* title */
  /* meta */
  /* date */
  /* on plate  */
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_body:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_default.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
  margin-top: 1.5em;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_content {
  position: relative;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_content .sc_blogger_item_excerpt:after {
  display: none;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_content > .post_meta.sc_blogger_item_meta.post_meta_date {
  position: absolute;
  left: 0;
  top: 0;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_content > .post_meta.sc_blogger_item_meta.post_meta_date ~ * {
  margin-left: 100px;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.8em;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_item_featured [class*="post_info_"] {
  padding: 30px;
  background: transparent !important;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_item_featured [class*="post_info_"] .post_meta_item.post_categories a:hover, .sc_blogger_default.sc_blogger_default_classic_time_2 .sc_item_featured [class*="post_info_"] .post_meta_item.post_categories a:focus {
  background-color: var(--theme-color-text_hover2) !important;
  color: var(--theme-color-inverse_link) !important;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories {
  margin: 0;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_category {
  margin: 0;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_categories {
  color: transparent !important;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_link2);
  color: var(--theme-color-inverse_link);
  text-transform: uppercase;
  padding: 5px 17px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 11px;
  line-height: 15px;
  letter-spacing: 0.7px;
  margin: 4px 0 4px 0;
  display: inline-block;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a:hover, .sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a:focus {
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-inverse_hover);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored .post_sponsored_label {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
  text-transform: uppercase;
  padding: 5px 17px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 11px;
  line-height: 15px;
  letter-spacing: 0.7px;
  margin: 4px 0 4px 0;
  display: inline-block;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored:after {
  color: var(--theme-color-alter_bg_color_07);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored a.post_sponsored_label:hover {
  background-color: var(--theme-color-text_dark);
  color: var(--theme-color-inverse_hover);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_title {
  font-size: 33px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta {
  margin: 1.1em 0 0 0;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_date {
  padding: 0;
  margin: 0;
  font-size: 12px;
  line-height: 1em;
  font-weight: 700;
  letter-spacing: 1px;
  text-transform: uppercase;
  display: inline-block;
  width: auto;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_date .post_date {
  width: 65px;
  padding: 0;
  text-align: center;
  display: inline-block;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_date b {
  font-size: 48px;
  line-height: 1em;
  font-weight: 500;
  display: block;
  margin-bottom: 5px;
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_date a,
.sc_blogger_default.sc_blogger_default_classic_time_2 .post_meta.sc_blogger_item_meta.post_meta_date a:hover {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_classic_time_2 .sc_blogger_item_default.sc_blogger_item_on_plate {
  height: auto;
}

/* default -> over_bottom */
.sc_blogger_default.sc_blogger_default_over_bottom {
  /* title */
  /* link */
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured .mask {
  background-color: rgba(0, 0, 0, 0.6);
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured:hover .mask {
  background-color: rgba(0, 0, 0, 0.75);
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] {
  padding: 45px;
  background-color: transparent;
  max-width: 100%;
  width: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  /* meta */
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .post_meta {
  margin: 0 0 1.1em 0;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .post_meta a {
  color: #A5A6AA;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .post_meta a:hover {
  color: #ffffff;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories a:hover {
  color: #A5A6AA;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_item_featured [class*="post_info_"] .sc_blogger_item_button .item_more_link {
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_title {
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_title a:hover {
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_button .item_more_link .link_text {
  display: none;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_button .item_more_link .link_icon {
  width: 17px;
  height: 20px;
  line-height: 20px;
  overflow: hidden;
  position: relative;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  will-change: transform;
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item_button .item_more_link .link_icon:before {
  top: 0;
  right: 1px;
  position: absolute;
  display: block;
  font-size: 11px;
  font-weight: 400;
  line-height: 20px;
  content: '\e9e2';
}
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item:hover .sc_blogger_item_button .item_more_link:hover .link_icon,
.sc_blogger_default.sc_blogger_default_over_bottom .sc_blogger_item:hover .sc_blogger_item_button .item_more_link .link_icon {
  width: 38px;
}

/* default -> over_centered_hover */
.sc_blogger_default.sc_blogger_default_over_centered_hover {
  /* divider */
  /* hover */
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .trx_addons_columns_wrap.no_margin {
  overflow: hidden;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .trx_addons_columns_wrap.no_margin > [class*="trx_addons_column-"] .sc_blogger_item:before, .sc_blogger_default.sc_blogger_default_over_centered_hover .trx_addons_columns_wrap.no_margin > [class*="trx_addons_column-"] .sc_blogger_item:after {
  content: '';
  display: block;
  position: absolute;
  z-index: 99;
  background-color: var(--theme-color-alter_bd_color);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .trx_addons_columns_wrap.no_margin > [class*="trx_addons_column-"] .sc_blogger_item:before {
  height: 1px;
  width: 100%;
  top: -1px;
  right: 0;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .trx_addons_columns_wrap.no_margin > [class*="trx_addons_column-"] .sc_blogger_item:after {
  height: 100%;
  width: 1px;
  top: 0;
  right: -1px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .trx_addons_columns_wrap.no_margin > [class*="trx_addons_column-"]:last-child .sc_blogger_item:after {
  display: none;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover .mask,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured .mask {
  background-color: rgba(0, 0, 0, 0.65);
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] {
  padding: 40px 48px 20px;
  max-width: calc(100% + 2px);
  min-width: calc(100% + 2px);
  min-height: calc(100% + 2px);
  width: calc(100% + 2px);
  height: calc(100% + 2px);
  text-align: left;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_text);
  -webkit-transition: all 0.4s ease-out;
  -ms-transition: all 0.4s ease-out;
  transition: all 0.4s ease-out;
  /* meta */
  /* title */
  /* link */
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.9em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta {
  margin: 0 0 1.1em 0;
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta a:hover,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta a {
  color: var(--theme-color-alter_light);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories a:hover,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item.post_sponsored .post_sponsored_label {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_title {
  margin: 0 !important;
  font-size: 26px;
  line-height: 1.2em;
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_button .item_more_link {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured [class*="post_info_"] .sc_blogger_item_button .item_more_link .link_text {
  color: currentColor;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] {
  color: #A5A6AA;
  background-color: transparent !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta {
  color: #96999F;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta a {
  color: #96999F;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta a:hover {
  color: #ffffff;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item.post_categories {
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item.post_categories a:hover {
  color: #A5A6AA;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item.post_sponsored .post_sponsored_label {
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item.post_sponsored a.post_sponsored_label:hover {
  color: #A5A6AA;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: #FCFCFC;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_button .item_more_link {
  color: #F9F9F9;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_blogger_item_body:hover .sc_blogger_item_button .item_more_link .link_text,
.sc_blogger_default.sc_blogger_default_over_centered_hover .sc_blogger_item_body .sc_blogger_item_button .item_more_link:hover .link_text {
  transition-delay: 0.1s;
}

/* default -> over_centered_hover_2 */
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 {
  /* hover */
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .slider_controls_wrap > a {
  z-index: 99;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb .post_audio:not(.with_iframe) {
  padding: 25px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb .post_info_mc {
  position: relative !important;
  top: 0;
  left: 0;
  right: 0;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] {
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb .post_info_mc {
  padding: 25px !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories {
  position: relative !important;
  top: 0 !important;
  left: 0 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta a, .sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .post_meta .post_meta_item:after, .sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .post_meta a {
  color: var(--theme-color-text_light);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta a:hover, .sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .post_meta a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] .sc_blogger_item_title a, .sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb [class*="post_info_"] .sc_blogger_item_title a:hover, .sc_blogger_default.sc_blogger_default_over_centered_hover_2 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body > .post_info_mc {
  padding: 25px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body > .post_info_mc .post_meta {
  margin: 0 0 1em 0;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body > .post_info_mc .post_meta:not(.post_meta_categories) {
  margin: 1em 0 0 0;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body .sc_blogger_item_title {
  margin: 0 !important;
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_blogger_item_body .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.9em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover .mask,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured .mask {
  background-color: rgba(0, 0, 0, 0.5);
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] {
  padding: 45px 40px;
  max-width: calc(100% + 4px);
  min-width: calc(100% + 4px);
  min-height: calc(100% + 4px);
  max-height: calc(100% + 4px);
  width: calc(100% + 4px);
  height: calc(100% + 4px);
  text-align: left;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_text);
  -webkit-transition: all 0.4s ease-out;
  -ms-transition: all 0.4s ease-out;
  transition: all 0.4s ease-out;
  /* cat */
  /* meta */
  /* title */
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.9em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories {
  margin: 0;
  position: absolute;
  top: 45px;
  left: 40px;
  right: 40px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_categories {
  color: transparent !important;
  font-weight: 700;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_link2);
  color: var(--theme-color-inverse_link);
  text-transform: uppercase;
  padding: 5px 17px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 11px;
  line-height: 15px;
  letter-spacing: 0.7px;
  margin: 4px 0 4px 0;
  display: inline-block;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a:hover, .sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a:focus {
  background-color: var(--theme-color-text_hover2);
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored .post_sponsored_label {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
  text-transform: uppercase;
  padding: 5px 17px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 11px;
  line-height: 15px;
  letter-spacing: 0.7px;
  margin: 4px 0 4px 0;
  display: inline-block;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored a.post_sponsored_label:hover {
  background-color: var(--theme-color-text_hover2);
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta {
  margin: 1.1em 0 0 0;
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta a:hover,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .post_meta a {
  color: var(--theme-color-alter_light);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title {
  margin: 0 !important;
  font-size: 26px;
  line-height: 1.2em;
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] {
  color: #A5A6AA;
  background-color: transparent !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] .post_meta {
  color: #ffffff;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] .post_meta a {
  color: #ffffff;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] .post_meta a:hover {
  color: #F6F6F6;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_centered_hover_2 .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: #FCFCFC;
}

/* default -> over_centered_hover_3 */
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 {
  /* hover */
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .slider_controls_wrap > a {
  z-index: 99;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb .post_audio:not(.with_iframe) {
  padding: 25px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb .post_info_mc {
  position: relative !important;
  top: 0;
  left: 0;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none;
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] {
  opacity: 1 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb .post_info_mc {
  padding: 25px !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories {
  position: relative !important;
  top: 0 !important;
  left: 0 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta a, .sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .post_meta .post_meta_item:after, .sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .post_meta a {
  color: var(--theme-color-text_light);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] .post_meta a:hover, .sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .post_meta a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] .sc_blogger_item_title a, .sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb [class*="post_info_"] .sc_blogger_item_title a:hover, .sc_blogger_default.sc_blogger_default_over_centered_hover_3 .format-audio .post_featured.without_thumb:hover [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured .mask {
  background-color: var(--theme-color-inverse_dark) !important;
  opacity: 0 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover .mask {
  opacity: 0.9 !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body > .post_info_mc {
  padding: 25px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body > .post_info_mc .post_meta {
  margin: 0 0 1em 0;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body > .post_info_mc .post_meta:not(.post_meta_categories) {
  margin: 1em 0 0 0;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body .sc_blogger_item_title {
  margin: 0 !important;
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_blogger_item_body .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.9em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] {
  padding: 45px 40px;
  max-width: 100%;
  width: 100%;
  height: 100%;
  text-align: left;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  background-color: transparent !important;
  color: var(--theme-color-alter_text);
  -webkit-transition: all 0.4s ease-out;
  -ms-transition: all 0.4s ease-out;
  transition: all 0.4s ease-out;
  opacity: 0;
  /* cat */
  /* meta */
  /* title */
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 0.9em;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories {
  margin: 0;
  position: absolute;
  top: 45px;
  left: 40px;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_categories {
  color: transparent !important;
  font-weight: 700;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_link2);
  color: var(--theme-color-inverse_link);
  text-transform: uppercase;
  padding: 5px 17px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 11px;
  line-height: 15px;
  letter-spacing: 0.7px;
  margin: 4px 0 4px 0;
  display: inline-block;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a:hover, .sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_categories a:focus {
  background-color: var(--theme-color-text_hover2);
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored .post_sponsored_label {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
  text-transform: uppercase;
  padding: 5px 17px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 11px;
  line-height: 15px;
  letter-spacing: 0.7px;
  margin: 4px 0 4px 0;
  display: inline-block;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta.sc_blogger_item_meta.post_meta_categories .post_meta_item.post_sponsored a.post_sponsored_label:hover {
  background-color: var(--theme-color-text_hover2);
  color: var(--theme-color-inverse_link);
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta {
  margin: 1.1em 0 0 0;
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title {
  margin: 0 !important;
  font-size: 26px;
  line-height: 1.2em;
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a {
  -webkit-transition: inherit;
  -ms-transition: inherit;
  transition: inherit;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"],
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] {
  color: #A5A6AA;
  background-color: transparent !important;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] .post_meta {
  color: #ffffff;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta a,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] .post_meta .post_meta_item:after,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] .post_meta a {
  color: #ffffff;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .post_meta a:hover,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] .post_meta a:hover {
  color: #F6F6F6;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured [class*="post_info_"] .sc_blogger_item_title a:hover,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_title a,
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] .sc_blogger_item_title a:hover {
  color: #FCFCFC;
}
.sc_blogger_default.sc_blogger_default_over_centered_hover_3 .sc_item_featured:hover [class*="post_info_"] {
  opacity: 1;
}

/* list global */
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_left .sc_blogger_item_title,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_right .sc_blogger_item_title,
.sc_blogger_item_list.sc_blogger_item_with_image.sc_blogger_item_image_position_alter .sc_blogger_item_title {
  margin-top: 0 !important;
}

.sc_blogger_item_list .sc_blogger_item_meta .post_meta_label {
  display: inherit;
}

/* list -> simple */
.sc_blogger_list.sc_blogger_list_simple {
  /* decor */
  /* title */
  /* meta */
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_body {
  position: relative;
  padding: 0 0 0 50px;
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_body:before {
  position: absolute;
  left: 0;
  top: 9px;
  width: 35px;
  height: 2px;
  content: "";
  display: block;
  background-color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_on_plate .sc_blogger_item_body {
  padding: 10px;
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_on_plate .sc_blogger_item_body:before {
  display: none !important;
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_title {
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_list.sc_blogger_list_simple .post_meta {
  margin: 0 0 1.1em 0;
}
.sc_blogger_list.sc_blogger_list_simple .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_simple .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_simple .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_list.sc_blogger_list_simple .sc_blogger_item_meta + .sc_blogger_item_button {
  margin-top: 1em;
}

/* list -> hover */
.sc_blogger_list.sc_blogger_list_hover {
  /* title */
  /* meta */
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_content .sc_blogger_item_list {
  margin-bottom: 0;
  padding-bottom: 0;
  border-bottom: none;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_content .sc_blogger_item_list.sc_blogger_item_image_position_top + .sc_blogger_item_list.sc_blogger_item_image_position_top {
  margin-top: 5em;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_title {
  font-size: 26px;
  line-height: 1.28em;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_title a:hover,
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_hover .post_meta {
  margin: 0 0 1.1em 0;
}
.sc_blogger_list.sc_blogger_list_hover .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_hover .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_hover .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_meta + .sc_blogger_item_button {
  margin-top: 1em;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_button .item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 500;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_button .item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_button .item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_button .item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, color, opacity;
}
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_body:hover .sc_blogger_item_button .item_more_link .link_text,
.sc_blogger_list.sc_blogger_list_hover .sc_blogger_item_body .sc_blogger_item_button .item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}

/* list -> with image */
.sc_blogger_list.sc_blogger_list_with_image {
  /* title */
  /* meta */
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_body:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_body:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_list.sc_blogger_list_with_image .post_featured.with_thumb.default-featured-size {
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_content .sc_blogger_item_list {
  margin-bottom: 30px;
  padding-bottom: 30px;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_content .sc_blogger_item_list:last-child {
  margin-bottom: 0;
  padding-bottom: 0;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_list.sc_blogger_item_image_position_left .sc_blogger_item_body,
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_list.sc_blogger_item_image_position_right .sc_blogger_item_body,
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_list.sc_blogger_item_image_position_alter .sc_blogger_item_body {
  overflow: hidden;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_title {
  font-size: 24px;
  line-height: 1.2em;
  padding-bottom: 3px;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_list.sc_blogger_list_with_image .post_meta {
  margin: 0 0 0.5em 0;
}
.sc_blogger_list.sc_blogger_list_with_image .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_with_image .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_with_image .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_meta + .sc_blogger_item_button {
  margin-top: 1em;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_button .item_more_link {
  position: relative;
  display: inline-block;
  top: auto;
  left: auto;
  height: auto;
  width: auto;
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: var(--theme-color-text_dark);
  z-index: 1;
  overflow: hidden;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_button .item_more_link .link_icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  overflow: hidden;
  width: 1.4em;
  height: 1.4em;
  line-height: 1.4em;
  text-align: center;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_button .item_more_link .link_icon:before {
  font-size: 11px;
  line-height: inherit;
  font-weight: 400;
  font-style: inherit;
  content: '\E9A4';
  font-family: "fontello";
  display: inline-block;
  vertical-align: top;
  color: currentColor;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_button .item_more_link .link_text {
  position: relative;
  margin-right: 0;
  display: inline-block;
  vertical-align: middle;
  text-indent: -110px;
  visibility: hidden;
  white-space: nowrap;
  opacity: 0;
  -webkit-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.4s ease-out, text-indent 0.5s ease-out, color 0.4s ease, opacity 0.4s ease;
  will-change: visibility, margin-right, text-indent, color, opacity;
}
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_body:hover .sc_blogger_item_button .item_more_link .link_text,
.sc_blogger_list.sc_blogger_list_with_image .sc_blogger_item_body .sc_blogger_item_button .item_more_link:hover .link_text {
  opacity: 1;
  text-indent: 0;
  margin-right: 6px;
  visibility: visible;
  -webkit-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  -ms-transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
  transition: visibility 0.4s ease, margin-right 0.3s ease-out, text-indent 0.4s ease-out, opacity 0.4s ease;
}

/* list -> hover 2 */
.sc_blogger_list.sc_blogger_list_hover_2 {
  /* title */
  /* meta */
  /* link */
}
.sc_blogger_list.sc_blogger_list_hover_2 .no_margin .sc_blogger_item:hover {
  -webkit-box-shadow: inherit;
  -ms-box-shadow: inherit;
  box-shadow: inherit;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item {
  background-color: var(--theme-color-alter_bg_color);
  position: relative;
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -ms-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item:hover {
  -webkit-box-shadow: 0 5px 30px 0 rgba(0, 0, 0, 0.08);
  -ms-box-shadow: 0 5px 30px 0 rgba(0, 0, 0, 0.08);
  box-shadow: 0 5px 30px 0 rgba(0, 0, 0, 0.08);
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item:before {
  content: ' ';
  width: 0;
  height: 0;
  display: inline-block;
  vertical-align: top;
  margin-left: -0.3em;
  padding-top: 102%;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_body {
  padding: 20px 60px;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  flex-direction: column;
  justify-content: center;
  position: absolute;
  left: 0;
  top: 0;
  bottom: 0;
  height: 100%;
  z-index: 1;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_body > .link {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_excerpt {
  font-size: 15px;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_title + .sc_blogger_item_excerpt,
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_meta + .sc_blogger_item_excerpt {
  margin-top: 1.2em;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_title + .sc_blogger_item_excerpt + .sc_blogger_item_button,
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item .sc_blogger_item_meta + .sc_blogger_item_excerpt + .sc_blogger_item_button {
  margin-top: 1.4em;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_content .sc_blogger_item_list {
  margin-bottom: 0;
  padding-bottom: 0;
  border-bottom: none;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_content .sc_blogger_item_list.sc_blogger_item_image_position_top + .sc_blogger_item_list.sc_blogger_item_image_position_top {
  margin-top: 5em;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_title {
  font-size: 26px;
  line-height: 1.2em;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_title a:hover,
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_hover_2 .post_meta {
  margin: 0 0 1.1em 0;
}
.sc_blogger_list.sc_blogger_list_hover_2 .post_meta .post_meta_item.post_categories {
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_hover_2 .post_meta .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_list.sc_blogger_list_hover_2 .post_meta .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_meta + .sc_blogger_item_button {
  margin-top: 1em;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_button .item_more_link .link_text {
  display: none;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_button .item_more_link .link_icon {
  width: 17px;
  height: 20px;
  line-height: 20px;
  overflow: hidden;
  position: relative;
  -webkit-transition: all 0.4s ease;
  -ms-transition: all 0.4s ease;
  transition: all 0.4s ease;
  will-change: transform;
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item_button .item_more_link .link_icon:before {
  top: 0;
  right: 1px;
  position: absolute;
  display: block;
  font-size: 11px;
  font-weight: 400;
  line-height: 20px;
  content: '\e9e2';
}
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item:hover .sc_blogger_item_button .item_more_link:hover .link_icon,
.sc_blogger_list.sc_blogger_list_hover_2 .sc_blogger_item:hover .sc_blogger_item_button .item_more_link .link_icon {
  width: 38px;
}

/* blogger news */
.sc_blogger_news .sc_blogger_item_default.sc_blogger_item_image_position_top .sc_blogger_item_featured + .sc_blogger_item_content {
  margin-top: 1.3em;
}
.sc_blogger_news .post_meta {
  margin: 0 0 0.5em;
}
.sc_blogger_news .sc_blogger_item_title + .post_meta {
  margin: 0.5em 0 0 0;
}
.sc_blogger_news .sc_blogger_item_title + .sc_blogger_item_button,
.sc_blogger_news .sc_blogger_item_meta + .sc_blogger_item_button,
.sc_blogger_news .sc_blogger_item_excerpt + .sc_blogger_item_button {
  margin-top: 0.7em;
}
.sc_blogger_news .post_featured.with_thumb .sc_blogger_item_button .item_more_link {
  color: #ffffff;
}

/* blogger blog -> classic masonry */
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default {
  /* bullets */
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 6px;
  background-color: #E2E1E0;
  border-color: #E2E1E0;
  opacity: 1;
  width: 8px;
  height: 8px;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet.swiper-pagination-bullet-active, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet:hover, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_outer .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_container .slider_pagination_wrap .swiper-pagination-bullet:hover, .sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_outer .slider_pagination_wrap .swiper-pagination-bullet:hover {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
  margin-top: 2em;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry {
  padding-bottom: 2px;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry .post_title {
  margin: 0;
  font-size: 28px;
  line-height: 1.18em;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry.post_layout_classic_1 .post_title {
  margin: 0;
  font-size: 35px;
  line-height: 1.15em;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry .post_featured {
  margin-bottom: 1.85em;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry .post_header {
  padding: 0 0 0 50px;
  position: relative;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry .post_header:before {
  position: absolute;
  left: 0;
  top: 9px;
  width: 35px;
  height: 2px;
  content: "";
  display: block;
  background-color: var(--theme-color-text_dark);
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry .post_header .post_meta {
  margin: 0 0 12px;
}
.sc_blogger_classic-masonry.sc_blogger_classic-masonry_default .post_layout_classic-masonry.post_layout_classic_1 .post_header {
  padding-right: 8%;
}

/* blogger blog -> band */
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child .post_content_wrap {
  padding: 2.5em;
}
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child .post_content_wrap .post_title {
  margin: 0;
  font-size: 35px;
  line-height: 1.09em;
}
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child .post_content_wrap .post_title a {
  color: var(--theme-color-text_dark);
}
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child .post_content_wrap .post_title a:hover {
  color: var(--theme-color-text);
}
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child .post_featured_bg:after {
  padding-top: 128%;
  content: ' ';
  width: 0;
  height: 0;
  display: inline-block;
  vertical-align: top;
  margin-left: -0.3em;
  position: relative;
}
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child:hover .post_featured.hover_link.with_thumb > .bg_in,
.sc_blogger_band.sc_blogger_band_default .post_layout_band:only-child:hover .post_featured.hover_link img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}

/* Categories Lists */
/* Style 1 */
.categories_list_style_1 .categories_list_item + .categories_list_item {
  margin-top: 0.9em;
}
.categories_list_style_1 .categories_list_item .categories_list_title {
  margin: 0.4em 0 0;
}

/* Style 2 */
.widget_categories_list .categories_list_style_2 .categories_list_icon {
  vertical-align: middle;
}
.widget_categories_list .categories_list_style_2 .categories_list_icon + .categories_list_caption {
  vertical-align: middle;
}
.widget_categories_list .categories_list_style_2 .categories_list_title {
  font-weight: 700;
  width: 45%;
  -webkit-box-shadow: 0 0 6px 0 rgba(0, 0, 0, 0.3);
  -ms-box-shadow: 0 0 6px 0 rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 6px 0 rgba(0, 0, 0, 0.3);
}

/* Style 3 */
.widget_categories_list .categories_list_style_3 .categories_list_title {
  font-weight: 700;
}

/* Extra 1 */
.categories_list_style_4 .categories_list_item {
  position: relative;
  text-align: center;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  perspective: none;
  z-index: 1;
}
.categories_list_style_4 .categories_list_item:hover {
  z-index: 10;
}
.categories_list_style_4 .categories_list_info_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  transform: none;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
}
.categories_list_style_4 .categories_list_info_wrap:before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  opacity: 0.4;
  background: rgba(0, 0, 0, 0.3);
  -webkit-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}
.categories_list_style_4 .categories_list_info {
  position: relative;
  top: auto;
  left: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 20px;
  -webkit-transform: translateZ(60px) scale(0.95);
  -ms-transform: translateZ(60px) scale(0.95);
  transform: translateZ(60px) scale(0.95);
}
.categories_list_style_4 .categories_list_link {
  -webkit-transform: translateZ(90px);
  -ms-transform: translateZ(90px);
  transform: translateZ(90px);
}
.categories_list_style_4 .categories_list_title {
  font-weight: 700;
  font-size: 35px;
  line-height: 1.3em;
  color: #ffffff;
  margin: 13px 0;
}
.categories_list_style_4 .categories_list_title * {
  color: #ffffff;
}
.categories_list_style_4 .categories_list_title .categories_list_count {
  margin-left: 0.2em;
}
.categories_list_style_4 .categories_link_more {
  font-size: 15px;
  line-height: 18px;
  font-weight: 700;
  color: #ffffff;
  display: inline-block;
  margin-bottom: -18px;
  opacity: 0;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.categories_list_style_4 .categories_list_item:hover .categories_link_more {
  opacity: 1;
  margin-bottom: 0;
}

/* Extra 2 */
.categories_list_style_5 .categories_list_image {
  display: block;
  overflow: hidden;
}
.categories_list_style_5 .categories_list_image img {
  -webkit-transition: all 0.35s ease-in-out;
  -ms-transition: all 0.35s ease-in-out;
  transition: all 0.35s ease-in-out;
  -webkit-transform: scale(1.01, 1.01);
  -ms-transform: scale(1.01, 1.01);
  transform: scale(1.01, 1.01);
}
.categories_list_style_5 .categories_list_item:hover .categories_list_image img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.categories_list_style_5 .categories_list_item:hover .categories_list_info_wrap:before {
  opacity: 1;
}
.categories_list_style_5 .trx_addons_columns_wrap {
  margin: 0 !important;
}
.categories_list_style_5 .trx_addons_columns_wrap > [class*="trx_addons_column-"] {
  padding: 0 !important;
}
.categories_list_style_5 .categories_list_info_wrap {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  overflow: hidden;
}
.categories_list_style_5 .categories_list_info_wrap:before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 102%;
  opacity: 0.6;
  background: rgba(0, 0, 0, 0.6);
  background: -moz-linear-gradient(0deg, rgba(0, 0, 0, 0.3) 0%, rgba(0, 0, 0, 0.6) 100%);
  background: -webkit-linear-gradient(0deg, rgba(0, 0, 0, 0.3) 0%, rgba(0, 0, 0, 0.6) 100%);
  background: linear-gradient(0deg, rgba(0, 0, 0, 0.3) 0%, rgba(0, 0, 0, 0.6) 100%);
  -webkit-transition: all 0.35s ease-in-out;
  -ms-transition: all 0.35s ease-in-out;
  transition: all 0.35s ease-in-out;
}
.categories_list_style_5 .categories_list_info_wrap .categories_list_info {
  z-index: 9;
  position: relative;
  top: auto;
  left: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: space-between;
  -ms-flex-pack: space-between;
  justify-content: space-between;
  -webkit-align-items: self-start;
  -ms-flex-align: self-start;
  align-items: self-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: left;
  width: 100%;
  height: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 53px 48px;
}
.categories_list_style_5 .categories_list_title {
  font-weight: 700;
  font-size: 35px;
  line-height: 1.12em;
  color: #FCFCFC;
  margin: 0;
  text-align: left;
}
.categories_list_style_5 .categories_list_title * {
  color: #FCFCFC;
}
.categories_list_style_5 .categories_list_title .categories_list_count {
  margin-left: 0.2em;
}
.categories_list_style_5 .categories_link_more {
  font-size: 17px;
  line-height: 20px;
  font-weight: 700;
  color: #A5A6AA;
  display: inline-block;
  margin: 0;
  position: relative;
  vertical-align: middle;
}
.categories_list_style_5 .categories_link_more:after {
  content: '\e9b2';
  font-family: "fontello";
  display: inline-block;
  font-size: 9px;
  font-weight: 400;
  margin-left: 13px;
  vertical-align: middle;
  margin-top: -2px;
  line-height: inherit;
}

/* Extra 3 */
.categories_list_style_6 .categories_list_columns .categories_list_item {
  height: auto;
}
.categories_list_style_6 .categories_list_image {
  display: block;
  overflow: hidden;
}
.categories_list_style_6 .categories_list_image img {
  -webkit-transition: all 0.35s ease-in-out;
  -ms-transition: all 0.35s ease-in-out;
  transition: all 0.35s ease-in-out;
  -webkit-transform: scale(1.01, 1.01);
  -ms-transform: scale(1.01, 1.01);
  transform: scale(1.01, 1.01);
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
  object-fit: cover;
}
.categories_list_style_6 .categories_list_info_wrap:before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  opacity: 0.2;
  background: rgba(0, 0, 0, 0.5);
  background: -moz-linear-gradient(0deg, rgba(0, 0, 0, 0.9) 0%, rgba(0, 0, 0, 0.3) 100%);
  background: -webkit-linear-gradient(0deg, rgba(0, 0, 0, 0.9) 0%, rgba(0, 0, 0, 0.3) 100%);
  background: linear-gradient(0deg, rgba(0, 0, 0, 0.9) 0%, rgba(0, 0, 0, 0.3) 100%);
  -webkit-transition: all 0.35s ease-in-out;
  -ms-transition: all 0.35s ease-in-out;
  transition: all 0.35s ease-in-out;
}
.categories_list_style_6 .categories_list_info_wrap {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.categories_list_style_6 .categories_list_info_wrap .categories_list_info {
  z-index: 9;
  position: relative;
  top: auto;
  left: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: self-start;
  -ms-flex-align: self-start;
  align-items: self-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: left;
  width: 100%;
  height: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 20px 35px;
}
.categories_list_style_6 .categories_list_title {
  font-weight: 700;
  font-size: 28px;
  line-height: 1.12em;
  color: #FCFCFC;
  margin: 0;
  text-align: left;
}
.categories_list_style_6 .categories_list_title * {
  color: #FCFCFC;
}
.categories_list_style_6 .categories_list_title .categories_list_count {
  margin-left: 0.2em;
}
.categories_list_style_6 .categories_link_more {
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #F9F9F9;
  display: inline-block;
  margin: 14px 0 -18px;
  opacity: 0;
  position: relative;
  vertical-align: middle;
}
.categories_list_style_6 .categories_link_more:after {
  content: '\e9b2';
  font-family: "fontello";
  display: inline-block;
  font-size: 11px;
  font-weight: 400;
  margin-left: 13px;
  vertical-align: middle;
  margin-top: -3px;
  line-height: inherit;
  position: relative;
  top: 2px;
}
.categories_list_style_6 .categories_list_item:hover .categories_list_image img {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.categories_list_style_6 .categories_list_item:hover .categories_list_info_wrap:before {
  opacity: 0.4;
}
.categories_list_style_6 .categories_list_item:hover .categories_link_more {
  margin-bottom: 15px;
  opacity: 1;
}

/* Grid 1 */
.categories_list_style_7 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 1fr;
  gap: 0 0;
  grid-template-areas: "md-1 md-2";
  overflow: hidden;
  /* featured */
}
.categories_list_style_7.count_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 1fr;
  gap: 0 0;
  grid-template-areas: "md-1";
}
.categories_list_style_7.count_1 .categories_list_item:nth-child(1) {
  grid-area: md-1;
}
.categories_list_style_7.count_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: 200px 200px;
  gap: 0 0;
  grid-template-areas: "md-3-1 md-3-2 md-3-3" "md-3-1 md-3-2 md-3-3";
}
.categories_list_style_7.count_3 .categories_list_item:nth-child(1) {
  grid-area: md-3-1;
}
.categories_list_style_7.count_3 .categories_list_item:nth-child(2) {
  grid-area: md-3-2;
}
.categories_list_style_7.count_3 .categories_list_item:nth-child(3) {
  grid-area: md-3-3;
}
.categories_list_style_7.count_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 1fr 1fr;
  gap: 0 0;
  grid-template-areas: "lg-3-1 lg-3-1 sm-3-1 sm-3-2" "lg-3-1 lg-3-1 md-3-1 md-3-1";
}
.categories_list_style_7.count_4 .categories_list_item:nth-child(1) {
  grid-area: lg-3-1;
}
.categories_list_style_7.count_4 .categories_list_item:nth-child(2) {
  grid-area: sm-3-1;
}
.categories_list_style_7.count_4 .categories_list_item:nth-child(3) {
  grid-area: sm-3-2;
}
.categories_list_style_7.count_4 .categories_list_item:nth-child(4) {
  grid-area: md-3-1;
}
.categories_list_style_7 .categories_list_item {
  margin: -1px;
  overflow: hidden;
}
.categories_list_style_7 .post_featured_bg .bg_in {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.categories_list_style_7 .post_featured_bg {
  width: 100%;
  height: 100%;
  overflow: hidden;
  display: block;
  position: relative;
}
.categories_list_style_7 .post_featured_bg:before {
  padding-top: 50%;
}
.categories_list_style_7 .post_featured_bg.hover_link .bg_in {
  -webkit-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
  -webkit-transform: scale(1.01, 1.01);
  -ms-transform: scale(1.01, 1.01);
  transform: scale(1.01, 1.01);
}
.categories_list_style_7 .categories_list_item:hover .bg_in,
.categories_list_style_7 .post_featured_bg.hover_link:hover .bg_in {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.categories_list_style_7 .categories_list_info_wrap:before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  opacity: 0.4;
  background: rgba(0, 0, 0, 0.7);
  background: -moz-linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.3) 100%);
  background: -webkit-linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.3) 100%);
  background: linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.3) 100%);
  -webkit-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}
.categories_list_style_7 .categories_list_info_wrap {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  overflow: hidden;
}
.categories_list_style_7 .categories_list_info_wrap .categories_list_info {
  z-index: 9;
  position: relative;
  top: auto;
  left: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: self-start;
  -ms-flex-align: self-start;
  align-items: self-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: left;
  width: 100%;
  height: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 27px 40px;
}
.categories_list_style_7 .categories_list_title {
  font-weight: 700;
  font-size: 28px;
  line-height: 1.12em;
  color: #FCFCFC;
  margin: 0;
  text-align: left;
}
.categories_list_style_7 .categories_list_title * {
  color: #FCFCFC;
}
.categories_list_style_7 .categories_list_title .categories_list_count {
  margin-left: 0.2em;
}
.categories_list_style_7 .categories_link_more {
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #F9F9F9;
  display: inline-block;
  margin: 14px 0 -18px;
  opacity: 0;
  position: relative;
  vertical-align: middle;
}
.categories_list_style_7 .categories_link_more:after {
  content: '\e9b2';
  font-family: "fontello";
  display: inline-block;
  font-size: 11px;
  font-weight: 400;
  margin-left: 13px;
  vertical-align: middle;
  margin-top: -2px;
  line-height: inherit;
}
.categories_list_style_7 .categories_list_item:hover .categories_link_more {
  margin-bottom: 15px;
  opacity: 1;
}

/* Grid 2 */
.categories_list_style_8 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-template-rows: 1fr;
  gap: 30px 30px;
  grid-template-areas: "md-1 md-2";
  /* featured */
}
.categories_list_style_8.count_1 {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 1fr;
  gap: 30px 30px;
  grid-template-areas: "md-1";
}
.categories_list_style_8.count_1 .categories_list_item:nth-child(1) {
  grid-area: md-1;
}
.categories_list_style_8.count_3 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: 200px 200px;
  gap: 30px 30px;
  grid-template-areas: "md-3-1 md-3-2 md-3-3" "md-3-1 md-3-2 md-3-3";
}
.categories_list_style_8.count_3 .categories_list_item:nth-child(1) {
  grid-area: md-3-1;
}
.categories_list_style_8.count_3 .categories_list_item:nth-child(2) {
  grid-area: md-3-2;
}
.categories_list_style_8.count_3 .categories_list_item:nth-child(3) {
  grid-area: md-3-3;
}
.categories_list_style_8.count_4 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 1fr 1fr;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 md-3-1 sm-3-1" "lg-3-1 lg-3-1 md-3-1 sm-3-2";
}
.categories_list_style_8.count_4 .categories_list_item:nth-child(1) {
  grid-area: lg-3-1;
}
.categories_list_style_8.count_4 .categories_list_item:nth-child(2) {
  grid-area: md-3-1;
}
.categories_list_style_8.count_4 .categories_list_item:nth-child(3) {
  grid-area: sm-3-1;
}
.categories_list_style_8.count_4 .categories_list_item:nth-child(4) {
  grid-area: sm-3-2;
}
.categories_list_style_8.count_5 {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr 1fr;
  grid-template-rows: 1fr 1fr;
  gap: 30px 30px;
  grid-template-areas: "lg-3-1 lg-3-1 sm-3-1 sm-3-2" "lg-3-1 lg-3-1 sm-3-3 sm-3-4";
}
.categories_list_style_8.count_5 .categories_list_item:nth-child(1) {
  grid-area: lg-3-1;
}
.categories_list_style_8.count_5 .categories_list_item:nth-child(2) {
  grid-area: sm-3-1;
}
.categories_list_style_8.count_5 .categories_list_item:nth-child(3) {
  grid-area: sm-3-2;
}
.categories_list_style_8.count_5 .categories_list_item:nth-child(4) {
  grid-area: sm-3-3;
}
.categories_list_style_8.count_5 .categories_list_item:nth-child(5) {
  grid-area: sm-3-4;
}
.categories_list_style_8 .post_featured_bg .bg_in {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.categories_list_style_8 .post_featured_bg {
  width: 100%;
  height: 100%;
  overflow: hidden;
  display: block;
  position: relative;
}
.categories_list_style_8 .post_featured_bg:before {
  padding-top: 100%;
}
.categories_list_style_8 .post_featured_bg.hover_link .bg_in {
  -webkit-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
  -webkit-transform: scale(1.01, 1.01);
  -ms-transform: scale(1.01, 1.01);
  transform: scale(1.01, 1.01);
}
.categories_list_style_8 .categories_list_item:hover .bg_in,
.categories_list_style_8 .post_featured_bg.hover_link:hover .bg_in {
  -webkit-transform: scale(1.07, 1.07);
  -ms-transform: scale(1.07, 1.07);
  transform: scale(1.07, 1.07);
}
.categories_list_style_8 .categories_list_info_wrap:before {
  content: "";
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  width: 100%;
  height: 100%;
  opacity: 0.4;
  background: rgba(0, 0, 0, 0.7);
  background: -moz-linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.3) 100%);
  background: -webkit-linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.3) 100%);
  background: linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.3) 100%);
  -webkit-transition: all 0.3s ease-in-out;
  -ms-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}
.categories_list_style_8 .categories_list_info_wrap {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.categories_list_style_8 .categories_list_info_wrap .categories_list_info {
  z-index: 9;
  position: relative;
  top: auto;
  left: auto;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: self-start;
  -ms-flex-align: self-start;
  align-items: self-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  text-align: left;
  width: 100%;
  height: 100%;
  max-height: 100%;
  overflow: hidden;
  padding: 15px 31px;
}
.categories_list_style_8 .categories_list_title {
  font-weight: 700;
  font-size: 24px;
  line-height: 1.12em;
  color: #FCFCFC;
  margin: 0;
  text-align: left;
}
.categories_list_style_8 .categories_list_title * {
  color: #FCFCFC;
}
.categories_list_style_8 .categories_list_title .categories_list_count {
  margin-left: 0.2em;
}
.categories_list_style_8 .categories_link_more {
  font-size: 15px;
  line-height: 20px;
  font-weight: 700;
  color: #F9F9F9;
  display: inline-block;
  margin: 14px 0 -18px;
  opacity: 0;
  position: relative;
  vertical-align: middle;
}
.categories_list_style_8 .categories_link_more:after {
  content: '\e9b2';
  font-family: "fontello";
  display: inline-block;
  font-size: 9px;
  font-weight: 400;
  margin-left: 13px;
  vertical-align: middle;
  margin-top: -1px;
  line-height: inherit;
}
.categories_list_style_8 .categories_list_item:hover .categories_link_more {
  margin-bottom: 15px;
  opacity: 1;
}

/* Cover */
.cover_hover .sc_cover.sc_cover_default + .elementor-container .sc_item_title_text {
  color: inherit;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.cover_hover .sc_cover.sc_cover_default + .elementor-container .elementor-icon {
  fill: var(--theme-color-text_dark);
}

.cover_hover .sc_cover.sc_cover_default:hover + .elementor-container .sc_item_title_text {
  color: var(--theme-color-text_dark);
}
.cover_hover .sc_cover.sc_cover_default:hover + .elementor-container .elementor-icon {
  fill: var(--theme-color-text_link);
}

/* Mouse Helper */
.trx_addons_mouse_helper.trx_addons_mouse_helper_top:not(.trx_addons_mouse_helper_centered) {
  top: var(--mouse-helper-top) !important;
}

.trx_addons_mouse_helper.trx_addons_mouse_helper_left:not(.trx_addons_mouse_helper_centered) {
  left: var(--mouse-helper-left) !important;
}

.trx_addons_mouse_helper {
  font-size: 16px;
  text-indent: 0;
  --mouse-helper-width: 8px;
  --mouse-helper-height: 8px;
  --mouse-helper-left: 20px;
  --mouse-helper-top: 20px;
  border: none;
  mix-blend-mode: difference;
  background-color: #ffffff;
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -ms-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -webkit-transition: width 0.3s ease, height 0.3s ease, opacity 0.3s ease, color 0.3s ease, background-color 0.3s ease, left 0.3s ease, top 0.3s ease, border-radius 0.1s ease, box-shadow 0.2s ease;
  -ms-transition: width 0.3s ease, height 0.3s ease, opacity 0.3s ease, color 0.3s ease, background-color 0.3s ease, left 0.3s ease, top 0.3s ease, border-radius 0.1s ease, box-shadow 0.2s ease;
  transition: width 0.3s ease, height 0.3s ease, opacity 0.3s ease, color 0.3s ease, background-color 0.3s ease, left 0.3s ease, top 0.3s ease, border-radius 0.1s ease, box-shadow 0.2s ease;
}

.trx_addons_mouse_helper.trx_addons_mouse_helper_permanent {
  opacity: 1;
}

.trx_addons_mouse_helper.trx_addons_mouse_helper_active.trx_addons_mouse_helper_with_icon {
  --mouse-helper-width: 65px;
  --mouse-helper-height: 65px;
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_active.trx_addons_mouse_helper_with_text {
  --mouse-helper-width: 80px;
  --mouse-helper-height: 80px;
}

.trx_addons_mouse_helper .trx_addons_mouse_helper_image {
  background-size: cover;
  background-position: center center;
}
.trx_addons_mouse_helper .trx_addons_mouse_helper_image:before {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  content: ' ';
  position: absolute;
  z-index: -1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(0, 0, 0, 0);
}

.trx_addons_mouse_helper.trx_addons_mouse_helper_with_image.trx_addons_mouse_helper_with_text,
.trx_addons_mouse_helper.trx_addons_mouse_helper_with_image {
  -webkit-box-shadow: 0 3px 46px rgba(0, 0, 0, 0.1);
  -ms-box-shadow: 0 3px 46px rgba(0, 0, 0, 0.1);
  box-shadow: 0 3px 46px rgba(0, 0, 0, 0.1);
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.trx_addons_mouse_helper.trx_addons_mouse_helper_active.trx_addons_mouse_helper_with_image.trx_addons_mouse_helper_with_text,
.trx_addons_mouse_helper.trx_addons_mouse_helper_active.trx_addons_mouse_helper_with_image {
  --mouse-helper-width: 288px;
  --mouse-helper-height: 288px;
  padding: 0;
  -webkit-box-sizing: "border-box";
  -ms-box-sizing: "border-box";
  box-sizing: "border-box";
}

/* Custom Helper */
.custom-helper {
  width: 67px;
  height: 67px;
  line-height: 67px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  justify-content: center;
  align-items: center;
}
.custom-helper span {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  justify-content: center;
  align-items: center;
  color: #ffffff;
  font-size: 10px;
  font-weight: 400;
}
.custom-helper span:after {
  content: '\e9e6';
  font-family: "fontello";
  will-change: transform;
  transform: translateX(10px);
  display: inline-block;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.custom-helper span:before {
  content: '\e9e5';
  font-family: "fontello";
  will-change: transform;
  transform: translateX(-10px);
  display: inline-block;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.direction_vertical .custom-helper span {
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
  will-change: transform;
}

.trx_addons_mouse_helper.trx_addons_mouse_helper_with_layout {
  --mouse-helper-width: 66px;
  --mouse-helper-height: 66px;
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_with_layout.trx_addons_mouse_helper_click {
  --mouse-helper-width: 56px;
  --mouse-helper-height: 56px;
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_with_layout.trx_addons_mouse_helper_click .custom-helper span:after {
  transform: translateX(5px);
}
.trx_addons_mouse_helper.trx_addons_mouse_helper_with_layout.trx_addons_mouse_helper_click .custom-helper span:before {
  transform: translateX(-5px);
}

/* Highlight Helper */
[data-mouse-helper="highlight"] {
  color: var(--theme-color-text_dark_03);
  background-image: radial-gradient(closest-side, var(--theme-color-text_dark) 78%, transparent 0);
}

/* Layouts Title */
.sc_layouts_title_breadcrumbs {
  margin-top: 1.3em;
}

.sc_layouts_title .sc_layouts_title_description {
  margin-top: 0.5em;
}
.sc_layouts_title .sc_layouts_title_content {
  max-width: 100%;
}
.sc_layouts_title .sc_layouts_title_meta {
  margin: 0 0 1em;
}
.sc_layouts_title .sc_layouts_title_content > .sc_layouts_title_breadcrumbs:first-child {
  margin-top: 0;
}
.sc_layouts_title .breadcrumbs {
  font-size: 13px;
  line-height: 18px;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 0.3px;
}
.sc_layouts_title .breadcrumbs a {
  color: var(--theme-color-text_dark) !important;
}
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .mejs-container {
  height: 100% !important;
  width: 100% !important;
}
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .mejs-container .mejs-controls {
  display: none !important;
}
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .mejs-container video {
  height: 100% !important;
}
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .wp-video,
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .video_frame {
  height: 100% !important;
  width: 100% !important;
}
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .wp-video iframe,
.sc_layouts_title .trx_addons_video_player.with_video_autoplay .video_frame iframe {
  object-fit: unset;
  height: 100% !important;
  width: 100% !important;
}

/* Single style Gallery Start */
.single-format-gallery .post_featured.with_gallery .sc_slider_controller_horizontal {
  padding-left: 0;
  padding-right: 0;
}
.single-format-gallery .post_featured.with_gallery .sc_slider_controller_horizontal .slider_controls_wrap a {
  display: none;
}
.single-format-gallery .post_featured.with_gallery .sc_slider_controller_horizontal .slider-slide.swiper-slide-active:after {
  display: none;
}
.single-format-gallery .post_featured.with_gallery .slider_outer_wrap.slider_outer_wrap_controller_pos_bottom .sc_slider_controller .slider_container:not(.slider_type_images) .slider-slide,
.single-format-gallery .post_featured.with_gallery .slider_outer_wrap.slider_outer_wrap_controller_pos_bottom .sc_slider_controller .slider_container:not(.slider_type_images) {
  min-height: 1px !important;
}
.single-format-gallery .slider_container.slider_controls_side .slider_controls_wrap > a.slider_prev,
.single-format-gallery .slider_outer_controls_side .slider_controls_wrap > a.slider_prev,
.single-format-gallery .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_prev,
.single-format-gallery .slider_outer_controls_side:hover .slider_controls_wrap > a.slider_prev {
  margin-left: 30px;
}
.single-format-gallery .slider_container.slider_controls_side .slider_controls_wrap > a.slider_next,
.single-format-gallery .slider_outer_controls_side .slider_controls_wrap > a.slider_next,
.single-format-gallery .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_next,
.single-format-gallery .slider_outer_controls_side:hover .slider_controls_wrap > a.slider_next {
  margin-right: 30px;
}
.single-format-gallery .sc_slider_controller .slider_container:not(.slider_multi):not(.slider_type_images),
.single-format-gallery .sc_slider_controller .slider_container:not(.slider_multi):not(.slider_type_images) .slider-slide {
  min-height: auto;
}
.single-format-gallery .sc_slider_controller .slider_container.slider_controls_side .slider_controls_wrap > a.slider_prev,
.single-format-gallery .sc_slider_controller .slider_outer_controls_side .slider_controls_wrap > a.slider_prev,
.single-format-gallery .sc_slider_controller .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_prev,
.single-format-gallery .sc_slider_controller .slider_outer_controls_side:hover .slider_controls_wrap > a.slider_prev {
  margin-left: 0;
}
.single-format-gallery .sc_slider_controller .slider_container.slider_controls_side .slider_controls_wrap > a.slider_next,
.single-format-gallery .sc_slider_controller .slider_outer_controls_side .slider_controls_wrap > a.slider_next,
.single-format-gallery .sc_slider_controller .slider_container.slider_controls_side:hover .slider_controls_wrap > a.slider_next,
.single-format-gallery .sc_slider_controller .slider_outer_controls_side:hover .slider_controls_wrap > a.slider_next {
  margin-right: 0;
}

/* Single style Gallery End */
/* Single style Video Start */
.single_style_style-5.single-format-video .post_header_wrap .post_featured.with_thumb .post_video_hover {
  font-size: 15px;
  width: 66px;
  height: 66px;
  line-height: 66px;
  overflow: visible;
  margin: -33px 0 0 -33px;
}
.single_style_style-5.single-format-video .post_header_wrap .post_featured.with_thumb .post_video_hover:after {
  content: '';
  position: absolute;
  top: -11px;
  left: -11px;
  width: 86px;
  height: 86px;
  border: 1px solid var(--theme-color-inverse_link);
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  opacity: 0.2;
}

/* Single style Gallery End */
/* Popup post details */
#trx_addons_post_details_popup .trx_addons_post_details_popup_close:before {
  font-size: 24px;
  font-family: "fontello";
  content: '\e9e1';
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -ms-transition: -ms-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
#trx_addons_post_details_popup .trx_addons_post_details_popup_close:hover:before {
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
#trx_addons_post_details_popup .services_page_header .post_details_page_title {
  padding: 0.3em 4em 0.4em 0.5em;
  font-size: 1.6em;
  line-height: 1.2em;
}
#trx_addons_post_details_popup .post_details_page_price {
  top: 0.3em;
}

/* Layout Languages */
.sc_layouts_language .sc_layouts_language_menu > li > a,
.sc_layouts_language .sc_layouts_language_menu > li > a:hover,
.sc_layouts_language .sc_layouts_language_menu > li.sfHover > a {
  color: var(--theme-color-text_dark) !important;
}
.sc_layouts_language .sc_layouts_language_menu > li.menu-item-has-children > a:after {
  margin-left: 0.5em;
  position: relative;
  right: 0;
  top: 2px;
}
.sc_layouts_language .sc_layouts_language_menu > li > ul {
  top: 4.5em;
}
.sc_layouts_language .sc_layouts_language_menu > li.menu-item > a > img {
  position: relative;
  top: 1px;
}
.sc_layouts_language .sc_layouts_language_menu li.menu-item > a > img + span {
  margin-left: 0.5em;
}

/* Extended Taxonomy */
.trx_addons_extended_taxonomy {
  vertical-align: inherit;
}
.trx_addons_extended_taxonomy .trx_addons_extended_taxonomy_icon {
  font-weight: 400;
}

.widget .trx_addons_extended_taxonomy .trx_addons_extended_taxonomy_icon {
  margin-left: 1px;
}

/* Widget Instagram +++++
+++++++++++++++++++++++++  */
/* Simple */
.widget_instagram_type_simple .widget_instagram_images_item_wrap .widget_instagram_images_item_counters {
  display: none;
}
.widget_instagram_type_simple .widget_instagram_images_item_wrap .widget_instagram_images_item:before {
  background-color: rgba(0, 0, 0, 0.2);
}

/* Alter */
.widget_instagram_type_alter .widget_instagram_images {
  margin: 0 !important;
}
.widget_instagram_type_alter .widget_instagram_images_item_wrap {
  padding: 0 !important;
}
.widget_instagram_type_alter .widget_instagram_images_item_wrap .widget_instagram_images_item_counters {
  display: none;
}
.widget_instagram_type_alter .widget_instagram_images_item_wrap .widget_instagram_images_item:before {
  background-color: rgba(0, 0, 0, 0.2);
}
.widget_instagram_type_alter .widget_instagram_follow_link_wrap {
  margin: 0 !important;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.widget_instagram_type_alter .widget_instagram_follow_link_wrap .widget_instagram_follow_link {
  position: relative;
  margin: 0;
  padding: 16px 30px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  font-size: 14px;
  line-height: 17px;
  font-weight: 700;
  letter-spacing: 0;
  text-transform: none;
  background: #FFFFFF !important;
  color: #071021 !important;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
}
.widget_instagram_type_alter .widget_instagram_follow_link_wrap .widget_instagram_follow_link:before {
  color: inherit;
  font-family: "fontello";
  content: '\E87E';
  font-size: 18px;
  font-weight: 400;
  margin: 0 8px 0 0;
  display: inline-block;
}

/* Modern */
.widget_instagram_type_modern .widget_instagram_images {
  margin: 0 !important;
}
.widget_instagram_type_modern .widget_instagram_images_item_wrap {
  padding: 0 !important;
}
.widget_instagram_type_modern .widget_instagram_images_item_wrap .widget_instagram_images_item_counters {
  display: none;
}
.widget_instagram_type_modern .widget_instagram_images_item_wrap .widget_instagram_images_item:before {
  background-color: rgba(0, 0, 0, 0.2);
}
.widget_instagram_type_modern .widget_instagram_follow_link_wrap {
  margin: 0 !important;
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.widget_instagram_type_modern .widget_instagram_follow_link_wrap .widget_instagram_follow_link {
  margin: 0;
  padding: 0;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  color: #A5A6AA !important;
  background-color: #FFFFFF !important;
  min-width: 102px;
  height: 102px;
  line-height: 102px;
  text-align: center;
  vertical-align: middle;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  text-indent: -200px;
  overflow: hidden;
  display: block;
}
.widget_instagram_type_modern .widget_instagram_follow_link_wrap .widget_instagram_follow_link:before {
  position: absolute;
  z-index: 1;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  color: inherit;
  font-family: "fontello";
  content: '\E87E';
  font-size: 25px;
  line-height: 1em;
  font-weight: 400;
  text-indent: 0;
}

/* Hotspot Default */
.sc_hotspot_default .sc_hotspot_item_sonar {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_hotspot_default .sc_hotspot_item_icon {
  background-color: var(--theme-color-alter_bg_color);
}
.sc_hotspot_default .sc_hotspot_item_icon span {
  display: block;
  font-size: 14px;
  line-height: 16px;
  color: var(--theme-color-alter_dark);
}
.sc_hotspot_default .sc_hotspot_item_popup {
  width: 300px;
  padding: 30px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-box-shadow: 0 3px 25px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 25px rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 25px rgba(0, 0, 0, 0.05);
  background: var(--theme-color-alter_bg_color);
}
.sc_hotspot_default .sc_hotspot_item_popup > .sc_hotspot_item_popup_close + [class*="sc_hotspot_item"],
.sc_hotspot_default .sc_hotspot_item_popup > [class*="sc_hotspot_item"]:first-child {
  margin-top: 0;
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_image + [class*="sc_hotspot_item"] {
  margin-top: 25px;
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_popup_close {
  color: var(--theme-color-alter_dark);
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_subtitle {
  color: var(--theme-color-alter_dark);
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_subtitle > span,
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_subtitle .post_meta_item {
  font-size: 12px;
  line-height: 20px;
  font-weight: 400;
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_title {
  margin-top: 8px;
  font-size: 19px;
  line-height: 1.3em;
  color: var(--theme-color-alter_dark);
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_price {
  margin-top: 8px;
  font-size: 18px;
  line-height: 1em;
  font-weight: 700;
  color: var(--theme-color-alter_text);
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_description {
  margin-top: 10px;
  font-size: 15px;
  line-height: 24px;
  color: var(--theme-color-alter_text);
}
.sc_hotspot_default .sc_hotspot_item_popup .sc_hotspot_item_link {
  margin-top: 15px;
}

/* Hotspot Simple */
.sc_hotspot_simple .sc_hotspot_item_sonar {
  background-color: var(--theme-color-text_link);
}
.sc_hotspot_simple .sc_hotspot_item_icon {
  background-color: var(--theme-color-text_link);
}
.sc_hotspot_simple .sc_hotspot_item_icon span {
  display: block;
  font-size: 12px;
  line-height: 14px;
  color: var(--theme-color-inverse_link);
}
.sc_hotspot_simple .sc_hotspot_item_popup {
  width: max-content;
  max-width: 250px;
  padding: 10px 20px 11px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background: var(--theme-color-alter_bg_color);
  -webkit-box-shadow: 0 3px 25px rgba(0, 0, 0, 0.05);
  -ms-box-shadow: 0 3px 25px rgba(0, 0, 0, 0.05);
  box-shadow: 0 3px 25px rgba(0, 0, 0, 0.05);
}
.sc_hotspot_simple .sc_hotspot_item_popup > .sc_hotspot_item_popup_close + [class*="sc_hotspot_item"],
.sc_hotspot_simple .sc_hotspot_item_popup > [class*="sc_hotspot_item"]:first-child {
  margin-top: 10px;
}
.sc_hotspot_simple .sc_hotspot_item_popup > [class*="sc_hotspot_item"]:last-child {
  margin-bottom: 10px;
}
.sc_hotspot_simple .sc_hotspot_item_popup > [class*="sc_hotspot_item"]:only-child {
  margin: 0;
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_image + [class*="sc_hotspot_item"] {
  margin-top: 10px;
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_popup_close {
  color: var(--theme-color-alter_dark);
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_subtitle {
  color: var(--theme-color-alter_dark);
  line-height: 1;
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_subtitle > span,
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_subtitle .post_meta_item {
  font-size: 15px;
  line-height: 20px;
  font-weight: 400;
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_title {
  margin-top: 5px;
  font-size: 16px;
  line-height: 22px;
  color: var(--theme-color-alter_dark);
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_price {
  margin-top: 5px;
  font-size: 16px;
  line-height: 22px;
  font-weight: var(--theme-font-h5_font-weight);
  color: var(--theme-color-alter_text);
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_description {
  margin-top: 8px;
  font-size: 16px;
  line-height: 24px;
  color: var(--theme-color-alter_text);
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_link {
  margin-top: 15px;
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_popup_close {
  width: 1.3em;
  height: 1.3em;
  line-height: 1.3em;
}
.sc_hotspot_simple .sc_hotspot_item_popup .sc_hotspot_item_popup_close .trx_addons_button_close_icon {
  font-size: 10px;
}

/* Images compare */
.sc_icompare_text_before,
.sc_icompare_text_after {
  font-size: 15px;
  line-height: 1.2em;
  font-weight: 400;
  background: rgba(0, 0, 0, 0.5);
  color: #fff;
  padding: 8px 20px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  text-shadow: none;
}

/* Switcher */
.sc_switcher_controls {
  margin-bottom: 2.5em;
}

.sc_switcher_controls_section_title {
  font-size: 1.056em;
  line-height: 1.3em;
}

.sc_switcher_controls_toggle {
  width: 50px;
  height: 28px;
  -webkit-border-radius: 30px;
  -ms-border-radius: 30px;
  border-radius: 30px;
  background-color: transparent;
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  border: 1px solid var(--theme-color-bd_color);
}

.sc_switcher_controls_toggle_button {
  position: absolute;
  top: 2px;
  left: 3px;
  width: 22px;
  height: 22px;
  line-height: 22px;
  background-color: var(--theme-color-text_link);
}
.sc_switcher_controls_toggle:not(.sc_switcher_controls_toggle_on) .sc_switcher_controls_toggle_button {
  -webkit-transform: translateX(20px);
  -ms-transform: translateX(20px);
  transform: translateX(20px);
}
.sc_switcher_controls_toggle_on .sc_switcher_controls_toggle_button {
  background-color: var(--theme-color-text_dark);
}

.sc_switcher_controls_section1 {
  margin-right: 1em;
}

.sc_switcher_controls_section2 {
  margin-left: 1em;
}

/* Switcher Tabs */
.sc_switcher_tabs .sc_switcher_tabs_controls {
  margin-bottom: var(--theme-var-grid_gap);
}
.sc_switcher_tabs .sc_switcher_tab {
  border-color: var(--theme-color-bd_color);
  padding: var(--theme-var-grid_gap);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.sc_switcher_tabs .sc_switcher_tab + .sc_switcher_tab {
  margin-left: var(--theme-var-grid_gap);
}
.sc_switcher_tabs .sc_switcher_tab.sc_switcher_tab_active {
  background-color: var(--theme-color-alter_bg_color);
  border-color: var(--theme-color-bd_color);
}

.elementor-section-full_width .style-switcher-tabs .sc_switcher_tabs_controls {
  max-width: calc( var(--theme-var-page) + var(--theme-var-elm_gap_extended) );
  padding: 0 calc( var(--theme-var-elm_gap_extended) / 2 );
  margin: 0 auto;
}
.style-switcher-tabs .sc_switcher_tab {
  width: 100%;
  padding: calc(var(--theme-var-grid_gap) + 8px) var(--theme-var-grid_gap);
}
.style-switcher-tabs .sc_switcher_tab h5:first-child:not(:last-child) {
  margin-bottom: 0.75em;
}

/* Expand / Collapse */
.trx_expcol_on {
  /* // for old trx-addon
  &.trx_expcol_state_collapsed .trx_expcol_button,
  &.trx_expcol_state_animated .trx_expcol_button {
  	transform: translate(-50%, -25%);
  }*/
}
.trx_expcol_on.trx_expcol_gradient_on:after {
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0, var(--theme-color-bg_color_0)), to(var(--theme-color-bg_color)));
  background: -webkit-linear-gradient(top, var(--theme-color-bg_color_0) 0, var(--theme-color-bg_color) 100%);
  background: linear-gradient(to bottom, var(--theme-color-bg_color_0) 0, var(--theme-color-bg_color) 100%);
}
.trx_expcol_on .trx_expcol_button {
  -webkit-appearance: none;
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  vertical-align: top;
  font-size: var(--theme-font-button_font-size);
  line-height: var(--theme-font-button_line-height);
  font-weight: var(--theme-font-button_font-weight);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  white-space: nowrap;
  height: auto;
  max-width: 100%;
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
  padding: 20px 44px;
  -webkit-transform: translate(-50%, -25%);
  -ms-transform: translate(-50%, -25%);
  transform: translate(-50%, -25%);
}
.trx_expcol_on .trx_expcol_button.sc_button_shadow {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link_02);
}
.trx_expcol_on .trx_expcol_button.sc_button_shadow.color_style_dark {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
  box-shadow: 0 7px 25px var(--theme-color-text_dark_02);
}
.trx_expcol_on .trx_expcol_button.sc_button_shadow.color_style_link2 {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link2_02);
}
.trx_expcol_on .trx_expcol_button.sc_button_shadow.color_style_link3 {
  -webkit-box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
  -ms-box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
  box-shadow: 0 7px 25px var(--theme-color-text_link3_02);
}
.trx_expcol_on .trx_expcol_button.trx_expcol_button_with_shadow {
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.trx_expcol_on .trx_expcol_button:hover, .trx_expcol_on .trx_expcol_button:focus {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover);
  background-color: var(--theme-color-text_hover);
}
.trx_expcol_on .trx_expcol_button_icon {
  font-weight: 400;
}

/* AI Helper Image Generator */
.sc_igenerator_form .trx_addons_loading {
  background-color: var(--theme-color-bg_color_07);
}

.sc_igenerator_form_field_inner > .select_container select,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"],
.sc_igenerator_form_field_inner > input[type="text"],
.sc_igenerator_form_field_inner > .theme_form_field_text {
  padding: 0 20px;
  height: 60px;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color) !important;
}
.sc_igenerator_form_field_inner > .select_container select:focus,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select:focus,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"]:focus,
.sc_igenerator_form_field_inner > input[type="text"]:focus,
.sc_igenerator_form_field_inner > .theme_form_field_text:focus {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]::-webkit-input-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]::-moz-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]::-moz-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]::-moz-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]::-moz-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]::-moz-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:-ms-input-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:-ms-input-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]::placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]::placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]::placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]::placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]::placeholder {
  color: var(--theme-color-alter_text);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:focus::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:focus::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:focus::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:focus::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:focus::-webkit-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:focus::-moz-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:focus::-moz-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:focus::-moz-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:focus::-moz-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:focus::-moz-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:focus:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:focus:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:focus:-ms-input-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:focus:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:focus:-ms-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:focus::placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:focus::placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:focus::placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:focus::placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:focus::placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:active::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:active::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:active::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:active::-webkit-input-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:active::-webkit-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:active::-moz-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:active::-moz-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:active::-moz-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:active::-moz-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:active::-moz-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:active:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:active:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:active:-ms-input-placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:active:-ms-input-placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:active:-ms-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .select_container select[placeholder]:active::placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_model_wrap > .select_container select[placeholder]:active::placeholder,
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"][placeholder]:active::placeholder,
.sc_igenerator_form_field_inner > input[type="text"][placeholder]:active::placeholder,
.sc_igenerator_form_field_inner > .theme_form_field_text[placeholder]:active::placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .theme_form_field_text {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap input[type="number"] {
  padding-right: 2.8em;
}
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap .sc_igenerator_form_field_numeric_wrap_button {
  padding: 0.15em 0.8em;
  color: var(--theme-color-alter_text);
}
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap .sc_igenerator_form_field_numeric_wrap_button:hover {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap .sc_igenerator_form_field_numeric_wrap_button.sc_igenerator_form_field_numeric_wrap_button_inc:before, .sc_igenerator_form_field_inner > .sc_igenerator_form_field_numeric_wrap .sc_igenerator_form_field_numeric_wrap_button.sc_igenerator_form_field_numeric_wrap_button_dec:before {
  width: 1em;
  height: 0.5em;
  line-height: 0.5em;
  font-weight: 400;
}
.sc_igenerator_form_field_inner .select_container:after {
  right: 1em;
  color: var(--theme-color-alter_text);
  font-weight: 400;
}
.sc_igenerator_form_field_inner .select_container:hover:after, .sc_igenerator_form_field_inner .select_container:focus:after {
  color: var(--theme-color-alter_dark);
}
.sc_igenerator_form_field_inner > label {
  color: var(--theme-color-text_dark);
  font-size: 16px;
  line-height: 1.5em;
  font-weight: var(--theme-font-h5_font-weight);
}

.sc_igenerator_form_field_upload_image_decorator .sc_igenerator_form_field_upload_image_text {
  font-size: var(--theme-font-input_font-size);
  line-height: var(--theme-font-input_line-height);
  font-weight: var(--theme-font-input_font-weight);
  letter-spacing: var(--theme-font-input_letter-spacing);
  color: var(--theme-color-alter_text);
}
.sc_igenerator_form_field_upload_image_decorator .sc_igenerator_form_field_upload_image_button {
  font-size: var(--theme-font-button_font-size);
  font-weight: var(--theme-font-button_font-weight);
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  right: 20px;
  padding: 0;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_dark);
}

.sc_igenerator_form_field_prompt .sc_igenerator_form_field_prompt_button {
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 5px;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  font-size: var(--theme-font-button_font-size);
  font-weight: var(--theme-font-button_font-weight);
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  display: inline-block;
  padding: 0 25px;
  height: 50px;
  line-height: 48px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_link);
}
.sc_igenerator_form_field_prompt .sc_igenerator_form_field_prompt_button:not(.sc_igenerator_form_field_prompt_button_disabled):hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_hover);
}
.sc_igenerator_form_field_prompt .sc_igenerator_form_field_prompt_button_disabled {
  opacity: .8;
}

.sc_igenerator_form_field_tags {
  margin-top: 20px;
}

.sc_igenerator_form_field_tags_label {
  padding: 9px 15px 9px 0;
  font-size: 14px;
  line-height: 17px;
  font-weight: 700;
}

.sc_igenerator_form_field_tags_item {
  padding: 11px 15px 12px 15px;
  margin: 0 5px 5px 0;
  font-size: 14px;
  line-height: 1em;
  font-weight: 400;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_igenerator_form_field_tags_item:hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}

.sc_igenerator_form_settings_button {
  flex-shrink: 0;
  width: 60px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_igenerator_form_settings_button:hover, .sc_igenerator_form_settings_button:focus {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_link);
}

.sc_igenerator_form_settings,
.sc_igenerator_form_settings.sc_igenerator_form_settings_light {
  max-height: 260px;
  overflow-y: auto;
  overflow-x: hidden;
  scrollbar-width: thin;
  scrollbar-color: var(--theme-color-alter_bd_color) var(--theme-color-alter_bg_color);
}
.sc_igenerator_form_settings::-webkit-scrollbar,
.sc_igenerator_form_settings.sc_igenerator_form_settings_light::-webkit-scrollbar {
  width: 8px;
}
.sc_igenerator_form_settings::-webkit-scrollbar-track,
.sc_igenerator_form_settings.sc_igenerator_form_settings_light::-webkit-scrollbar-track {
  background: var(--theme-color-alter_bg_color);
}
.sc_igenerator_form_settings::-webkit-scrollbar-thumb,
.sc_igenerator_form_settings.sc_igenerator_form_settings_light::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-alter_bd_hover);
  border: 1px solid var(--theme-color-alter_bg_color);
  -webkit-border-radius: 6px;
  -ms-border-radius: 6px;
  border-radius: 6px;
}
.sc_igenerator_form_settings::-webkit-scrollbar-thumb,
.sc_igenerator_form_settings.sc_igenerator_form_settings_light::-webkit-scrollbar-thumb {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}

.sc_igenerator_form_settings {
  max-width: 230px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_dark);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_igenerator_form_settings .sc_igenerator_form_settings_field_numeric_wrap .sc_igenerator_form_settings_field_numeric_wrap_button {
  padding: 0.1em 0;
  color: var(--theme-color-input_text);
}
.sc_igenerator_form_settings .sc_igenerator_form_settings_field_numeric_wrap .sc_igenerator_form_settings_field_numeric_wrap_button:hover {
  color: var(--theme-color-input_dark);
}
.sc_igenerator_form_settings .sc_igenerator_form_settings_field_numeric_wrap .sc_igenerator_form_settings_field_numeric_wrap_button_dec:before,
.sc_igenerator_form_settings .sc_igenerator_form_settings_field_numeric_wrap .sc_igenerator_form_settings_field_numeric_wrap_button_inc:before {
  width: 1em;
  height: 0.5em;
  line-height: 0.5em;
  font-weight: 400;
}
.sc_igenerator_form_settings:not(.sc_igenerator_form_settings_light) label {
  font-family: var(--theme-font-h5_font-family);
  font-size: 16px;
  line-height: 1.5em;
  font-weight: var(--theme-font-h5_font-weight);
}

.sc_igenerator_limits .sc_igenerator_limits_used {
  color: var(--theme-color-text_dark);
}

/* Extended */
.sc_igenerator_extended .sc_igenerator_form_actions_item > a {
  font-size: 15px;
  line-height: 21px;
  font-weight: 700;
  color: var(--theme-color-text);
}
.sc_igenerator_extended .sc_igenerator_form_actions_item.sc_igenerator_form_actions_item_active > a,
.sc_igenerator_extended .sc_igenerator_form_actions_item > a:hover,
.sc_igenerator_extended .sc_igenerator_form_actions_item > a:focus {
  color: var(--theme-color-text_dark);
}
.sc_igenerator_extended .sc_igenerator_form_actions_list:after {
  background-color: var(--theme-color-bd_color);
}
.sc_igenerator_extended .sc_igenerator_form_actions_slider {
  background-color: var(--theme-color-text_dark);
}
.sc_igenerator_extended .sc_igenerator_form_field_generate .sc_igenerator_form_field_generate_button .sc_button_icon {
  display: none;
}
.sc_igenerator_extended .sc_igenerator_form_field_generate .sc_igenerator_form_field_generate_button.sc_igenerator_form_field_disabled {
  opacity: .8;
}
.sc_igenerator_extended .sc_igenerator_limits {
  border-color: var(--theme-color-bd_color);
}
.sc_igenerator_extended .sc_igenerator_form_field_model_wrap_with_settings .sc_igenerator_form_settings_field_description {
  color: var(--theme-color-alter_light);
}

/* AI Helper Text Generator */
.sc_tgenerator_form .trx_addons_loading {
  background-color: var(--theme-color-bg_color_07);
}

.sc_tgenerator_form_field_prompt input[type="text"] {
  padding: 0 140px 0 20px;
  height: 60px;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_tgenerator_form_field_prompt input[type="text"]:focus {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]::-webkit-input-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]::-moz-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:-ms-input-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]::placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:focus::-webkit-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:focus::-moz-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:focus:-ms-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:focus::placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:active::-webkit-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:active::-moz-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:active:-ms-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt input[type="text"][placeholder]:active::placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_form_field_prompt .sc_tgenerator_form_field_prompt_button {
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 5px;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  font-size: var(--theme-font-button_font-size);
  font-weight: var(--theme-font-button_font-weight);
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  display: inline-block;
  padding: 0 25px;
  height: 50px;
  line-height: 48px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_link);
}
.sc_tgenerator_form_field_prompt .sc_tgenerator_form_field_prompt_button:not(.sc_tgenerator_form_field_prompt_button_disabled):hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-alter_hover);
}
.sc_tgenerator_form_field_prompt .sc_tgenerator_form_field_prompt_button_disabled {
  opacity: .8;
}

.sc_tgenerator_form_field_tags {
  color: var(--theme-color-text_dark);
}

.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_options {
  border: 1px solid var(--theme-color-bd_color);
  background-color: var(--theme-color-bg_color);
  -webkit-box-shadow: none;
  -ms-box-shadow: none;
  box-shadow: none;
  max-height: 300px;
  overflow-y: auto;
  overflow-x: hidden;
  scrollbar-width: thin;
  scrollbar-color: var(--theme-color-alter_bd_color) var(--theme-color-alter_bg_color);
}
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_options::-webkit-scrollbar {
  width: 8px;
}
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_options::-webkit-scrollbar-track {
  background: var(--theme-color-alter_bg_color);
}
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_options::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-alter_bd_hover);
  border: 1px solid var(--theme-color-alter_bg_color);
  -webkit-border-radius: 6px;
  -ms-border-radius: 6px;
  border-radius: 6px;
}
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_options::-webkit-scrollbar-thumb {
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
}
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_label {
  color: var(--theme-color-text_link);
  padding: 0;
  border-bottom: none;
}
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_option:hover,
.sc_tgenerator_form_field_select .sc_tgenerator_form_field_select_option:focus {
  background-color: var(--theme-color-alter_bg_color);
  color: var(--theme-color-alter_link);
}

.sc_tgenerator_text {
  margin-top: 1.4em;
  padding: 18px 22px;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_text:focus {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]::-webkit-input-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_text[placeholder]::-moz-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_text[placeholder]:-ms-input-placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_text[placeholder]::placeholder {
  color: var(--theme-color-alter_text);
}
.sc_tgenerator_text[placeholder]:focus::-webkit-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:focus::-moz-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:focus:-ms-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:focus::placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:active::-webkit-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:active::-moz-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:active:-ms-input-placeholder {
  color: var(--theme-color-alter_dark);
}
.sc_tgenerator_text[placeholder]:active::placeholder {
  color: var(--theme-color-alter_dark);
}

.sc_tgenerator_text,
.sc_tgenerator_text.filled,
.sc_tgenerator_text:focus {
  background-color: var(--theme-color-alter_bg_color);
}

.sc_tgenerator_result .sc_tgenerator_result_label {
  margin-bottom: 0.8em;
  text-align: center;
  font-weight: var(--theme-font-h6_font-weight);
  color: var(--theme-color-text_dark);
}
.sc_tgenerator_result .sc_tgenerator_result_content {
  padding: 18px 22px;
  border: none;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-alter_text);
  background-color: var(--theme-color-alter_bg_color);
}
.sc_tgenerator_result .sc_tgenerator_result_copy .sc_button {
  padding: 13px 28px;
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}
.sc_tgenerator_result .sc_tgenerator_result_copy .sc_button:hover {
  color: var(--theme-color-inverse_link);
  border-color: var(--theme-color-text_hover);
  background-color: var(--theme-color-text_hover);
}

.sc_tgenerator_text h1, .sc_tgenerator_text h2, .sc_tgenerator_text h3, .sc_tgenerator_text h4, .sc_tgenerator_text h5, .sc_tgenerator_text h6,
.sc_tgenerator_result h1,
.sc_tgenerator_result h2,
.sc_tgenerator_result h3,
.sc_tgenerator_result h4,
.sc_tgenerator_result h5,
.sc_tgenerator_result h6 {
  margin: 0 0 0.8em 0;
  font-weight: var(--theme-font-h1_font-weight);
}
.sc_tgenerator_text h1,
.sc_tgenerator_result h1 {
  font-size: 1.882em;
}
.sc_tgenerator_text h2,
.sc_tgenerator_result h2 {
  font-size: 1.706em;
}
.sc_tgenerator_text h3,
.sc_tgenerator_result h3 {
  font-size: 1.471em;
}
.sc_tgenerator_text h4,
.sc_tgenerator_result h4 {
  font-size: 1.294em;
}
.sc_tgenerator_text h5,
.sc_tgenerator_result h5 {
  font-size: 1.176em;
}
.sc_tgenerator_text h6,
.sc_tgenerator_result h6 {
  font-size: 1.118em;
}
.sc_tgenerator_text p, .sc_tgenerator_text ol, .sc_tgenerator_text ul, .sc_tgenerator_text dl,
.sc_tgenerator_result p,
.sc_tgenerator_result ol,
.sc_tgenerator_result ul,
.sc_tgenerator_result dl {
  margin: 0 0 1.2em 0;
}
.sc_tgenerator_text p:last-child, .sc_tgenerator_text ol:last-child, .sc_tgenerator_text ul:last-child, .sc_tgenerator_text dl:last-child, .sc_tgenerator_text h1:last-child, .sc_tgenerator_text h2:last-child, .sc_tgenerator_text h3:last-child, .sc_tgenerator_text h4:last-child, .sc_tgenerator_text h5:last-child, .sc_tgenerator_text h6:last-child,
.sc_tgenerator_result p:last-child,
.sc_tgenerator_result ol:last-child,
.sc_tgenerator_result ul:last-child,
.sc_tgenerator_result dl:last-child,
.sc_tgenerator_result h1:last-child,
.sc_tgenerator_result h2:last-child,
.sc_tgenerator_result h3:last-child,
.sc_tgenerator_result h4:last-child,
.sc_tgenerator_result h5:last-child,
.sc_tgenerator_result h6:last-child {
  margin-bottom: 0;
}

/* AI Helper Chat */
.sc_chat_content {
  --trx-addons-ai-helper-chat-content-border-radius: 0;
  background-color: var(--theme-color-alter_bg_color);
}

.sc_chat_form_field_prompt_label {
  line-height: 1.2em;
  font-weight: var(--theme-font-h6_font-weight);
  color: var(--theme-color-inverse_hover);
  background-color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new {
  color: inherit;
  font-weight: inherit;
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new:hover {
  color: inherit;
  opacity: .8;
}

.sc_chat_form_field_prompt input[type="text"] {
  --trx-addons-ai-helper-chat-fields-border-radius: 0;
  padding: 0 20px;
  height: 60px;
  border: none;
  color: var(--theme-color-text);
  background-color: var(--theme-color-bg_color);
}
.sc_chat_form_field_prompt input[type="text"]:focus {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]::-webkit-input-placeholder {
  color: var(--theme-color-text);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]::-moz-placeholder {
  color: var(--theme-color-text);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:-ms-input-placeholder {
  color: var(--theme-color-text);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]::placeholder {
  color: var(--theme-color-text);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:focus::-webkit-input-placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:focus::-moz-placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:focus:-ms-input-placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:focus::placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:active::-webkit-input-placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:active::-moz-placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:active:-ms-input-placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt input[type="text"][placeholder]:active::placeholder {
  color: var(--theme-color-text_dark);
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button {
  --trx-addons-ai-helper-chat-button-border-radius: 0;
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 5px;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  font-size: var(--theme-font-button_font-size);
  font-weight: var(--theme-font-button_font-weight);
  text-transform: var(--theme-font-button_text-transform);
  letter-spacing: var(--theme-font-button_letter-spacing);
  display: inline-block;
  padding: 0 25px;
  height: 50px;
  line-height: 48px;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button:not(.sc_chat_form_field_prompt_button_disabled):hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_hover);
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button_disabled {
  opacity: .8;
}

.sc_chat_result {
  border-left: none;
  border-right: none;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_time {
  font-size: 14px;
  line-height: 26px;
  color: var(--theme-color-text_light);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content {
  background-color: var(--theme-color-bg_color);
  color: var(--theme-color-text_dark);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6 {
  margin: 0 0 0.8em 0;
  color: var(--theme-color-text_dark);
  font-weight: var(--theme-font-h1_font-weight);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1 {
  font-size: 1.882em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2 {
  font-size: 1.706em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3 {
  font-size: 1.471em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4 {
  font-size: 1.294em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5 {
  font-size: 1.176em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6 {
  font-size: 1.118em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content p, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ol, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ul, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content dl {
  margin: 0 0 1.2em 0;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content p, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ol, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ul, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content dl, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6 {
  margin: 0 0 0.8em 0;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content p:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ol:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ul:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content dl:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6:last-child {
  margin-bottom: 0;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item.sc_chat_list_item_user .sc_chat_list_item_content {
  background-color: var(--theme-color-text_link);
  color: var(--theme-color-inverse_link);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_loading .sc_chat_list_item_loading_dot {
  background-color: var(--theme-color-text_link);
}

.sc_chat_form_field_tags_item {
  --trx-addons-ai-helper-chat-tags-border-radius: 0;
  padding: 11px 15px 12px 15px;
  margin: 0 5px 5px 0;
  font-size: 13px;
  line-height: 1em;
  font-weight: 400;
  color: var(--theme-color-text_dark);
  background-color: var(--theme-color-bg_color);
}
.sc_chat_form_field_tags_item:hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}

.sc_chat_form_field_tags_label {
  padding: 9px 15px 9px 0;
  font-size: 14px;
  line-height: 17px;
  font-weight: 700;
}

/* Squeeze images */
.sc_squeeze_titles .sc_squeeze_title .sc_squeeze_title_text {
  font-size: var(--theme-font-h1_font-size);
  line-height: var(--theme-font-h1_line-height);
  font-weight: var(--theme-font-h1_font-weight);
}
.sc_squeeze_titles .sc_squeeze_title .sc_squeeze_subtitle_text {
  font-family: var(--theme-font-h1_font-family);
  font-size: 12px;
  line-height: 18px;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 1.6px;
  margin-bottom: 12px;
}

/*# sourceMappingURL=trx_addons.css.map */
